// Copyright © 2022 BytePlusRTC All rights reserved.
// SPDX-License-Identifier: MIT

package com.volcengine.reactnative.vertc;

import androidx.annotation.Nullable;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.module.annotations.ReactModule;
import com.facebook.react.modules.core.DeviceEventManagerModule;
import com.ss.bytertc.engine.RTCVideo;
import com.ss.bytertc.engine.engineimpl.RTCVideoImpl;
import com.volcengine.VolcApiEngine.IEventReceiver;
import com.volcengine.VolcApiEngine.VolcApiEngine;
import com.volcengine.reactnative.vertc.events.ClassHelper;

@ReactModule(name = VertcModuleSpec.NAME)
public class VertcModule extends VertcModuleSpec implements IEventReceiver {
  public static ReactApplicationContext reactApplicationContext = null;
  
  public VolcApiEngine apiEngine = null;

  VertcModule(ReactApplicationContext context) {
    super(context);
    VertcApiEngineManager.instance.init(this);
    reactApplicationContext = context;
  }
  
  @Override
  public String getName() {
    return VertcModuleSpec.NAME;
  }

  @ReactMethod(isBlockingSynchronousMethod = true)
  public boolean newApiEngine() {
    if (apiEngine == null) {
      apiEngine = new VolcApiEngine(super.context, this);
      NativeVariableManager.init(this.apiEngine.msgClient, super.context);
      ClassHelper.init();
      return true;
    }
    
    return false;
  }

  @ReactMethod(isBlockingSynchronousMethod = true)
  public String callApiSync(ReadableMap arg)  {
    try {
      newApiEngine();
      String params = arg.getString("params");
      return this.apiEngine.callApi(params);
    } catch (Exception e) {
      e.printStackTrace();
      throw new RuntimeException(e);
    }
  }

  @ReactMethod(isBlockingSynchronousMethod = false)
  public void callApi(ReadableMap arg, Callback callback)  {
    try {
      newApiEngine();
      String params = arg.getString("params");
      this.apiEngine.callApi(params, (res) -> {
        callback.invoke(res.toJsonString());
      });
    } catch (Exception e) {
      e.printStackTrace();
      throw new RuntimeException(e);
    }
  }

  @ReactMethod(isBlockingSynchronousMethod = true)
  public void testSome(ReadableMap arg)  {
    RTCVideo v = new RTCVideoImpl(null, "AppId", null, null, null);
//    v.feedback()
  }

  private int listenerCount = 0;

  @ReactMethod
  public void addListener(String eventName) {
    if (listenerCount == 0) {
      // Set up any upstream listeners or background tasks as necessary
    }

    listenerCount += 1;
  }

  @ReactMethod
  public void removeListeners(Integer count) {
    listenerCount -= count;
    if (listenerCount == 0) {
      // Remove upstream listeners, stop unnecessary background tasks
    }
  }

  private void sendEvent(ReactContext reactContext,
                          String eventName,
                          @Nullable WritableMap params) {
    reactContext
      .getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter.class)
      .emit(eventName, params);
  }

  @Override
  public void OnEvent(String event, String data) {
    final WritableMap map = Arguments.createMap();
    map.putString("event", event);
    map.putString("data", data);

    super.context
      .getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter.class)
      .emit(VertcModuleSpec.EVENT, map);
  }
}
