// Copyright © 2022 BytePlusRTC All rights reserved.
// SPDX-License-Identifier: MIT

package com.volcengine.reactnative.vertc.vod;

import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import com.ss.bytertc.engine.RTCVideo;
import com.ss.bytertc.engine.data.VideoPixelFormat;
import com.ss.bytertc.engine.data.VideoRotation;
import com.ss.bytertc.engine.video.VideoFrame;
import com.ss.bytertc.engine.video.builder.CpuBufferVideoFrameBuilder;

import java.nio.ByteBuffer;
import java.util.concurrent.TimeUnit;

public class VodMock {
  public String TAG = "VideoAudioProcessor";

  private final RTCVideo mRTCEngine;

  public VodMock(RTCVideo engine) {
    mRTCEngine = engine;
  }
  
  public void useFakeVideoFrame() {
    final Handler handler = new Handler(Looper.getMainLooper());
    var width = 998;
    var height = 554;
    Runnable runnable = new Runnable() {
      @Override
      public void run() {
        handler.postDelayed(this, 30);  // Repeats every 5 seconds

        var frame = useInternalVideoFrame(width, height);
        mRTCEngine.pushScreenVideoFrame(frame);
//        Log.d(TAG, "pushScreenVideoFrame");
      }
    };
    handler.post(runnable);
  }

  public VideoFrame useInternalVideoFrame(int width, int height){
    int chromaWidth = (width + 1) / 2;
    int chromaHeight = (height + 1) /2;
    int uvSize = chromaWidth * chromaHeight;
    int uStart = width * height;
    int vStart = uStart + uvSize;

    int yLength = width * height;
    int length = yLength + uvSize * 2;

    byte[] buffer = new byte[length];
    for(int i = 0;i < yLength;++i) {
      buffer[i] = 0;
    }
    ByteBuffer directBuffer = ByteBuffer.allocateDirect(buffer.length);
    
    directBuffer.put(buffer);
    directBuffer.rewind();
    directBuffer.limit(uStart);
    ByteBuffer directBufferY = directBuffer.slice();

    directBuffer.position(uStart);
    directBuffer.limit(uStart + uvSize);
    ByteBuffer directBufferU = directBuffer.slice();

    directBuffer.position(vStart);
    directBuffer.limit(vStart + uvSize);
    ByteBuffer directBufferV = directBuffer.slice();

    long time = System.currentTimeMillis() * TimeUnit.MILLISECONDS.toNanos(1);
    CpuBufferVideoFrameBuilder builder  = new CpuBufferVideoFrameBuilder(VideoPixelFormat.I420);
    builder.setWidth(width)
      .setHeight(height)
      .setRotation(VideoRotation.VIDEO_ROTATION_0)
      .setTimeStampUs(time)
      .setPlaneData(0, directBufferY)
      .setPlaneStride(0, width)
      .setPlaneData(1, directBufferU)
      .setPlaneStride(1, chromaWidth)
      .setPlaneData(2, directBufferV)
      .setPlaneStride(2, chromaWidth);
    return builder.build();
  }
}
