// Copyright © 2022 BytePlusRTC All rights reserved.
// SPDX-License-Identifier: MIT

package com.volcengine.reactnative.vertc.vod;

import android.graphics.SurfaceTexture;
import android.opengl.EGLContext;
import android.util.Log;
import android.view.Surface;

import com.ss.bytertc.engine.RTCVideo;
import com.ss.bytertc.engine.data.ColorSpace;
import com.ss.bytertc.engine.data.ReturnStatus;
import com.ss.bytertc.engine.data.StreamIndex;
import com.ss.bytertc.engine.data.VideoPixelFormat;
import com.ss.bytertc.engine.data.VideoRotation;
import com.ss.bytertc.engine.data.VideoSourceType;
import com.ss.bytertc.engine.video.VideoFrame;
import com.ss.bytertc.engine.video.builder.GLTextureVideoFrameBuilder;
import com.ss.ttvideoengine.TTVideoEngine;
import com.ss.ttvideoengine.VideoEngineCallback;

public class VodVideoProxy {
  private String TAG = "VodVideoProxy";

  private TTVideoEngine mVideoEngine;
  private RTCVideo mRTCVideo;

  private OESTextureProcessor mOESTextureProcessor;

  private final OESTextureProcessor.IProcessorCallback mProcessorCallback = new OESTextureProcessor.IProcessorCallback() {
    @Override
    public void onSurfaceTextureAvailable(SurfaceTexture surface, int width, int height) {
      TTVideoEngine videoEngine = mVideoEngine;
      if (videoEngine != null) {
        videoEngine.setSurface(new Surface(surface));
      }
    }

    @Override
    public void onSurfaceTextureDestroyed(SurfaceTexture surface) {
      TTVideoEngine videoEngine = mVideoEngine;
      if (videoEngine != null) {
        videoEngine.setSurface(null);
      }
    }

    @Override
    public void onFrameAvailable(EGLContext eglContext, int oesTextureId, float[] transformMatrix, int width, int height, long timestamp) {
      GLTextureVideoFrameBuilder builder = new GLTextureVideoFrameBuilder(VideoPixelFormat.TEXTURE_OES)
        .setTextureID(oesTextureId)
        .setWidth(width)
        .setHeight(height)
        .setRotation(VideoRotation.VIDEO_ROTATION_0)
        .setTextureMatrix(transformMatrix)
//        .setTimeStampUs(timestamp)
        .setTimeStampUs(System.nanoTime())
        .setColorSpace(ColorSpace.UNKNOWN)
        .setEGLContext(eglContext);
      VideoFrame frame = builder.build();
//      frame.retain();
//      Log.d(TAG, "pushScreenVideoFrame: " + frame));
      int ret_status = mRTCVideo.pushScreenVideoFrame(frame);
      boolean result = ret_status == ReturnStatus.RETURN_STATUS_SUCCESS.value()
        || ret_status == ReturnStatus.RETURN_STATUS_VIDEO_TIMESTAMP_WARNING.value();
      if (!result) {
        Log.d(TAG, "pushScreenVideoFrame fail: " + ret_status);
      }
    }
  };

  public void initEngine(TTVideoEngine videoEngine, RTCVideo rtcEngine) {
    OESTextureProcessor textureProcessor = mOESTextureProcessor;
    if (textureProcessor != null) {
      textureProcessor.destroy();
    }
    
    mVideoEngine = videoEngine;
    mRTCVideo = rtcEngine;
    mOESTextureProcessor = new OESTextureProcessor();
    
//    var width = mVideoEngine.getVideoWidth();
//    var height = mVideoEngine.getVideoWidth();
    var width = 1920;
    var height = 1080;
    mRTCVideo.setVideoSourceType(StreamIndex.STREAM_INDEX_SCREEN, VideoSourceType.VIDEO_SOURCE_TYPE_EXTERNAL);
    mOESTextureProcessor.initSurfaceTexture(width, height, mProcessorCallback);
  }
  
  public void release() {
    if (mOESTextureProcessor != null) {
      mOESTextureProcessor.destroy();
      mOESTextureProcessor = null;
    }
    mVideoEngine = null;
  }
}
