// Copyright © 2022 BytePlusRTC All rights reserved.
// SPDX-License-Identifier: MIT

import { NSString, int, int64_t, float, id, BOOL, NSArray, NSUInteger, NSInteger, NSData, NSDictionary, bool, CGPoint, CVPixelBufferRef, CMTime } from './types';
import { ByteRTCMediaPlayerConfig, ByteRTCMediaPlayerCustomSource, ByteRTCAudioMixingType, ByteRTCAudioMixingDualMonoMode, ByteRTCAudioFrame, ByteRTCAudioEffectPlayerConfig, ByteRTCPositionInfo, ByteRTCPosition, ByteRTCHumanOrientation, ByteRTCSingScoringConfig, ByteRTCStandardPitchInfo, ByteRTCMusicFilterType, ByteRTCMusicHotType, ByteRTCDownloadLyricType, ByteRTCVirtualBackgroundSource, ByteRTCUserInfo, ByteRTCRoomConfig, ByteRTCRemoteVideoConfig, ByteRTCMediaStreamType, ByteRTCPauseResumControlMediaType, ByteRTCMessageConfig, ByteRTCForwardStreamConfiguration, ByteRTCAudioSelectionPriority, ByteRTCSubtitleConfig, ByteRTCStreamIndex, ByteRTCSubscribeMediaType, ByteRTCSubscribeVideoConfig, ByteRTCLogConfig, ByteRTCAudioSourceType, ByteRTCAudioRenderType, ByteRTCAudioScenarioType, ByteRTCAudioProfileType, ByteRTCAnsMode, ByteRTCVoiceChangerType, ByteRTCVoiceReverbType, ByteRTCVoiceEqualizationConfig, ByteRTCVoiceReverbConfig, ByteRTCAudioPropertiesConfig, ByteRTCEarMonitorMode, ByteRTCBluetoothMode, ByteRTCVideoSinkDelegate, ByteRTCLocalVideoSinkConfig, ByteRTCRemoteStreamKey, ByteRTCRemoteVideoSinkConfig, ByteRTCVideoSuperResolutionMode, ByteRTCVideoRotation, ByteRTCVideoEncoderConfig, ByteRTCScreenVideoEncoderConfig, ByteRTCAlphaLayout, ByteRTCVideoCaptureConfig, ByteRTCVideoCanvas, ByteRTCRenderMode, ByteRTCRemoteVideoRenderConfig, ByteRTCMirrorType, ByteRTCRemoteMirrorType, ByteRTCVideoRotationMode, ByteRTCVideoOrientation, ByteRTCCameraID, ByteRTCEffectBeautyMode, ByteRTCTorchState, ByteRTCSEICountPerFrame, ByteRTCZoomConfigType, ByteRTCZoomDirectionType, ByteRTCVideoPreprocessorConfig, ByteRTCAudioRoute, ByteRTCMixedStreamConfig, ByteRTCPushSingleStreamParam, ByteRTCPublicStreaming, ByteRTCVideoSinkPixelFormat, ByteRTCVideoFrame, ByteRTCAudioFrameCallbackMethod, ByteRTCAudioFormat, ByteRTCAudioFrameMethod, ByteRTCProblemFeedbackOption, ByteRTCProblemFeedbackInfo, ByteRTCPublishFallbackOption, ByteRTCSubscribeFallbackOption, ByteRTCRemoteUserPriority, ByteRTCEncryptType, ByteRTCScreenMediaType, ByteRTCASRConfig, ByteRTCRecordingConfig, ByteRTCRecordingType, ByteRTCAudioRecordingConfig, ByteRTCVideoSourceType, ByteRTCEncodedVideoFrame, ByteRTCVideoDecoderConfig, ByteRTCStreamSycnInfoConfig, ByteRTCEchoTestConfig, ByteRTCVideoWatermarkConfig, ByteRTCCloudProxyInfo, ByteRTCNetworkTimeInfo, ByteRTCMediaTypeEnhancementConfig, ByteRTCLocalProxyInfo, ByteRTCVideoSolution, ByteRTCAudioPlaybackDevice, ByteRTCLiveTranscoding, ByteRTCMuteState, ByteRTCAudioMixingConfig, ByteRTCAudioTrackType, ByteRTCAudioPlayType, ByteRTCReceiveRange, ByteRTCAttenuationType } from './keytype';
import { ByteRTCMediaPlayerAudioFrameObserver, ByteRTCMediaPlayerEventHandler, ByteRTCAudioEffectPlayerEventHandler, ByteRTCSingScoringDelegate, ByteRTCKTVManagerDelegate, ByteRTCFaceDetectionObserver, ByteRTCRoomDelegate, ByteRTCVideoDelegate, ByteRTCVideoProcessorDelegate, ByteRTCLocalEncodedVideoFrameObserver, ByteRTCMixedStreamObserver, ByteRTCPushSingleStreamToCDNObserver, ByteRTCAudioFrameObserver, ByteRTCAudioFrameProcessor, ByteRTCEncryptHandler, ByteRTCASREngineEventHandler, ByteRTCExternalVideoEncoderEventHandler, ByteRTCRemoteEncodedVideoFrameObserver, ByteRTCVideoSnapshotCallbackDelegate, LiveTranscodingDelegate, ByteRTCAudioFileFrameObserver, ByteRTCKTVPlayerDelegate } from './callback';
export declare class ByteRTCMediaPlayer {
    open(filePath: NSString, config: ByteRTCMediaPlayerConfig): int;
    start(): int;
    openWithCustomSource(source: ByteRTCMediaPlayerCustomSource, config: ByteRTCMediaPlayerConfig): int;
    stop(): int;
    pause(): int;
    resume(): int;
    setVolume(volume: int, type: ByteRTCAudioMixingType): int;
    getVolume(type: ByteRTCAudioMixingType): int;
    getTotalDuration(): int;
    getPlaybackDuration(): int;
    getPosition(): int;
    setAudioPitch(pitch: int): int;
    setPosition(position: int): int;
    setAudioDualMonoMode(mode: ByteRTCAudioMixingDualMonoMode): int;
    getAudioTrackCount(): int;
    selectAudioTrack(index: int): int;
    setPlaybackSpeed(speed: int): int;
    setProgressInterval(interval: int64_t): int;
    setLoudness(loudness: float): int;
    registerAudioFrameObserver(observer: id<ByteRTCMediaPlayerAudioFrameObserver>): int;
    pushExternalAudioFrame(audioFrame: ByteRTCAudioFrame): int;
    setEventHandler(handler: id<ByteRTCMediaPlayerEventHandler>): int;
    init(): this;
}
export declare class ByteRTCAudioEffectPlayer {
    start(effectId: int, filePath: NSString, config: ByteRTCAudioEffectPlayerConfig): int;
    stop(effectId: int): int;
    stopAll(): int;
    preload(effectId: int, filePath: NSString): int;
    unload(effectId: int): int;
    unloadAll(): int;
    pause(effectId: int): int;
    pauseAll(): int;
    resume(effectId: int): int;
    resumeAll(): int;
    setPosition(effectId: int, position: int): int;
    getPosition(effectId: int): int;
    setVolume(effectId: int, volume: int): int;
    setVolumeAll(volume: int): int;
    getVolume(effectId: int): int;
    getDuration(effectId: int): int;
    setEventHandler(handler: id<ByteRTCAudioEffectPlayerEventHandler>): int;
    init(): this;
}
export declare class ByteRTCSpatialAudio {
    enableSpatialAudio(enable: BOOL): void;
    disableRemoteOrientation(): void;
    updateSelfPosition(positionInfo: ByteRTCPositionInfo): int;
    updateRemotePosition(uid: NSString, positionInfo: ByteRTCPositionInfo): int;
    removeRemotePosition(uid: NSString): int;
    removeAllRemotePosition(): int;
    updatePosition(pos: ByteRTCPosition): int;
    updateSelfOrientation(orientation: ByteRTCHumanOrientation): int;
    updateListenerPosition(pos: ByteRTCPosition): int;
    updateListenerOrientation(orientation: ByteRTCHumanOrientation): int;
    init(): this;
}
export declare class ByteRTCSingScoringManager {
    initSingScoring(singScoringAppkey: NSString, singScoringToken: NSString, delegate: id<ByteRTCSingScoringDelegate>): int;
    setSingScoringConfig(config: ByteRTCSingScoringConfig): int;
    getStandardPitchInfo(midiFilepath: NSString): ByteRTCStandardPitchInfo;
    startSingScoring(position: int, scoringInfoInterval: int): int;
    stopSingScoring(): int;
    getLastSentenceScore(): int;
    getTotalScore(): int;
    getAverageScore(): int;
}
export declare class ByteRTCKTVManager {
    delegate: id<ByteRTCKTVManagerDelegate>;
    getMusicList(pageNumber: int, pageSize: int, filterType: ByteRTCMusicFilterType): void;
    searchMusic(keyWord: NSString, pageNumber: int, pageSize: int, filterType: ByteRTCMusicFilterType): void;
    getHotMusic(hotType: ByteRTCMusicHotType, filterType: ByteRTCMusicFilterType): void;
    getMusicDetail(musicId: NSString): void;
    downloadMusic(musicId: NSString): int;
    downloadLyric(musicId: NSString, lyricType: ByteRTCDownloadLyricType): int;
    downloadMidi(musicId: NSString): int;
    cancelDownload(downloadId: int): void;
    clearCache(): void;
    setMaxCacheSize(maxCacheSizeMB: int): void;
    getKTVPlayer(): ByteRTCKTVPlayer;
    init(): this;
}
export declare class ByteRTCVideoEffect {
    initCVResource(licenseFile: NSString, algoModelDir: NSString): int;
    enableVideoEffect(): int;
    disableVideoEffect(): int;
    setEffectNodes(effectNodes: NSArray<NSString>): int;
    updateEffectNode(node: NSString, key: NSString, value: float): int;
    setColorFilter(filterRes: NSString): int;
    setColorFilterIntensity(intensity: float): int;
    enableVirtualBackground(backgroundStickerPath: NSString, source: ByteRTCVirtualBackgroundSource): int;
    disableVirtualBackground(): int;
    enableFaceDetection(observer: id<ByteRTCFaceDetectionObserver>, interval: NSUInteger, path: NSString): int;
    disableFaceDetection(): int;
    registerFaceDetectionObserver(observer: id<ByteRTCFaceDetectionObserver>, interval: NSInteger): int;
}
export declare class ByteRTCRoom {
    delegate: id<ByteRTCRoomDelegate>;
    destroy(): void;
    getRoomId(): NSString;
    setRTCRoomDelegate(roomDelegate: id<ByteRTCRoomDelegate>): int;
    joinRoom(token: NSString, userInfo: ByteRTCUserInfo, roomConfig: ByteRTCRoomConfig): int;
    setUserVisibility(enable: BOOL): int;
    setMultiDeviceAVSync(audioUserId: NSString): int;
    leaveRoom(): int;
    updateToken(token: NSString): int;
    setRemoteVideoConfig(userId: NSString, remoteVideoConfig: ByteRTCRemoteVideoConfig): int;
    publishStream(type: ByteRTCMediaStreamType): int;
    unpublishStream(type: ByteRTCMediaStreamType): int;
    publishScreen(type: ByteRTCMediaStreamType): int;
    unpublishScreen(type: ByteRTCMediaStreamType): int;
    subscribeStream(userId: NSString, mediaStreamType: ByteRTCMediaStreamType): int;
    subscribeAllStreamsWithMediaStreamType(mediaStreamType: ByteRTCMediaStreamType): int;
    unsubscribeStream(userId: NSString, mediaStreamType: ByteRTCMediaStreamType): int;
    unsubscribeAllStreamsWithMediaStreamType(mediaStreamType: ByteRTCMediaStreamType): int;
    subscribeScreen(userId: NSString, mediaStreamType: ByteRTCMediaStreamType): int;
    unsubscribeScreen(userId: NSString, mediaStreamType: ByteRTCMediaStreamType): int;
    pauseAllSubscribedStream(mediaType: ByteRTCPauseResumControlMediaType): int;
    resumeAllSubscribedStream(mediaType: ByteRTCPauseResumControlMediaType): int;
    sendUserMessage(userId: NSString, message: NSString, config: ByteRTCMessageConfig): NSInteger;
    sendUserBinaryMessage(uid: NSString, message: NSData, config: ByteRTCMessageConfig): NSInteger;
    sendRoomMessage(message: NSString): NSInteger;
    sendRoomBinaryMessage(message: NSData): NSInteger;
    startForwardStreamToRooms(configurations: NSArray<ByteRTCForwardStreamConfiguration>): int;
    updateForwardStreamToRooms(configurations: NSArray<ByteRTCForwardStreamConfiguration>): int;
    stopForwardStreamToRooms(): int;
    pauseForwardStreamToAllRooms(): int;
    resumeForwardStreamToAllRooms(): int;
    getRangeAudio(): ByteRTCRangeAudio;
    getSpatialAudio(): ByteRTCSpatialAudio;
    setRemoteRoomAudioPlaybackVolume(volume: NSInteger): int;
    setAudioSelectionConfig(audioSelectionPriority: ByteRTCAudioSelectionPriority): int;
    setRoomExtraInfo(key: NSString, value: NSString): NSInteger;
    startSubtitle(subtitleConfig: ByteRTCSubtitleConfig): int;
    stopSubtitle(): int;
    subscribeUserStream(userId: NSString, streamType: ByteRTCStreamIndex, mediaType: ByteRTCSubscribeMediaType, videoConfig: ByteRTCSubscribeVideoConfig): int;
    init(): this;
}
export declare class ByteRTCVideo {
    static createRTCVideo(appId: NSString, delegate: id<ByteRTCVideoDelegate>, parameters: NSDictionary): ByteRTCVideo;
    static destroyRTCVideo(): void;
    static getSDKVersion(): NSString;
    static setLogConfig(logConfig: ByteRTCLogConfig): int;
    static getErrorDescription(code: NSInteger): NSString;
    delegate: id<ByteRTCVideoDelegate>;
    setAudioSourceType(type: ByteRTCAudioSourceType): int;
    setAudioRenderType(type: ByteRTCAudioRenderType): int;
    startAudioCapture(): int;
    stopAudioCapture(): int;
    setAudioScenario(audioScenario: ByteRTCAudioScenarioType): int;
    setAudioProfile(audioProfile: ByteRTCAudioProfileType): int;
    setAnsMode(ansMode: ByteRTCAnsMode): int;
    setVoiceChangerType(voiceChanger: ByteRTCVoiceChangerType): int;
    setVoiceReverbType(voiceReverb: ByteRTCVoiceReverbType): int;
    setLocalVoiceEqualization(config: ByteRTCVoiceEqualizationConfig): int;
    setLocalVoiceReverbParam(param: ByteRTCVoiceReverbConfig): int;
    enableLocalVoiceReverb(enable: bool): int;
    muteAudioCapture(index: ByteRTCStreamIndex, mute: bool): int;
    setCaptureVolume(index: ByteRTCStreamIndex, volume: int): int;
    setPlaybackVolume(volume: NSInteger): int;
    enableAudioPropertiesReport(config: ByteRTCAudioPropertiesConfig): int;
    setRemoteAudioPlaybackVolume(streamKey: ByteRTCRemoteStreamKey, volume: int): int;
    setEarMonitorMode(mode: ByteRTCEarMonitorMode): int;
    setEarMonitorVolume(volume: NSInteger): int;
    setBluetoothMode(mode: ByteRTCBluetoothMode): int;
    setLocalVoicePitch(pitch: NSInteger): int;
    enableVocalInstrumentBalance(enable: BOOL): int;
    enablePlaybackDucking(enable: BOOL): int;
    setLocalVideoRender(index: ByteRTCStreamIndex, videoSink: id<ByteRTCVideoSinkDelegate>, config: ByteRTCLocalVideoSinkConfig): int;
    setRemoteVideoRender(streamKey: ByteRTCRemoteStreamKey, videoSink: id<ByteRTCVideoSinkDelegate>, config: ByteRTCRemoteVideoSinkConfig): int;
    setRemoteVideoSuperResolution(streamKey: ByteRTCRemoteStreamKey, mode: ByteRTCVideoSuperResolutionMode): int;
    setVideoCaptureRotation(rotation: ByteRTCVideoRotation): int;
    enableSimulcastMode(enabled: BOOL): int;
    setMaxVideoEncoderConfig(encoderConfig: ByteRTCVideoEncoderConfig): int;
    setVideoEncoderConfig(encoderConfigs: NSArray<ByteRTCVideoEncoderConfig>): int;
    setScreenVideoEncoderConfig(encoderConfig: ByteRTCScreenVideoEncoderConfig): int;
    enableAlphaChannelVideoEncode(streamIndex: ByteRTCStreamIndex, alphaLayout: ByteRTCAlphaLayout): int;
    disableAlphaChannelVideoEncode(streamIndex: ByteRTCStreamIndex): int;
    setVideoCaptureConfig(captureConfig: ByteRTCVideoCaptureConfig): int;
    setLocalVideoCanvas(streamIndex: ByteRTCStreamIndex, canvas: ByteRTCVideoCanvas): int;
    updateLocalVideoCanvas(streamIndex: ByteRTCStreamIndex, renderMode: ByteRTCRenderMode, backgroundColor: NSUInteger): int;
    setRemoteVideoCanvas(key: ByteRTCRemoteStreamKey, canvas: ByteRTCVideoCanvas): int;
    updateRemoteStreamVideoCanvas(key: ByteRTCRemoteStreamKey, remoteVideoRenderConfig: ByteRTCRemoteVideoRenderConfig): int;
    startVideoCapture(): int;
    stopVideoCapture(): int;
    setLocalVideoMirrorType(mirrorType: ByteRTCMirrorType): int;
    setRemoteVideoMirrorType(key: ByteRTCRemoteStreamKey, mirrorType: ByteRTCRemoteMirrorType): int;
    setVideoRotationMode(rotationMode: ByteRTCVideoRotationMode): int;
    setVideoOrientation(orientation: ByteRTCVideoOrientation): int;
    switchCamera(cameraId: ByteRTCCameraID): int;
    getVideoEffectInterface(): ByteRTCVideoEffect;
    enableEffectBeauty(enable: BOOL): int;
    setBeautyIntensity(beautyMode: ByteRTCEffectBeautyMode, intensity: float): int;
    setCameraZoomRatio(zoomRatio: float): int;
    getCameraZoomMaxRatio(): float;
    isCameraZoomSupported(): bool;
    isCameraTorchSupported(): bool;
    setCameraTorch(torchState: ByteRTCTorchState): int;
    isCameraFocusPositionSupported(): bool;
    setCameraFocusPosition(position: CGPoint): int;
    isCameraExposurePositionSupported(): bool;
    setCameraExposurePosition(position: CGPoint): int;
    setCameraExposureCompensation(val: float): int;
    enableCameraAutoExposureFaceMode(enable: bool): int;
    setCameraAdaptiveMinimumFrameRate(framerate: int): int;
    sendSEIMessage(streamIndex: ByteRTCStreamIndex, message: NSData, repeatCount: int, mode: ByteRTCSEICountPerFrame): int;
    setVideoDigitalZoomConfig(type: ByteRTCZoomConfigType, size: float): int;
    setVideoDigitalZoomControl(direction: ByteRTCZoomDirectionType): int;
    startVideoDigitalZoomControl(direction: ByteRTCZoomDirectionType): int;
    stopVideoDigitalZoomControl(): int;
    registerLocalVideoProcessor(processor: id<ByteRTCVideoProcessorDelegate>, config: ByteRTCVideoPreprocessorConfig): int;
    registerLocalEncodedVideoFrameObserver(frameObserver: id<ByteRTCLocalEncodedVideoFrameObserver>): int;
    setAudioRoute(audioRoute: ByteRTCAudioRoute): int;
    getAudioRoute(): ByteRTCAudioRoute;
    enableExternalSoundCard(enable: bool): int;
    setDefaultAudioRoute(audioRoute: ByteRTCAudioRoute): int;
    startPushMixedStreamToCDN(taskID: NSString, config: ByteRTCMixedStreamConfig, observer: id<ByteRTCMixedStreamObserver>): int;
    updatePushMixedStreamToCDN(taskID: NSString, config: ByteRTCMixedStreamConfig): int;
    startPushSingleStreamToCDN(taskID: NSString, singleStream: ByteRTCPushSingleStreamParam, observer: id<ByteRTCPushSingleStreamToCDNObserver>): int;
    stopPushStreamToCDN(taskID: NSString): int;
    startPushPublicStream(publicStreamId: NSString, publicStream: ByteRTCPublicStreaming): int;
    stopPushPublicStream(publicStreamId: NSString): int;
    updatePublicStreamParam(publicStreamId: NSString, publicStream: ByteRTCPublicStreaming): int;
    startPlayPublicStream(publicStreamId: NSString): int;
    stopPlayPublicStream(publicStreamId: NSString): int;
    setPublicStreamVideoCanvas(publicStreamId: NSString, canvas: ByteRTCVideoCanvas): int;
    setPublicStreamVideoSink(publicStreamId: NSString, videoSink: id<ByteRTCVideoSinkDelegate>, requiredFormat: ByteRTCVideoSinkPixelFormat): int;
    setPublicStreamAudioPlaybackVolume(publicStreamId: NSString, volume: NSInteger): int;
    pushExternalVideoFrame(frame: ByteRTCVideoFrame): int;
    enableAudioFrameCallback(method: ByteRTCAudioFrameCallbackMethod, format: ByteRTCAudioFormat): int;
    disableAudioFrameCallback(method: ByteRTCAudioFrameCallbackMethod): int;
    registerAudioFrameObserver(audioFrameObserver: id<ByteRTCAudioFrameObserver>): int;
    registerAudioProcessor(processor: id<ByteRTCAudioFrameProcessor>): int;
    enableAudioProcessor(method: ByteRTCAudioFrameMethod, format: ByteRTCAudioFormat): int;
    disableAudioProcessor(method: ByteRTCAudioFrameMethod): int;
    pushExternalAudioFrame(audioFrame: ByteRTCAudioFrame): int;
    pullExternalAudioFrame(audioFrame: ByteRTCAudioFrame): int;
    setBusinessId(businessId: NSString): int;
    feedback(types: ByteRTCProblemFeedbackOption, info: ByteRTCProblemFeedbackInfo): int;
    getNativeHandle(): void;
    setPublishFallbackOption(option: ByteRTCPublishFallbackOption): int;
    setSubscribeFallbackOption(option: ByteRTCSubscribeFallbackOption): int;
    setRemoteUserPriority(priority: ByteRTCRemoteUserPriority, roomId: NSString, uid: NSString): int;
    setEncryptInfo(encrypt_type: ByteRTCEncryptType, key: NSString): int;
    setCustomizeEncryptHandler(handler: id<ByteRTCEncryptHandler>): int;
    createRTCRoom(roomId: NSString): ByteRTCRoom;
    pushScreenVideoFrame(frame: CVPixelBufferRef, pts: CMTime, rotation: int): int;
    setExtensionConfig(groupId: NSString): int;
    startScreenCapture(type: ByteRTCScreenMediaType, bundleId: NSString): int;
    updateScreenCapture(type: ByteRTCScreenMediaType): int;
    stopScreenCapture(): int;
    sendScreenCaptureExtensionMessage(messsage: NSData): int;
    setRuntimeParameters(parameters: NSDictionary): int;
    startASR(asrConfig: ByteRTCASRConfig, handler: id<ByteRTCASREngineEventHandler>): int;
    stopASR(): int;
    startFileRecording(streamIndex: ByteRTCStreamIndex, recordingConfig: ByteRTCRecordingConfig, recordingType: ByteRTCRecordingType): int;
    stopFileRecording(streamIndex: ByteRTCStreamIndex): int;
    startAudioRecording(recordingConfig: ByteRTCAudioRecordingConfig): int;
    stopAudioRecording(): int;
    getAudioEffectPlayer(): ByteRTCAudioEffectPlayer;
    getMediaPlayer(playerId: int): ByteRTCMediaPlayer;
    login(token: NSString, uid: NSString): int;
    logout(): int;
    updateLoginToken(token: NSString): int;
    setServerParams(signature: NSString, url: NSString): int;
    getPeerOnlineStatus(peerUserId: NSString): int;
    sendUserMessageOutsideRoom(userId: NSString, messageStr: NSString, config: ByteRTCMessageConfig): NSInteger;
    sendUserBinaryMessageOutsideRoom(userId: NSString, messageStr: NSData, config: ByteRTCMessageConfig): NSInteger;
    sendServerMessage(messageStr: NSString): NSInteger;
    sendServerBinaryMessage(messageStr: NSData): NSInteger;
    startNetworkDetection(isTestUplink: bool, expectedUplinkBitrate: int, isTestDownlink: bool, expectedDownlinkBitrate: int): int;
    stopNetworkDetection(): int;
    setScreenAudioSourceType(sourceType: ByteRTCAudioSourceType): int;
    setScreenAudioStreamIndex(index: ByteRTCStreamIndex): int;
    pushScreenAudioFrame(audioFrame: ByteRTCAudioFrame): int;
    setVideoSourceType(type: ByteRTCVideoSourceType, streamIndex: ByteRTCStreamIndex): int;
    setExternalVideoEncoderEventHandler(handler: id<ByteRTCExternalVideoEncoderEventHandler>): int;
    pushExternalEncodedVideoFrame(streamIndex: ByteRTCStreamIndex, videoIndex: NSInteger, videoFrame: ByteRTCEncodedVideoFrame): int;
    setVideoDecoderConfig(key: ByteRTCRemoteStreamKey, config: ByteRTCVideoDecoderConfig): int;
    requestRemoteVideoKeyFrame(key: ByteRTCRemoteStreamKey): int;
    registerRemoteEncodedVideoFrameObserver(observer: id<ByteRTCRemoteEncodedVideoFrameObserver>): int;
    sendStreamSyncInfo(data: NSData, config: ByteRTCStreamSycnInfoConfig): int;
    startEchoTest(echoConfig: ByteRTCEchoTestConfig, delayTime: NSInteger): int;
    stopEchoTest(): int;
    setVideoWatermark(streamIndex: ByteRTCStreamIndex, imagePath: NSString, rtcWatermarkConfig: ByteRTCVideoWatermarkConfig): int;
    clearVideoWatermark(streamIndex: ByteRTCStreamIndex): int;
    takeLocalSnapshot(streamIndex: ByteRTCStreamIndex, callback: id<ByteRTCVideoSnapshotCallbackDelegate>): NSInteger;
    takeRemoteSnapshot(streamKey: ByteRTCRemoteStreamKey, callback: id<ByteRTCVideoSnapshotCallbackDelegate>): NSInteger;
    startCloudProxy(cloudProxiesInfo: NSArray<ByteRTCCloudProxyInfo>): int;
    stopCloudProxy(): int;
    getSingScoringManager(): ByteRTCSingScoringManager;
    setDummyCaptureImagePath(filePath: NSString): int;
    getNetworkTimeInfo(): ByteRTCNetworkTimeInfo;
    getKTVManager(): ByteRTCKTVManager;
    startHardwareEchoDetection(testAudioFilePath: NSString): int;
    stopHardwareEchoDetection(): int;
    setCellularEnhancement(config: ByteRTCMediaTypeEnhancementConfig): int;
    setLocalProxy(configurations: NSArray<ByteRTCLocalProxyInfo>): int;
    setLocalVideoSink(index: ByteRTCStreamIndex, videoSink: id<ByteRTCVideoSinkDelegate>, requiredFormat: ByteRTCVideoSinkPixelFormat): int;
    setRemoteVideoSink(streamKey: ByteRTCRemoteStreamKey, videoSink: id<ByteRTCVideoSinkDelegate>, requiredFormat: ByteRTCVideoSinkPixelFormat): int;
    setVideoEncoderConfig$config$(streamIndex: ByteRTCStreamIndex, videoSolutions: NSArray<ByteRTCVideoSolution>): int;
    updateRemoteStreamVideoCanvas$withRenderMode$withBackgroundColor$(key: ByteRTCRemoteStreamKey, renderMode: ByteRTCRenderMode, backgroundColor: NSUInteger): int;
    checkVideoEffectLicense(licenseFile: NSString): int;
    setVideoEffectAlgoModelPath(modelPath: NSString): void;
    enableVideoEffect(enabled: BOOL): int;
    setVideoEffectNodes(effectNodePaths: NSArray<NSString>): int;
    updateVideoEffectNode(nodePath: NSString, nodeKey: NSString, nodeValue: float): int;
    setVideoEffectColorFilter(resPath: NSString): int;
    setVideoEffectColorFilterIntensity(intensity: float): int;
    setBackgroundSticker(modelPath: NSString, source: ByteRTCVirtualBackgroundSource): int;
    registerFaceDetectionObserver(faceDetectionObserver: id<ByteRTCFaceDetectionObserver>, interval: NSInteger): int;
    sendSEIMessage$andMessage$andRepeatCount$(streamIndex: ByteRTCStreamIndex, message: NSData, repeatCount: int): int;
    setAudioPlaybackDevice(audioPlaybackDevice: ByteRTCAudioPlaybackDevice): int;
    startLiveTranscoding(taskID: NSString, transcoding: ByteRTCLiveTranscoding, observer: id<LiveTranscodingDelegate>): int;
    stopLiveTranscoding(taskID: NSString): int;
    updateLiveTranscoding(taskID: NSString, transcoding: ByteRTCLiveTranscoding): int;
    getAudioMixingManager(): ByteRTCAudioMixingManager;
    muteAudioPlayback(muteState: ByteRTCMuteState): int;
    init(): this;
}
export declare class ByteRTCVideoDeviceManager {
    getVideoCaptureDevice(deviceID: NSString): int;
    setVideoCaptureDevice(deviceID: NSString): int;
    init(): this;
}
export declare class ByteRTCAudioMixingManager {
    startAudioMixing(mixId: int, filePath: NSString, config: ByteRTCAudioMixingConfig): void;
    stopAudioMixing(mixId: int): void;
    stopAllAudioMixing(): void;
    pauseAudioMixing(mixId: int): void;
    pauseAllAudioMixing(): void;
    resumeAudioMixing(mixId: int): void;
    resumeAllAudioMixing(): void;
    preloadAudioMixing(mixId: int, filePath: NSString): void;
    unloadAudioMixing(mixId: int): void;
    setAllAudioMixingVolume(volume: int, type: ByteRTCAudioMixingType): void;
    setAudioMixingVolume(mixId: int, volume: int, type: ByteRTCAudioMixingType): void;
    getAudioMixingDuration(mixId: int): int;
    getAudioMixingCurrentPosition(mixId: int): int;
    setAudioMixingPosition(mixId: int, position: int): void;
    setAudioMixingDualMonoMode(mixId: int, mode: ByteRTCAudioMixingDualMonoMode): void;
    setAudioMixingPitch(mixId: int, pitch: int): void;
    setAudioMixingPlaybackSpeed(mixId: int, speed: int): int;
    setAudioMixingLoudness(mixId: int, loudness: float): void;
    setAudioMixingProgressInterval(mixId: int, interval: int64_t): void;
    enableAudioMixingFrame(mixId: int, type: ByteRTCAudioMixingType): void;
    disableAudioMixingFrame(mixId: int): void;
    pushAudioMixingFrame(mixId: int, audioFrame: ByteRTCAudioFrame): int;
    getAudioTrackCount(mixId: int): int;
    selectAudioTrack(mixId: int, audioTrackIndex: int): void;
    registerAudioFileFrameObserver(observer: id<ByteRTCAudioFileFrameObserver>): void;
    getAudioMixingPlaybackDuration(mixId: int): int;
    init(): this;
}
export declare class ByteRTCKTVPlayer {
    delegate: id<ByteRTCKTVPlayerDelegate>;
    playMusic(musicId: NSString, trackType: ByteRTCAudioTrackType, playType: ByteRTCAudioPlayType): void;
    pauseMusic(musicId: NSString): void;
    resumeMusic(musicId: NSString): void;
    stopMusic(musicId: NSString): void;
    seekMusic(musicId: NSString, position: int): void;
    setMusicVolume(musicId: NSString, volume: int): void;
    switchAudioTrackType(musicId: NSString): void;
    setMusicPitch(musicId: NSString, pitch: int): void;
    init(): this;
}
export declare class ByteRTCRangeAudio {
    enableRangeAudio(enable: BOOL): void;
    updateReceiveRange(range: ByteRTCReceiveRange): int;
    updatePosition(pos: ByteRTCPosition): int;
    setAttenuationModel(type: ByteRTCAttenuationType, coefficient: float): int;
    setNoAttenuationFlags(flags: NSArray<NSString>): void;
    init(): this;
}
