// Copyright © 2022 BytePlusRTC All rights reserved.
// SPDX-License-Identifier: MIT

'use strict';

var reactNative = require('react-native');

/**
 *  base64.ts
 *
 *  Licensed under the BSD 3-Clause License.
 *    http://opensource.org/licenses/BSD-3-Clause
 *
 *  References:
 *    http://en.wikipedia.org/wiki/Base64
 *
 * @author Dan Kogai (https://github.com/dankogai)
 */
const version = '3.7.7';
/**
 * @deprecated use lowercase `version`.
 */
const VERSION = version;
const _hasBuffer = typeof Buffer === 'function';
const _TD = typeof TextDecoder === 'function' ? new TextDecoder() : undefined;
const _TE = typeof TextEncoder === 'function' ? new TextEncoder() : undefined;
const b64ch = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=';
const b64chs = Array.prototype.slice.call(b64ch);
const b64tab = ((a) => {
    let tab = {};
    a.forEach((c, i) => tab[c] = i);
    return tab;
})(b64chs);
const b64re = /^(?:[A-Za-z\d+\/]{4})*?(?:[A-Za-z\d+\/]{2}(?:==)?|[A-Za-z\d+\/]{3}=?)?$/;
const _fromCC = String.fromCharCode.bind(String);
const _U8Afrom = typeof Uint8Array.from === 'function'
    ? Uint8Array.from.bind(Uint8Array)
    : (it) => new Uint8Array(Array.prototype.slice.call(it, 0));
const _mkUriSafe = (src) => src
    .replace(/=/g, '').replace(/[+\/]/g, (m0) => m0 == '+' ? '-' : '_');
const _tidyB64 = (s) => s.replace(/[^A-Za-z0-9\+\/]/g, '');
/**
 * polyfill version of `btoa`
 */
const btoaPolyfill = (bin) => {
    // console.log('polyfilled');
    let u32, c0, c1, c2, asc = '';
    const pad = bin.length % 3;
    for (let i = 0; i < bin.length;) {
        if ((c0 = bin.charCodeAt(i++)) > 255 ||
            (c1 = bin.charCodeAt(i++)) > 255 ||
            (c2 = bin.charCodeAt(i++)) > 255)
            throw new TypeError('invalid character found');
        u32 = (c0 << 16) | (c1 << 8) | c2;
        asc += b64chs[u32 >> 18 & 63]
            + b64chs[u32 >> 12 & 63]
            + b64chs[u32 >> 6 & 63]
            + b64chs[u32 & 63];
    }
    return pad ? asc.slice(0, pad - 3) + "===".substring(pad) : asc;
};
/**
 * does what `window.btoa` of web browsers do.
 * @param {String} bin binary string
 * @returns {string} Base64-encoded string
 */
const _btoa = typeof btoa === 'function' ? (bin) => btoa(bin)
    : _hasBuffer ? (bin) => Buffer.from(bin, 'binary').toString('base64')
        : btoaPolyfill;
const _fromUint8Array = _hasBuffer
    ? (u8a) => Buffer.from(u8a).toString('base64')
    : (u8a) => {
        // cf. https://stackoverflow.com/questions/12710001/how-to-convert-uint8-array-to-base64-encoded-string/12713326#12713326
        const maxargs = 0x1000;
        let strs = [];
        for (let i = 0, l = u8a.length; i < l; i += maxargs) {
            strs.push(_fromCC.apply(null, u8a.subarray(i, i + maxargs)));
        }
        return _btoa(strs.join(''));
    };
/**
 * converts a Uint8Array to a Base64 string.
 * @param {boolean} [urlsafe] URL-and-filename-safe a la RFC4648 §5
 * @returns {string} Base64 string
 */
const fromUint8Array = (u8a, urlsafe = false) => urlsafe ? _mkUriSafe(_fromUint8Array(u8a)) : _fromUint8Array(u8a);
// This trick is found broken https://github.com/dankogai/js-base64/issues/130
// const utob = (src: string) => unescape(encodeURIComponent(src));
// reverting good old fationed regexp
const cb_utob = (c) => {
    if (c.length < 2) {
        var cc = c.charCodeAt(0);
        return cc < 0x80 ? c
            : cc < 0x800 ? (_fromCC(0xc0 | (cc >>> 6))
                + _fromCC(0x80 | (cc & 0x3f)))
                : (_fromCC(0xe0 | ((cc >>> 12) & 0x0f))
                    + _fromCC(0x80 | ((cc >>> 6) & 0x3f))
                    + _fromCC(0x80 | (cc & 0x3f)));
    }
    else {
        var cc = 0x10000
            + (c.charCodeAt(0) - 0xD800) * 0x400
            + (c.charCodeAt(1) - 0xDC00);
        return (_fromCC(0xf0 | ((cc >>> 18) & 0x07))
            + _fromCC(0x80 | ((cc >>> 12) & 0x3f))
            + _fromCC(0x80 | ((cc >>> 6) & 0x3f))
            + _fromCC(0x80 | (cc & 0x3f)));
    }
};
const re_utob = /[\uD800-\uDBFF][\uDC00-\uDFFFF]|[^\x00-\x7F]/g;
/**
 * @deprecated should have been internal use only.
 * @param {string} src UTF-8 string
 * @returns {string} UTF-16 string
 */
const utob = (u) => u.replace(re_utob, cb_utob);
//
const _encode = _hasBuffer
    ? (s) => Buffer.from(s, 'utf8').toString('base64')
    : _TE
        ? (s) => _fromUint8Array(_TE.encode(s))
        : (s) => _btoa(utob(s));
/**
 * converts a UTF-8-encoded string to a Base64 string.
 * @param {boolean} [urlsafe] if `true` make the result URL-safe
 * @returns {string} Base64 string
 */
const encode = (src, urlsafe = false) => urlsafe
    ? _mkUriSafe(_encode(src))
    : _encode(src);
/**
 * converts a UTF-8-encoded string to URL-safe Base64 RFC4648 §5.
 * @returns {string} Base64 string
 */
const encodeURI = (src) => encode(src, true);
// This trick is found broken https://github.com/dankogai/js-base64/issues/130
// const btou = (src: string) => decodeURIComponent(escape(src));
// reverting good old fationed regexp
const re_btou = /[\xC0-\xDF][\x80-\xBF]|[\xE0-\xEF][\x80-\xBF]{2}|[\xF0-\xF7][\x80-\xBF]{3}/g;
const cb_btou = (cccc) => {
    switch (cccc.length) {
        case 4:
            var cp = ((0x07 & cccc.charCodeAt(0)) << 18)
                | ((0x3f & cccc.charCodeAt(1)) << 12)
                | ((0x3f & cccc.charCodeAt(2)) << 6)
                | (0x3f & cccc.charCodeAt(3)), offset = cp - 0x10000;
            return (_fromCC((offset >>> 10) + 0xD800)
                + _fromCC((offset & 0x3FF) + 0xDC00));
        case 3:
            return _fromCC(((0x0f & cccc.charCodeAt(0)) << 12)
                | ((0x3f & cccc.charCodeAt(1)) << 6)
                | (0x3f & cccc.charCodeAt(2)));
        default:
            return _fromCC(((0x1f & cccc.charCodeAt(0)) << 6)
                | (0x3f & cccc.charCodeAt(1)));
    }
};
/**
 * @deprecated should have been internal use only.
 * @param {string} src UTF-16 string
 * @returns {string} UTF-8 string
 */
const btou = (b) => b.replace(re_btou, cb_btou);
/**
 * polyfill version of `atob`
 */
const atobPolyfill = (asc) => {
    // console.log('polyfilled');
    asc = asc.replace(/\s+/g, '');
    if (!b64re.test(asc))
        throw new TypeError('malformed base64.');
    asc += '=='.slice(2 - (asc.length & 3));
    let u24, bin = '', r1, r2;
    for (let i = 0; i < asc.length;) {
        u24 = b64tab[asc.charAt(i++)] << 18
            | b64tab[asc.charAt(i++)] << 12
            | (r1 = b64tab[asc.charAt(i++)]) << 6
            | (r2 = b64tab[asc.charAt(i++)]);
        bin += r1 === 64 ? _fromCC(u24 >> 16 & 255)
            : r2 === 64 ? _fromCC(u24 >> 16 & 255, u24 >> 8 & 255)
                : _fromCC(u24 >> 16 & 255, u24 >> 8 & 255, u24 & 255);
    }
    return bin;
};
/**
 * does what `window.atob` of web browsers do.
 * @param {String} asc Base64-encoded string
 * @returns {string} binary string
 */
const _atob = typeof atob === 'function' ? (asc) => atob(_tidyB64(asc))
    : _hasBuffer ? (asc) => Buffer.from(asc, 'base64').toString('binary')
        : atobPolyfill;
//
const _toUint8Array = _hasBuffer
    ? (a) => _U8Afrom(Buffer.from(a, 'base64'))
    : (a) => _U8Afrom(_atob(a).split('').map(c => c.charCodeAt(0)));
/**
 * converts a Base64 string to a Uint8Array.
 */
const toUint8Array = (a) => _toUint8Array(_unURI(a));
//
const _decode = _hasBuffer
    ? (a) => Buffer.from(a, 'base64').toString('utf8')
    : _TD
        ? (a) => _TD.decode(_toUint8Array(a))
        : (a) => btou(_atob(a));
const _unURI = (a) => _tidyB64(a.replace(/[-_]/g, (m0) => m0 == '-' ? '+' : '/'));
/**
 * converts a Base64 string to a UTF-8 string.
 * @param {String} src Base64 string.  Both normal and URL-safe are supported
 * @returns {string} UTF-8 string
 */
const decode = (src) => _decode(_unURI(src));
/**
 * check if a value is a valid Base64 string
 * @param {String} src a value to check
  */
const isValid = (src) => {
    if (typeof src !== 'string')
        return false;
    const s = src.replace(/\s+/g, '').replace(/={0,2}$/, '');
    return !/[^\s0-9a-zA-Z\+/]/.test(s) || !/[^\s0-9a-zA-Z\-_]/.test(s);
};
//
const _noEnum = (v) => {
    return {
        value: v, enumerable: false, writable: true, configurable: true
    };
};
/**
 * extend String.prototype with relevant methods
 */
const extendString = function () {
    const _add = (name, body) => Object.defineProperty(String.prototype, name, _noEnum(body));
    _add('fromBase64', function () { return decode(this); });
    _add('toBase64', function (urlsafe) { return encode(this, urlsafe); });
    _add('toBase64URI', function () { return encode(this, true); });
    _add('toBase64URL', function () { return encode(this, true); });
    _add('toUint8Array', function () { return toUint8Array(this); });
};
/**
 * extend Uint8Array.prototype with relevant methods
 */
const extendUint8Array = function () {
    const _add = (name, body) => Object.defineProperty(Uint8Array.prototype, name, _noEnum(body));
    _add('toBase64', function (urlsafe) { return fromUint8Array(this, urlsafe); });
    _add('toBase64URI', function () { return fromUint8Array(this, true); });
    _add('toBase64URL', function () { return fromUint8Array(this, true); });
};
/**
 * extend Builtin prototypes with relevant methods
 */
const extendBuiltins = () => {
    extendString();
    extendUint8Array();
};
const gBase64 = {
    version: version,
    VERSION: VERSION,
    atob: _atob,
    atobPolyfill: atobPolyfill,
    btoa: _btoa,
    btoaPolyfill: btoaPolyfill,
    fromBase64: decode,
    toBase64: encode,
    encode: encode,
    encodeURI: encodeURI,
    encodeURL: encodeURI,
    utob: utob,
    btou: btou,
    decode: decode,
    isValid: isValid,
    fromUint8Array: fromUint8Array,
    toUint8Array: toUint8Array,
    extendString: extendString,
    extendUint8Array: extendUint8Array,
    extendBuiltins: extendBuiltins
};

Symbol.metadata ?? (Symbol.metadata = Symbol('Symbol.metadata'));

const DISABLE_INIT = Symbol();
function PackClass() {
    return (target, ctx) => {
        return class extends target {
            constructor(...args) {
                super(...args);
                const _init = () => {
                    this.__init?.(...args);
                };
                const isDisableInit = args.includes(DISABLE_INIT);
                if (!isDisableInit) {
                    _init();
                }
                Object.defineProperty(this, '$$pack', {
                    value: true,
                    enumerable: false,
                });
            }
        };
    };
}

function packObject(receiver, ctor) {
    const ins = new ctor(DISABLE_INIT);
    Object.defineProperty(ins, '_instance', {
        value: receiver,
        enumerable: false,
    });
    return ins;
}
function unpackObject(proxyInstance, _nativeClass) {
    return proxyInstance._instance;
}
function extendsClassMethod(ctor, methodName, overrideFn) {
    const proto = ctor.prototype;
    const originalFn = ctor.prototype[methodName];
    proto[methodName] = function (...args) {
        return overrideFn(originalFn?.bind(this)).apply(this, args);
    };
}

let impl;
function setupEnv(e) {
    impl = e;
}
function getOS() {
    return impl.os();
}
function resolveImageResource(input) {
    return impl.resolveImageResource(input);
}

var env = /*#__PURE__*/Object.freeze({
    __proto__: null,
    getOS: getOS,
    resolveImageResource: resolveImageResource,
    setupEnv: setupEnv
});

var BRIDGE_NATIVE_API$1;
(function (BRIDGE_NATIVE_API) {
    BRIDGE_NATIVE_API["CALL_API"] = "callApi";
    BRIDGE_NATIVE_API["CALL_API_SYNC"] = "callApiSync";
})(BRIDGE_NATIVE_API$1 || (BRIDGE_NATIVE_API$1 = {}));
var CALL_TYPE$1;
(function (CALL_TYPE) {
    /**
     * 获取动态变量
     */
    CALL_TYPE["VAR_GETTER"] = "var_get";
    /**
     * 调用静态方法
     */
    CALL_TYPE["PLAIN_API_CALL"] = "plain_api_call";
    /**
     * 实例化对象
     */
    CALL_TYPE["NEW_INSTANCE"] = "new_instance";
    /**
     * 调用 api 上的方法
     */
    CALL_TYPE["INSTANCE_METHOD_INVOKE"] = "instance_method_invoke";
    /**
     * 设置属性
     */
    CALL_TYPE["INSTANCE_MEMBER_SET"] = "instance_member_set";
    /**
     * 设置属性
     */
    CALL_TYPE["INSTANCE_MEMBER_GET"] = "instance_member_get";
    /**
     * 注册回调函数
     */
    CALL_TYPE["INSTANCE_EVENT_LISTENER_ADD"] = "instance_event_add";
    /**
     * 移除回调函数
     */
    CALL_TYPE["INSTANCE_EVENT_LISTENER_REMOVE"] = "instance_event_remove";
    /**
     * 触发事件
     */
    CALL_TYPE["INSTANCE_EVENT_EMIT"] = "instance_event_emit";
    /**
     * 触发事件
     */
    CALL_TYPE["CALLBACK_EMIT"] = "callback_emit";
})(CALL_TYPE$1 || (CALL_TYPE$1 = {}));
var RETURN_STATUS$1;
(function (RETURN_STATUS) {
    RETURN_STATUS["SUCCESS"] = "success";
    RETURN_STATUS["FAILED"] = "failed";
})(RETURN_STATUS$1 || (RETURN_STATUS$1 = {}));

class DefaultBridgeImpl {
    call() {
        return new Promise((resolve, reject) => {
            resolve({
                status: 'success',
                msg: null,
            });
        });
    }
    callSync() {
        return {
            status: 'success',
            msg: null,
        };
    }
    registerHandler(handlerName, handler) {
        // dsBridge.register(handlerName, handler);
    }
    registerAsyncHandler(handlerName, handler) {
        //
    }
}

const createJSBridge = () => {
    return new DefaultBridgeImpl();
};

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise, SuppressedError, Symbol */


function __esDecorate$1(ctor, descriptorIn, decorators, contextIn, initializers, extraInitializers) {
    function accept(f) { if (f !== void 0 && typeof f !== "function") throw new TypeError("Function expected"); return f; }
    var kind = contextIn.kind, key = kind === "getter" ? "get" : kind === "setter" ? "set" : "value";
    var target = ctor ? contextIn["static"] ? ctor : ctor.prototype : null;
    var descriptor = (target ? Object.getOwnPropertyDescriptor(target, contextIn.name) : {});
    var _, done = false;
    for (var i = decorators.length - 1; i >= 0; i--) {
        var context = {};
        for (var p in contextIn) context[p] = p === "access" ? {} : contextIn[p];
        for (var p in contextIn.access) context.access[p] = contextIn.access[p];
        context.addInitializer = function (f) { if (done) throw new TypeError("Cannot add initializers after decoration has completed"); extraInitializers.push(accept(f || null)); };
        var result = (0, decorators[i])(kind === "accessor" ? { get: descriptor.get, set: descriptor.set } : descriptor[key], context);
        if (kind === "accessor") {
            if (result === void 0) continue;
            if (result === null || typeof result !== "object") throw new TypeError("Object expected");
            if (_ = accept(result.get)) descriptor.get = _;
            if (_ = accept(result.set)) descriptor.set = _;
            if (_ = accept(result.init)) initializers.unshift(_);
        }
        else if (_ = accept(result)) {
            if (kind === "field") initializers.unshift(_);
            else descriptor[key] = _;
        }
    }
    if (target) Object.defineProperty(target, contextIn.name, descriptor);
    done = true;
}
function __runInitializers$1(thisArg, initializers, value) {
    var useValue = arguments.length > 2;
    for (var i = 0; i < initializers.length; i++) {
        value = useValue ? initializers[i].call(thisArg, value) : initializers[i].call(thisArg);
    }
    return useValue ? value : void 0;
}
typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
    var e = new Error(message);
    return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
};

function assert(expression, msg) {
    if (!expression) {
        throw new Error(msg);
    }
}

const isArray = (value) => Array.isArray(value);
const isInstance = (value) => {
    if (typeof value !== 'object' || value === null) {
        return false;
    }
    if ('instanceId' in value || '_instanceId' in value) {
        return true;
    }
    const proto = Object.getPrototypeOf(value);
    return (!!proto &&
        proto.constructor.name !== 'Array' &&
        proto.constructor.name !== 'Object');
};
const isCallback = (value) => {
    return typeof value === 'function';
};
const isPlainObject = (value) => {
    return typeof value === 'object' && value !== null;
};
const isInstanceArg = (value) => {
    return (isPlainObject(value) && value._type === "instance" /* ARG_TYPE.INSTANCE */);
};

const SIZE = 32;
const getUuid = (namespace = '') => {
    const random = String(Math.random()).slice(2);
    const prefix = namespace.slice(0, 24);
    return '@js' + prefix + '#' + random.slice(0, SIZE - prefix.length - 1);
};

function safeStringify(val) {
    try {
        if (val instanceof Error) {
            return `Error: ${val.message}`;
        }
        return JSON.stringify(val);
    }
    catch (er) {
        return String(val);
    }
}

function fromPairs(entries) {
    return entries.reduce((acc, [k, v]) => {
        acc[k] = v;
        return acc;
    }, {});
}
function toPairs(obj) {
    return Object.entries(obj);
}
function mapValues(data, fn) {
    const paris = toPairs(data);
    const mappedPairs = paris.map(([k, v]) => [k, fn(v, k)]);
    return fromPairs(mappedPairs);
}

const keyPathVisitor = (obj, path, defaultValue) => {
    const getResult = obj
        ? path.reduce((pre, next) => {
            if (pre && pre !== defaultValue) {
                const preValue = pre;
                const nextvalue = preValue[next];
                return !nextvalue ? defaultValue : nextvalue;
            }
            return defaultValue;
        }, obj)
        : defaultValue;
    return getResult;
};

const Bind = (target, context) => {
    context.addInitializer(function () {
        const fnName = context.name;
        this[fnName] = this[fnName].bind(this);
    });
    return target;
};

var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["verbose"] = 0] = "verbose";
    LogLevel[LogLevel["debug"] = 1] = "debug";
    LogLevel[LogLevel["info"] = 2] = "info";
    LogLevel[LogLevel["warn"] = 3] = "warn";
    LogLevel[LogLevel["error"] = 4] = "error";
})(LogLevel || (LogLevel = {}));

class LoggerImpl {
    constructor() {
        this._enablePrintVerbose = false;
        this._consumers = [];
    }
    init(opt) {
        this.options = opt;
    }
    enableVerbose(enable) {
        this._enablePrintVerbose = enable;
    }
    registerConsumer(consumer) {
        this._consumers.push(consumer);
    }
    verbose(...args) {
        if (this._enablePrintVerbose) {
            console.debug('[verbose]', ...args);
        }
    }
    debug(...args) {
        const msg = {
            level: LogLevel.debug,
            content: args,
        };
        this._log(msg);
        if (this._enablePrintVerbose) {
            console.debug('[debug]', ...args);
        }
    }
    info(...args) {
        const msg = {
            level: LogLevel.info,
            content: args,
        };
        this._log(msg);
        console.log(...args);
    }
    warn(...args) {
        const msg = {
            level: LogLevel.warn,
            content: args,
        };
        this._log(msg);
        console.warn(...args);
    }
    error(...args) {
        const msg = {
            level: LogLevel.error,
            content: args,
        };
        this._log(msg);
        console.error(...args);
    }
    _log(msg) {
        this._consumers.forEach(async (c) => {
            try {
                await c(msg);
            }
            catch (ignore) {
                //
            }
        });
    }
}

const logger = new LoggerImpl();

class ApiCallSpan {
    constructor(tracer, action) {
        this.tracer = tracer;
        this.action = action;
        this.startTimestamp = Date.now();
        this.status = 'unknown';
        const record = {
            ts: Date.now(),
            type: 'call',
            data: action,
            traceId: action.traceId,
        };
        const msg = `<TO ${action.target}> ${action.callType} call:${action.serviceName || ''}.${action.methodName || action.memberName || ''} args=${safeStringify(action.args)}`;
        this.tracer.report(record, msg, {
            serviceName: action.serviceName,
        });
    }
    setReturnValue(value) {
        this.action.return = value;
    }
    success(value) {
        this.setReturnValue(value);
        this.status = 'success';
        this.finish();
    }
    fail(error) {
        this.setReturnValue(error);
        this.status = 'fail';
        this.finish();
    }
    finish() {
        this.endTimestamp = Date.now();
        this._report();
    }
    _report() {
        const { action } = this;
        const record = {
            ts: Date.now(),
            type: 'call',
            data: action,
            traceId: this.action.traceId,
        };
        const msg = `<${action.target} Return> ${action.callType} call:${action.serviceName}.${action.methodName || action.memberName || ''} args=${safeStringify(action.args)} return=${safeStringify(action.return)}`;
        const cost = this.endTimestamp - this.startTimestamp;
        this.tracer.report(record, msg, {
            level: this.status === 'fail' ||
                this.action.return?.status === 'failed'
                ? 'warn'
                : 'debug',
            serviceName: action.serviceName,
            cost,
            status: this.status,
            [this.status]: '1',
        });
    }
}
class Tracer {
    constructor() {
        this._consumers = [];
    }
    registerConsumer(consumer) {
        this._consumers.push(consumer);
    }
    init(opt) {
        this.options = opt;
    }
    collectApiCall(action) {
        const span = new ApiCallSpan(this, action);
        return span;
    }
    collectEventEmit(action) {
        const record = {
            ts: Date.now(),
            type: 'event_emit',
            data: action,
        };
        const { eventName, eventData } = action;
        const msg = `<TO ${action.target}> emit:${eventName} event=${safeStringify(eventData)}`;
        this.report(record, msg, {
            callType: 'event_emit',
            eventName: eventName,
        });
    }
    collectEventOn(action) {
        const record = {
            ts: Date.now(),
            type: 'event_on',
            data: action,
        };
        const { eventName } = action;
        const msg = `<TO ${action.target}> on:${eventName}`;
        this.report(record, msg, {
            callType: 'event_on',
            eventName,
        });
    }
    collectEventOff(action) {
        const record = {
            ts: Date.now(),
            type: 'event_off',
            data: action,
        };
        const { eventName } = action;
        const msg = `<TO ${action.target}> off:${eventName}`;
        this.report(record, msg, {
            callType: 'event_off',
            eventName,
        });
    }
    collectCallbackEmit(action) {
        const record = {
            ts: Date.now(),
            type: 'callback_emit',
            data: action,
        };
        const { eventName, eventData } = action;
        const msg = `<TO ${action.target}> emit callback:${eventName} event=${safeStringify(eventData)}`;
        this.report(record, msg, {
            callType: 'callback_emit',
            eventName: eventName,
        });
    }
    report(record, msg, extra) {
        this._consumers.forEach(async (c) => {
            try {
                await c(record, msg, extra);
            }
            catch (ignore) {
                //
            }
        });
        try {
            const level = extra.level || 'info';
            if (level === 'warn' || level === 'error') {
                console.warn(`[Trace] ${level} `, msg);
            }
            else if (false) ;
        }
        catch (err) {
            //
        }
    }
}

const globalTracer = new Tracer();

let MessageSenderImpl = (() => {
    var _a;
    let _instanceExtraInitializers = [];
    let _sendVarGet_decorators;
    let _sendStaticCall_decorators;
    let _sendStaticCallSync_decorators;
    let _sendNewInstanceCall_decorators;
    let _sendInstanceCall_decorators;
    let _sendInstanceCallSync_decorators;
    let _sendInstanceSet_decorators;
    let _sendInstanceGet_decorators;
    let _sendInstanceEventAdd_decorators;
    let _sendInstanceEventRemove_decorators;
    let _sendEventEmit_decorators;
    return _a = class MessageSenderImpl {
            constructor(proto, bridge) {
                this.proto = (__runInitializers$1(this, _instanceExtraInitializers), proto);
                this.bridge = bridge;
                this.logger = logger;
                this.tracer = globalTracer;
            }
            async sendVarGet(varName, args) {
                const traceId = getUuid('trace');
                const encodeArgs = this.proto.encodeArgs(args);
                const params = {
                    serviceName: varName,
                    memberName: varName,
                    args: encodeArgs,
                    callType: CALL_TYPE$1.VAR_GETTER,
                    _traceId: traceId,
                };
                const span = this.tracer.collectApiCall({
                    source: 'js',
                    target: 'native',
                    serviceName: '$var',
                    memberName: varName,
                    args: encodeArgs,
                    traceId,
                    callType: params.callType,
                });
                try {
                    const res = await this._send(params);
                    span.success(res);
                    return res;
                }
                catch (err) {
                    span.fail(err);
                    throw err;
                }
            }
            async sendStaticCall(serviceName, methodName, args) {
                const encodeArgs = this.proto.encodeArgs(args);
                const traceId = getUuid('trace');
                const params = {
                    serviceName,
                    methodName,
                    args: encodeArgs,
                    callType: CALL_TYPE$1.PLAIN_API_CALL,
                    _traceId: traceId,
                };
                const span = this.tracer.collectApiCall({
                    source: 'js',
                    target: 'native',
                    serviceName,
                    methodName,
                    args,
                    traceId,
                    callType: params.callType,
                });
                try {
                    const res = await this._send(params);
                    span.success(res);
                    return res;
                }
                catch (err) {
                    span.fail(err);
                    throw err;
                }
            }
            sendStaticCallSync(serviceName, methodName, args) {
                const encodeArgs = this.proto.encodeArgs(args);
                const traceId = getUuid('trace');
                const params = {
                    serviceName,
                    methodName,
                    args: encodeArgs,
                    callType: CALL_TYPE$1.PLAIN_API_CALL,
                    _traceId: traceId,
                };
                const span = this.tracer.collectApiCall({
                    source: 'js',
                    target: 'native',
                    serviceName,
                    methodName,
                    args,
                    traceId,
                    callType: params.callType,
                });
                try {
                    const res = this._sendSync(params);
                    span.success(res);
                    return res;
                }
                catch (err) {
                    span.fail(err);
                    throw err;
                }
            }
            sendNewInstanceCall(serviceName, args, instanceId, instance) {
                const encodeArgs = this.proto.encodeArgs(args);
                const traceId = getUuid('trace');
                const params = {
                    serviceName,
                    args: encodeArgs,
                    callType: CALL_TYPE$1.NEW_INSTANCE,
                    _instanceId: instanceId,
                    _traceId: traceId,
                };
                const span = this.tracer.collectApiCall({
                    source: 'js',
                    target: 'native',
                    serviceName,
                    args,
                    traceId,
                    callType: params.callType,
                });
                try {
                    this.proto.registerProxyInstance(instanceId, instance);
                    const res = this._sendSync(params);
                    span.success(res);
                    return res;
                }
                catch (err) {
                    span.fail(err);
                    throw err;
                }
            }
            async sendInstanceCall(instanceOrId, serviceName, methodName, args = [], meta) {
                const instanceId = this._resolveInstanceId(instanceOrId);
                assert(!!instanceId, 'unknown instance');
                const encodeArgs = this.proto.encodeArgs(args);
                const traceId = getUuid('trace');
                const params = {
                    callType: CALL_TYPE$1.INSTANCE_METHOD_INVOKE,
                    _instanceId: instanceId,
                    serviceName: serviceName,
                    methodName,
                    args: encodeArgs,
                    _traceId: traceId,
                };
                const span = this.tracer.collectApiCall({
                    source: 'js',
                    target: 'native',
                    serviceName,
                    methodName,
                    args,
                    traceId,
                    callType: params.callType,
                });
                try {
                    const res = await this._send(params);
                    span.success(res);
                    return res;
                }
                catch (err) {
                    span.fail(err);
                    throw err;
                }
            }
            sendInstanceCallSync(instanceOrId, serviceName, methodName, args = [], meta) {
                const instanceId = this._resolveInstanceId(instanceOrId);
                assert(!!instanceId, 'unknown instance');
                const encodeArgs = this.proto.encodeArgs(args);
                const traceId = getUuid('trace');
                const params = {
                    callType: CALL_TYPE$1.INSTANCE_METHOD_INVOKE,
                    _instanceId: instanceId,
                    serviceName: serviceName,
                    args: encodeArgs,
                    methodName,
                    _traceId: traceId,
                };
                const span = this.tracer.collectApiCall({
                    source: 'js',
                    target: 'native',
                    serviceName,
                    methodName,
                    args,
                    traceId,
                    callType: params.callType,
                });
                try {
                    const res = this._sendSync(params);
                    span.success(res);
                    return res;
                }
                catch (err) {
                    span.fail(err);
                    throw err;
                }
            }
            sendInstanceSet(instanceOrId, serviceName, memberName, value) {
                const arg = this.proto.encodeArg(value);
                const instanceId = this._resolveInstanceId(instanceOrId);
                assert(!!instanceId, 'unknown instance');
                const traceId = getUuid('trace');
                const params = {
                    callType: CALL_TYPE$1.INSTANCE_MEMBER_SET,
                    _instanceId: instanceId,
                    serviceName,
                    memberName,
                    args: [arg],
                    _traceId: traceId,
                };
                const span = this.tracer.collectApiCall({
                    source: 'js',
                    target: 'native',
                    serviceName: memberName,
                    memberName,
                    args: [arg],
                    traceId,
                    callType: params.callType,
                });
                try {
                    const res = this._sendSync(params);
                    span.success(res);
                    return res;
                }
                catch (err) {
                    span.fail(err);
                    throw err;
                }
            }
            sendInstanceGet(instanceOrId, serviceName, memberName) {
                const instanceId = this._resolveInstanceId(instanceOrId);
                assert(!!instanceId, 'unknown instance');
                const traceId = getUuid('trace');
                const params = {
                    callType: CALL_TYPE$1.INSTANCE_MEMBER_GET,
                    _instanceId: instanceId,
                    serviceName,
                    memberName,
                    args: [],
                    _traceId: traceId,
                };
                const span = this.tracer.collectApiCall({
                    source: 'js',
                    target: 'native',
                    serviceName: memberName,
                    memberName,
                    args: [],
                    traceId,
                    callType: params.callType,
                });
                try {
                    const res = this._sendSync(params);
                    span.success(res);
                    return res;
                }
                catch (err) {
                    span.fail(err);
                    throw err;
                }
            }
            sendInstanceEventAdd(instanceOrId, serviceName, eventName) {
                const instanceId = this._resolveInstanceId(instanceOrId);
                assert(!!instanceId, 'unknown instance');
                // const encodeCallback = this.proto.encodeCallback(callback);
                const params = {
                    callType: CALL_TYPE$1.INSTANCE_EVENT_LISTENER_ADD,
                    _instanceId: instanceId,
                    serviceName: serviceName,
                    methodName: eventName,
                    // args: [encodeCallback],
                };
                this.tracer.collectEventOn({
                    source: 'js',
                    target: 'native',
                    eventName: serviceName,
                });
                return this._sendSync(params);
            }
            sendInstanceEventRemove(instanceOrId, serviceName, eventName) {
                const instanceId = this._resolveInstanceId(instanceOrId);
                assert(!!instanceId, 'unknown instance');
                // const encodeCallback = this.proto.encodeCallback(callback);
                const params = {
                    callType: CALL_TYPE$1.INSTANCE_EVENT_LISTENER_REMOVE,
                    _instanceId: instanceId,
                    serviceName: serviceName,
                    methodName: eventName,
                    // args: [encodeCallback],
                };
                this.tracer.collectEventOn({
                    source: 'js',
                    target: 'native',
                    eventName: serviceName,
                });
                return this._sendSync(params);
            }
            async sendEventEmit(instanceId, serviceName, callbackId, args) {
                const encodeArgs = this.proto.encodeArgs(args);
                const params = {
                    callType: CALL_TYPE$1.INSTANCE_EVENT_EMIT,
                    _instanceId: instanceId,
                    serviceName: serviceName,
                    args: [
                        {
                            callback_id: callbackId,
                        },
                        ...encodeArgs,
                    ],
                };
                this.tracer.collectEventEmit({
                    source: 'js',
                    target: 'native',
                    eventName: serviceName,
                    eventData: encodeArgs,
                });
                return this._send(params);
            }
            async _send(params) {
                const traceId = params._traceId || getUuid('trace');
                params._traceId = traceId;
                const res = await this.bridge.call(params);
                return this._resolveReturn(res, params);
            }
            _sendSync(params) {
                const traceId = params._traceId || getUuid('trace');
                params._traceId = traceId;
                const res = this.bridge.callSync(params);
                return this._resolveReturn(res, params);
            }
            _resolveReturn(res, req) {
                if (res.status === RETURN_STATUS$1.SUCCESS && res.msg) {
                    Object.defineProperty(res, 'decoded', {
                        value: this.proto.decodeArg(res.msg),
                        enumerable: false,
                        writable: true,
                    });
                }
                return res;
            }
            _resolveInstanceId(instanceOrId) {
                if (typeof instanceOrId === 'string') {
                    return instanceOrId;
                }
                if (isInstanceArg(instanceOrId)) {
                    return instanceOrId._instanceId;
                }
            }
        },
        (() => {
            const _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
            _sendVarGet_decorators = [Bind];
            _sendStaticCall_decorators = [Bind];
            _sendStaticCallSync_decorators = [Bind];
            _sendNewInstanceCall_decorators = [Bind];
            _sendInstanceCall_decorators = [Bind];
            _sendInstanceCallSync_decorators = [Bind];
            _sendInstanceSet_decorators = [Bind];
            _sendInstanceGet_decorators = [Bind];
            _sendInstanceEventAdd_decorators = [Bind];
            _sendInstanceEventRemove_decorators = [Bind];
            _sendEventEmit_decorators = [Bind];
            __esDecorate$1(_a, null, _sendVarGet_decorators, { kind: "method", name: "sendVarGet", static: false, private: false, access: { has: obj => "sendVarGet" in obj, get: obj => obj.sendVarGet }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _sendStaticCall_decorators, { kind: "method", name: "sendStaticCall", static: false, private: false, access: { has: obj => "sendStaticCall" in obj, get: obj => obj.sendStaticCall }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _sendStaticCallSync_decorators, { kind: "method", name: "sendStaticCallSync", static: false, private: false, access: { has: obj => "sendStaticCallSync" in obj, get: obj => obj.sendStaticCallSync }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _sendNewInstanceCall_decorators, { kind: "method", name: "sendNewInstanceCall", static: false, private: false, access: { has: obj => "sendNewInstanceCall" in obj, get: obj => obj.sendNewInstanceCall }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _sendInstanceCall_decorators, { kind: "method", name: "sendInstanceCall", static: false, private: false, access: { has: obj => "sendInstanceCall" in obj, get: obj => obj.sendInstanceCall }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _sendInstanceCallSync_decorators, { kind: "method", name: "sendInstanceCallSync", static: false, private: false, access: { has: obj => "sendInstanceCallSync" in obj, get: obj => obj.sendInstanceCallSync }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _sendInstanceSet_decorators, { kind: "method", name: "sendInstanceSet", static: false, private: false, access: { has: obj => "sendInstanceSet" in obj, get: obj => obj.sendInstanceSet }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _sendInstanceGet_decorators, { kind: "method", name: "sendInstanceGet", static: false, private: false, access: { has: obj => "sendInstanceGet" in obj, get: obj => obj.sendInstanceGet }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _sendInstanceEventAdd_decorators, { kind: "method", name: "sendInstanceEventAdd", static: false, private: false, access: { has: obj => "sendInstanceEventAdd" in obj, get: obj => obj.sendInstanceEventAdd }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _sendInstanceEventRemove_decorators, { kind: "method", name: "sendInstanceEventRemove", static: false, private: false, access: { has: obj => "sendInstanceEventRemove" in obj, get: obj => obj.sendInstanceEventRemove }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _sendEventEmit_decorators, { kind: "method", name: "sendEventEmit", static: false, private: false, access: { has: obj => "sendEventEmit" in obj, get: obj => obj.sendEventEmit }, metadata: _metadata }, null, _instanceExtraInitializers);
            if (_metadata) Object.defineProperty(_a, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        })(),
        _a;
})();

let MessageClientImpl = (() => {
    var _a;
    let _classSuper = MessageSenderImpl;
    let _instanceExtraInitializers = [];
    let _registerService_decorators;
    let _registerInstance_decorators;
    let _handlerMessage_decorators;
    return _a = class MessageClientImpl extends _classSuper {
            constructor() {
                super(...arguments);
                this._globalScope = (__runInitializers$1(this, _instanceExtraInitializers), {});
            }
            registerService(name, service) {
                this._globalScope[name] = service;
            }
            registerInstance(id, instance) {
                this.proto.registerProxyInstance(id, instance);
            }
            async handlerMessage(req) {
                try {
                    const { callType } = req;
                    switch (callType) {
                        case CALL_TYPE$1.PLAIN_API_CALL:
                            return this._onCallStaticApi(req);
                        case CALL_TYPE$1.INSTANCE_METHOD_INVOKE:
                            return this._onCallInstanceApi(req);
                        case CALL_TYPE$1.INSTANCE_EVENT_LISTENER_ADD:
                            return this._onCallEventRegister(req);
                        case CALL_TYPE$1.INSTANCE_EVENT_EMIT:
                            return this._onCallEventEmit(req);
                        case CALL_TYPE$1.CALLBACK_EMIT:
                            return this._onCallbackEmit(req);
                        default:
                            throw new Error(`unknown callType "${callType}"`);
                    }
                }
                catch (err) {
                    this.logger.warn('handle remote call fail:', req, err);
                    throw err;
                }
            }
            async _onCallStaticApi(req) {
                const { serviceName, args = [] } = req;
                const paths = serviceName.split('.');
                const property = paths.pop();
                const root = this._globalScope;
                const target = keyPathVisitor(root, paths);
                assert(!!target, `can"t find static api, please check serviceName ${serviceName}`);
                const api = Reflect.get(target, property);
                assert(!!api, `can"t find static api ${target}.${property}, please check serviceName ${serviceName}`);
                const decodeArgs = this.proto.decodeArgs(args);
                const span = this.tracer.collectApiCall({
                    source: 'native',
                    target: 'js',
                    serviceName: serviceName,
                    callType: CALL_TYPE$1.PLAIN_API_CALL,
                    args,
                });
                try {
                    const value = typeof api === 'function' ? await api.apply(target, decodeArgs) : api;
                    const res = this._returnHandler(value);
                    span.success(res);
                    return res;
                }
                catch (err) {
                    span.fail(err);
                    throw err;
                }
            }
            async _onCallInstanceApi(req) {
                const { serviceName, args = [], _instanceId } = req;
                const paths = serviceName.split('.');
                assert(!!_instanceId, 'callType is instanceCall, but missing _instanceId Params');
                const instance = this.proto.decodeInstance({
                    _type: "instance" /* ARG_TYPE.INSTANCE */,
                    _instanceId,
                });
                assert(!!instance, `can"t find instance, instanceId ${_instanceId} incorrect`);
                paths.shift();
                const property = paths.pop();
                assert(typeof property === 'string', `incorrect serviceName "${serviceName}"`);
                const target = keyPathVisitor(instance, paths);
                assert(!!target, `can"t find instance@${_instanceId} api, please check serviceName "${serviceName}" ${target}`);
                const api = Reflect.get(target, property, target);
                assert(!!api, `can"t find instance@${_instanceId} api, please check serviceName "${serviceName}" ${target}.${api}`);
                const decodeArgs = args.map(arg => {
                    if (isPlainObject(arg) &&
                        arg._type === "instance" /* ARG_TYPE.INSTANCE */) {
                        return this.proto.decodeInstance(arg);
                    }
                    if (isPlainObject(arg) &&
                        arg._type === "callback" /* ARG_TYPE.CALLBACK */) {
                        return (...eventData) => {
                            this.sendEventEmit(_instanceId, serviceName, arg._callbackId, eventData);
                        };
                    }
                    return arg;
                });
                const span = this.tracer.collectApiCall({
                    source: 'native',
                    target: 'js',
                    serviceName: serviceName,
                    callType: CALL_TYPE$1.INSTANCE_METHOD_INVOKE,
                    args,
                });
                try {
                    const value = typeof api === 'function' ? await api.apply(target, decodeArgs) : api;
                    const res = this._returnHandler(value);
                    span.success(res);
                    return res;
                }
                catch (err) {
                    span.fail(err);
                    throw err;
                }
            }
            async _onCallEventRegister(req) {
                const { args = [], _instanceId, serviceName } = req;
                assert(!!_instanceId, 'callType is "instance_event_register", but missing _instanceId Params');
                const instance = this.proto.decodeInstance({
                    _type: "instance" /* ARG_TYPE.INSTANCE */,
                    _instanceId,
                });
                assert(!!instance, `can"t find instance, instanceId ${_instanceId} incorrect`);
                assert(typeof instance.on === 'function', 'instance can"t "on"');
                this.tracer.collectEventOn({
                    source: 'native',
                    target: 'js',
                    eventName: serviceName,
                });
                const remoteCallbackId = args[0]._callbackId;
                const proxyCallback = (...eventData) => {
                    this.sendEventEmit(_instanceId, serviceName, remoteCallbackId, eventData);
                };
                const paths = serviceName.split('.');
                const eventName = paths[paths.length - 1];
                instance.on(eventName, proxyCallback);
                return this._returnHandler(null);
            }
            /**
             * 触发事件，优先通过 callbackId 找 callback，找不到通过 instanceId 找实例 emit
             * @param req
             * @returns
             */
            async _onCallEventEmit(req) {
                const { args = [], serviceName, methodName, _instanceId } = req;
                const decodeArgs = this.proto.decodeArgs(args);
                const eventName = methodName || serviceName;
                this.tracer.collectEventEmit({
                    source: 'native',
                    target: 'js',
                    eventName: eventName,
                    eventData: decodeArgs,
                });
                assert(!!_instanceId, 'callType is "instance_event_emit", but missing "_instanceId" Params');
                const instance = this.proto.decodeInstance({
                    _type: "instance" /* ARG_TYPE.INSTANCE */,
                    _instanceId,
                });
                assert(!!instance, `can"t find instance, instanceId ${_instanceId} incorrect`);
                if (typeof instance.emit === 'function') {
                    instance.emit(eventName, ...decodeArgs);
                }
                else if (typeof instance[eventName] === 'function') {
                    instance[eventName].apply(instance, decodeArgs);
                }
                else {
                    this.logger.warn(`unknown event "${eventName}"`);
                }
                return this._returnHandler(null);
            }
            /**
             * 触发回调，优先通过 callbackId 找 callback，找不到通过 instanceId 找实例 emit
             * @param req
             * @returns
             */
            async _onCallbackEmit(req) {
                const { args = [], serviceName, methodName, _instanceId } = req;
                const decodeArgs = this.proto.decodeArgs(args);
                const eventName = methodName || serviceName;
                this.tracer.collectCallbackEmit({
                    source: 'native',
                    target: 'js',
                    eventName: eventName,
                    eventData: decodeArgs,
                });
                assert(!!_instanceId, 'callType is "callback_emit", but missing "_instanceId" Params');
                const callback = this.proto.decodeCallback({
                    _type: "callback" /* ARG_TYPE.CALLBACK */,
                    _callbackId: _instanceId,
                });
                assert(typeof callback === 'function', `can"t find callback, callback_id ${_instanceId} incorrect`);
                callback.apply(null, decodeArgs);
                return this._returnHandler(null);
            }
            _returnHandler(response) {
                this.logger.verbose('response:', response);
                const encodeResponse = this.proto.encodeArg(response);
                const returnVal = {
                    status: RETURN_STATUS$1.SUCCESS,
                    msg: encodeResponse === undefined
                        ? null
                        : encodeResponse === null
                            ? null
                            : encodeResponse,
                };
                return returnVal;
            }
        },
        (() => {
            const _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(_classSuper[Symbol.metadata] ?? null) : void 0;
            _registerService_decorators = [Bind];
            _registerInstance_decorators = [Bind];
            _handlerMessage_decorators = [Bind];
            __esDecorate$1(_a, null, _registerService_decorators, { kind: "method", name: "registerService", static: false, private: false, access: { has: obj => "registerService" in obj, get: obj => obj.registerService }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _registerInstance_decorators, { kind: "method", name: "registerInstance", static: false, private: false, access: { has: obj => "registerInstance" in obj, get: obj => obj.registerInstance }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _handlerMessage_decorators, { kind: "method", name: "handlerMessage", static: false, private: false, access: { has: obj => "handlerMessage" in obj, get: obj => obj.handlerMessage }, metadata: _metadata }, null, _instanceExtraInitializers);
            if (_metadata) Object.defineProperty(_a, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        })(),
        _a;
})();

function createProxyInstance(raw) {
    Object.defineProperty(raw, '$$native', {
        value: true,
        enumerable: false,
    });
    return new Proxy(raw, {
        get(target, p, receiver) {
            // @ts-ignore
            return target[p];
        },
    });
}

function buf2base64(buffer) {
    return gBase64.fromUint8Array(new Uint8Array(buffer));
}
function isDateView(val) {
    return (typeof val === 'object' &&
        val !== null &&
        val.buffer instanceof ArrayBuffer);
}
function isArrayBuffer(val) {
    return val instanceof ArrayBuffer;
}
function isBuffer(val) {
    return isArrayBuffer(val) || isDateView(val);
}
let MessageProtoImpl = (() => {
    var _a;
    let _instanceExtraInitializers = [];
    let _encodeArgs_decorators;
    let _encodeInstance_decorators;
    let _decodeInstance_decorators;
    let _encodeCallback_decorators;
    let _decodeCallback_decorators;
    let _encodeBase64_decorators;
    let _decodeBase64_decorators;
    let _encodeArg_decorators;
    let _decodeArgs_decorators;
    let _decodeArg_decorators;
    return _a = class MessageProtoImpl {
            constructor() {
                this._idMapInstance = (__runInitializers$1(this, _instanceExtraInitializers), {});
                this._instanceMapId = new WeakMap();
                this._idMapCallback = {};
                this._callbackMapId = new WeakMap();
            }
            registerProxyInstance(id, instance) {
                this._idMapInstance[id] = instance;
                this._instanceMapId.set(instance, id);
            }
            encodeArgs(args) {
                return args.map(this.encodeArg);
            }
            encodeInstance(arg) {
                return {
                    _type: "instance" /* ARG_TYPE.INSTANCE */,
                    _instanceId: this._findOrCreateInstanceId(arg),
                    _serviceName: arg.namespace ||
                        arg._namespace ||
                        arg._serviceName,
                };
            }
            decodeInstance(arg) {
                let instance = this._findInstance(arg._instanceId);
                if (!instance) {
                    // TODO:
                    instance = createProxyInstance(arg);
                    this._idMapInstance[arg._instanceId] = instance;
                }
                return instance;
            }
            encodeCallback(arg) {
                return {
                    _type: "callback" /* ARG_TYPE.CALLBACK */,
                    _callbackId: this._findOrCreateCallbackId(arg),
                };
            }
            decodeCallback(arg) {
                return this._findCallback(arg._callbackId) || arg;
            }
            encodeBase64(bufferLike) {
                const buf = bufferLike.buffer || bufferLike;
                return {
                    _type: "base64" /* ARG_TYPE.BASE64 */,
                    _value: buf2base64(buf),
                };
            }
            decodeBase64(arg) {
                const base64 = arg._value;
                const uint8 = gBase64.toUint8Array(base64);
                const buf = uint8.buffer;
                return buf;
            }
            encodeArg(arg) {
                if (isBuffer(arg)) {
                    return this.encodeBase64(arg);
                }
                if (isCallback(arg)) {
                    return this.encodeCallback(arg);
                }
                if (isArray(arg)) {
                    return arg.map(this.encodeArg);
                }
                if (isInstance(arg)) {
                    return this.encodeInstance(arg);
                }
                if (isPlainObject(arg)) {
                    return mapValues(arg, (value) => {
                        return this.encodeArg(value);
                    });
                }
                return arg;
            }
            decodeArgs(args) {
                return args.map(this.decodeArg);
            }
            // @CatchError
            decodeArg(arg) {
                if (isPlainObject(arg) &&
                    arg._type === "base64" /* ARG_TYPE.BASE64 */) {
                    return this.decodeBase64(arg);
                }
                if (isPlainObject(arg) && arg._type === "instance" /* ARG_TYPE.INSTANCE */) {
                    return this.decodeInstance(arg);
                }
                if (isPlainObject(arg) && arg._type === "callback" /* ARG_TYPE.CALLBACK */) {
                    return this.decodeCallback(arg);
                }
                if (isArray(arg)) {
                    return arg.map(this.decodeArg);
                }
                if (isPlainObject(arg)) {
                    return mapValues(arg, (value) => {
                        return this.decodeArg(value);
                    });
                }
                return arg;
            }
            _findInstance(id) {
                return this._idMapInstance[id];
            }
            _findOrCreateInstanceId(instance) {
                let id = this._instanceMapId.get(instance);
                if (id === undefined) {
                    id =
                        instance?.instanceId ||
                            instance?._instanceId ||
                            getUuid(instance?.constructor?.name);
                    this._instanceMapId.set(instance, id);
                    this._idMapInstance[id] = instance;
                }
                return id;
            }
            _findCallback(id) {
                return this._idMapCallback[id];
            }
            _findOrCreateCallbackId(value) {
                let id = this._callbackMapId.get(value);
                if (id === undefined) {
                    id = getUuid(value?.name);
                    this._callbackMapId.set(value, id);
                    this._idMapCallback[id] = value;
                }
                return id;
            }
        },
        (() => {
            const _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
            _encodeArgs_decorators = [Bind];
            _encodeInstance_decorators = [Bind];
            _decodeInstance_decorators = [Bind];
            _encodeCallback_decorators = [Bind];
            _decodeCallback_decorators = [Bind];
            _encodeBase64_decorators = [Bind];
            _decodeBase64_decorators = [Bind];
            _encodeArg_decorators = [Bind];
            _decodeArgs_decorators = [Bind];
            _decodeArg_decorators = [Bind];
            __esDecorate$1(_a, null, _encodeArgs_decorators, { kind: "method", name: "encodeArgs", static: false, private: false, access: { has: obj => "encodeArgs" in obj, get: obj => obj.encodeArgs }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _encodeInstance_decorators, { kind: "method", name: "encodeInstance", static: false, private: false, access: { has: obj => "encodeInstance" in obj, get: obj => obj.encodeInstance }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _decodeInstance_decorators, { kind: "method", name: "decodeInstance", static: false, private: false, access: { has: obj => "decodeInstance" in obj, get: obj => obj.decodeInstance }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _encodeCallback_decorators, { kind: "method", name: "encodeCallback", static: false, private: false, access: { has: obj => "encodeCallback" in obj, get: obj => obj.encodeCallback }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _decodeCallback_decorators, { kind: "method", name: "decodeCallback", static: false, private: false, access: { has: obj => "decodeCallback" in obj, get: obj => obj.decodeCallback }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _encodeBase64_decorators, { kind: "method", name: "encodeBase64", static: false, private: false, access: { has: obj => "encodeBase64" in obj, get: obj => obj.encodeBase64 }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _decodeBase64_decorators, { kind: "method", name: "decodeBase64", static: false, private: false, access: { has: obj => "decodeBase64" in obj, get: obj => obj.decodeBase64 }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _encodeArg_decorators, { kind: "method", name: "encodeArg", static: false, private: false, access: { has: obj => "encodeArg" in obj, get: obj => obj.encodeArg }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _decodeArgs_decorators, { kind: "method", name: "decodeArgs", static: false, private: false, access: { has: obj => "decodeArgs" in obj, get: obj => obj.decodeArgs }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _decodeArg_decorators, { kind: "method", name: "decodeArg", static: false, private: false, access: { has: obj => "decodeArg" in obj, get: obj => obj.decodeArg }, metadata: _metadata }, null, _instanceExtraInitializers);
            if (_metadata) Object.defineProperty(_a, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        })(),
        _a;
})();

const createMessageClient = (jsBridge) => {
    const proto = new MessageProtoImpl();
    const client = new MessageClientImpl(proto, jsBridge);
    return client;
};

let jsBridge = createJSBridge();
const globalMessageClient = createMessageClient(jsBridge);
function getGlobalMessageClient() {
    return globalMessageClient;
}
function setupJSBridge(impl) {
    jsBridge = impl;
    globalMessageClient.bridge = impl;
    impl.registerAsyncHandler('emitEvent', (params) => {
        return globalMessageClient.handlerMessage(params);
    });
}

function assertReturn(ret) {
    if (!ret) {
        return;
    }
    if (ret.status === RETURN_STATUS$1.FAILED) {
        throw new Error(String(ret.msg));
    }
    return ret.decoded || ret.msg;
}
function isPromiseLike(val) {
    if (typeof val === 'object' && val !== null) {
        if (typeof val.then === 'function') {
            return true;
        }
    }
    return false;
}
function getMessageClient(impl) {
    if (typeof impl === 'object' &&
        !!impl &&
        'messageClient' in impl &&
        !!impl.messageClient) {
        return impl.messageClient;
    }
    return getGlobalMessageClient();
}

const KEY_NAMESPACE = Symbol.for('#namespace');
const KEY_NATIVE_CLASS_NAME = Symbol.for('#nativeClassName');
function findNamespace(ctor) {
    let obj = ctor;
    let desc;
    while (!desc && obj) {
        desc = Object.getOwnPropertyDescriptor(obj, KEY_NAMESPACE);
        obj = Object.getPrototypeOf(obj);
    }
    return desc?.value;
}
function findMethods(ins, opt = {}) {
    let methodNames = [];
    let proto = Object.getPrototypeOf(ins);
    while (proto && proto !== Object.prototype) {
        const ownMethods = Object.getOwnPropertyNames(proto)
            .filter(name => name !== 'constructor')
            .map(name => opt[name] || name);
        methodNames.push(...ownMethods);
        proto = Object.getPrototypeOf(proto);
    }
    return methodNames;
}
const NativeObserverClass = (className, opt = {}) => (target, ctx) => {
    ctx.addInitializer(function () {
        Object.defineProperty(this, KEY_NAMESPACE, {
            value: className,
            writable: true,
        });
        Object.defineProperty(this, KEY_NATIVE_CLASS_NAME, { value: className });
    });
    // @ts-ignore
    return class extends target {
        constructor(...args) {
            super(...args);
            const t = this;
            const instanceId = getUuid(className);
            t.namespace = className;
            t.instanceId = instanceId;
            t.messageClient = getMessageClient(t);
            t.options = opt;
            // custom consume native event
            /**
             * @param this
             * @param name native method name
             * @param params
             */
            t.emit = function (name, ...params) {
                const curName = Object.entries(opt).find(([, v]) => v === name)?.[0] || name;
                const fn = this[curName];
                if (typeof fn === 'function') {
                    fn.apply(this, params);
                }
            };
            const _init = () => {
                const events = findMethods(this, opt);
                t.messageClient.sendNewInstanceCall(className, [events], instanceId, this);
            };
            // proxy native created class
            if (!args.includes(DISABLE_INIT)) {
                _init();
            }
        }
    };
};
const NativeClass = (className, opt = {}) => (target, ctx) => {
    ctx.addInitializer(function () {
        Object.defineProperty(this, KEY_NAMESPACE, {
            value: className,
            writable: true,
        });
        Object.defineProperty(this, KEY_NATIVE_CLASS_NAME, { value: className });
    });
    // @ts-ignore
    return class extends target {
        constructor(...args) {
            super(...args);
            const t = this;
            const instanceId = getUuid(className);
            t.namespace = className;
            t.instanceId = instanceId;
            t.messageClient = getMessageClient(t);
            const _init = () => {
                t.messageClient.sendNewInstanceCall(className, args.filter(v => v !== undefined), instanceId, this);
                if (getOS() === "ios" /* OS.ios */ &&
                    typeof this.init === 'function') {
                    this.init();
                }
            };
            // proxy native created class
            if (!args.includes(DISABLE_INIT)) {
                _init();
            }
        }
    };
};
const NativeStaticMethodSync = (methodSelector) => (target, ctx) => {
    const name = ctx.name;
    return function impl(...args) {
        const namespace = findNamespace(this);
        const client = getMessageClient(this);
        const returnValue = client.sendStaticCallSync(namespace || '', methodSelector || name, args);
        const data = assertReturn(returnValue);
        return data;
    };
};
const ReturnClass = (getCtor) => (target, ctx) => {
    // TODO: impl
    function isNativeCreatedInstance(val) {
        if (typeof val === 'object' &&
            val !== null &&
            val.$$native) {
            return true;
        }
        return false;
    }
    function proxyValue(val) {
        const client = getMessageClient(val);
        const ctor = getCtor();
        const service = new ctor(DISABLE_INIT);
        service.messageClient = client;
        service.instanceId = val._instanceId;
        // @ts-ignore
        service.$raw = val;
        client.proto.registerProxyInstance(service.instanceId, service);
        return service;
    }
    return function impl(...args) {
        const returnValue = target.apply(this, args);
        if (isPromiseLike(returnValue)) {
            return returnValue.then(v => {
                return isNativeCreatedInstance(v) ? proxyValue(v) : v;
            });
        }
        return isNativeCreatedInstance(returnValue)
            ? proxyValue(returnValue)
            : returnValue;
    };
};
const NativeMember = ({ cache, readonly } = {}) => (_, ctx) => {
    ctx.addInitializer(function () {
        const field = ctx.name;
        const key = Symbol.for(ctx.name);
        Object.defineProperty(this, field, {
            get: () => {
                if (cache && this[key] !== undefined) {
                    return this[key];
                }
                const { instanceId, namespace } = this;
                const ret = getMessageClient(this).sendInstanceGet(instanceId, namespace || '', field);
                const value = assertReturn(ret);
                this[key] = value;
                return value;
            },
            set: v => {
                if (readonly) {
                    throw new Error(`field ${field} is readonly.`);
                }
                this[key] = v;
                const { instanceId, namespace } = this;
                getMessageClient(this).sendInstanceSet(instanceId, namespace || '', field, v);
            },
        });
    });
    return _;
};

const key = Symbol.for('args');
function processArg(method) {
    const args = method[key] ?? [];
    return (arg, idx) => {
        return args[idx]?.transform(arg) ?? arg;
    };
}
const NativeMethod = (methodSelector, opt) => (_, ctx) => {
    const name = ctx.name;
    async function impl(...args) {
        const { instanceId, namespace } = this;
        const returnValue = await getMessageClient(this).sendInstanceCall(instanceId, namespace || '', methodSelector || name, args.map(processArg(_)).filter(v => v !== undefined), opt);
        const data = assertReturn(returnValue);
        return data;
    }
    return impl;
};
const NativeMethodSync = (methodSelector, opt) => (_, ctx) => {
    const name = ctx.name;
    function impl(...args) {
        const { instanceId, namespace } = this;
        const returnValue = getMessageClient(this).sendInstanceCallSync(instanceId, namespace || '', methodSelector || name, args.map(processArg(_)).filter(v => v !== undefined), opt);
        const data = assertReturn(returnValue);
        return data;
    }
    return impl;
};

const NativeVar = (varName, ctor) => (_, ctx) => {
    return async function impl(...args) {
        const client = getMessageClient(this);
        const ret = await client.sendVarGet(varName, args);
        const ins = new ctor(DISABLE_INIT);
        ins.instanceId = ret.msg._instanceId;
        ins.messageClient = client;
        ins.namespace = '$var';
        return ins;
    };
};

(() => {
    var _a;
    let _instanceExtraInitializers = [];
    let _on_decorators;
    let _emit_decorators;
    return _a = class NativeObserver {
            constructor(className) {
                this._events = __runInitializers$1(this, _instanceExtraInitializers);
                this.namespace = className;
                this.instanceId = getUuid(className);
                this.messageClient = getGlobalMessageClient();
                this._events = {};
            }
            on(ev, handler) {
                let handlers = this._events[ev];
                if (!handlers) {
                    handlers = [];
                    this._events[ev] = handlers;
                }
                if (handlers.length === 0) {
                    // 第一次，通知 native 注册
                    this.messageClient.sendInstanceEventAdd(this.instanceId, this.namespace || '', ev);
                }
                handlers.push(handler);
            }
            emit(ev, ...args) {
                const handlers = this._events[ev];
                // console.log('emit:', ev, args.length);
                handlers?.forEach(cb => {
                    cb(...args);
                });
            }
        },
        (() => {
            const _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
            _on_decorators = [Bind];
            _emit_decorators = [Bind];
            __esDecorate$1(_a, null, _on_decorators, { kind: "method", name: "on", static: false, private: false, access: { has: obj => "on" in obj, get: obj => obj.on }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _emit_decorators, { kind: "method", name: "emit", static: false, private: false, access: { has: obj => "emit" in obj, get: obj => obj.emit }, metadata: _metadata }, null, _instanceExtraInitializers);
            if (_metadata) Object.defineProperty(_a, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        })(),
        _a;
})();
(() => {
    var _a;
    let _instanceExtraInitializers = [];
    let _on_decorators;
    let _emit_decorators;
    return _a = class NativeObserverProxy {
            constructor() {
                this.__observer = __runInitializers$1(this, _instanceExtraInitializers);
            }
            on(ev, handler) {
                this.__observer.on(ev, handler);
            }
            emit(ev, ...args) {
                this.__observer.emit(ev, ...args);
            }
        },
        (() => {
            const _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
            _on_decorators = [Bind];
            _emit_decorators = [Bind];
            __esDecorate$1(_a, null, _on_decorators, { kind: "method", name: "on", static: false, private: false, access: { has: obj => "on" in obj, get: obj => obj.on }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate$1(_a, null, _emit_decorators, { kind: "method", name: "emit", static: false, private: false, access: { has: obj => "emit" in obj, get: obj => obj.emit }, metadata: _metadata }, null, _instanceExtraInitializers);
            if (_metadata) Object.defineProperty(_a, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        })(),
        _a;
})();

class NativeView {
    static getView(viewId, ctor) {
        const _ins = new ctor(viewId);
        const ins = initViewProxyObject(_ins, viewId);
        return ins;
    }
    constructor(viewId) {
        this.viewId = viewId;
        initViewProxyObject(this, viewId);
    }
}
function initViewProxyObject(obj, viewId) {
    obj.instanceId = obj._instanceId = viewId;
    obj.namespace = obj._serviceName = '$View';
    obj._type = "instance" /* ARG_TYPE.INSTANCE */;
    return obj;
}

var BRIDGE_NATIVE_API;
(function (BRIDGE_NATIVE_API) {
    BRIDGE_NATIVE_API["CALL_API"] = "callApi";
    BRIDGE_NATIVE_API["CALL_API_SYNC"] = "callApiSync";
})(BRIDGE_NATIVE_API || (BRIDGE_NATIVE_API = {}));
var CALL_TYPE;
(function (CALL_TYPE) {
    /**
     * 获取动态变量
     */
    CALL_TYPE["VAR_GETTER"] = "var_get";
    /**
     * 调用静态方法
     */
    CALL_TYPE["PLAIN_API_CALL"] = "plain_api_call";
    /**
     * 实例化对象
     */
    CALL_TYPE["NEW_INSTANCE"] = "new_instance";
    /**
     * 调用 api 上的方法
     */
    CALL_TYPE["INSTANCE_METHOD_INVOKE"] = "instance_method_invoke";
    /**
     * 设置属性
     */
    CALL_TYPE["INSTANCE_MEMBER_SET"] = "instance_member_set";
    /**
     * 设置属性
     */
    CALL_TYPE["INSTANCE_MEMBER_GET"] = "instance_member_get";
    /**
     * 注册回调函数
     */
    CALL_TYPE["INSTANCE_EVENT_LISTENER_ADD"] = "instance_event_add";
    /**
     * 移除回调函数
     */
    CALL_TYPE["INSTANCE_EVENT_LISTENER_REMOVE"] = "instance_event_remove";
    /**
     * 触发事件
     */
    CALL_TYPE["INSTANCE_EVENT_EMIT"] = "instance_event_emit";
    /**
     * 触发事件
     */
    CALL_TYPE["CALLBACK_EMIT"] = "callback_emit";
})(CALL_TYPE || (CALL_TYPE = {}));
var RETURN_STATUS;
(function (RETURN_STATUS) {
    RETURN_STATUS["SUCCESS"] = "success";
    RETURN_STATUS["FAILED"] = "failed";
})(RETURN_STATUS || (RETURN_STATUS = {}));

class ReactNativeBridge {
    constructor(BridgeModule, NativeEventName) {
        this.BridgeModule = BridgeModule;
        this.NativeEventName = NativeEventName;
        this._handlers = {};
        if (BridgeModule === undefined) {
            throw new Error(`can't find module "${BridgeModule}", please enure install the module correctly`);
        }
        this._nativeEventEmitter = new reactNative.NativeEventEmitter(BridgeModule);
        this._init();
    }
    _init() {
        this._nativeEventEmitter.addListener(this.NativeEventName, (ev) => {
            try {
                const eventName = ev.event;
                const eventData = typeof ev.data === 'string' ? JSON.parse(ev.data) : ev.data;
                // console.log(`handle native event:`, ev, eventData);
                this._handlers[eventName]?.(eventData);
            }
            catch (err) {
                console.error('handle native event fail:', err);
            }
        });
    }
    call(params) {
        return new Promise((resolve, reject) => {
            // console.debug(`<Bridge> js call native "${handlerName}()":`, ...args);
            try {
                let resolved = false;
                this.BridgeModule[BRIDGE_NATIVE_API.CALL_API]({ params: JSON.stringify(params) }, (res) => {
                    // console.log('async call value:', res);
                    const val = typeof res === 'string' ? JSON.parse(res) : res;
                    resolved = true;
                    resolve(val);
                });
                setTimeout(() => {
                    if (resolved) {
                        return;
                    }
                    resolve({
                        status: RETURN_STATUS.SUCCESS,
                        msg: 'over timeout and auto success',
                    });
                }, 1000 * 60 * 5);
            }
            catch (err) {
                // console.error(`<RNBridge> call native "${handlerName}()" fail`, err);
                reject(err);
            }
        });
    }
    callSync(params) {
        // console.debug(`<Bridge> js call native "${handlerName}()":`, ...args);
        try {
            const res = this.BridgeModule[BRIDGE_NATIVE_API.CALL_API_SYNC]({
                params: JSON.stringify(params),
            });
            // console.debug(`<Bridge> native return "${handlerName}()":`, res, args)
            return typeof res === 'string' ? JSON.parse(res) : res;
        }
        catch (err) {
            // console.error(`<RNBridge> call native "${handlerName}()" fail`, err);
            throw err;
        }
    }
    registerHandler(handlerName, handler) {
        this._handlers[handlerName] = handler;
    }
    registerAsyncHandler(handlerName, handler) {
        this._handlers[handlerName] = handler;
    }
}

class ReactNativeEnv {
    resolveImageResource(input) {
        const r = reactNative.Image.resolveAssetSource(input);
        return {
            ...r,
            _type: "image_resource" /* ARG_TYPE.IMAGE_RESOURCE */,
        };
    }
    os() {
        return reactNative.Platform.OS;
    }
}

var moduleName = 'VertcModule';
var moduleEventName = 'VertcModule:onEvent';
setupJSBridge(new ReactNativeBridge(reactNative.NativeModules[moduleName], moduleEventName));
setupEnv(new ReactNativeEnv());

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise, SuppressedError, Symbol */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    if (typeof b !== "function" && b !== null)
        throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

function __esDecorate(ctor, descriptorIn, decorators, contextIn, initializers, extraInitializers) {
    function accept(f) { if (f !== void 0 && typeof f !== "function") throw new TypeError("Function expected"); return f; }
    var kind = contextIn.kind, key = kind === "getter" ? "get" : kind === "setter" ? "set" : "value";
    var target = !descriptorIn && ctor ? contextIn["static"] ? ctor : ctor.prototype : null;
    var descriptor = descriptorIn || (target ? Object.getOwnPropertyDescriptor(target, contextIn.name) : {});
    var _, done = false;
    for (var i = decorators.length - 1; i >= 0; i--) {
        var context = {};
        for (var p in contextIn) context[p] = p === "access" ? {} : contextIn[p];
        for (var p in contextIn.access) context.access[p] = contextIn.access[p];
        context.addInitializer = function (f) { if (done) throw new TypeError("Cannot add initializers after decoration has completed"); extraInitializers.push(accept(f || null)); };
        var result = (0, decorators[i])(kind === "accessor" ? { get: descriptor.get, set: descriptor.set } : descriptor[key], context);
        if (kind === "accessor") {
            if (result === void 0) continue;
            if (result === null || typeof result !== "object") throw new TypeError("Object expected");
            if (_ = accept(result.get)) descriptor.get = _;
            if (_ = accept(result.set)) descriptor.set = _;
            if (_ = accept(result.init)) initializers.unshift(_);
        }
        else if (_ = accept(result)) {
            if (kind === "field") initializers.unshift(_);
            else descriptor[key] = _;
        }
    }
    if (target) Object.defineProperty(target, contextIn.name, descriptor);
    done = true;
}
function __runInitializers(thisArg, initializers, value) {
    var useValue = arguments.length > 2;
    for (var i = 0; i < initializers.length; i++) {
        value = useValue ? initializers[i].call(thisArg, value) : initializers[i].call(thisArg);
    }
    return useValue ? value : void 0;
}
function __setFunctionName(f, name, prefix) {
    if (typeof name === "symbol") name = name.description ? "[".concat(name.description, "]") : "";
    return Object.defineProperty(f, "name", { configurable: true, value: name });
}
function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

function __spreadArray(to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
}

typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
    var e = new Error(message);
    return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
};

var CodecMode;
(function (CodecMode) {
    CodecMode[CodecMode["CODEC_MODE_AUTO"] = 0] = "CODEC_MODE_AUTO";
    CodecMode[CodecMode["CODEC_MODE_HARDWARE"] = 1] = "CODEC_MODE_HARDWARE";
    CodecMode[CodecMode["CODEC_MODE_SOFTWARE"] = 2] = "CODEC_MODE_SOFTWARE";
})(CodecMode || (CodecMode = {}));
var MixedStreamAlternateImageFillMode;
(function (MixedStreamAlternateImageFillMode) {
    MixedStreamAlternateImageFillMode[MixedStreamAlternateImageFillMode["FIT"] = 0] = "FIT";
    MixedStreamAlternateImageFillMode[MixedStreamAlternateImageFillMode["FILL"] = 1] = "FILL";
})(MixedStreamAlternateImageFillMode || (MixedStreamAlternateImageFillMode = {}));
var CapturePreference;
(function (CapturePreference) {
    CapturePreference[CapturePreference["AUTO"] = 0] = "AUTO";
    CapturePreference[CapturePreference["MANUAL"] = 1] = "MANUAL";
    CapturePreference[CapturePreference["AUTO_PERFORMANCE"] = 2] = "AUTO_PERFORMANCE";
})(CapturePreference || (CapturePreference = {}));
var Layout = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.LiveTranscoding$Layout')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _getAppData_decorators;
    var _setAppData_decorators;
    var _getBackgroundColor_decorators;
    var _setBackgroundColor_decorators;
    _classThis = /** @class */ (function () {
        function Layout_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        Layout_1.prototype.getAppData = function () {
            throw new Error('not implement');
        };
        Layout_1.prototype.setAppData = function (appData) {
            throw new Error('not implement');
        };
        Layout_1.prototype.getBackgroundColor = function () {
            throw new Error('not implement');
        };
        Layout_1.prototype.setBackgroundColor = function (backgroundColor) {
            throw new Error('not implement');
        };
        return Layout_1;
    }());
    __setFunctionName(_classThis, "Layout");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _getAppData_decorators = [NativeMethodSync()];
        _setAppData_decorators = [NativeMethodSync()];
        _getBackgroundColor_decorators = [NativeMethodSync()];
        _setBackgroundColor_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _getAppData_decorators, { kind: "method", name: "getAppData", static: false, private: false, access: { has: function (obj) { return "getAppData" in obj; }, get: function (obj) { return obj.getAppData; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAppData_decorators, { kind: "method", name: "setAppData", static: false, private: false, access: { has: function (obj) { return "setAppData" in obj; }, get: function (obj) { return obj.setAppData; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getBackgroundColor_decorators, { kind: "method", name: "getBackgroundColor", static: false, private: false, access: { has: function (obj) { return "getBackgroundColor" in obj; }, get: function (obj) { return obj.getBackgroundColor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBackgroundColor_decorators, { kind: "method", name: "setBackgroundColor", static: false, private: false, access: { has: function (obj) { return "setBackgroundColor" in obj; }, get: function (obj) { return obj.setBackgroundColor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioProcessorMethod;
(function (AudioProcessorMethod) {
    AudioProcessorMethod[AudioProcessorMethod["AUDIO_FRAME_PROCESSOR_RECORD"] = 0] = "AUDIO_FRAME_PROCESSOR_RECORD";
    AudioProcessorMethod[AudioProcessorMethod["AUDIO_FRAME_PROCESSOR_PLAYBACK"] = 1] = "AUDIO_FRAME_PROCESSOR_PLAYBACK";
    AudioProcessorMethod[AudioProcessorMethod["AUDIO_FRAME_PROCESSOR_REMOTE_USER"] = 2] = "AUDIO_FRAME_PROCESSOR_REMOTE_USER";
    AudioProcessorMethod[AudioProcessorMethod["AUDIO_FRAME_PROCESSOR_EAR_MONITOR"] = 3] = "AUDIO_FRAME_PROCESSOR_EAR_MONITOR";
    AudioProcessorMethod[AudioProcessorMethod["AUDIO_FRAME_PROCESSOR_SCREEN"] = 4] = "AUDIO_FRAME_PROCESSOR_SCREEN";
})(AudioProcessorMethod || (AudioProcessorMethod = {}));
var VideoSourceType;
(function (VideoSourceType) {
    VideoSourceType[VideoSourceType["VIDEO_SOURCE_TYPE_EXTERNAL"] = 0] = "VIDEO_SOURCE_TYPE_EXTERNAL";
    VideoSourceType[VideoSourceType["VIDEO_SOURCE_TYPE_INTERNAL"] = 1] = "VIDEO_SOURCE_TYPE_INTERNAL";
    VideoSourceType[VideoSourceType["VIDEO_SOURCE_TYPE_ENCODED_WITH_SIMULCAST"] = 2] = "VIDEO_SOURCE_TYPE_ENCODED_WITH_SIMULCAST";
    VideoSourceType[VideoSourceType["VIDEO_SOURCE_TYPE_ENCODED_WITHOUT_SIMULCAST"] = 3] = "VIDEO_SOURCE_TYPE_ENCODED_WITHOUT_SIMULCAST";
})(VideoSourceType || (VideoSourceType = {}));
var MessageConfig;
(function (MessageConfig) {
    MessageConfig[MessageConfig["RELIABLE_ORDERED"] = 0] = "RELIABLE_ORDERED";
    MessageConfig[MessageConfig["UNRELIABLE_ORDERED"] = 1] = "UNRELIABLE_ORDERED";
    MessageConfig[MessageConfig["UNRELIABLE_UNORDERED"] = 2] = "UNRELIABLE_UNORDERED";
})(MessageConfig || (MessageConfig = {}));
var ProblemFeedbackInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.ProblemFeedbackInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _problemDesc_decorators;
    var _problemDesc_initializers = [];
    var _problemDesc_extraInitializers = [];
    var _roomInfo_decorators;
    var _roomInfo_initializers = [];
    var _roomInfo_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function ProblemFeedbackInfo_1() {
            this.problemDesc = __runInitializers(this, _problemDesc_initializers, void 0);
            this.roomInfo = (__runInitializers(this, _problemDesc_extraInitializers), __runInitializers(this, _roomInfo_initializers, void 0));
            __runInitializers(this, _roomInfo_extraInitializers);
        }
        return ProblemFeedbackInfo_1;
    }());
    __setFunctionName(_classThis, "ProblemFeedbackInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _problemDesc_decorators = [NativeMember()];
        _roomInfo_decorators = [NativeMember()];
        __esDecorate(null, null, _problemDesc_decorators, { kind: "field", name: "problemDesc", static: false, private: false, access: { has: function (obj) { return "problemDesc" in obj; }, get: function (obj) { return obj.problemDesc; }, set: function (obj, value) { obj.problemDesc = value; } }, metadata: _metadata }, _problemDesc_initializers, _problemDesc_extraInitializers);
        __esDecorate(null, null, _roomInfo_decorators, { kind: "field", name: "roomInfo", static: false, private: false, access: { has: function (obj) { return "roomInfo" in obj; }, get: function (obj) { return obj.roomInfo; }, set: function (obj, value) { obj.roomInfo = value; } }, metadata: _metadata }, _roomInfo_initializers, _roomInfo_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.ExpressionDetectResult')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _detectResult_decorators;
    var _detectResult_initializers = [];
    var _detectResult_extraInitializers = [];
    var _faceCount_decorators;
    var _faceCount_initializers = [];
    var _faceCount_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function ExpressionDetectResult_1() {
            this.detectResult = __runInitializers(this, _detectResult_initializers, void 0);
            this.faceCount = (__runInitializers(this, _detectResult_extraInitializers), __runInitializers(this, _faceCount_initializers, void 0));
            __runInitializers(this, _faceCount_extraInitializers);
        }
        return ExpressionDetectResult_1;
    }());
    __setFunctionName(_classThis, "ExpressionDetectResult");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _detectResult_decorators = [NativeMember()];
        _faceCount_decorators = [NativeMember()];
        __esDecorate(null, null, _detectResult_decorators, { kind: "field", name: "detectResult", static: false, private: false, access: { has: function (obj) { return "detectResult" in obj; }, get: function (obj) { return obj.detectResult; }, set: function (obj, value) { obj.detectResult = value; } }, metadata: _metadata }, _detectResult_initializers, _detectResult_extraInitializers);
        __esDecorate(null, null, _faceCount_decorators, { kind: "field", name: "faceCount", static: false, private: false, access: { has: function (obj) { return "faceCount" in obj; }, get: function (obj) { return obj.faceCount; }, set: function (obj, value) { obj.faceCount = value; } }, metadata: _metadata }, _faceCount_initializers, _faceCount_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
    })();
    _classThis.MAX_COUNT = 10;
    (function () {
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var MediaDeviceType;
(function (MediaDeviceType) {
    MediaDeviceType[MediaDeviceType["MEDIA_DEVICE_TYPE_AUDIO_UNKNOWN"] = -1] = "MEDIA_DEVICE_TYPE_AUDIO_UNKNOWN";
    MediaDeviceType[MediaDeviceType["MEDIA_DEVICE_TYPE_AUDIO_RENDER_DEVICE"] = 0] = "MEDIA_DEVICE_TYPE_AUDIO_RENDER_DEVICE";
    MediaDeviceType[MediaDeviceType["MEDIA_DEVICE_TYPE_AUDIO_CAPTURE_DEVICE"] = 1] = "MEDIA_DEVICE_TYPE_AUDIO_CAPTURE_DEVICE";
    MediaDeviceType[MediaDeviceType["MEDIA_DEVICE_TYPE_VIDEO_RENDER_DEVICE"] = 2] = "MEDIA_DEVICE_TYPE_VIDEO_RENDER_DEVICE";
    MediaDeviceType[MediaDeviceType["MEDIA_DEVICE_TYPE_VIDEO_CAPTURE_DEVICE"] = 3] = "MEDIA_DEVICE_TYPE_VIDEO_CAPTURE_DEVICE";
    MediaDeviceType[MediaDeviceType["MEDIA_DEVICE_TYPE_SCREEN_VIDEO_CAPTURE_DEVICE"] = 4] = "MEDIA_DEVICE_TYPE_SCREEN_VIDEO_CAPTURE_DEVICE";
    MediaDeviceType[MediaDeviceType["MEDIA_DEVICE_TYPE_SCREEN_AUDIO_CAPTURE_DEVICE"] = 5] = "MEDIA_DEVICE_TYPE_SCREEN_AUDIO_CAPTURE_DEVICE";
})(MediaDeviceType || (MediaDeviceType = {}));
var UserInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.UserInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _uid_decorators;
    var _uid_initializers = [];
    var _uid_extraInitializers = [];
    var _extraInfo_decorators;
    var _extraInfo_initializers = [];
    var _extraInfo_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function UserInfo_1(uid, extraInfo) {
            this.uid = __runInitializers(this, _uid_initializers, void 0);
            this.extraInfo = (__runInitializers(this, _uid_extraInitializers), __runInitializers(this, _extraInfo_initializers, void 0));
            __runInitializers(this, _extraInfo_extraInitializers);
        }
        return UserInfo_1;
    }());
    __setFunctionName(_classThis, "UserInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _uid_decorators = [NativeMember()];
        _extraInfo_decorators = [NativeMember()];
        __esDecorate(null, null, _uid_decorators, { kind: "field", name: "uid", static: false, private: false, access: { has: function (obj) { return "uid" in obj; }, get: function (obj) { return obj.uid; }, set: function (obj, value) { obj.uid = value; } }, metadata: _metadata }, _uid_initializers, _uid_extraInitializers);
        __esDecorate(null, null, _extraInfo_decorators, { kind: "field", name: "extraInfo", static: false, private: false, access: { has: function (obj) { return "extraInfo" in obj; }, get: function (obj) { return obj.extraInfo; }, set: function (obj, value) { obj.extraInfo = value; } }, metadata: _metadata }, _extraInfo_initializers, _extraInfo_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ForwardStreamEvent;
(function (ForwardStreamEvent) {
    ForwardStreamEvent[ForwardStreamEvent["FORWARD_STREAM_EVENT_DISCONNECTED"] = 0] = "FORWARD_STREAM_EVENT_DISCONNECTED";
    ForwardStreamEvent[ForwardStreamEvent["FORWARD_STREAM_EVENT_CONNECTED"] = 1] = "FORWARD_STREAM_EVENT_CONNECTED";
    ForwardStreamEvent[ForwardStreamEvent["FORWARD_STREAM_EVENT_INTERRUPT"] = 2] = "FORWARD_STREAM_EVENT_INTERRUPT";
    ForwardStreamEvent[ForwardStreamEvent["FORWARD_STREAM_EVENT_DST_ROOM_UPDATED"] = 3] = "FORWARD_STREAM_EVENT_DST_ROOM_UPDATED";
    ForwardStreamEvent[ForwardStreamEvent["FORWARD_STREAM_EVENT_UN_EXPECT_API_CALL"] = 4] = "FORWARD_STREAM_EVENT_UN_EXPECT_API_CALL";
})(ForwardStreamEvent || (ForwardStreamEvent = {}));
var SubscribeMediaType;
(function (SubscribeMediaType) {
    SubscribeMediaType[SubscribeMediaType["NONE"] = 0] = "NONE";
    SubscribeMediaType[SubscribeMediaType["AUDIO_ONLY"] = 1] = "AUDIO_ONLY";
    SubscribeMediaType[SubscribeMediaType["VIDEO_ONLY"] = 2] = "VIDEO_ONLY";
    SubscribeMediaType[SubscribeMediaType["AUDIO_AND_VIDEO"] = 3] = "AUDIO_AND_VIDEO";
})(SubscribeMediaType || (SubscribeMediaType = {}));
var ConnectionState;
(function (ConnectionState) {
    ConnectionState[ConnectionState["CONNECTION_STATE_DISCONNECTED"] = 1] = "CONNECTION_STATE_DISCONNECTED";
    ConnectionState[ConnectionState["CONNECTION_STATE_CONNECTING"] = 2] = "CONNECTION_STATE_CONNECTING";
    ConnectionState[ConnectionState["CONNECTION_STATE_CONNECTED"] = 3] = "CONNECTION_STATE_CONNECTED";
    ConnectionState[ConnectionState["CONNECTION_STATE_RECONNECTING"] = 4] = "CONNECTION_STATE_RECONNECTING";
    ConnectionState[ConnectionState["CONNECTION_STATE_RECONNECTED"] = 5] = "CONNECTION_STATE_RECONNECTED";
    ConnectionState[ConnectionState["CONNECTION_STATE_LOST"] = 6] = "CONNECTION_STATE_LOST";
    ConnectionState[ConnectionState["CONNECTION_STATE_FAILED"] = 7] = "CONNECTION_STATE_FAILED";
})(ConnectionState || (ConnectionState = {}));
var RecordingType;
(function (RecordingType) {
    RecordingType[RecordingType["RECORD_AUDIO_ONLY"] = 0] = "RECORD_AUDIO_ONLY";
    RecordingType[RecordingType["RECORD_VIDEO_ONLY"] = 1] = "RECORD_VIDEO_ONLY";
    RecordingType[RecordingType["RECORD_VIDEO_AND_AUDIO"] = 2] = "RECORD_VIDEO_AND_AUDIO";
})(RecordingType || (RecordingType = {}));
var AudioConfig = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.LiveTranscoding$AudioConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setCodec_decorators;
    var _setKBitRate_decorators;
    var _setSampleRate_decorators;
    var _setChannels_decorators;
    var _setAacProfile_decorators;
    _classThis = /** @class */ (function () {
        function AudioConfig_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        AudioConfig_1.prototype.setCodec = function (codec) {
            throw new Error('not implement');
        };
        AudioConfig_1.prototype.setKBitRate = function (kBitRate) {
            throw new Error('not implement');
        };
        AudioConfig_1.prototype.setSampleRate = function (sampleRate) {
            throw new Error('not implement');
        };
        AudioConfig_1.prototype.setChannels = function (channels) {
            throw new Error('not implement');
        };
        AudioConfig_1.prototype.setAacProfile = function (aacProfile) {
            throw new Error('not implement');
        };
        return AudioConfig_1;
    }());
    __setFunctionName(_classThis, "AudioConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setCodec_decorators = [NativeMethodSync()];
        _setKBitRate_decorators = [NativeMethodSync()];
        _setSampleRate_decorators = [NativeMethodSync()];
        _setChannels_decorators = [NativeMethodSync()];
        _setAacProfile_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setCodec_decorators, { kind: "method", name: "setCodec", static: false, private: false, access: { has: function (obj) { return "setCodec" in obj; }, get: function (obj) { return obj.setCodec; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setKBitRate_decorators, { kind: "method", name: "setKBitRate", static: false, private: false, access: { has: function (obj) { return "setKBitRate" in obj; }, get: function (obj) { return obj.setKBitRate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setSampleRate_decorators, { kind: "method", name: "setSampleRate", static: false, private: false, access: { has: function (obj) { return "setSampleRate" in obj; }, get: function (obj) { return obj.setSampleRate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setChannels_decorators, { kind: "method", name: "setChannels", static: false, private: false, access: { has: function (obj) { return "setChannels" in obj; }, get: function (obj) { return obj.setChannels; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAacProfile_decorators, { kind: "method", name: "setAacProfile", static: false, private: false, access: { has: function (obj) { return "setAacProfile" in obj; }, get: function (obj) { return obj.setAacProfile; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MixedStreamPushMode;
(function (MixedStreamPushMode) {
    MixedStreamPushMode[MixedStreamPushMode["ON_STREAM"] = 0] = "ON_STREAM";
    MixedStreamPushMode[MixedStreamPushMode["ON_START_REQUEST"] = 1] = "ON_START_REQUEST";
})(MixedStreamPushMode || (MixedStreamPushMode = {}));
var EarMonitorMode;
(function (EarMonitorMode) {
    EarMonitorMode[EarMonitorMode["EAR_MONITOR_MODE_OFF"] = 0] = "EAR_MONITOR_MODE_OFF";
    EarMonitorMode[EarMonitorMode["EAR_MONITOR_MODE_ON"] = 1] = "EAR_MONITOR_MODE_ON";
})(EarMonitorMode || (EarMonitorMode = {}));
var FirstFrameSendState;
(function (FirstFrameSendState) {
    FirstFrameSendState[FirstFrameSendState["FIRST_FRAME_SEND_STATE_SENDING"] = 0] = "FIRST_FRAME_SEND_STATE_SENDING";
    FirstFrameSendState[FirstFrameSendState["FIRST_FRAME_SEND_STATE_SENT"] = 1] = "FIRST_FRAME_SEND_STATE_SENT";
    FirstFrameSendState[FirstFrameSendState["FIRST_FRAME_SEND_STAT_END"] = 2] = "FIRST_FRAME_SEND_STAT_END";
})(FirstFrameSendState || (FirstFrameSendState = {}));
var MixedStreamMediaType;
(function (MixedStreamMediaType) {
    MixedStreamMediaType[MixedStreamMediaType["MIXED_STREAM_MEDIA_TYPE_AUDIO_AND_VIDEO"] = 0] = "MIXED_STREAM_MEDIA_TYPE_AUDIO_AND_VIDEO";
    MixedStreamMediaType[MixedStreamMediaType["MIXED_STREAM_MEDIA_TYPE_AUDIO_ONLY"] = 1] = "MIXED_STREAM_MEDIA_TYPE_AUDIO_ONLY";
    MixedStreamMediaType[MixedStreamMediaType["MIXED_STREAM_MEDIA_TYPE_VIDEO_ONLY"] = 2] = "MIXED_STREAM_MEDIA_TYPE_VIDEO_ONLY";
})(MixedStreamMediaType || (MixedStreamMediaType = {}));
var SubtitleMode;
(function (SubtitleMode) {
    SubtitleMode[SubtitleMode["SUBTITLE_MODE_RECOGINTE"] = 0] = "SUBTITLE_MODE_RECOGINTE";
    SubtitleMode[SubtitleMode["SUBTITLE_MODE_TRANSLATION"] = 1] = "SUBTITLE_MODE_TRANSLATION";
})(SubtitleMode || (SubtitleMode = {}));
var SourceWantedData$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.SourceWantedData')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _frameRate_decorators;
    var _frameRate_initializers = [];
    var _frameRate_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function SourceWantedData_1() {
            this.width = __runInitializers(this, _width_initializers, void 0);
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.frameRate = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _frameRate_initializers, void 0));
            __runInitializers(this, _frameRate_extraInitializers);
        }
        return SourceWantedData_1;
    }());
    __setFunctionName(_classThis, "SourceWantedData");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _frameRate_decorators = [NativeMember()];
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _frameRate_decorators, { kind: "field", name: "frameRate", static: false, private: false, access: { has: function (obj) { return "frameRate" in obj; }, get: function (obj) { return obj.frameRate; }, set: function (obj, value) { obj.frameRate = value; } }, metadata: _metadata }, _frameRate_initializers, _frameRate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VoiceChangerType;
(function (VoiceChangerType) {
    VoiceChangerType[VoiceChangerType["VOICE_CHANGER_ORIGINAL"] = 0] = "VOICE_CHANGER_ORIGINAL";
    VoiceChangerType[VoiceChangerType["VOICE_CHANGER_GIANT"] = 1] = "VOICE_CHANGER_GIANT";
    VoiceChangerType[VoiceChangerType["VOICE_CHANGER_CHIPMUNK"] = 2] = "VOICE_CHANGER_CHIPMUNK";
    VoiceChangerType[VoiceChangerType["VOICE_CHANGER_MINIONST"] = 3] = "VOICE_CHANGER_MINIONST";
    VoiceChangerType[VoiceChangerType["VOICE_CHANGER_VIBRATO"] = 4] = "VOICE_CHANGER_VIBRATO";
    VoiceChangerType[VoiceChangerType["VOICE_CHANGER_ROBOT"] = 5] = "VOICE_CHANGER_ROBOT";
})(VoiceChangerType || (VoiceChangerType = {}));
var VideoCodecType;
(function (VideoCodecType) {
    VideoCodecType[VideoCodecType["CODEC_TYPE_AUTO"] = 0] = "CODEC_TYPE_AUTO";
    VideoCodecType[VideoCodecType["CODEC_TYPE_H264"] = 1] = "CODEC_TYPE_H264";
    VideoCodecType[VideoCodecType["CODEC_TYPE_BYTEVC1"] = 2] = "CODEC_TYPE_BYTEVC1";
})(VideoCodecType || (VideoCodecType = {}));
var EffectBeautyMode;
(function (EffectBeautyMode) {
    EffectBeautyMode[EffectBeautyMode["WHITE"] = 0] = "WHITE";
    EffectBeautyMode[EffectBeautyMode["SMOOTH"] = 1] = "SMOOTH";
    EffectBeautyMode[EffectBeautyMode["SHARPEN"] = 2] = "SHARPEN";
    EffectBeautyMode[EffectBeautyMode["CLEAR"] = 3] = "CLEAR";
})(EffectBeautyMode || (EffectBeautyMode = {}));
var Orientation$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.Orientation')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _x_decorators;
    var _x_initializers = [];
    var _x_extraInitializers = [];
    var _y_decorators;
    var _y_initializers = [];
    var _y_extraInitializers = [];
    var _z_decorators;
    var _z_initializers = [];
    var _z_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function Orientation_1(x, y, z) {
            this.x = __runInitializers(this, _x_initializers, void 0);
            this.y = (__runInitializers(this, _x_extraInitializers), __runInitializers(this, _y_initializers, void 0));
            this.z = (__runInitializers(this, _y_extraInitializers), __runInitializers(this, _z_initializers, void 0));
            __runInitializers(this, _z_extraInitializers);
        }
        return Orientation_1;
    }());
    __setFunctionName(_classThis, "Orientation");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _x_decorators = [NativeMember()];
        _y_decorators = [NativeMember()];
        _z_decorators = [NativeMember()];
        __esDecorate(null, null, _x_decorators, { kind: "field", name: "x", static: false, private: false, access: { has: function (obj) { return "x" in obj; }, get: function (obj) { return obj.x; }, set: function (obj, value) { obj.x = value; } }, metadata: _metadata }, _x_initializers, _x_extraInitializers);
        __esDecorate(null, null, _y_decorators, { kind: "field", name: "y", static: false, private: false, access: { has: function (obj) { return "y" in obj; }, get: function (obj) { return obj.y; }, set: function (obj, value) { obj.y = value; } }, metadata: _metadata }, _y_initializers, _y_extraInitializers);
        __esDecorate(null, null, _z_decorators, { kind: "field", name: "z", static: false, private: false, access: { has: function (obj) { return "z" in obj; }, get: function (obj) { return obj.z; }, set: function (obj, value) { obj.z = value; } }, metadata: _metadata }, _z_initializers, _z_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MusicHotType;
(function (MusicHotType) {
    MusicHotType[MusicHotType["CONTENT_CENTER"] = 1] = "CONTENT_CENTER";
    MusicHotType[MusicHotType["PROJECT"] = 2] = "PROJECT";
})(MusicHotType || (MusicHotType = {}));
var MixedStreamAudioCodecType;
(function (MixedStreamAudioCodecType) {
    MixedStreamAudioCodecType["MIXED_STREAM_AUDIO_CODEC_TYPE_AAC"] = "AAC";
})(MixedStreamAudioCodecType || (MixedStreamAudioCodecType = {}));
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.VideoStreamDescription')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _videoSize_decorators;
    var _videoSize_initializers = [];
    var _videoSize_extraInitializers = [];
    var _frameRate_decorators;
    var _frameRate_initializers = [];
    var _frameRate_extraInitializers = [];
    var _maxKbps_decorators;
    var _maxKbps_initializers = [];
    var _maxKbps_extraInitializers = [];
    var _minKbps_decorators;
    var _minKbps_initializers = [];
    var _minKbps_extraInitializers = [];
    var _encodePreference_decorators;
    var _encodePreference_initializers = [];
    var _encodePreference_extraInitializers = [];
    var _maxQp_decorators;
    var _maxQp_initializers = [];
    var _maxQp_extraInitializers = [];
    var _minQp_decorators;
    var _minQp_initializers = [];
    var _minQp_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function VideoStreamDescription_1() {
            this.videoSize = __runInitializers(this, _videoSize_initializers, void 0);
            this.frameRate = (__runInitializers(this, _videoSize_extraInitializers), __runInitializers(this, _frameRate_initializers, void 0));
            this.maxKbps = (__runInitializers(this, _frameRate_extraInitializers), __runInitializers(this, _maxKbps_initializers, void 0));
            this.minKbps = (__runInitializers(this, _maxKbps_extraInitializers), __runInitializers(this, _minKbps_initializers, void 0));
            this.encodePreference = (__runInitializers(this, _minKbps_extraInitializers), __runInitializers(this, _encodePreference_initializers, void 0));
            this.maxQp = (__runInitializers(this, _encodePreference_extraInitializers), __runInitializers(this, _maxQp_initializers, void 0));
            this.minQp = (__runInitializers(this, _maxQp_extraInitializers), __runInitializers(this, _minQp_initializers, void 0));
            __runInitializers(this, _minQp_extraInitializers);
        }
        return VideoStreamDescription_1;
    }());
    __setFunctionName(_classThis, "VideoStreamDescription");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _videoSize_decorators = [NativeMember()];
        _frameRate_decorators = [NativeMember()];
        _maxKbps_decorators = [NativeMember()];
        _minKbps_decorators = [NativeMember()];
        _encodePreference_decorators = [NativeMember()];
        _maxQp_decorators = [NativeMember()];
        _minQp_decorators = [NativeMember()];
        __esDecorate(null, null, _videoSize_decorators, { kind: "field", name: "videoSize", static: false, private: false, access: { has: function (obj) { return "videoSize" in obj; }, get: function (obj) { return obj.videoSize; }, set: function (obj, value) { obj.videoSize = value; } }, metadata: _metadata }, _videoSize_initializers, _videoSize_extraInitializers);
        __esDecorate(null, null, _frameRate_decorators, { kind: "field", name: "frameRate", static: false, private: false, access: { has: function (obj) { return "frameRate" in obj; }, get: function (obj) { return obj.frameRate; }, set: function (obj, value) { obj.frameRate = value; } }, metadata: _metadata }, _frameRate_initializers, _frameRate_extraInitializers);
        __esDecorate(null, null, _maxKbps_decorators, { kind: "field", name: "maxKbps", static: false, private: false, access: { has: function (obj) { return "maxKbps" in obj; }, get: function (obj) { return obj.maxKbps; }, set: function (obj, value) { obj.maxKbps = value; } }, metadata: _metadata }, _maxKbps_initializers, _maxKbps_extraInitializers);
        __esDecorate(null, null, _minKbps_decorators, { kind: "field", name: "minKbps", static: false, private: false, access: { has: function (obj) { return "minKbps" in obj; }, get: function (obj) { return obj.minKbps; }, set: function (obj, value) { obj.minKbps = value; } }, metadata: _metadata }, _minKbps_initializers, _minKbps_extraInitializers);
        __esDecorate(null, null, _encodePreference_decorators, { kind: "field", name: "encodePreference", static: false, private: false, access: { has: function (obj) { return "encodePreference" in obj; }, get: function (obj) { return obj.encodePreference; }, set: function (obj, value) { obj.encodePreference = value; } }, metadata: _metadata }, _encodePreference_initializers, _encodePreference_extraInitializers);
        __esDecorate(null, null, _maxQp_decorators, { kind: "field", name: "maxQp", static: false, private: false, access: { has: function (obj) { return "maxQp" in obj; }, get: function (obj) { return obj.maxQp; }, set: function (obj, value) { obj.maxQp = value; } }, metadata: _metadata }, _maxQp_initializers, _maxQp_extraInitializers);
        __esDecorate(null, null, _minQp_decorators, { kind: "field", name: "minQp", static: false, private: false, access: { has: function (obj) { return "minQp" in obj; }, get: function (obj) { return obj.minQp; }, set: function (obj, value) { obj.minQp = value; } }, metadata: _metadata }, _minQp_initializers, _minQp_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var LocalLogLevel;
(function (LocalLogLevel) {
    LocalLogLevel[LocalLogLevel["INFO"] = 0] = "INFO";
    LocalLogLevel[LocalLogLevel["WARNING"] = 1] = "WARNING";
    LocalLogLevel[LocalLogLevel["ERROR"] = 2] = "ERROR";
    LocalLogLevel[LocalLogLevel["NONE"] = 3] = "NONE";
})(LocalLogLevel || (LocalLogLevel = {}));
var ForwardStreamState;
(function (ForwardStreamState) {
    ForwardStreamState[ForwardStreamState["FORWARD_STREAM_STATE_IDLE"] = 0] = "FORWARD_STREAM_STATE_IDLE";
    ForwardStreamState[ForwardStreamState["FORWARD_STREAM_STATE_SUCCESS"] = 1] = "FORWARD_STREAM_STATE_SUCCESS";
    ForwardStreamState[ForwardStreamState["FORWARD_STREAM_STATE_FAILURE"] = 2] = "FORWARD_STREAM_STATE_FAILURE";
})(ForwardStreamState || (ForwardStreamState = {}));
var TorchState;
(function (TorchState) {
    TorchState[TorchState["TORCH_STATE_OFF"] = 0] = "TORCH_STATE_OFF";
    TorchState[TorchState["TORCH_STATE_ON"] = 1] = "TORCH_STATE_ON";
})(TorchState || (TorchState = {}));
var VideoConfig$VideoCodecType;
(function (VideoConfig$VideoCodecType) {
    VideoConfig$VideoCodecType["VIDEO_CODEC_TYPE_H264"] = "H264";
    VideoConfig$VideoCodecType["VIDEO_CODEC_TYPE_BYTEVC1"] = "ByteVC1";
})(VideoConfig$VideoCodecType || (VideoConfig$VideoCodecType = {}));
var RTCASRConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.RTCASRConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _accessToken_decorators;
    var _accessToken_initializers = [];
    var _accessToken_extraInitializers = [];
    var _secretKey_decorators;
    var _secretKey_initializers = [];
    var _secretKey_extraInitializers = [];
    var _authorizationType_decorators;
    var _authorizationType_initializers = [];
    var _authorizationType_extraInitializers = [];
    var _cluster_decorators;
    var _cluster_initializers = [];
    var _cluster_extraInitializers = [];
    var _appId_decorators;
    var _appId_initializers = [];
    var _appId_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RTCASRConfig_1(userId, accessToken, secretKey, authorizationType, cluster, appId) {
            this.userId = __runInitializers(this, _userId_initializers, void 0);
            this.accessToken = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _accessToken_initializers, void 0));
            this.secretKey = (__runInitializers(this, _accessToken_extraInitializers), __runInitializers(this, _secretKey_initializers, void 0));
            this.authorizationType = (__runInitializers(this, _secretKey_extraInitializers), __runInitializers(this, _authorizationType_initializers, void 0));
            this.cluster = (__runInitializers(this, _authorizationType_extraInitializers), __runInitializers(this, _cluster_initializers, void 0));
            this.appId = (__runInitializers(this, _cluster_extraInitializers), __runInitializers(this, _appId_initializers, void 0));
            __runInitializers(this, _appId_extraInitializers);
        }
        return RTCASRConfig_1;
    }());
    __setFunctionName(_classThis, "RTCASRConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _userId_decorators = [NativeMember()];
        _accessToken_decorators = [NativeMember()];
        _secretKey_decorators = [NativeMember()];
        _authorizationType_decorators = [NativeMember()];
        _cluster_decorators = [NativeMember()];
        _appId_decorators = [NativeMember()];
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _accessToken_decorators, { kind: "field", name: "accessToken", static: false, private: false, access: { has: function (obj) { return "accessToken" in obj; }, get: function (obj) { return obj.accessToken; }, set: function (obj, value) { obj.accessToken = value; } }, metadata: _metadata }, _accessToken_initializers, _accessToken_extraInitializers);
        __esDecorate(null, null, _secretKey_decorators, { kind: "field", name: "secretKey", static: false, private: false, access: { has: function (obj) { return "secretKey" in obj; }, get: function (obj) { return obj.secretKey; }, set: function (obj, value) { obj.secretKey = value; } }, metadata: _metadata }, _secretKey_initializers, _secretKey_extraInitializers);
        __esDecorate(null, null, _authorizationType_decorators, { kind: "field", name: "authorizationType", static: false, private: false, access: { has: function (obj) { return "authorizationType" in obj; }, get: function (obj) { return obj.authorizationType; }, set: function (obj, value) { obj.authorizationType = value; } }, metadata: _metadata }, _authorizationType_initializers, _authorizationType_extraInitializers);
        __esDecorate(null, null, _cluster_decorators, { kind: "field", name: "cluster", static: false, private: false, access: { has: function (obj) { return "cluster" in obj; }, get: function (obj) { return obj.cluster; }, set: function (obj, value) { obj.cluster = value; } }, metadata: _metadata }, _cluster_initializers, _cluster_extraInitializers);
        __esDecorate(null, null, _appId_decorators, { kind: "field", name: "appId", static: false, private: false, access: { has: function (obj) { return "appId" in obj; }, get: function (obj) { return obj.appId; }, set: function (obj, value) { obj.appId = value; } }, metadata: _metadata }, _appId_initializers, _appId_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RTCASRErrorCode;
(function (RTCASRErrorCode) {
    RTCASRErrorCode[RTCASRErrorCode["NETWORK_INTERRUPTED"] = -1] = "NETWORK_INTERRUPTED";
    RTCASRErrorCode[RTCASRErrorCode["ALREADY_STARTED"] = -2] = "ALREADY_STARTED";
    RTCASRErrorCode[RTCASRErrorCode["TOKEN_EMPTY"] = -3] = "TOKEN_EMPTY";
    RTCASRErrorCode[RTCASRErrorCode["SIGNATURE_KEY_EMPTY"] = -4] = "SIGNATURE_KEY_EMPTY";
    RTCASRErrorCode[RTCASRErrorCode["USERID_NULL"] = -5] = "USERID_NULL";
    RTCASRErrorCode[RTCASRErrorCode["APPID_NULL"] = -6] = "APPID_NULL";
    RTCASRErrorCode[RTCASRErrorCode["CLUSTER_NULL"] = -7] = "CLUSTER_NULL";
    RTCASRErrorCode[RTCASRErrorCode["OPERATION_DENIED"] = -8] = "OPERATION_DENIED";
})(RTCASRErrorCode || (RTCASRErrorCode = {}));
var ForwardStreamEventInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.ForwardStreamEventInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _event_decorators;
    var _event_initializers = [];
    var _event_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function ForwardStreamEventInfo_1(roomId, event) {
            this.roomId = __runInitializers(this, _roomId_initializers, void 0);
            this.event = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _event_initializers, void 0));
            __runInitializers(this, _event_extraInitializers);
        }
        return ForwardStreamEventInfo_1;
    }());
    __setFunctionName(_classThis, "ForwardStreamEventInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _roomId_decorators = [NativeMember()];
        _event_decorators = [NativeMember()];
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _event_decorators, { kind: "field", name: "event", static: false, private: false, access: { has: function (obj) { return "event" in obj; }, get: function (obj) { return obj.event; }, set: function (obj, value) { obj.event = value; } }, metadata: _metadata }, _event_initializers, _event_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RecordingConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.RecordingConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _dirPath_decorators;
    var _dirPath_initializers = [];
    var _dirPath_extraInitializers = [];
    var _recordingFileType_decorators;
    var _recordingFileType_initializers = [];
    var _recordingFileType_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RecordingConfig_1() {
            this.dirPath = __runInitializers(this, _dirPath_initializers, void 0);
            this.recordingFileType = (__runInitializers(this, _dirPath_extraInitializers), __runInitializers(this, _recordingFileType_initializers, void 0));
            __runInitializers(this, _recordingFileType_extraInitializers);
        }
        return RecordingConfig_1;
    }());
    __setFunctionName(_classThis, "RecordingConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _dirPath_decorators = [NativeMember()];
        _recordingFileType_decorators = [NativeMember()];
        __esDecorate(null, null, _dirPath_decorators, { kind: "field", name: "dirPath", static: false, private: false, access: { has: function (obj) { return "dirPath" in obj; }, get: function (obj) { return obj.dirPath; }, set: function (obj, value) { obj.dirPath = value; } }, metadata: _metadata }, _dirPath_initializers, _dirPath_extraInitializers);
        __esDecorate(null, null, _recordingFileType_decorators, { kind: "field", name: "recordingFileType", static: false, private: false, access: { has: function (obj) { return "recordingFileType" in obj; }, get: function (obj) { return obj.recordingFileType; }, set: function (obj, value) { obj.recordingFileType = value; } }, metadata: _metadata }, _recordingFileType_initializers, _recordingFileType_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoCaptureConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.VideoCaptureConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _capturePreference_decorators;
    var _capturePreference_initializers = [];
    var _capturePreference_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _frameRate_decorators;
    var _frameRate_initializers = [];
    var _frameRate_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function VideoCaptureConfig_1() {
            this.capturePreference = __runInitializers(this, _capturePreference_initializers, void 0);
            this.width = (__runInitializers(this, _capturePreference_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.frameRate = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _frameRate_initializers, void 0));
            __runInitializers(this, _frameRate_extraInitializers);
        }
        return VideoCaptureConfig_1;
    }());
    __setFunctionName(_classThis, "VideoCaptureConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _capturePreference_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _frameRate_decorators = [NativeMember()];
        __esDecorate(null, null, _capturePreference_decorators, { kind: "field", name: "capturePreference", static: false, private: false, access: { has: function (obj) { return "capturePreference" in obj; }, get: function (obj) { return obj.capturePreference; }, set: function (obj, value) { obj.capturePreference = value; } }, metadata: _metadata }, _capturePreference_initializers, _capturePreference_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _frameRate_decorators, { kind: "field", name: "frameRate", static: false, private: false, access: { has: function (obj) { return "frameRate" in obj; }, get: function (obj) { return obj.frameRate; }, set: function (obj, value) { obj.frameRate = value; } }, metadata: _metadata }, _frameRate_initializers, _frameRate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var HumanOrientation$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.HumanOrientation')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _forward_decorators;
    var _forward_initializers = [];
    var _forward_extraInitializers = [];
    var _right_decorators;
    var _right_initializers = [];
    var _right_extraInitializers = [];
    var _up_decorators;
    var _up_initializers = [];
    var _up_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function HumanOrientation_1() {
            this.forward = __runInitializers(this, _forward_initializers, void 0);
            this.right = (__runInitializers(this, _forward_extraInitializers), __runInitializers(this, _right_initializers, void 0));
            this.up = (__runInitializers(this, _right_extraInitializers), __runInitializers(this, _up_initializers, void 0));
            __runInitializers(this, _up_extraInitializers);
        }
        return HumanOrientation_1;
    }());
    __setFunctionName(_classThis, "HumanOrientation");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _forward_decorators = [NativeMember()];
        _right_decorators = [NativeMember()];
        _up_decorators = [NativeMember()];
        __esDecorate(null, null, _forward_decorators, { kind: "field", name: "forward", static: false, private: false, access: { has: function (obj) { return "forward" in obj; }, get: function (obj) { return obj.forward; }, set: function (obj, value) { obj.forward = value; } }, metadata: _metadata }, _forward_initializers, _forward_extraInitializers);
        __esDecorate(null, null, _right_decorators, { kind: "field", name: "right", static: false, private: false, access: { has: function (obj) { return "right" in obj; }, get: function (obj) { return obj.right; }, set: function (obj, value) { obj.right = value; } }, metadata: _metadata }, _right_initializers, _right_extraInitializers);
        __esDecorate(null, null, _up_decorators, { kind: "field", name: "up", static: false, private: false, access: { has: function (obj) { return "up" in obj; }, get: function (obj) { return obj.up; }, set: function (obj, value) { obj.up = value; } }, metadata: _metadata }, _up_initializers, _up_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var LocalAudioPropertiesInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.LocalAudioPropertiesInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _streamIndex_decorators;
    var _streamIndex_initializers = [];
    var _streamIndex_extraInitializers = [];
    var _audioPropertiesInfo_decorators;
    var _audioPropertiesInfo_initializers = [];
    var _audioPropertiesInfo_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function LocalAudioPropertiesInfo_1(streamIndex, audioPropertiesInfo) {
            this.streamIndex = __runInitializers(this, _streamIndex_initializers, void 0);
            this.audioPropertiesInfo = (__runInitializers(this, _streamIndex_extraInitializers), __runInitializers(this, _audioPropertiesInfo_initializers, void 0));
            __runInitializers(this, _audioPropertiesInfo_extraInitializers);
        }
        return LocalAudioPropertiesInfo_1;
    }());
    __setFunctionName(_classThis, "LocalAudioPropertiesInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _streamIndex_decorators = [NativeMember()];
        _audioPropertiesInfo_decorators = [NativeMember()];
        __esDecorate(null, null, _streamIndex_decorators, { kind: "field", name: "streamIndex", static: false, private: false, access: { has: function (obj) { return "streamIndex" in obj; }, get: function (obj) { return obj.streamIndex; }, set: function (obj, value) { obj.streamIndex = value; } }, metadata: _metadata }, _streamIndex_initializers, _streamIndex_extraInitializers);
        __esDecorate(null, null, _audioPropertiesInfo_decorators, { kind: "field", name: "audioPropertiesInfo", static: false, private: false, access: { has: function (obj) { return "audioPropertiesInfo" in obj; }, get: function (obj) { return obj.audioPropertiesInfo; }, set: function (obj, value) { obj.audioPropertiesInfo = value; } }, metadata: _metadata }, _audioPropertiesInfo_initializers, _audioPropertiesInfo_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.LiveTranscoding.Region$DataParam')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setImageWidth_decorators;
    var _setImageHeight_decorators;
    var DataParam = _classThis = /** @class */ (function () {
        function DataParam_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        DataParam_1.prototype.setImageWidth = function (imageWidth) {
            throw new Error('not implement');
        };
        DataParam_1.prototype.setImageHeight = function (imageHeight) {
            throw new Error('not implement');
        };
        return DataParam_1;
    }());
    __setFunctionName(_classThis, "DataParam");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setImageWidth_decorators = [ReturnClass(function () { return DataParam; }), NativeMethodSync()];
        _setImageHeight_decorators = [ReturnClass(function () { return DataParam; }), NativeMethodSync()];
        __esDecorate(_classThis, null, _setImageWidth_decorators, { kind: "method", name: "setImageWidth", static: false, private: false, access: { has: function (obj) { return "setImageWidth" in obj; }, get: function (obj) { return obj.setImageWidth; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setImageHeight_decorators, { kind: "method", name: "setImageHeight", static: false, private: false, access: { has: function (obj) { return "setImageHeight" in obj; }, get: function (obj) { return obj.setImageHeight; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        DataParam = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return DataParam = _classThis;
})();
var ByteRTCStreamMixingEvent$1;
(function (ByteRTCStreamMixingEvent) {
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_START"] = 1] = "STREAM_MIXING_START";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_START_SUCCESS"] = 2] = "STREAM_MIXING_START_SUCCESS";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_START_FAILED"] = 3] = "STREAM_MIXING_START_FAILED";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_UPDATE"] = 4] = "STREAM_MIXING_UPDATE";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_UPDATE_SUCCESS"] = 5] = "STREAM_MIXING_UPDATE_SUCCESS";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_UPDATE_FAILED"] = 6] = "STREAM_MIXING_UPDATE_FAILED";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_STOP"] = 7] = "STREAM_MIXING_STOP";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_STOP_SUCCESS"] = 8] = "STREAM_MIXING_STOP_SUCCESS";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_STOP_FAILED"] = 9] = "STREAM_MIXING_STOP_FAILED";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_CHANGE_MIX_TYPE"] = 10] = "STREAM_MIXING_CHANGE_MIX_TYPE";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_FIRST_AUDIO_FRAME_BY_CLIENT_MIX"] = 11] = "STREAM_MIXING_FIRST_AUDIO_FRAME_BY_CLIENT_MIX";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_FIRST_VIDEO_FRAME_BY_CLIENT_MIX"] = 12] = "STREAM_MIXING_FIRST_VIDEO_FRAME_BY_CLIENT_MIX";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_UPDATE_TIMEOUT"] = 13] = "STREAM_MIXING_UPDATE_TIMEOUT";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_START_TIMEOUT"] = 14] = "STREAM_MIXING_START_TIMEOUT";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_REQUEST_PARAM_ERROR"] = 15] = "STREAM_MIXING_REQUEST_PARAM_ERROR";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_MIX_IMAGE_EVENT"] = 16] = "STREAM_MIXING_MIX_IMAGE_EVENT";
})(ByteRTCStreamMixingEvent$1 || (ByteRTCStreamMixingEvent$1 = {}));
var AudioAlignmentMode;
(function (AudioAlignmentMode) {
    AudioAlignmentMode[AudioAlignmentMode["AUDIO_ALIGNMENT_MODE_OFF"] = 0] = "AUDIO_ALIGNMENT_MODE_OFF";
    AudioAlignmentMode[AudioAlignmentMode["AUDIO_ALIGNMENT_MODE_AUDIOMIXING"] = 1] = "AUDIO_ALIGNMENT_MODE_AUDIOMIXING";
})(AudioAlignmentMode || (AudioAlignmentMode = {}));
var FallbackOrRecoverReason;
(function (FallbackOrRecoverReason) {
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_UNKNOWN"] = -1] = "FALLBACK_OR_RECOVER_REASON_UNKNOWN";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_BANDWIDTH"] = 0] = "FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_BANDWIDTH";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_PERFORMANCE"] = 1] = "FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_PERFORMANCE";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_BANDWIDTH"] = 2] = "FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_BANDWIDTH";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_PERFORMANCE"] = 3] = "FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_PERFORMANCE";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_BANDWIDTH"] = 4] = "FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_BANDWIDTH";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_PERFORMANCE"] = 5] = "FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_PERFORMANCE";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_BANDWIDTH"] = 6] = "FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_BANDWIDTH";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_PERFORMANCE"] = 7] = "FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_PERFORMANCE";
})(FallbackOrRecoverReason || (FallbackOrRecoverReason = {}));
var SEIStreamUpdateEvent;
(function (SEIStreamUpdateEvent) {
    SEIStreamUpdateEvent[SEIStreamUpdateEvent["STREAM_ADD"] = 0] = "STREAM_ADD";
    SEIStreamUpdateEvent[SEIStreamUpdateEvent["STREAM_REMOVE"] = 1] = "STREAM_REMOVE";
})(SEIStreamUpdateEvent || (SEIStreamUpdateEvent = {}));
var RemoteStreamStats$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.RemoteStreamStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _uid_decorators;
    var _uid_initializers = [];
    var _uid_extraInitializers = [];
    var _audioStats_decorators;
    var _audioStats_initializers = [];
    var _audioStats_extraInitializers = [];
    var _videoStats_decorators;
    var _videoStats_initializers = [];
    var _videoStats_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _txQuality_decorators;
    var _txQuality_initializers = [];
    var _txQuality_extraInitializers = [];
    var _rxQuality_decorators;
    var _rxQuality_initializers = [];
    var _rxQuality_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RemoteStreamStats_1() {
            this.uid = __runInitializers(this, _uid_initializers, void 0);
            this.audioStats = (__runInitializers(this, _uid_extraInitializers), __runInitializers(this, _audioStats_initializers, void 0));
            this.videoStats = (__runInitializers(this, _audioStats_extraInitializers), __runInitializers(this, _videoStats_initializers, void 0));
            this.isScreen = (__runInitializers(this, _videoStats_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.txQuality = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _txQuality_initializers, void 0));
            this.rxQuality = (__runInitializers(this, _txQuality_extraInitializers), __runInitializers(this, _rxQuality_initializers, void 0));
            __runInitializers(this, _rxQuality_extraInitializers);
        }
        return RemoteStreamStats_1;
    }());
    __setFunctionName(_classThis, "RemoteStreamStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _uid_decorators = [NativeMember()];
        _audioStats_decorators = [NativeMember()];
        _videoStats_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _txQuality_decorators = [NativeMember()];
        _rxQuality_decorators = [NativeMember()];
        __esDecorate(null, null, _uid_decorators, { kind: "field", name: "uid", static: false, private: false, access: { has: function (obj) { return "uid" in obj; }, get: function (obj) { return obj.uid; }, set: function (obj, value) { obj.uid = value; } }, metadata: _metadata }, _uid_initializers, _uid_extraInitializers);
        __esDecorate(null, null, _audioStats_decorators, { kind: "field", name: "audioStats", static: false, private: false, access: { has: function (obj) { return "audioStats" in obj; }, get: function (obj) { return obj.audioStats; }, set: function (obj, value) { obj.audioStats = value; } }, metadata: _metadata }, _audioStats_initializers, _audioStats_extraInitializers);
        __esDecorate(null, null, _videoStats_decorators, { kind: "field", name: "videoStats", static: false, private: false, access: { has: function (obj) { return "videoStats" in obj; }, get: function (obj) { return obj.videoStats; }, set: function (obj, value) { obj.videoStats = value; } }, metadata: _metadata }, _videoStats_initializers, _videoStats_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _txQuality_decorators, { kind: "field", name: "txQuality", static: false, private: false, access: { has: function (obj) { return "txQuality" in obj; }, get: function (obj) { return obj.txQuality; }, set: function (obj, value) { obj.txQuality = value; } }, metadata: _metadata }, _txQuality_initializers, _txQuality_extraInitializers);
        __esDecorate(null, null, _rxQuality_decorators, { kind: "field", name: "rxQuality", static: false, private: false, access: { has: function (obj) { return "rxQuality" in obj; }, get: function (obj) { return obj.rxQuality; }, set: function (obj, value) { obj.rxQuality = value; } }, metadata: _metadata }, _rxQuality_initializers, _rxQuality_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MediaDeviceWarning;
(function (MediaDeviceWarning) {
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_OK"] = 0] = "MEDIA_DEVICE_WARNING_OK";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_OPERATION_DENIED"] = 1] = "MEDIA_DEVICE_WARNING_OPERATION_DENIED";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_CAPTURE_SILENCE"] = 2] = "MEDIA_DEVICE_WARNING_CAPTURE_SILENCE";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE"] = 3] = "MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE_DISAPPEAR"] = 4] = "MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE_DISAPPEAR";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_DETECT_CLIPPING"] = 10] = "MEDIA_DEVICE_WARNING_DETECT_CLIPPING";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_DETECT_LEAK_ECHO"] = 11] = "MEDIA_DEVICE_WARNING_DETECT_LEAK_ECHO";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_DETECT_LOW_SNR"] = 12] = "MEDIA_DEVICE_WARNING_DETECT_LOW_SNR";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_DETECT_INSERT_SILENCE"] = 13] = "MEDIA_DEVICE_WARNING_DETECT_INSERT_SILENCE";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_CAPTURE_DETECT_SILENCE"] = 14] = "MEDIA_DEVICE_WARNING_CAPTURE_DETECT_SILENCE";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_CAPTURE_DETECT_SILENCE_DISAPPEAR"] = 15] = "MEDIA_DEVICE_WARNING_CAPTURE_DETECT_SILENCE_DISAPPEAR";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_CAPTURE_DETECT_HOWLING"] = 16] = "MEDIA_DEVICE_WARNING_CAPTURE_DETECT_HOWLING";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_INVALID_SCENARIO"] = 20] = "MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_INVALID_SCENARIO";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_EXISTS"] = 21] = "MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_EXISTS";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_FAILED_BY_PRIORITY"] = 22] = "MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_FAILED_BY_PRIORITY";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_VOIP_MODE"] = 23] = "MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_VOIP_MODE";
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_DEVICE_NOT_START"] = 24] = "MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_DEVICE_NOT_START";
})(MediaDeviceWarning || (MediaDeviceWarning = {}));
var RemoteVideoRenderConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.RemoteVideoRenderConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _renderMode_decorators;
    var _renderMode_initializers = [];
    var _renderMode_extraInitializers = [];
    var _backgroundColor_decorators;
    var _backgroundColor_initializers = [];
    var _backgroundColor_extraInitializers = [];
    var _renderRotation_decorators;
    var _renderRotation_initializers = [];
    var _renderRotation_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RemoteVideoRenderConfig_1() {
            this.renderMode = __runInitializers(this, _renderMode_initializers, void 0);
            this.backgroundColor = (__runInitializers(this, _renderMode_extraInitializers), __runInitializers(this, _backgroundColor_initializers, void 0));
            this.renderRotation = (__runInitializers(this, _backgroundColor_extraInitializers), __runInitializers(this, _renderRotation_initializers, void 0));
            __runInitializers(this, _renderRotation_extraInitializers);
        }
        return RemoteVideoRenderConfig_1;
    }());
    __setFunctionName(_classThis, "RemoteVideoRenderConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _renderMode_decorators = [NativeMember()];
        _backgroundColor_decorators = [NativeMember()];
        _renderRotation_decorators = [NativeMember()];
        __esDecorate(null, null, _renderMode_decorators, { kind: "field", name: "renderMode", static: false, private: false, access: { has: function (obj) { return "renderMode" in obj; }, get: function (obj) { return obj.renderMode; }, set: function (obj, value) { obj.renderMode = value; } }, metadata: _metadata }, _renderMode_initializers, _renderMode_extraInitializers);
        __esDecorate(null, null, _backgroundColor_decorators, { kind: "field", name: "backgroundColor", static: false, private: false, access: { has: function (obj) { return "backgroundColor" in obj; }, get: function (obj) { return obj.backgroundColor; }, set: function (obj, value) { obj.backgroundColor = value; } }, metadata: _metadata }, _backgroundColor_initializers, _backgroundColor_extraInitializers);
        __esDecorate(null, null, _renderRotation_decorators, { kind: "field", name: "renderRotation", static: false, private: false, access: { has: function (obj) { return "renderRotation" in obj; }, get: function (obj) { return obj.renderRotation; }, set: function (obj, value) { obj.renderRotation = value; } }, metadata: _metadata }, _renderRotation_initializers, _renderRotation_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioProfileType;
(function (AudioProfileType) {
    AudioProfileType[AudioProfileType["AUDIO_PROFILE_DEFAULT"] = 0] = "AUDIO_PROFILE_DEFAULT";
    AudioProfileType[AudioProfileType["AUDIO_PROFILE_FLUENT"] = 1] = "AUDIO_PROFILE_FLUENT";
    AudioProfileType[AudioProfileType["AUDIO_PROFILE_STANDARD"] = 2] = "AUDIO_PROFILE_STANDARD";
    AudioProfileType[AudioProfileType["AUDIO_PROFILE_HD"] = 3] = "AUDIO_PROFILE_HD";
    AudioProfileType[AudioProfileType["AUDIO_PROFILE_STANDARD_STEREO"] = 4] = "AUDIO_PROFILE_STANDARD_STEREO";
    AudioProfileType[AudioProfileType["AUDIO_PROFILE_HD_MONO"] = 5] = "AUDIO_PROFILE_HD_MONO";
})(AudioProfileType || (AudioProfileType = {}));
var CameraId;
(function (CameraId) {
    CameraId[CameraId["CAMERA_ID_FRONT"] = 0] = "CAMERA_ID_FRONT";
    CameraId[CameraId["CAMERA_ID_BACK"] = 1] = "CAMERA_ID_BACK";
    CameraId[CameraId["CAMERA_ID_INVALID"] = 3] = "CAMERA_ID_INVALID";
})(CameraId || (CameraId = {}));
var SingScoringRealtimeInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.SingScoringRealtimeInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _static_create_decorators;
    var _currentPosition_decorators;
    var _currentPosition_initializers = [];
    var _currentPosition_extraInitializers = [];
    var _userPitch_decorators;
    var _userPitch_initializers = [];
    var _userPitch_extraInitializers = [];
    var _standardPitch_decorators;
    var _standardPitch_initializers = [];
    var _standardPitch_extraInitializers = [];
    var _sentenceIndex_decorators;
    var _sentenceIndex_initializers = [];
    var _sentenceIndex_extraInitializers = [];
    var _sentenceScore_decorators;
    var _sentenceScore_initializers = [];
    var _sentenceScore_extraInitializers = [];
    var _totalScore_decorators;
    var _totalScore_initializers = [];
    var _totalScore_extraInitializers = [];
    var _averageScore_decorators;
    var _averageScore_initializers = [];
    var _averageScore_extraInitializers = [];
    var SingScoringRealtimeInfo = _classThis = /** @class */ (function () {
        function SingScoringRealtimeInfo_1(currentPosition, userPitch, standardPitch, sentenceIndex, sentenceScore, totalScore, averageScore) {
            this.currentPosition = __runInitializers(this, _currentPosition_initializers, void 0);
            this.userPitch = (__runInitializers(this, _currentPosition_extraInitializers), __runInitializers(this, _userPitch_initializers, void 0));
            this.standardPitch = (__runInitializers(this, _userPitch_extraInitializers), __runInitializers(this, _standardPitch_initializers, void 0));
            this.sentenceIndex = (__runInitializers(this, _standardPitch_extraInitializers), __runInitializers(this, _sentenceIndex_initializers, void 0));
            this.sentenceScore = (__runInitializers(this, _sentenceIndex_extraInitializers), __runInitializers(this, _sentenceScore_initializers, void 0));
            this.totalScore = (__runInitializers(this, _sentenceScore_extraInitializers), __runInitializers(this, _totalScore_initializers, void 0));
            this.averageScore = (__runInitializers(this, _totalScore_extraInitializers), __runInitializers(this, _averageScore_initializers, void 0));
            __runInitializers(this, _averageScore_extraInitializers);
        }
        SingScoringRealtimeInfo_1.create = function (currentPosition, userPitch, standardPitch, sentenceIndex, sentenceScore, totalScore, averageScore) {
            throw new Error('not implement');
        };
        return SingScoringRealtimeInfo_1;
    }());
    __setFunctionName(_classThis, "SingScoringRealtimeInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_create_decorators = [ReturnClass(function () { return SingScoringRealtimeInfo; }), NativeStaticMethodSync()];
        _currentPosition_decorators = [NativeMember()];
        _userPitch_decorators = [NativeMember()];
        _standardPitch_decorators = [NativeMember()];
        _sentenceIndex_decorators = [NativeMember()];
        _sentenceScore_decorators = [NativeMember()];
        _totalScore_decorators = [NativeMember()];
        _averageScore_decorators = [NativeMember()];
        __esDecorate(_classThis, null, _static_create_decorators, { kind: "method", name: "create", static: true, private: false, access: { has: function (obj) { return "create" in obj; }, get: function (obj) { return obj.create; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(null, null, _currentPosition_decorators, { kind: "field", name: "currentPosition", static: false, private: false, access: { has: function (obj) { return "currentPosition" in obj; }, get: function (obj) { return obj.currentPosition; }, set: function (obj, value) { obj.currentPosition = value; } }, metadata: _metadata }, _currentPosition_initializers, _currentPosition_extraInitializers);
        __esDecorate(null, null, _userPitch_decorators, { kind: "field", name: "userPitch", static: false, private: false, access: { has: function (obj) { return "userPitch" in obj; }, get: function (obj) { return obj.userPitch; }, set: function (obj, value) { obj.userPitch = value; } }, metadata: _metadata }, _userPitch_initializers, _userPitch_extraInitializers);
        __esDecorate(null, null, _standardPitch_decorators, { kind: "field", name: "standardPitch", static: false, private: false, access: { has: function (obj) { return "standardPitch" in obj; }, get: function (obj) { return obj.standardPitch; }, set: function (obj, value) { obj.standardPitch = value; } }, metadata: _metadata }, _standardPitch_initializers, _standardPitch_extraInitializers);
        __esDecorate(null, null, _sentenceIndex_decorators, { kind: "field", name: "sentenceIndex", static: false, private: false, access: { has: function (obj) { return "sentenceIndex" in obj; }, get: function (obj) { return obj.sentenceIndex; }, set: function (obj, value) { obj.sentenceIndex = value; } }, metadata: _metadata }, _sentenceIndex_initializers, _sentenceIndex_extraInitializers);
        __esDecorate(null, null, _sentenceScore_decorators, { kind: "field", name: "sentenceScore", static: false, private: false, access: { has: function (obj) { return "sentenceScore" in obj; }, get: function (obj) { return obj.sentenceScore; }, set: function (obj, value) { obj.sentenceScore = value; } }, metadata: _metadata }, _sentenceScore_initializers, _sentenceScore_extraInitializers);
        __esDecorate(null, null, _totalScore_decorators, { kind: "field", name: "totalScore", static: false, private: false, access: { has: function (obj) { return "totalScore" in obj; }, get: function (obj) { return obj.totalScore; }, set: function (obj, value) { obj.totalScore = value; } }, metadata: _metadata }, _totalScore_initializers, _totalScore_extraInitializers);
        __esDecorate(null, null, _averageScore_decorators, { kind: "field", name: "averageScore", static: false, private: false, access: { has: function (obj) { return "averageScore" in obj; }, get: function (obj) { return obj.averageScore; }, set: function (obj, value) { obj.averageScore = value; } }, metadata: _metadata }, _averageScore_initializers, _averageScore_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        SingScoringRealtimeInfo = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _staticExtraInitializers);
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return SingScoringRealtimeInfo = _classThis;
}();
var VideoEncoderConfig$CodecMode;
(function (VideoEncoderConfig$CodecMode) {
    VideoEncoderConfig$CodecMode[VideoEncoderConfig$CodecMode["CODEC_MODE_AUTO"] = 0] = "CODEC_MODE_AUTO";
    VideoEncoderConfig$CodecMode[VideoEncoderConfig$CodecMode["CODEC_MODE_HARDWARE"] = 1] = "CODEC_MODE_HARDWARE";
    VideoEncoderConfig$CodecMode[VideoEncoderConfig$CodecMode["CODEC_MODE_SOFTWARE"] = 2] = "CODEC_MODE_SOFTWARE";
})(VideoEncoderConfig$CodecMode || (VideoEncoderConfig$CodecMode = {}));
var RemoteVideoRenderPosition;
(function (RemoteVideoRenderPosition) {
    RemoteVideoRenderPosition[RemoteVideoRenderPosition["AFTER_DECODER"] = 0] = "AFTER_DECODER";
    RemoteVideoRenderPosition[RemoteVideoRenderPosition["AFTER_POST_PROCESS"] = 1] = "AFTER_POST_PROCESS";
})(RemoteVideoRenderPosition || (RemoteVideoRenderPosition = {}));
var TranscoderLayoutRegionType;
(function (TranscoderLayoutRegionType) {
    TranscoderLayoutRegionType[TranscoderLayoutRegionType["LAYOUT_REGION_TYPE_VIDEO_STREAM"] = 0] = "LAYOUT_REGION_TYPE_VIDEO_STREAM";
    TranscoderLayoutRegionType[TranscoderLayoutRegionType["LAYOUT_REGION_TYPE_IMAGE"] = 1] = "LAYOUT_REGION_TYPE_IMAGE";
})(TranscoderLayoutRegionType || (TranscoderLayoutRegionType = {}));
var AudioEffectPlayerConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.AudioEffectPlayerConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _type_decorators;
    var _type_initializers = [];
    var _type_extraInitializers = [];
    var _playCount_decorators;
    var _playCount_initializers = [];
    var _playCount_extraInitializers = [];
    var _startPos_decorators;
    var _startPos_initializers = [];
    var _startPos_extraInitializers = [];
    var _pitch_decorators;
    var _pitch_initializers = [];
    var _pitch_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function AudioEffectPlayerConfig_1() {
            this.type = __runInitializers(this, _type_initializers, void 0);
            this.playCount = (__runInitializers(this, _type_extraInitializers), __runInitializers(this, _playCount_initializers, void 0));
            this.startPos = (__runInitializers(this, _playCount_extraInitializers), __runInitializers(this, _startPos_initializers, void 0));
            this.pitch = (__runInitializers(this, _startPos_extraInitializers), __runInitializers(this, _pitch_initializers, void 0));
            __runInitializers(this, _pitch_extraInitializers);
        }
        return AudioEffectPlayerConfig_1;
    }());
    __setFunctionName(_classThis, "AudioEffectPlayerConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _type_decorators = [NativeMember()];
        _playCount_decorators = [NativeMember()];
        _startPos_decorators = [NativeMember()];
        _pitch_decorators = [NativeMember()];
        __esDecorate(null, null, _type_decorators, { kind: "field", name: "type", static: false, private: false, access: { has: function (obj) { return "type" in obj; }, get: function (obj) { return obj.type; }, set: function (obj, value) { obj.type = value; } }, metadata: _metadata }, _type_initializers, _type_extraInitializers);
        __esDecorate(null, null, _playCount_decorators, { kind: "field", name: "playCount", static: false, private: false, access: { has: function (obj) { return "playCount" in obj; }, get: function (obj) { return obj.playCount; }, set: function (obj, value) { obj.playCount = value; } }, metadata: _metadata }, _playCount_initializers, _playCount_extraInitializers);
        __esDecorate(null, null, _startPos_decorators, { kind: "field", name: "startPos", static: false, private: false, access: { has: function (obj) { return "startPos" in obj; }, get: function (obj) { return obj.startPos; }, set: function (obj, value) { obj.startPos = value; } }, metadata: _metadata }, _startPos_initializers, _startPos_extraInitializers);
        __esDecorate(null, null, _pitch_decorators, { kind: "field", name: "pitch", static: false, private: false, access: { has: function (obj) { return "pitch" in obj; }, get: function (obj) { return obj.pitch; }, set: function (obj, value) { obj.pitch = value; } }, metadata: _metadata }, _pitch_initializers, _pitch_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MixedStreamLayoutRegionImageWaterMarkConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.MixedStreamConfig.MixedStreamLayoutRegionConfig$MixedStreamLayoutRegionImageWaterMarkConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setImageHeight_decorators;
    var _getImageHeight_decorators;
    var _setImageWidth_decorators;
    var _getImageWidth_decorators;
    _classThis = /** @class */ (function () {
        function MixedStreamLayoutRegionImageWaterMarkConfig_1(width, height) {
            __runInitializers(this, _instanceExtraInitializers);
        }
        MixedStreamLayoutRegionImageWaterMarkConfig_1.prototype.setImageHeight = function (imageHeight) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionImageWaterMarkConfig_1.prototype.getImageHeight = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionImageWaterMarkConfig_1.prototype.setImageWidth = function (imageWidth) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionImageWaterMarkConfig_1.prototype.getImageWidth = function () {
            throw new Error('not implement');
        };
        return MixedStreamLayoutRegionImageWaterMarkConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamLayoutRegionImageWaterMarkConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setImageHeight_decorators = [NativeMethodSync()];
        _getImageHeight_decorators = [NativeMethodSync()];
        _setImageWidth_decorators = [NativeMethodSync()];
        _getImageWidth_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setImageHeight_decorators, { kind: "method", name: "setImageHeight", static: false, private: false, access: { has: function (obj) { return "setImageHeight" in obj; }, get: function (obj) { return obj.setImageHeight; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getImageHeight_decorators, { kind: "method", name: "getImageHeight", static: false, private: false, access: { has: function (obj) { return "getImageHeight" in obj; }, get: function (obj) { return obj.getImageHeight; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setImageWidth_decorators, { kind: "method", name: "setImageWidth", static: false, private: false, access: { has: function (obj) { return "setImageWidth" in obj; }, get: function (obj) { return obj.setImageWidth; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getImageWidth_decorators, { kind: "method", name: "getImageWidth", static: false, private: false, access: { has: function (obj) { return "getImageWidth" in obj; }, get: function (obj) { return obj.getImageWidth; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var LocalVideoStreamError;
(function (LocalVideoStreamError) {
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_OK"] = 0] = "LOCAL_VIDEO_STREAM_ERROR_OK";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_FAILURE"] = 1] = "LOCAL_VIDEO_STREAM_ERROR_FAILURE";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_DEVICE_NO_PERMISSION"] = 2] = "LOCAL_VIDEO_STREAM_ERROR_DEVICE_NO_PERMISSION";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_DEVICE_BUSY"] = 3] = "LOCAL_VIDEO_STREAM_ERROR_DEVICE_BUSY";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_DEVICE_NOT_FOUND"] = 4] = "LOCAL_VIDEO_STREAM_ERROR_DEVICE_NOT_FOUND";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_CAPTURE_FAILURE"] = 5] = "LOCAL_VIDEO_STREAM_ERROR_CAPTURE_FAILURE";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_ENCODE_FAILURE"] = 6] = "LOCAL_VIDEO_STREAM_ERROR_ENCODE_FAILURE";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_DEVICE_DISCONNECTED"] = 7] = "LOCAL_VIDEO_STREAM_ERROR_DEVICE_DISCONNECTED";
})(LocalVideoStreamError || (LocalVideoStreamError = {}));
var NetworkQualityStats$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.NetworkQualityStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _uid_decorators;
    var _uid_initializers = [];
    var _uid_extraInitializers = [];
    var _fractionLost_decorators;
    var _fractionLost_initializers = [];
    var _fractionLost_extraInitializers = [];
    var _rtt_decorators;
    var _rtt_initializers = [];
    var _rtt_extraInitializers = [];
    var _totalBandwidth_decorators;
    var _totalBandwidth_initializers = [];
    var _totalBandwidth_extraInitializers = [];
    var _txQuality_decorators;
    var _txQuality_initializers = [];
    var _txQuality_extraInitializers = [];
    var _rxQuality_decorators;
    var _rxQuality_initializers = [];
    var _rxQuality_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function NetworkQualityStats_1(uid, lost, rtt, bandwidth, txQuality, rxQuality) {
            this.uid = __runInitializers(this, _uid_initializers, void 0);
            this.fractionLost = (__runInitializers(this, _uid_extraInitializers), __runInitializers(this, _fractionLost_initializers, void 0));
            this.rtt = (__runInitializers(this, _fractionLost_extraInitializers), __runInitializers(this, _rtt_initializers, void 0));
            this.totalBandwidth = (__runInitializers(this, _rtt_extraInitializers), __runInitializers(this, _totalBandwidth_initializers, void 0));
            this.txQuality = (__runInitializers(this, _totalBandwidth_extraInitializers), __runInitializers(this, _txQuality_initializers, void 0));
            this.rxQuality = (__runInitializers(this, _txQuality_extraInitializers), __runInitializers(this, _rxQuality_initializers, void 0));
            __runInitializers(this, _rxQuality_extraInitializers);
        }
        return NetworkQualityStats_1;
    }());
    __setFunctionName(_classThis, "NetworkQualityStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _uid_decorators = [NativeMember()];
        _fractionLost_decorators = [NativeMember()];
        _rtt_decorators = [NativeMember()];
        _totalBandwidth_decorators = [NativeMember()];
        _txQuality_decorators = [NativeMember()];
        _rxQuality_decorators = [NativeMember()];
        __esDecorate(null, null, _uid_decorators, { kind: "field", name: "uid", static: false, private: false, access: { has: function (obj) { return "uid" in obj; }, get: function (obj) { return obj.uid; }, set: function (obj, value) { obj.uid = value; } }, metadata: _metadata }, _uid_initializers, _uid_extraInitializers);
        __esDecorate(null, null, _fractionLost_decorators, { kind: "field", name: "fractionLost", static: false, private: false, access: { has: function (obj) { return "fractionLost" in obj; }, get: function (obj) { return obj.fractionLost; }, set: function (obj, value) { obj.fractionLost = value; } }, metadata: _metadata }, _fractionLost_initializers, _fractionLost_extraInitializers);
        __esDecorate(null, null, _rtt_decorators, { kind: "field", name: "rtt", static: false, private: false, access: { has: function (obj) { return "rtt" in obj; }, get: function (obj) { return obj.rtt; }, set: function (obj, value) { obj.rtt = value; } }, metadata: _metadata }, _rtt_initializers, _rtt_extraInitializers);
        __esDecorate(null, null, _totalBandwidth_decorators, { kind: "field", name: "totalBandwidth", static: false, private: false, access: { has: function (obj) { return "totalBandwidth" in obj; }, get: function (obj) { return obj.totalBandwidth; }, set: function (obj, value) { obj.totalBandwidth = value; } }, metadata: _metadata }, _totalBandwidth_initializers, _totalBandwidth_extraInitializers);
        __esDecorate(null, null, _txQuality_decorators, { kind: "field", name: "txQuality", static: false, private: false, access: { has: function (obj) { return "txQuality" in obj; }, get: function (obj) { return obj.txQuality; }, set: function (obj, value) { obj.txQuality = value; } }, metadata: _metadata }, _txQuality_initializers, _txQuality_extraInitializers);
        __esDecorate(null, null, _rxQuality_decorators, { kind: "field", name: "rxQuality", static: false, private: false, access: { has: function (obj) { return "rxQuality" in obj; }, get: function (obj) { return obj.rxQuality; }, set: function (obj, value) { obj.rxQuality = value; } }, metadata: _metadata }, _rxQuality_initializers, _rxQuality_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var UserVisibilityChangeError;
(function (UserVisibilityChangeError) {
    UserVisibilityChangeError[UserVisibilityChangeError["OK"] = 0] = "OK";
    UserVisibilityChangeError[UserVisibilityChangeError["UNKNOWN"] = 1] = "UNKNOWN";
    UserVisibilityChangeError[UserVisibilityChangeError["TOO_MANY_VISIBLE_USER"] = 2] = "TOO_MANY_VISIBLE_USER";
})(UserVisibilityChangeError || (UserVisibilityChangeError = {}));
var PublishFallbackOption;
(function (PublishFallbackOption) {
    PublishFallbackOption[PublishFallbackOption["DISABLE"] = 0] = "DISABLE";
    PublishFallbackOption[PublishFallbackOption["SIMULCAST_SMALL_VIDEO_ONLY"] = 1] = "SIMULCAST_SMALL_VIDEO_ONLY";
})(PublishFallbackOption || (PublishFallbackOption = {}));
var LocalAudioStreamError;
(function (LocalAudioStreamError) {
    LocalAudioStreamError[LocalAudioStreamError["LOCAL_AUDIO_STREAM_ERROR_OK"] = 0] = "LOCAL_AUDIO_STREAM_ERROR_OK";
    LocalAudioStreamError[LocalAudioStreamError["LOCAL_AUDIO_STREAM_ERROR_FAILURE"] = 1] = "LOCAL_AUDIO_STREAM_ERROR_FAILURE";
    LocalAudioStreamError[LocalAudioStreamError["LOCAL_AUDIO_STREAM_ERROR_DEVICE_NO_PERMISSION"] = 2] = "LOCAL_AUDIO_STREAM_ERROR_DEVICE_NO_PERMISSION";
    LocalAudioStreamError[LocalAudioStreamError["LOCAL_AUDIO_STREAM_ERROR_RECORD_FAILURE"] = 4] = "LOCAL_AUDIO_STREAM_ERROR_RECORD_FAILURE";
    LocalAudioStreamError[LocalAudioStreamError["LOCAL_AUDIO_STREAM_ERROR_ENCODE_FAILURE"] = 5] = "LOCAL_AUDIO_STREAM_ERROR_ENCODE_FAILURE";
    LocalAudioStreamError[LocalAudioStreamError["LOCAL_AUDIO_STREAM_ERROR_NO_RECORDING_DEVICE"] = 6] = "LOCAL_AUDIO_STREAM_ERROR_NO_RECORDING_DEVICE";
})(LocalAudioStreamError || (LocalAudioStreamError = {}));
var SubtitleMessage$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.SubtitleMessage')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _static_create_decorators;
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _text_decorators;
    var _text_initializers = [];
    var _text_extraInitializers = [];
    var _language_decorators;
    var _language_initializers = [];
    var _language_extraInitializers = [];
    var _mode_decorators;
    var _mode_initializers = [];
    var _mode_extraInitializers = [];
    var _sequence_decorators;
    var _sequence_initializers = [];
    var _sequence_extraInitializers = [];
    var _definite_decorators;
    var _definite_initializers = [];
    var _definite_extraInitializers = [];
    var SubtitleMessage = _classThis = /** @class */ (function () {
        function SubtitleMessage_1(userId, text, language, mode, sequence, definite) {
            this.userId = __runInitializers(this, _userId_initializers, void 0);
            this.text = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _text_initializers, void 0));
            this.language = (__runInitializers(this, _text_extraInitializers), __runInitializers(this, _language_initializers, void 0));
            this.mode = (__runInitializers(this, _language_extraInitializers), __runInitializers(this, _mode_initializers, void 0));
            this.sequence = (__runInitializers(this, _mode_extraInitializers), __runInitializers(this, _sequence_initializers, void 0));
            this.definite = (__runInitializers(this, _sequence_extraInitializers), __runInitializers(this, _definite_initializers, void 0));
            __runInitializers(this, _definite_extraInitializers);
        }
        SubtitleMessage_1.create = function (userId, text, language, mode, sequence, definite) {
            throw new Error('not implement');
        };
        return SubtitleMessage_1;
    }());
    __setFunctionName(_classThis, "SubtitleMessage");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_create_decorators = [ReturnClass(function () { return SubtitleMessage; }), NativeStaticMethodSync()];
        _userId_decorators = [NativeMember()];
        _text_decorators = [NativeMember()];
        _language_decorators = [NativeMember()];
        _mode_decorators = [NativeMember()];
        _sequence_decorators = [NativeMember()];
        _definite_decorators = [NativeMember()];
        __esDecorate(_classThis, null, _static_create_decorators, { kind: "method", name: "create", static: true, private: false, access: { has: function (obj) { return "create" in obj; }, get: function (obj) { return obj.create; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _text_decorators, { kind: "field", name: "text", static: false, private: false, access: { has: function (obj) { return "text" in obj; }, get: function (obj) { return obj.text; }, set: function (obj, value) { obj.text = value; } }, metadata: _metadata }, _text_initializers, _text_extraInitializers);
        __esDecorate(null, null, _language_decorators, { kind: "field", name: "language", static: false, private: false, access: { has: function (obj) { return "language" in obj; }, get: function (obj) { return obj.language; }, set: function (obj, value) { obj.language = value; } }, metadata: _metadata }, _language_initializers, _language_extraInitializers);
        __esDecorate(null, null, _mode_decorators, { kind: "field", name: "mode", static: false, private: false, access: { has: function (obj) { return "mode" in obj; }, get: function (obj) { return obj.mode; }, set: function (obj, value) { obj.mode = value; } }, metadata: _metadata }, _mode_initializers, _mode_extraInitializers);
        __esDecorate(null, null, _sequence_decorators, { kind: "field", name: "sequence", static: false, private: false, access: { has: function (obj) { return "sequence" in obj; }, get: function (obj) { return obj.sequence; }, set: function (obj, value) { obj.sequence = value; } }, metadata: _metadata }, _sequence_initializers, _sequence_extraInitializers);
        __esDecorate(null, null, _definite_decorators, { kind: "field", name: "definite", static: false, private: false, access: { has: function (obj) { return "definite" in obj; }, get: function (obj) { return obj.definite; }, set: function (obj, value) { obj.definite = value; } }, metadata: _metadata }, _definite_initializers, _definite_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        SubtitleMessage = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _staticExtraInitializers);
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return SubtitleMessage = _classThis;
}();
var RecordingInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.RecordingInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _filePath_decorators;
    var _filePath_initializers = [];
    var _filePath_extraInitializers = [];
    var _videoCodecType_decorators;
    var _videoCodecType_initializers = [];
    var _videoCodecType_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RecordingInfo_1(filePath, videoCodecType, width, height) {
            this.filePath = __runInitializers(this, _filePath_initializers, void 0);
            this.videoCodecType = (__runInitializers(this, _filePath_extraInitializers), __runInitializers(this, _videoCodecType_initializers, void 0));
            this.width = (__runInitializers(this, _videoCodecType_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            __runInitializers(this, _height_extraInitializers);
        }
        return RecordingInfo_1;
    }());
    __setFunctionName(_classThis, "RecordingInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _filePath_decorators = [NativeMember()];
        _videoCodecType_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        __esDecorate(null, null, _filePath_decorators, { kind: "field", name: "filePath", static: false, private: false, access: { has: function (obj) { return "filePath" in obj; }, get: function (obj) { return obj.filePath; }, set: function (obj, value) { obj.filePath = value; } }, metadata: _metadata }, _filePath_initializers, _filePath_extraInitializers);
        __esDecorate(null, null, _videoCodecType_decorators, { kind: "field", name: "videoCodecType", static: false, private: false, access: { has: function (obj) { return "videoCodecType" in obj; }, get: function (obj) { return obj.videoCodecType; }, set: function (obj, value) { obj.videoCodecType = value; } }, metadata: _metadata }, _videoCodecType_initializers, _videoCodecType_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioMixingConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.AudioMixingConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _type_decorators;
    var _type_initializers = [];
    var _type_extraInitializers = [];
    var _playCount_decorators;
    var _playCount_initializers = [];
    var _playCount_extraInitializers = [];
    var _position_decorators;
    var _position_initializers = [];
    var _position_extraInitializers = [];
    var _callbackOnProgressInterval_decorators;
    var _callbackOnProgressInterval_initializers = [];
    var _callbackOnProgressInterval_extraInitializers = [];
    var _syncProgressToRecordFrame_decorators;
    var _syncProgressToRecordFrame_initializers = [];
    var _syncProgressToRecordFrame_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function AudioMixingConfig_1() {
            this.type = __runInitializers(this, _type_initializers, void 0);
            this.playCount = (__runInitializers(this, _type_extraInitializers), __runInitializers(this, _playCount_initializers, void 0));
            this.position = (__runInitializers(this, _playCount_extraInitializers), __runInitializers(this, _position_initializers, void 0));
            this.callbackOnProgressInterval = (__runInitializers(this, _position_extraInitializers), __runInitializers(this, _callbackOnProgressInterval_initializers, void 0));
            this.syncProgressToRecordFrame = (__runInitializers(this, _callbackOnProgressInterval_extraInitializers), __runInitializers(this, _syncProgressToRecordFrame_initializers, void 0));
            __runInitializers(this, _syncProgressToRecordFrame_extraInitializers);
        }
        return AudioMixingConfig_1;
    }());
    __setFunctionName(_classThis, "AudioMixingConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _type_decorators = [NativeMember()];
        _playCount_decorators = [NativeMember()];
        _position_decorators = [NativeMember()];
        _callbackOnProgressInterval_decorators = [NativeMember()];
        _syncProgressToRecordFrame_decorators = [NativeMember()];
        __esDecorate(null, null, _type_decorators, { kind: "field", name: "type", static: false, private: false, access: { has: function (obj) { return "type" in obj; }, get: function (obj) { return obj.type; }, set: function (obj, value) { obj.type = value; } }, metadata: _metadata }, _type_initializers, _type_extraInitializers);
        __esDecorate(null, null, _playCount_decorators, { kind: "field", name: "playCount", static: false, private: false, access: { has: function (obj) { return "playCount" in obj; }, get: function (obj) { return obj.playCount; }, set: function (obj, value) { obj.playCount = value; } }, metadata: _metadata }, _playCount_initializers, _playCount_extraInitializers);
        __esDecorate(null, null, _position_decorators, { kind: "field", name: "position", static: false, private: false, access: { has: function (obj) { return "position" in obj; }, get: function (obj) { return obj.position; }, set: function (obj, value) { obj.position = value; } }, metadata: _metadata }, _position_initializers, _position_extraInitializers);
        __esDecorate(null, null, _callbackOnProgressInterval_decorators, { kind: "field", name: "callbackOnProgressInterval", static: false, private: false, access: { has: function (obj) { return "callbackOnProgressInterval" in obj; }, get: function (obj) { return obj.callbackOnProgressInterval; }, set: function (obj, value) { obj.callbackOnProgressInterval = value; } }, metadata: _metadata }, _callbackOnProgressInterval_initializers, _callbackOnProgressInterval_extraInitializers);
        __esDecorate(null, null, _syncProgressToRecordFrame_decorators, { kind: "field", name: "syncProgressToRecordFrame", static: false, private: false, access: { has: function (obj) { return "syncProgressToRecordFrame" in obj; }, get: function (obj) { return obj.syncProgressToRecordFrame; }, set: function (obj, value) { obj.syncProgressToRecordFrame = value; } }, metadata: _metadata }, _syncProgressToRecordFrame_initializers, _syncProgressToRecordFrame_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var SyncInfoStreamType;
(function (SyncInfoStreamType) {
    SyncInfoStreamType[SyncInfoStreamType["SYNC_INFO_STREAM_TYPE_AUDIO"] = 0] = "SYNC_INFO_STREAM_TYPE_AUDIO";
})(SyncInfoStreamType || (SyncInfoStreamType = {}));
var MixedStreamAudioProfile;
(function (MixedStreamAudioProfile) {
    MixedStreamAudioProfile["MIXED_STREAM_AUDIO_PROFILE_LC"] = "LC";
    MixedStreamAudioProfile["MIXED_STREAM_AUDIO_PROFILE_HEV1"] = "HEv1";
    MixedStreamAudioProfile["MIXED_STREAM_AUDIO_PROFILE_HEV2"] = "HEv2";
})(MixedStreamAudioProfile || (MixedStreamAudioProfile = {}));
var RTCRoomStats$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.RTCRoomStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _totalDuration_decorators;
    var _totalDuration_initializers = [];
    var _totalDuration_extraInitializers = [];
    var _txBytes_decorators;
    var _txBytes_initializers = [];
    var _txBytes_extraInitializers = [];
    var _rxBytes_decorators;
    var _rxBytes_initializers = [];
    var _rxBytes_extraInitializers = [];
    var _txKBitRate_decorators;
    var _txKBitRate_initializers = [];
    var _txKBitRate_extraInitializers = [];
    var _rxKBitRate_decorators;
    var _rxKBitRate_initializers = [];
    var _rxKBitRate_extraInitializers = [];
    var _txAudioKBitRate_decorators;
    var _txAudioKBitRate_initializers = [];
    var _txAudioKBitRate_extraInitializers = [];
    var _rxAudioKBitRate_decorators;
    var _rxAudioKBitRate_initializers = [];
    var _rxAudioKBitRate_extraInitializers = [];
    var _txVideoKBitRate_decorators;
    var _txVideoKBitRate_initializers = [];
    var _txVideoKBitRate_extraInitializers = [];
    var _rxVideoKBitRate_decorators;
    var _rxVideoKBitRate_initializers = [];
    var _rxVideoKBitRate_extraInitializers = [];
    var _txScreenKBitRate_decorators;
    var _txScreenKBitRate_initializers = [];
    var _txScreenKBitRate_extraInitializers = [];
    var _rxScreenKBitRate_decorators;
    var _rxScreenKBitRate_initializers = [];
    var _rxScreenKBitRate_extraInitializers = [];
    var _users_decorators;
    var _users_initializers = [];
    var _users_extraInitializers = [];
    var _cpuTotalUsage_decorators;
    var _cpuTotalUsage_initializers = [];
    var _cpuTotalUsage_extraInitializers = [];
    var _cpuAppUsage_decorators;
    var _cpuAppUsage_initializers = [];
    var _cpuAppUsage_extraInitializers = [];
    var _txLostrate_decorators;
    var _txLostrate_initializers = [];
    var _txLostrate_extraInitializers = [];
    var _rxLostrate_decorators;
    var _rxLostrate_initializers = [];
    var _rxLostrate_extraInitializers = [];
    var _rtt_decorators;
    var _rtt_initializers = [];
    var _rtt_extraInitializers = [];
    var _txCellularKBitrate_decorators;
    var _txCellularKBitrate_initializers = [];
    var _txCellularKBitrate_extraInitializers = [];
    var _rxCellularKBitrate_decorators;
    var _rxCellularKBitrate_initializers = [];
    var _rxCellularKBitrate_extraInitializers = [];
    var _reset_decorators;
    _classThis = /** @class */ (function () {
        function RTCRoomStats_1() {
            this.totalDuration = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _totalDuration_initializers, void 0));
            this.txBytes = (__runInitializers(this, _totalDuration_extraInitializers), __runInitializers(this, _txBytes_initializers, void 0));
            this.rxBytes = (__runInitializers(this, _txBytes_extraInitializers), __runInitializers(this, _rxBytes_initializers, void 0));
            this.txKBitRate = (__runInitializers(this, _rxBytes_extraInitializers), __runInitializers(this, _txKBitRate_initializers, void 0));
            this.rxKBitRate = (__runInitializers(this, _txKBitRate_extraInitializers), __runInitializers(this, _rxKBitRate_initializers, void 0));
            this.txAudioKBitRate = (__runInitializers(this, _rxKBitRate_extraInitializers), __runInitializers(this, _txAudioKBitRate_initializers, void 0));
            this.rxAudioKBitRate = (__runInitializers(this, _txAudioKBitRate_extraInitializers), __runInitializers(this, _rxAudioKBitRate_initializers, void 0));
            this.txVideoKBitRate = (__runInitializers(this, _rxAudioKBitRate_extraInitializers), __runInitializers(this, _txVideoKBitRate_initializers, void 0));
            this.rxVideoKBitRate = (__runInitializers(this, _txVideoKBitRate_extraInitializers), __runInitializers(this, _rxVideoKBitRate_initializers, void 0));
            this.txScreenKBitRate = (__runInitializers(this, _rxVideoKBitRate_extraInitializers), __runInitializers(this, _txScreenKBitRate_initializers, void 0));
            this.rxScreenKBitRate = (__runInitializers(this, _txScreenKBitRate_extraInitializers), __runInitializers(this, _rxScreenKBitRate_initializers, void 0));
            this.users = (__runInitializers(this, _rxScreenKBitRate_extraInitializers), __runInitializers(this, _users_initializers, void 0));
            this.cpuTotalUsage = (__runInitializers(this, _users_extraInitializers), __runInitializers(this, _cpuTotalUsage_initializers, void 0));
            this.cpuAppUsage = (__runInitializers(this, _cpuTotalUsage_extraInitializers), __runInitializers(this, _cpuAppUsage_initializers, void 0));
            this.txLostrate = (__runInitializers(this, _cpuAppUsage_extraInitializers), __runInitializers(this, _txLostrate_initializers, void 0));
            this.rxLostrate = (__runInitializers(this, _txLostrate_extraInitializers), __runInitializers(this, _rxLostrate_initializers, void 0));
            this.rtt = (__runInitializers(this, _rxLostrate_extraInitializers), __runInitializers(this, _rtt_initializers, void 0));
            this.txCellularKBitrate = (__runInitializers(this, _rtt_extraInitializers), __runInitializers(this, _txCellularKBitrate_initializers, void 0));
            this.rxCellularKBitrate = (__runInitializers(this, _txCellularKBitrate_extraInitializers), __runInitializers(this, _rxCellularKBitrate_initializers, void 0));
            __runInitializers(this, _rxCellularKBitrate_extraInitializers);
        }
        RTCRoomStats_1.prototype.reset = function () {
            throw new Error('not implement');
        };
        return RTCRoomStats_1;
    }());
    __setFunctionName(_classThis, "RTCRoomStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _totalDuration_decorators = [NativeMember()];
        _txBytes_decorators = [NativeMember()];
        _rxBytes_decorators = [NativeMember()];
        _txKBitRate_decorators = [NativeMember()];
        _rxKBitRate_decorators = [NativeMember()];
        _txAudioKBitRate_decorators = [NativeMember()];
        _rxAudioKBitRate_decorators = [NativeMember()];
        _txVideoKBitRate_decorators = [NativeMember()];
        _rxVideoKBitRate_decorators = [NativeMember()];
        _txScreenKBitRate_decorators = [NativeMember()];
        _rxScreenKBitRate_decorators = [NativeMember()];
        _users_decorators = [NativeMember()];
        _cpuTotalUsage_decorators = [NativeMember()];
        _cpuAppUsage_decorators = [NativeMember()];
        _txLostrate_decorators = [NativeMember()];
        _rxLostrate_decorators = [NativeMember()];
        _rtt_decorators = [NativeMember()];
        _txCellularKBitrate_decorators = [NativeMember()];
        _rxCellularKBitrate_decorators = [NativeMember()];
        _reset_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _reset_decorators, { kind: "method", name: "reset", static: false, private: false, access: { has: function (obj) { return "reset" in obj; }, get: function (obj) { return obj.reset; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _totalDuration_decorators, { kind: "field", name: "totalDuration", static: false, private: false, access: { has: function (obj) { return "totalDuration" in obj; }, get: function (obj) { return obj.totalDuration; }, set: function (obj, value) { obj.totalDuration = value; } }, metadata: _metadata }, _totalDuration_initializers, _totalDuration_extraInitializers);
        __esDecorate(null, null, _txBytes_decorators, { kind: "field", name: "txBytes", static: false, private: false, access: { has: function (obj) { return "txBytes" in obj; }, get: function (obj) { return obj.txBytes; }, set: function (obj, value) { obj.txBytes = value; } }, metadata: _metadata }, _txBytes_initializers, _txBytes_extraInitializers);
        __esDecorate(null, null, _rxBytes_decorators, { kind: "field", name: "rxBytes", static: false, private: false, access: { has: function (obj) { return "rxBytes" in obj; }, get: function (obj) { return obj.rxBytes; }, set: function (obj, value) { obj.rxBytes = value; } }, metadata: _metadata }, _rxBytes_initializers, _rxBytes_extraInitializers);
        __esDecorate(null, null, _txKBitRate_decorators, { kind: "field", name: "txKBitRate", static: false, private: false, access: { has: function (obj) { return "txKBitRate" in obj; }, get: function (obj) { return obj.txKBitRate; }, set: function (obj, value) { obj.txKBitRate = value; } }, metadata: _metadata }, _txKBitRate_initializers, _txKBitRate_extraInitializers);
        __esDecorate(null, null, _rxKBitRate_decorators, { kind: "field", name: "rxKBitRate", static: false, private: false, access: { has: function (obj) { return "rxKBitRate" in obj; }, get: function (obj) { return obj.rxKBitRate; }, set: function (obj, value) { obj.rxKBitRate = value; } }, metadata: _metadata }, _rxKBitRate_initializers, _rxKBitRate_extraInitializers);
        __esDecorate(null, null, _txAudioKBitRate_decorators, { kind: "field", name: "txAudioKBitRate", static: false, private: false, access: { has: function (obj) { return "txAudioKBitRate" in obj; }, get: function (obj) { return obj.txAudioKBitRate; }, set: function (obj, value) { obj.txAudioKBitRate = value; } }, metadata: _metadata }, _txAudioKBitRate_initializers, _txAudioKBitRate_extraInitializers);
        __esDecorate(null, null, _rxAudioKBitRate_decorators, { kind: "field", name: "rxAudioKBitRate", static: false, private: false, access: { has: function (obj) { return "rxAudioKBitRate" in obj; }, get: function (obj) { return obj.rxAudioKBitRate; }, set: function (obj, value) { obj.rxAudioKBitRate = value; } }, metadata: _metadata }, _rxAudioKBitRate_initializers, _rxAudioKBitRate_extraInitializers);
        __esDecorate(null, null, _txVideoKBitRate_decorators, { kind: "field", name: "txVideoKBitRate", static: false, private: false, access: { has: function (obj) { return "txVideoKBitRate" in obj; }, get: function (obj) { return obj.txVideoKBitRate; }, set: function (obj, value) { obj.txVideoKBitRate = value; } }, metadata: _metadata }, _txVideoKBitRate_initializers, _txVideoKBitRate_extraInitializers);
        __esDecorate(null, null, _rxVideoKBitRate_decorators, { kind: "field", name: "rxVideoKBitRate", static: false, private: false, access: { has: function (obj) { return "rxVideoKBitRate" in obj; }, get: function (obj) { return obj.rxVideoKBitRate; }, set: function (obj, value) { obj.rxVideoKBitRate = value; } }, metadata: _metadata }, _rxVideoKBitRate_initializers, _rxVideoKBitRate_extraInitializers);
        __esDecorate(null, null, _txScreenKBitRate_decorators, { kind: "field", name: "txScreenKBitRate", static: false, private: false, access: { has: function (obj) { return "txScreenKBitRate" in obj; }, get: function (obj) { return obj.txScreenKBitRate; }, set: function (obj, value) { obj.txScreenKBitRate = value; } }, metadata: _metadata }, _txScreenKBitRate_initializers, _txScreenKBitRate_extraInitializers);
        __esDecorate(null, null, _rxScreenKBitRate_decorators, { kind: "field", name: "rxScreenKBitRate", static: false, private: false, access: { has: function (obj) { return "rxScreenKBitRate" in obj; }, get: function (obj) { return obj.rxScreenKBitRate; }, set: function (obj, value) { obj.rxScreenKBitRate = value; } }, metadata: _metadata }, _rxScreenKBitRate_initializers, _rxScreenKBitRate_extraInitializers);
        __esDecorate(null, null, _users_decorators, { kind: "field", name: "users", static: false, private: false, access: { has: function (obj) { return "users" in obj; }, get: function (obj) { return obj.users; }, set: function (obj, value) { obj.users = value; } }, metadata: _metadata }, _users_initializers, _users_extraInitializers);
        __esDecorate(null, null, _cpuTotalUsage_decorators, { kind: "field", name: "cpuTotalUsage", static: false, private: false, access: { has: function (obj) { return "cpuTotalUsage" in obj; }, get: function (obj) { return obj.cpuTotalUsage; }, set: function (obj, value) { obj.cpuTotalUsage = value; } }, metadata: _metadata }, _cpuTotalUsage_initializers, _cpuTotalUsage_extraInitializers);
        __esDecorate(null, null, _cpuAppUsage_decorators, { kind: "field", name: "cpuAppUsage", static: false, private: false, access: { has: function (obj) { return "cpuAppUsage" in obj; }, get: function (obj) { return obj.cpuAppUsage; }, set: function (obj, value) { obj.cpuAppUsage = value; } }, metadata: _metadata }, _cpuAppUsage_initializers, _cpuAppUsage_extraInitializers);
        __esDecorate(null, null, _txLostrate_decorators, { kind: "field", name: "txLostrate", static: false, private: false, access: { has: function (obj) { return "txLostrate" in obj; }, get: function (obj) { return obj.txLostrate; }, set: function (obj, value) { obj.txLostrate = value; } }, metadata: _metadata }, _txLostrate_initializers, _txLostrate_extraInitializers);
        __esDecorate(null, null, _rxLostrate_decorators, { kind: "field", name: "rxLostrate", static: false, private: false, access: { has: function (obj) { return "rxLostrate" in obj; }, get: function (obj) { return obj.rxLostrate; }, set: function (obj, value) { obj.rxLostrate = value; } }, metadata: _metadata }, _rxLostrate_initializers, _rxLostrate_extraInitializers);
        __esDecorate(null, null, _rtt_decorators, { kind: "field", name: "rtt", static: false, private: false, access: { has: function (obj) { return "rtt" in obj; }, get: function (obj) { return obj.rtt; }, set: function (obj, value) { obj.rtt = value; } }, metadata: _metadata }, _rtt_initializers, _rtt_extraInitializers);
        __esDecorate(null, null, _txCellularKBitrate_decorators, { kind: "field", name: "txCellularKBitrate", static: false, private: false, access: { has: function (obj) { return "txCellularKBitrate" in obj; }, get: function (obj) { return obj.txCellularKBitrate; }, set: function (obj, value) { obj.txCellularKBitrate = value; } }, metadata: _metadata }, _txCellularKBitrate_initializers, _txCellularKBitrate_extraInitializers);
        __esDecorate(null, null, _rxCellularKBitrate_decorators, { kind: "field", name: "rxCellularKBitrate", static: false, private: false, access: { has: function (obj) { return "rxCellularKBitrate" in obj; }, get: function (obj) { return obj.rxCellularKBitrate; }, set: function (obj, value) { obj.rxCellularKBitrate = value; } }, metadata: _metadata }, _rxCellularKBitrate_initializers, _rxCellularKBitrate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioTrackType;
(function (AudioTrackType) {
    AudioTrackType[AudioTrackType["ORIGINAL"] = 1] = "ORIGINAL";
    AudioTrackType[AudioTrackType["ACCOMPANY"] = 2] = "ACCOMPANY";
})(AudioTrackType || (AudioTrackType = {}));
var ProblemFeedbackRoomInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.ProblemFeedbackRoomInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function ProblemFeedbackRoomInfo_1() {
            this.roomId = __runInitializers(this, _roomId_initializers, void 0);
            this.userId = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _userId_initializers, void 0));
            __runInitializers(this, _userId_extraInitializers);
        }
        return ProblemFeedbackRoomInfo_1;
    }());
    __setFunctionName(_classThis, "ProblemFeedbackRoomInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _roomId_decorators = [NativeMember()];
        _userId_decorators = [NativeMember()];
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioSourceType;
(function (AudioSourceType) {
    AudioSourceType[AudioSourceType["AUDIO_SOURCE_TYPE_EXTERNAL"] = 0] = "AUDIO_SOURCE_TYPE_EXTERNAL";
    AudioSourceType[AudioSourceType["AUDIO_SOURCE_TYPE_INTERNAL"] = 1] = "AUDIO_SOURCE_TYPE_INTERNAL";
})(AudioSourceType || (AudioSourceType = {}));
var PerformanceAlarmMode;
(function (PerformanceAlarmMode) {
    PerformanceAlarmMode[PerformanceAlarmMode["NORMAL"] = 0] = "NORMAL";
    PerformanceAlarmMode[PerformanceAlarmMode["SIMULCAST"] = 1] = "SIMULCAST";
})(PerformanceAlarmMode || (PerformanceAlarmMode = {}));
var RecordingErrorCode;
(function (RecordingErrorCode) {
    RecordingErrorCode[RecordingErrorCode["RECORDING_ERROR_CODE_OK"] = 0] = "RECORDING_ERROR_CODE_OK";
    RecordingErrorCode[RecordingErrorCode["RECORDING_ERROR_CODE_NO_PERMISSION"] = -1] = "RECORDING_ERROR_CODE_NO_PERMISSION";
    RecordingErrorCode[RecordingErrorCode["RECORDING_ERROR_CODE_NOT_SUPPORT"] = -2] = "RECORDING_ERROR_CODE_NOT_SUPPORT";
    RecordingErrorCode[RecordingErrorCode["RECORDING_ERROR_CODE_NO_OTHER"] = -3] = "RECORDING_ERROR_CODE_NO_OTHER";
})(RecordingErrorCode || (RecordingErrorCode = {}));
var EchoTestResult;
(function (EchoTestResult) {
    EchoTestResult[EchoTestResult["ECHO_TEST_SUCCESS"] = 0] = "ECHO_TEST_SUCCESS";
    EchoTestResult[EchoTestResult["ECHO_TEST_TIMEOUT"] = 1] = "ECHO_TEST_TIMEOUT";
    EchoTestResult[EchoTestResult["ECHO_TEST_INTERVAL_SHORT"] = 2] = "ECHO_TEST_INTERVAL_SHORT";
    EchoTestResult[EchoTestResult["ECHO_TEST_AUDIO_DEVICE_ERROR"] = 3] = "ECHO_TEST_AUDIO_DEVICE_ERROR";
    EchoTestResult[EchoTestResult["ECHO_TEST_VIDEO_DEVICE_ERROR"] = 4] = "ECHO_TEST_VIDEO_DEVICE_ERROR";
    EchoTestResult[EchoTestResult["ECHO_TEST_AUDIO_RECEIVE_ERROR"] = 5] = "ECHO_TEST_AUDIO_RECEIVE_ERROR";
    EchoTestResult[EchoTestResult["ECHO_TEST_VIDEO_RECEIVE_ERROR"] = 6] = "ECHO_TEST_VIDEO_RECEIVE_ERROR";
    EchoTestResult[EchoTestResult["ECHO_TEST_INTERNAL_ERROR"] = 7] = "ECHO_TEST_INTERNAL_ERROR";
})(EchoTestResult || (EchoTestResult = {}));
var NetworkTimeInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.NetworkTimeInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _timestamp_decorators;
    var _timestamp_initializers = [];
    var _timestamp_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function NetworkTimeInfo_1() {
            this.timestamp = __runInitializers(this, _timestamp_initializers, void 0);
            __runInitializers(this, _timestamp_extraInitializers);
        }
        return NetworkTimeInfo_1;
    }());
    __setFunctionName(_classThis, "NetworkTimeInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _timestamp_decorators = [NativeMember()];
        __esDecorate(null, null, _timestamp_decorators, { kind: "field", name: "timestamp", static: false, private: false, access: { has: function (obj) { return "timestamp" in obj; }, get: function (obj) { return obj.timestamp; }, set: function (obj, value) { obj.timestamp = value; } }, metadata: _metadata }, _timestamp_initializers, _timestamp_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RemoteMirrorType;
(function (RemoteMirrorType) {
    RemoteMirrorType[RemoteMirrorType["NONE"] = 0] = "NONE";
    RemoteMirrorType[RemoteMirrorType["RENDER"] = 1] = "RENDER";
})(RemoteMirrorType || (RemoteMirrorType = {}));
var SubscribeState;
(function (SubscribeState) {
    SubscribeState[SubscribeState["SUBSCRIBE_STATE_SUCCESS"] = 0] = "SUBSCRIBE_STATE_SUCCESS";
    SubscribeState[SubscribeState["SUBSCRIBE_STATE_FAILED_NOT_IN_ROOM"] = 1] = "SUBSCRIBE_STATE_FAILED_NOT_IN_ROOM";
    SubscribeState[SubscribeState["SUBSCRIBE_STATE_FAILED_STREAM_NOT_FOUND"] = 2] = "SUBSCRIBE_STATE_FAILED_STREAM_NOT_FOUND";
    SubscribeState[SubscribeState["SUBSCRIBE_STATE_FAILED_SIGNAL"] = 4] = "SUBSCRIBE_STATE_FAILED_SIGNAL";
})(SubscribeState || (SubscribeState = {}));
var VirtualBackgroundSource$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.VirtualBackgroundSource')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _sourceType_decorators;
    var _sourceType_initializers = [];
    var _sourceType_extraInitializers = [];
    var _sourceColor_decorators;
    var _sourceColor_initializers = [];
    var _sourceColor_extraInitializers = [];
    var _sourcePath_decorators;
    var _sourcePath_initializers = [];
    var _sourcePath_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function VirtualBackgroundSource_1() {
            this.sourceType = __runInitializers(this, _sourceType_initializers, void 0);
            this.sourceColor = (__runInitializers(this, _sourceType_extraInitializers), __runInitializers(this, _sourceColor_initializers, void 0));
            this.sourcePath = (__runInitializers(this, _sourceColor_extraInitializers), __runInitializers(this, _sourcePath_initializers, void 0));
            __runInitializers(this, _sourcePath_extraInitializers);
        }
        return VirtualBackgroundSource_1;
    }());
    __setFunctionName(_classThis, "VirtualBackgroundSource");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _sourceType_decorators = [NativeMember()];
        _sourceColor_decorators = [NativeMember()];
        _sourcePath_decorators = [NativeMember()];
        __esDecorate(null, null, _sourceType_decorators, { kind: "field", name: "sourceType", static: false, private: false, access: { has: function (obj) { return "sourceType" in obj; }, get: function (obj) { return obj.sourceType; }, set: function (obj, value) { obj.sourceType = value; } }, metadata: _metadata }, _sourceType_initializers, _sourceType_extraInitializers);
        __esDecorate(null, null, _sourceColor_decorators, { kind: "field", name: "sourceColor", static: false, private: false, access: { has: function (obj) { return "sourceColor" in obj; }, get: function (obj) { return obj.sourceColor; }, set: function (obj, value) { obj.sourceColor = value; } }, metadata: _metadata }, _sourceColor_initializers, _sourceColor_extraInitializers);
        __esDecorate(null, null, _sourcePath_decorators, { kind: "field", name: "sourcePath", static: false, private: false, access: { has: function (obj) { return "sourcePath" in obj; }, get: function (obj) { return obj.sourcePath; }, set: function (obj, value) { obj.sourcePath = value; } }, metadata: _metadata }, _sourcePath_initializers, _sourcePath_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MixedStreamClientMixConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.MixedStreamConfig.MixedStreamClientMixConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setVideoFormat_decorators;
    var _getVideoFormat_decorators;
    var _setUseAudioMixer_decorators;
    var _getUseAudioMixer_decorators;
    _classThis = /** @class */ (function () {
        function MixedStreamClientMixConfig_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        MixedStreamClientMixConfig_1.prototype.setVideoFormat = function (videoFormat) {
            throw new Error('not implement');
        };
        MixedStreamClientMixConfig_1.prototype.getVideoFormat = function () {
            throw new Error('not implement');
        };
        MixedStreamClientMixConfig_1.prototype.setUseAudioMixer = function (useAudioMixer) {
            throw new Error('not implement');
        };
        MixedStreamClientMixConfig_1.prototype.getUseAudioMixer = function () {
            throw new Error('not implement');
        };
        return MixedStreamClientMixConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamClientMixConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setVideoFormat_decorators = [NativeMethodSync()];
        _getVideoFormat_decorators = [NativeMethodSync()];
        _setUseAudioMixer_decorators = [NativeMethodSync()];
        _getUseAudioMixer_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setVideoFormat_decorators, { kind: "method", name: "setVideoFormat", static: false, private: false, access: { has: function (obj) { return "setVideoFormat" in obj; }, get: function (obj) { return obj.setVideoFormat; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getVideoFormat_decorators, { kind: "method", name: "getVideoFormat", static: false, private: false, access: { has: function (obj) { return "getVideoFormat" in obj; }, get: function (obj) { return obj.getVideoFormat; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setUseAudioMixer_decorators, { kind: "method", name: "setUseAudioMixer", static: false, private: false, access: { has: function (obj) { return "setUseAudioMixer" in obj; }, get: function (obj) { return obj.setUseAudioMixer; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getUseAudioMixer_decorators, { kind: "method", name: "getUseAudioMixer", static: false, private: false, access: { has: function (obj) { return "getUseAudioMixer" in obj; }, get: function (obj) { return obj.getUseAudioMixer; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var PublicStreaming$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.publicstream.PublicStreaming')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _instanceExtraInitializers = [];
    var _static_getDefualtPublicStreaming_decorators;
    var _setRoomId_decorators;
    var _setAction_decorators;
    var _setLayout_decorators;
    var _getLayout_decorators;
    var PublicStreaming = _classThis = /** @class */ (function () {
        function PublicStreaming_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        PublicStreaming_1.getDefualtPublicStreaming = function () {
            throw new Error('not implement');
        };
        PublicStreaming_1.prototype.setRoomId = function (roomId) {
            throw new Error('not implement');
        };
        PublicStreaming_1.prototype.setAction = function (action) {
            throw new Error('not implement');
        };
        PublicStreaming_1.prototype.setLayout = function (layout) {
            throw new Error('not implement');
        };
        PublicStreaming_1.prototype.getLayout = function () {
            throw new Error('not implement');
        };
        return PublicStreaming_1;
    }());
    __setFunctionName(_classThis, "PublicStreaming");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_getDefualtPublicStreaming_decorators = [ReturnClass(function () { return PublicStreaming; }), NativeStaticMethodSync()];
        _setRoomId_decorators = [NativeMethodSync()];
        _setAction_decorators = [NativeMethodSync()];
        _setLayout_decorators = [NativeMethodSync()];
        _getLayout_decorators = [ReturnClass(function () { return Layout; }), NativeMethodSync()];
        __esDecorate(_classThis, null, _static_getDefualtPublicStreaming_decorators, { kind: "method", name: "getDefualtPublicStreaming", static: true, private: false, access: { has: function (obj) { return "getDefualtPublicStreaming" in obj; }, get: function (obj) { return obj.getDefualtPublicStreaming; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _setRoomId_decorators, { kind: "method", name: "setRoomId", static: false, private: false, access: { has: function (obj) { return "setRoomId" in obj; }, get: function (obj) { return obj.setRoomId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAction_decorators, { kind: "method", name: "setAction", static: false, private: false, access: { has: function (obj) { return "setAction" in obj; }, get: function (obj) { return obj.setAction; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLayout_decorators, { kind: "method", name: "setLayout", static: false, private: false, access: { has: function (obj) { return "setLayout" in obj; }, get: function (obj) { return obj.setLayout; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getLayout_decorators, { kind: "method", name: "getLayout", static: false, private: false, access: { has: function (obj) { return "getLayout" in obj; }, get: function (obj) { return obj.getLayout; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        PublicStreaming = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
    })();
    _classThis.ACTION_START = (__runInitializers(_classThis, _staticExtraInitializers), 'started');
    _classThis.ACTION_CHANGED = 'layoutChanged';
    _classThis.ACTION_STOPPED = 'stopped';
    (function () {
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return PublicStreaming = _classThis;
}();
var StreamIndex;
(function (StreamIndex) {
    StreamIndex[StreamIndex["STREAM_INDEX_MAIN"] = 0] = "STREAM_INDEX_MAIN";
    StreamIndex[StreamIndex["STREAM_INDEX_SCREEN"] = 1] = "STREAM_INDEX_SCREEN";
})(StreamIndex || (StreamIndex = {}));
var RemoteAudioStateChangeReason;
(function (RemoteAudioStateChangeReason) {
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_INTERNAL"] = 0] = "REMOTE_AUDIO_STATE_CHANGE_REASON_INTERNAL";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_CONGESTION"] = 1] = "REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_CONGESTION";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_RECOVERY"] = 2] = "REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_RECOVERY";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_MUTED"] = 3] = "REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_MUTED";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_UNMUTED"] = 4] = "REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_UNMUTED";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_MUTED"] = 5] = "REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_MUTED";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_UNMUTED"] = 6] = "REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_UNMUTED";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_OFFLINE"] = 7] = "REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_OFFLINE";
})(RemoteAudioStateChangeReason || (RemoteAudioStateChangeReason = {}));
var PlayerError;
(function (PlayerError) {
    PlayerError[PlayerError["OK"] = 0] = "OK";
    PlayerError[PlayerError["FORMAT_NOT_SUPPORT"] = 1] = "FORMAT_NOT_SUPPORT";
    PlayerError[PlayerError["INVALID_PATH"] = 2] = "INVALID_PATH";
    PlayerError[PlayerError["INVALID_STATE"] = 3] = "INVALID_STATE";
    PlayerError[PlayerError["INVALID_POSITION"] = 4] = "INVALID_POSITION";
    PlayerError[PlayerError["INVALID_VOLUME"] = 5] = "INVALID_VOLUME";
    PlayerError[PlayerError["INVALID_PITCH"] = 6] = "INVALID_PITCH";
    PlayerError[PlayerError["INVALID_AUDIO_TRACK_INDEX"] = 7] = "INVALID_AUDIO_TRACK_INDEX";
    PlayerError[PlayerError["INVALID_PLAYBACK_SPEED"] = 8] = "INVALID_PLAYBACK_SPEED";
    PlayerError[PlayerError["INVALID_EFFECT_ID"] = 9] = "INVALID_EFFECT_ID";
})(PlayerError || (PlayerError = {}));
var ReturnStatus;
(function (ReturnStatus) {
    ReturnStatus[ReturnStatus["RETURN_STATUS_SUCCESS"] = 0] = "RETURN_STATUS_SUCCESS";
    ReturnStatus[ReturnStatus["RETURN_STATUS_FAILURE"] = -1] = "RETURN_STATUS_FAILURE";
    ReturnStatus[ReturnStatus["RETURN_STATUS_PARAMETER_ERR"] = -2] = "RETURN_STATUS_PARAMETER_ERR";
    ReturnStatus[ReturnStatus["RETURN_STATUS_WRONG_STATE"] = -3] = "RETURN_STATUS_WRONG_STATE";
    ReturnStatus[ReturnStatus["RETURN_STATUS_HAS_IN_ROOM"] = -4] = "RETURN_STATUS_HAS_IN_ROOM";
    ReturnStatus[ReturnStatus["RETURN_STATUS_HAS_IN_LOGIN"] = -5] = "RETURN_STATUS_HAS_IN_LOGIN";
    ReturnStatus[ReturnStatus["RETURN_STATUS_HAS_IN_ECHO_TEST"] = -6] = "RETURN_STATUS_HAS_IN_ECHO_TEST";
    ReturnStatus[ReturnStatus["RETURN_STATUS_NEITHER_VIDEO_NOR_AUDIO"] = -7] = "RETURN_STATUS_NEITHER_VIDEO_NOR_AUDIO";
    ReturnStatus[ReturnStatus["RETURN_STATUS_ROOMID_IN_USE"] = -8] = "RETURN_STATUS_ROOMID_IN_USE";
    ReturnStatus[ReturnStatus["RETURN_STATUS_SCREEN_NOT_SUPPORT"] = -9] = "RETURN_STATUS_SCREEN_NOT_SUPPORT";
    ReturnStatus[ReturnStatus["RETURN_STATUS_NOT_SUPPORT"] = -10] = "RETURN_STATUS_NOT_SUPPORT";
    ReturnStatus[ReturnStatus["RETURN_STATUS_RESOURCE_OVERFLOW"] = -11] = "RETURN_STATUS_RESOURCE_OVERFLOW";
    ReturnStatus[ReturnStatus["RETURN_STATUS_VIDEO_NOT_SUPPORT"] = -12] = "RETURN_STATUS_VIDEO_NOT_SUPPORT";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_NO_FRAME"] = -101] = "RETURN_STATUS_AUDIO_NO_FRAME";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_NOT_IMPLEMENTED"] = -102] = "RETURN_STATUS_AUDIO_NOT_IMPLEMENTED";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_NO_PERMISSION"] = -103] = "RETURN_STATUS_AUDIO_NO_PERMISSION";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_DEVICE_NOT_EXISTS"] = -104] = "RETURN_STATUS_AUDIO_DEVICE_NOT_EXISTS";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_DEVICE_FORMAT_NOT_SUPPORT"] = -105] = "RETURN_STATUS_AUDIO_DEVICE_FORMAT_NOT_SUPPORT";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_DEVICE_NO_DEVICE"] = -106] = "RETURN_STATUS_AUDIO_DEVICE_NO_DEVICE";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_DEVICE_CAN_NOT_USE"] = -107] = "RETURN_STATUS_AUDIO_DEVICE_CAN_NOT_USE";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_DEVICE_INIT_FAILED"] = -108] = "RETURN_STATUS_AUDIO_DEVICE_INIT_FAILED";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_DEVICE_START_FAILED"] = -109] = "RETURN_STATUS_AUDIO_DEVICE_START_FAILED";
    ReturnStatus[ReturnStatus["RETURN_STATUS_NATIVE_IN_VALID"] = -201] = "RETURN_STATUS_NATIVE_IN_VALID";
    ReturnStatus[ReturnStatus["RETURN_STATUS_VIDEO_TIMESTAMP_WARNING"] = -202] = "RETURN_STATUS_VIDEO_TIMESTAMP_WARNING";
})(ReturnStatus || (ReturnStatus = {}));
var VideoStreamDescription$VideoCodecType;
(function (VideoStreamDescription$VideoCodecType) {
    VideoStreamDescription$VideoCodecType[VideoStreamDescription$VideoCodecType["CODEC_TYPE_AUTO"] = 0] = "CODEC_TYPE_AUTO";
    VideoStreamDescription$VideoCodecType[VideoStreamDescription$VideoCodecType["CODEC_TYPE_H264"] = 1] = "CODEC_TYPE_H264";
    VideoStreamDescription$VideoCodecType[VideoStreamDescription$VideoCodecType["CODEC_TYPE_BYTEVC1"] = 2] = "CODEC_TYPE_BYTEVC1";
})(VideoStreamDescription$VideoCodecType || (VideoStreamDescription$VideoCodecType = {}));
var ScreenVideoEncoderConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.ScreenVideoEncoderConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _frameRate_decorators;
    var _frameRate_initializers = [];
    var _frameRate_extraInitializers = [];
    var _maxBitrate_decorators;
    var _maxBitrate_initializers = [];
    var _maxBitrate_extraInitializers = [];
    var _minBitrate_decorators;
    var _minBitrate_initializers = [];
    var _minBitrate_extraInitializers = [];
    var _encodePreference_decorators;
    var _encodePreference_initializers = [];
    var _encodePreference_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function ScreenVideoEncoderConfig_1() {
            this.width = __runInitializers(this, _width_initializers, void 0);
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.frameRate = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _frameRate_initializers, void 0));
            this.maxBitrate = (__runInitializers(this, _frameRate_extraInitializers), __runInitializers(this, _maxBitrate_initializers, void 0));
            this.minBitrate = (__runInitializers(this, _maxBitrate_extraInitializers), __runInitializers(this, _minBitrate_initializers, void 0));
            this.encodePreference = (__runInitializers(this, _minBitrate_extraInitializers), __runInitializers(this, _encodePreference_initializers, void 0));
            __runInitializers(this, _encodePreference_extraInitializers);
        }
        return ScreenVideoEncoderConfig_1;
    }());
    __setFunctionName(_classThis, "ScreenVideoEncoderConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _frameRate_decorators = [NativeMember()];
        _maxBitrate_decorators = [NativeMember()];
        _minBitrate_decorators = [NativeMember()];
        _encodePreference_decorators = [NativeMember()];
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _frameRate_decorators, { kind: "field", name: "frameRate", static: false, private: false, access: { has: function (obj) { return "frameRate" in obj; }, get: function (obj) { return obj.frameRate; }, set: function (obj, value) { obj.frameRate = value; } }, metadata: _metadata }, _frameRate_initializers, _frameRate_extraInitializers);
        __esDecorate(null, null, _maxBitrate_decorators, { kind: "field", name: "maxBitrate", static: false, private: false, access: { has: function (obj) { return "maxBitrate" in obj; }, get: function (obj) { return obj.maxBitrate; }, set: function (obj, value) { obj.maxBitrate = value; } }, metadata: _metadata }, _maxBitrate_initializers, _maxBitrate_extraInitializers);
        __esDecorate(null, null, _minBitrate_decorators, { kind: "field", name: "minBitrate", static: false, private: false, access: { has: function (obj) { return "minBitrate" in obj; }, get: function (obj) { return obj.minBitrate; }, set: function (obj, value) { obj.minBitrate = value; } }, metadata: _metadata }, _minBitrate_initializers, _minBitrate_extraInitializers);
        __esDecorate(null, null, _encodePreference_decorators, { kind: "field", name: "encodePreference", static: false, private: false, access: { has: function (obj) { return "encodePreference" in obj; }, get: function (obj) { return obj.encodePreference; }, set: function (obj, value) { obj.encodePreference = value; } }, metadata: _metadata }, _encodePreference_initializers, _encodePreference_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MediaPlayerConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.MediaPlayerConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _type_decorators;
    var _type_initializers = [];
    var _type_extraInitializers = [];
    var _playCount_decorators;
    var _playCount_initializers = [];
    var _playCount_extraInitializers = [];
    var _startPos_decorators;
    var _startPos_initializers = [];
    var _startPos_extraInitializers = [];
    var _callbackOnProgressInterval_decorators;
    var _callbackOnProgressInterval_initializers = [];
    var _callbackOnProgressInterval_extraInitializers = [];
    var _syncProgressToRecordFrame_decorators;
    var _syncProgressToRecordFrame_initializers = [];
    var _syncProgressToRecordFrame_extraInitializers = [];
    var _autoPlay_decorators;
    var _autoPlay_initializers = [];
    var _autoPlay_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function MediaPlayerConfig_1() {
            this.type = __runInitializers(this, _type_initializers, void 0);
            this.playCount = (__runInitializers(this, _type_extraInitializers), __runInitializers(this, _playCount_initializers, void 0));
            this.startPos = (__runInitializers(this, _playCount_extraInitializers), __runInitializers(this, _startPos_initializers, void 0));
            this.callbackOnProgressInterval = (__runInitializers(this, _startPos_extraInitializers), __runInitializers(this, _callbackOnProgressInterval_initializers, void 0));
            this.syncProgressToRecordFrame = (__runInitializers(this, _callbackOnProgressInterval_extraInitializers), __runInitializers(this, _syncProgressToRecordFrame_initializers, void 0));
            this.autoPlay = (__runInitializers(this, _syncProgressToRecordFrame_extraInitializers), __runInitializers(this, _autoPlay_initializers, void 0));
            __runInitializers(this, _autoPlay_extraInitializers);
        }
        return MediaPlayerConfig_1;
    }());
    __setFunctionName(_classThis, "MediaPlayerConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _type_decorators = [NativeMember()];
        _playCount_decorators = [NativeMember()];
        _startPos_decorators = [NativeMember()];
        _callbackOnProgressInterval_decorators = [NativeMember()];
        _syncProgressToRecordFrame_decorators = [NativeMember()];
        _autoPlay_decorators = [NativeMember()];
        __esDecorate(null, null, _type_decorators, { kind: "field", name: "type", static: false, private: false, access: { has: function (obj) { return "type" in obj; }, get: function (obj) { return obj.type; }, set: function (obj, value) { obj.type = value; } }, metadata: _metadata }, _type_initializers, _type_extraInitializers);
        __esDecorate(null, null, _playCount_decorators, { kind: "field", name: "playCount", static: false, private: false, access: { has: function (obj) { return "playCount" in obj; }, get: function (obj) { return obj.playCount; }, set: function (obj, value) { obj.playCount = value; } }, metadata: _metadata }, _playCount_initializers, _playCount_extraInitializers);
        __esDecorate(null, null, _startPos_decorators, { kind: "field", name: "startPos", static: false, private: false, access: { has: function (obj) { return "startPos" in obj; }, get: function (obj) { return obj.startPos; }, set: function (obj, value) { obj.startPos = value; } }, metadata: _metadata }, _startPos_initializers, _startPos_extraInitializers);
        __esDecorate(null, null, _callbackOnProgressInterval_decorators, { kind: "field", name: "callbackOnProgressInterval", static: false, private: false, access: { has: function (obj) { return "callbackOnProgressInterval" in obj; }, get: function (obj) { return obj.callbackOnProgressInterval; }, set: function (obj, value) { obj.callbackOnProgressInterval = value; } }, metadata: _metadata }, _callbackOnProgressInterval_initializers, _callbackOnProgressInterval_extraInitializers);
        __esDecorate(null, null, _syncProgressToRecordFrame_decorators, { kind: "field", name: "syncProgressToRecordFrame", static: false, private: false, access: { has: function (obj) { return "syncProgressToRecordFrame" in obj; }, get: function (obj) { return obj.syncProgressToRecordFrame; }, set: function (obj, value) { obj.syncProgressToRecordFrame = value; } }, metadata: _metadata }, _syncProgressToRecordFrame_initializers, _syncProgressToRecordFrame_extraInitializers);
        __esDecorate(null, null, _autoPlay_decorators, { kind: "field", name: "autoPlay", static: false, private: false, access: { has: function (obj) { return "autoPlay" in obj; }, get: function (obj) { return obj.autoPlay; }, set: function (obj, value) { obj.autoPlay = value; } }, metadata: _metadata }, _autoPlay_initializers, _autoPlay_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoPictureType;
(function (VideoPictureType) {
    VideoPictureType[VideoPictureType["VIDEO_PICTURE_TYPE_UNKNOWN"] = 0] = "VIDEO_PICTURE_TYPE_UNKNOWN";
    VideoPictureType[VideoPictureType["VIDEO_PICTURE_TYPE_I"] = 1] = "VIDEO_PICTURE_TYPE_I";
    VideoPictureType[VideoPictureType["VIDEO_PICTURE_TYPE_P"] = 2] = "VIDEO_PICTURE_TYPE_P";
    VideoPictureType[VideoPictureType["VIDEO_PICTURE_TYPE_B"] = 3] = "VIDEO_PICTURE_TYPE_B";
})(VideoPictureType || (VideoPictureType = {}));
var ColorSpace;
(function (ColorSpace) {
    ColorSpace[ColorSpace["UNKNOWN"] = 0] = "UNKNOWN";
    ColorSpace[ColorSpace["BT601_LIMITED_RANGE"] = 1] = "BT601_LIMITED_RANGE";
    ColorSpace[ColorSpace["BT601_FULL_RANGE"] = 2] = "BT601_FULL_RANGE";
    ColorSpace[ColorSpace["BT709_LIMITED_RANGE"] = 3] = "BT709_LIMITED_RANGE";
    ColorSpace[ColorSpace["BT709_FULL_RANGE"] = 4] = "BT709_FULL_RANGE";
})(ColorSpace || (ColorSpace = {}));
var AudioPropertiesInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.AudioPropertiesInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _linearVolume_decorators;
    var _linearVolume_initializers = [];
    var _linearVolume_extraInitializers = [];
    var _nonlinearVolume_decorators;
    var _nonlinearVolume_initializers = [];
    var _nonlinearVolume_extraInitializers = [];
    var _spectrum_decorators;
    var _spectrum_initializers = [];
    var _spectrum_extraInitializers = [];
    var _vad_decorators;
    var _vad_initializers = [];
    var _vad_extraInitializers = [];
    var _voicePitch_decorators;
    var _voicePitch_initializers = [];
    var _voicePitch_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function AudioPropertiesInfo_1(linearVolume, nonlinearVolume, spectrum, vad) {
            this.linearVolume = __runInitializers(this, _linearVolume_initializers, void 0);
            this.nonlinearVolume = (__runInitializers(this, _linearVolume_extraInitializers), __runInitializers(this, _nonlinearVolume_initializers, void 0));
            this.spectrum = (__runInitializers(this, _nonlinearVolume_extraInitializers), __runInitializers(this, _spectrum_initializers, void 0));
            this.vad = (__runInitializers(this, _spectrum_extraInitializers), __runInitializers(this, _vad_initializers, void 0));
            this.voicePitch = (__runInitializers(this, _vad_extraInitializers), __runInitializers(this, _voicePitch_initializers, void 0));
            __runInitializers(this, _voicePitch_extraInitializers);
        }
        return AudioPropertiesInfo_1;
    }());
    __setFunctionName(_classThis, "AudioPropertiesInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _linearVolume_decorators = [NativeMember()];
        _nonlinearVolume_decorators = [NativeMember()];
        _spectrum_decorators = [NativeMember()];
        _vad_decorators = [NativeMember()];
        _voicePitch_decorators = [NativeMember()];
        __esDecorate(null, null, _linearVolume_decorators, { kind: "field", name: "linearVolume", static: false, private: false, access: { has: function (obj) { return "linearVolume" in obj; }, get: function (obj) { return obj.linearVolume; }, set: function (obj, value) { obj.linearVolume = value; } }, metadata: _metadata }, _linearVolume_initializers, _linearVolume_extraInitializers);
        __esDecorate(null, null, _nonlinearVolume_decorators, { kind: "field", name: "nonlinearVolume", static: false, private: false, access: { has: function (obj) { return "nonlinearVolume" in obj; }, get: function (obj) { return obj.nonlinearVolume; }, set: function (obj, value) { obj.nonlinearVolume = value; } }, metadata: _metadata }, _nonlinearVolume_initializers, _nonlinearVolume_extraInitializers);
        __esDecorate(null, null, _spectrum_decorators, { kind: "field", name: "spectrum", static: false, private: false, access: { has: function (obj) { return "spectrum" in obj; }, get: function (obj) { return obj.spectrum; }, set: function (obj, value) { obj.spectrum = value; } }, metadata: _metadata }, _spectrum_initializers, _spectrum_extraInitializers);
        __esDecorate(null, null, _vad_decorators, { kind: "field", name: "vad", static: false, private: false, access: { has: function (obj) { return "vad" in obj; }, get: function (obj) { return obj.vad; }, set: function (obj, value) { obj.vad = value; } }, metadata: _metadata }, _vad_initializers, _vad_extraInitializers);
        __esDecorate(null, null, _voicePitch_decorators, { kind: "field", name: "voicePitch", static: false, private: false, access: { has: function (obj) { return "voicePitch" in obj; }, get: function (obj) { return obj.voicePitch; }, set: function (obj, value) { obj.voicePitch = value; } }, metadata: _metadata }, _voicePitch_initializers, _voicePitch_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
    })();
    _classThis.SPECTRUM_SIZE = 257;
    (function () {
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RemoteVideoState;
(function (RemoteVideoState) {
    RemoteVideoState[RemoteVideoState["REMOTE_VIDEO_STATE_STOPPED"] = 0] = "REMOTE_VIDEO_STATE_STOPPED";
    RemoteVideoState[RemoteVideoState["REMOTE_VIDEO_STATE_STARTING"] = 1] = "REMOTE_VIDEO_STATE_STARTING";
    RemoteVideoState[RemoteVideoState["REMOTE_VIDEO_STATE_DECODING"] = 2] = "REMOTE_VIDEO_STATE_DECODING";
    RemoteVideoState[RemoteVideoState["REMOTE_VIDEO_STATE_FROZEN"] = 3] = "REMOTE_VIDEO_STATE_FROZEN";
})(RemoteVideoState || (RemoteVideoState = {}));
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.VideoEncoderConfiguration')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _dimensions_decorators;
    var _dimensions_initializers = [];
    var _dimensions_extraInitializers = [];
    var _kBitrate_decorators;
    var _kBitrate_initializers = [];
    var _kBitrate_extraInitializers = [];
    var _kMinBitrate_decorators;
    var _kMinBitrate_initializers = [];
    var _kMinBitrate_extraInitializers = [];
    var _orientationMode_decorators;
    var _orientationMode_initializers = [];
    var _orientationMode_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function VideoEncoderConfiguration_1() {
            this.dimensions = __runInitializers(this, _dimensions_initializers, void 0);
            this.kBitrate = (__runInitializers(this, _dimensions_extraInitializers), __runInitializers(this, _kBitrate_initializers, void 0));
            this.kMinBitrate = (__runInitializers(this, _kBitrate_extraInitializers), __runInitializers(this, _kMinBitrate_initializers, void 0));
            this.orientationMode = (__runInitializers(this, _kMinBitrate_extraInitializers), __runInitializers(this, _orientationMode_initializers, void 0));
            __runInitializers(this, _orientationMode_extraInitializers);
        }
        return VideoEncoderConfiguration_1;
    }());
    __setFunctionName(_classThis, "VideoEncoderConfiguration");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _dimensions_decorators = [NativeMember()];
        _kBitrate_decorators = [NativeMember()];
        _kMinBitrate_decorators = [NativeMember()];
        _orientationMode_decorators = [NativeMember()];
        __esDecorate(null, null, _dimensions_decorators, { kind: "field", name: "dimensions", static: false, private: false, access: { has: function (obj) { return "dimensions" in obj; }, get: function (obj) { return obj.dimensions; }, set: function (obj, value) { obj.dimensions = value; } }, metadata: _metadata }, _dimensions_initializers, _dimensions_extraInitializers);
        __esDecorate(null, null, _kBitrate_decorators, { kind: "field", name: "kBitrate", static: false, private: false, access: { has: function (obj) { return "kBitrate" in obj; }, get: function (obj) { return obj.kBitrate; }, set: function (obj, value) { obj.kBitrate = value; } }, metadata: _metadata }, _kBitrate_initializers, _kBitrate_extraInitializers);
        __esDecorate(null, null, _kMinBitrate_decorators, { kind: "field", name: "kMinBitrate", static: false, private: false, access: { has: function (obj) { return "kMinBitrate" in obj; }, get: function (obj) { return obj.kMinBitrate; }, set: function (obj, value) { obj.kMinBitrate = value; } }, metadata: _metadata }, _kMinBitrate_initializers, _kMinBitrate_extraInitializers);
        __esDecorate(null, null, _orientationMode_decorators, { kind: "field", name: "orientationMode", static: false, private: false, access: { has: function (obj) { return "orientationMode" in obj; }, get: function (obj) { return obj.orientationMode; }, set: function (obj, value) { obj.orientationMode = value; } }, metadata: _metadata }, _orientationMode_initializers, _orientationMode_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.IVideoSink.PixelFormat')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function PixelFormat_1() {
        }
        return PixelFormat_1;
    }());
    __setFunctionName(_classThis, "PixelFormat");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
    })();
    _classThis.Original = 0;
    _classThis.I420 = 1;
    _classThis.RGBA = 5;
    (function () {
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var HardwareEchoDetectionResult;
(function (HardwareEchoDetectionResult) {
    HardwareEchoDetectionResult[HardwareEchoDetectionResult["HARDWARE_ECHO_RESULT_CANCELED"] = 0] = "HARDWARE_ECHO_RESULT_CANCELED";
    HardwareEchoDetectionResult[HardwareEchoDetectionResult["HARDWARE_ECHO_RESULT_UNKNOWN"] = 1] = "HARDWARE_ECHO_RESULT_UNKNOWN";
    HardwareEchoDetectionResult[HardwareEchoDetectionResult["HARDWARE_ECHO_RESULT_NORMAL"] = 2] = "HARDWARE_ECHO_RESULT_NORMAL";
    HardwareEchoDetectionResult[HardwareEchoDetectionResult["HARDWARE_ECHO_RESULT_POOR"] = 3] = "HARDWARE_ECHO_RESULT_POOR";
})(HardwareEchoDetectionResult || (HardwareEchoDetectionResult = {}));
var SubscribeVideoConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.SubscribeVideoConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function SubscribeVideoConfig_1(videoIndex, priority) {
        }
        return SubscribeVideoConfig_1;
    }());
    __setFunctionName(_classThis, "SubscribeVideoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RecordingState;
(function (RecordingState) {
    RecordingState[RecordingState["RECORDING_STATE_ERROE"] = 0] = "RECORDING_STATE_ERROE";
    RecordingState[RecordingState["RECORDING_STATE_PROCESSING"] = 1] = "RECORDING_STATE_PROCESSING";
    RecordingState[RecordingState["RECORDING_STATE_SUCCESS"] = 2] = "RECORDING_STATE_SUCCESS";
})(RecordingState || (RecordingState = {}));
var NetworkDetectionLinkType;
(function (NetworkDetectionLinkType) {
    NetworkDetectionLinkType[NetworkDetectionLinkType["UP"] = 0] = "UP";
    NetworkDetectionLinkType[NetworkDetectionLinkType["DOWN"] = 1] = "DOWN";
})(NetworkDetectionLinkType || (NetworkDetectionLinkType = {}));
var RTCStream$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.RTCStream')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _static_create_decorators;
    var _static_createWithStreamDescriptions_decorators;
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _hasVideo_decorators;
    var _hasVideo_initializers = [];
    var _hasVideo_extraInitializers = [];
    var _hasAudio_decorators;
    var _hasAudio_initializers = [];
    var _hasAudio_extraInitializers = [];
    var _videoStreamDescriptions_decorators;
    var _videoStreamDescriptions_initializers = [];
    var _videoStreamDescriptions_extraInitializers = [];
    var RTCStream = _classThis = /** @class */ (function () {
        function RTCStream_1() {
            this.userId = __runInitializers(this, _userId_initializers, void 0);
            this.isScreen = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.hasVideo = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _hasVideo_initializers, void 0));
            this.hasAudio = (__runInitializers(this, _hasVideo_extraInitializers), __runInitializers(this, _hasAudio_initializers, void 0));
            this.videoStreamDescriptions = (__runInitializers(this, _hasAudio_extraInitializers), __runInitializers(this, _videoStreamDescriptions_initializers, void 0));
            __runInitializers(this, _videoStreamDescriptions_extraInitializers);
        }
        RTCStream_1.create = function (userId, streamIndex, isScreen, hasVideo, hasAudio) {
            throw new Error('not implement');
        };
        RTCStream_1.createWithStreamDescriptions = function (userId, streamIndex, isScreen, hasVideo, hasAudio, videoStreamDescriptions) {
            throw new Error('not implement');
        };
        return RTCStream_1;
    }());
    __setFunctionName(_classThis, "RTCStream");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_create_decorators = [ReturnClass(function () { return RTCStream; }), NativeStaticMethodSync()];
        _static_createWithStreamDescriptions_decorators = [ReturnClass(function () { return RTCStream; }), NativeStaticMethodSync()];
        _userId_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _hasVideo_decorators = [NativeMember()];
        _hasAudio_decorators = [NativeMember()];
        _videoStreamDescriptions_decorators = [NativeMember()];
        __esDecorate(_classThis, null, _static_create_decorators, { kind: "method", name: "create", static: true, private: false, access: { has: function (obj) { return "create" in obj; }, get: function (obj) { return obj.create; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _static_createWithStreamDescriptions_decorators, { kind: "method", name: "createWithStreamDescriptions", static: true, private: false, access: { has: function (obj) { return "createWithStreamDescriptions" in obj; }, get: function (obj) { return obj.createWithStreamDescriptions; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _hasVideo_decorators, { kind: "field", name: "hasVideo", static: false, private: false, access: { has: function (obj) { return "hasVideo" in obj; }, get: function (obj) { return obj.hasVideo; }, set: function (obj, value) { obj.hasVideo = value; } }, metadata: _metadata }, _hasVideo_initializers, _hasVideo_extraInitializers);
        __esDecorate(null, null, _hasAudio_decorators, { kind: "field", name: "hasAudio", static: false, private: false, access: { has: function (obj) { return "hasAudio" in obj; }, get: function (obj) { return obj.hasAudio; }, set: function (obj, value) { obj.hasAudio = value; } }, metadata: _metadata }, _hasAudio_initializers, _hasAudio_extraInitializers);
        __esDecorate(null, null, _videoStreamDescriptions_decorators, { kind: "field", name: "videoStreamDescriptions", static: false, private: false, access: { has: function (obj) { return "videoStreamDescriptions" in obj; }, get: function (obj) { return obj.videoStreamDescriptions; }, set: function (obj, value) { obj.videoStreamDescriptions = value; } }, metadata: _metadata }, _videoStreamDescriptions_initializers, _videoStreamDescriptions_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        RTCStream = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _staticExtraInitializers);
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return RTCStream = _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.ByteWatermark')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _x_decorators;
    var _x_initializers = [];
    var _x_extraInitializers = [];
    var _y_decorators;
    var _y_initializers = [];
    var _y_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function ByteWatermark_1() {
            this.x = __runInitializers(this, _x_initializers, void 0);
            this.y = (__runInitializers(this, _x_extraInitializers), __runInitializers(this, _y_initializers, void 0));
            this.width = (__runInitializers(this, _y_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            __runInitializers(this, _height_extraInitializers);
        }
        return ByteWatermark_1;
    }());
    __setFunctionName(_classThis, "ByteWatermark");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _x_decorators = [NativeMember()];
        _y_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        __esDecorate(null, null, _x_decorators, { kind: "field", name: "x", static: false, private: false, access: { has: function (obj) { return "x" in obj; }, get: function (obj) { return obj.x; }, set: function (obj, value) { obj.x = value; } }, metadata: _metadata }, _x_initializers, _x_extraInitializers);
        __esDecorate(null, null, _y_decorators, { kind: "field", name: "y", static: false, private: false, access: { has: function (obj) { return "y" in obj; }, get: function (obj) { return obj.y; }, set: function (obj, value) { obj.y = value; } }, metadata: _metadata }, _y_initializers, _y_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var VideoDenoiseModeChangedReason;
(function (VideoDenoiseModeChangedReason) {
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_NULL"] = -1] = "VIDEO_DENOISE_MODE_CHANGED_REASON_NULL";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_API_OFF"] = 0] = "VIDEO_DENOISE_MODE_CHANGED_REASON_API_OFF";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_API_ON"] = 1] = "VIDEO_DENOISE_MODE_CHANGED_REASON_API_ON";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_DISABLED"] = 2] = "VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_DISABLED";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_ENABLED"] = 3] = "VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_ENABLED";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_INTERNAL_EXCEPTION"] = 4] = "VIDEO_DENOISE_MODE_CHANGED_REASON_INTERNAL_EXCEPTION";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_CLOSE"] = 5] = "VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_CLOSE";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_OPEN"] = 6] = "VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_OPEN";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_RESOLUTION"] = 7] = "VIDEO_DENOISE_MODE_CHANGED_REASON_RESOLUTION";
})(VideoDenoiseModeChangedReason || (VideoDenoiseModeChangedReason = {}));
var AudioDeviceType;
(function (AudioDeviceType) {
    AudioDeviceType[AudioDeviceType["AUDIO_DEVICE_TYPE_UNKNOWN"] = -1] = "AUDIO_DEVICE_TYPE_UNKNOWN";
    AudioDeviceType[AudioDeviceType["AUDIO_DEVICE_TYPE_RENDER_DEVICE"] = 0] = "AUDIO_DEVICE_TYPE_RENDER_DEVICE";
    AudioDeviceType[AudioDeviceType["AUDIO_DEVICE_TYPE_CAPTURE_DEVICE"] = 1] = "AUDIO_DEVICE_TYPE_CAPTURE_DEVICE";
    AudioDeviceType[AudioDeviceType["AUDIO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE"] = 2] = "AUDIO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE";
})(AudioDeviceType || (AudioDeviceType = {}));
var SetRoomExtraInfoResult;
(function (SetRoomExtraInfoResult) {
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["SUCCESS"] = 0] = "SUCCESS";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["NOT_JOIN_ROOM"] = -1] = "NOT_JOIN_ROOM";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["KEY_IS_NULL"] = -2] = "KEY_IS_NULL";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["VALUE_IS_NULL"] = -3] = "VALUE_IS_NULL";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["UNKNOW"] = -99] = "UNKNOW";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["KEY_IS_EMPTY"] = -400] = "KEY_IS_EMPTY";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["TOO_OFTEN"] = -406] = "TOO_OFTEN";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["SILENT_USER"] = -412] = "SILENT_USER";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["KEY_TOO_LONG"] = -413] = "KEY_TOO_LONG";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["VALUE_TOO_LONG"] = -414] = "VALUE_TOO_LONG";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["SERVER_ERROR"] = -500] = "SERVER_ERROR";
})(SetRoomExtraInfoResult || (SetRoomExtraInfoResult = {}));
var LocalProxyState;
(function (LocalProxyState) {
    LocalProxyState[LocalProxyState["INITED"] = 0] = "INITED";
    LocalProxyState[LocalProxyState["CONNECTED"] = 1] = "CONNECTED";
    LocalProxyState[LocalProxyState["ERROR"] = 2] = "ERROR";
})(LocalProxyState || (LocalProxyState = {}));
var AVSyncState;
(function (AVSyncState) {
    AVSyncState[AVSyncState["AV_SYNC_STATE_STREAM_SYNC_BEGIN"] = 0] = "AV_SYNC_STATE_STREAM_SYNC_BEGIN";
    AVSyncState[AVSyncState["AV_SYNC_STATE_AUDIO_STREAM_REMOVE"] = 1] = "AV_SYNC_STATE_AUDIO_STREAM_REMOVE";
    AVSyncState[AVSyncState["AV_SYNC_STATE_VIDEO_STREAM_REMOVE"] = 2] = "AV_SYNC_STATE_VIDEO_STREAM_REMOVE";
})(AVSyncState || (AVSyncState = {}));
var RTCRoomConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.RTCRoomConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _profile_decorators;
    var _profile_initializers = [];
    var _profile_extraInitializers = [];
    var _isAutoPublish_decorators;
    var _isAutoPublish_initializers = [];
    var _isAutoPublish_extraInitializers = [];
    var _isAutoSubscribeAudio_decorators;
    var _isAutoSubscribeAudio_initializers = [];
    var _isAutoSubscribeAudio_extraInitializers = [];
    var _isAutoSubscribeVideo_decorators;
    var _isAutoSubscribeVideo_initializers = [];
    var _isAutoSubscribeVideo_extraInitializers = [];
    var _remoteVideoConfig_decorators;
    var _remoteVideoConfig_initializers = [];
    var _remoteVideoConfig_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RTCRoomConfig_1() {
            this.profile = __runInitializers(this, _profile_initializers, void 0);
            this.isAutoPublish = (__runInitializers(this, _profile_extraInitializers), __runInitializers(this, _isAutoPublish_initializers, void 0));
            this.isAutoSubscribeAudio = (__runInitializers(this, _isAutoPublish_extraInitializers), __runInitializers(this, _isAutoSubscribeAudio_initializers, void 0));
            this.isAutoSubscribeVideo = (__runInitializers(this, _isAutoSubscribeAudio_extraInitializers), __runInitializers(this, _isAutoSubscribeVideo_initializers, void 0));
            this.remoteVideoConfig = (__runInitializers(this, _isAutoSubscribeVideo_extraInitializers), __runInitializers(this, _remoteVideoConfig_initializers, void 0));
            __runInitializers(this, _remoteVideoConfig_extraInitializers);
        }
        return RTCRoomConfig_1;
    }());
    __setFunctionName(_classThis, "RTCRoomConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _profile_decorators = [NativeMember()];
        _isAutoPublish_decorators = [NativeMember()];
        _isAutoSubscribeAudio_decorators = [NativeMember()];
        _isAutoSubscribeVideo_decorators = [NativeMember()];
        _remoteVideoConfig_decorators = [NativeMember()];
        __esDecorate(null, null, _profile_decorators, { kind: "field", name: "profile", static: false, private: false, access: { has: function (obj) { return "profile" in obj; }, get: function (obj) { return obj.profile; }, set: function (obj, value) { obj.profile = value; } }, metadata: _metadata }, _profile_initializers, _profile_extraInitializers);
        __esDecorate(null, null, _isAutoPublish_decorators, { kind: "field", name: "isAutoPublish", static: false, private: false, access: { has: function (obj) { return "isAutoPublish" in obj; }, get: function (obj) { return obj.isAutoPublish; }, set: function (obj, value) { obj.isAutoPublish = value; } }, metadata: _metadata }, _isAutoPublish_initializers, _isAutoPublish_extraInitializers);
        __esDecorate(null, null, _isAutoSubscribeAudio_decorators, { kind: "field", name: "isAutoSubscribeAudio", static: false, private: false, access: { has: function (obj) { return "isAutoSubscribeAudio" in obj; }, get: function (obj) { return obj.isAutoSubscribeAudio; }, set: function (obj, value) { obj.isAutoSubscribeAudio = value; } }, metadata: _metadata }, _isAutoSubscribeAudio_initializers, _isAutoSubscribeAudio_extraInitializers);
        __esDecorate(null, null, _isAutoSubscribeVideo_decorators, { kind: "field", name: "isAutoSubscribeVideo", static: false, private: false, access: { has: function (obj) { return "isAutoSubscribeVideo" in obj; }, get: function (obj) { return obj.isAutoSubscribeVideo; }, set: function (obj, value) { obj.isAutoSubscribeVideo = value; } }, metadata: _metadata }, _isAutoSubscribeVideo_initializers, _isAutoSubscribeVideo_extraInitializers);
        __esDecorate(null, null, _remoteVideoConfig_decorators, { kind: "field", name: "remoteVideoConfig", static: false, private: false, access: { has: function (obj) { return "remoteVideoConfig" in obj; }, get: function (obj) { return obj.remoteVideoConfig; }, set: function (obj, value) { obj.remoteVideoConfig = value; } }, metadata: _metadata }, _remoteVideoConfig_initializers, _remoteVideoConfig_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var SVCLayer;
(function (SVCLayer) {
    SVCLayer[SVCLayer["DEFAULT"] = 0] = "DEFAULT";
    SVCLayer[SVCLayer["BASE"] = 1] = "BASE";
    SVCLayer[SVCLayer["MAIN"] = 2] = "MAIN";
    SVCLayer[SVCLayer["HIGH"] = 3] = "HIGH";
    SVCLayer[SVCLayer["value"] = 0] = "value";
})(SVCLayer || (SVCLayer = {}));
var Rectangle$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.Rectangle')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _x_decorators;
    var _x_initializers = [];
    var _x_extraInitializers = [];
    var _y_decorators;
    var _y_initializers = [];
    var _y_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function Rectangle_1(x, y, w, h) {
            this.x = __runInitializers(this, _x_initializers, void 0);
            this.y = (__runInitializers(this, _x_extraInitializers), __runInitializers(this, _y_initializers, void 0));
            this.width = (__runInitializers(this, _y_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            __runInitializers(this, _height_extraInitializers);
        }
        return Rectangle_1;
    }());
    __setFunctionName(_classThis, "Rectangle");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _x_decorators = [NativeMember()];
        _y_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        __esDecorate(null, null, _x_decorators, { kind: "field", name: "x", static: false, private: false, access: { has: function (obj) { return "x" in obj; }, get: function (obj) { return obj.x; }, set: function (obj, value) { obj.x = value; } }, metadata: _metadata }, _x_initializers, _x_extraInitializers);
        __esDecorate(null, null, _y_decorators, { kind: "field", name: "y", static: false, private: false, access: { has: function (obj) { return "y" in obj; }, get: function (obj) { return obj.y; }, set: function (obj, value) { obj.y = value; } }, metadata: _metadata }, _y_initializers, _y_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MixedStreamClientMixVideoFormat;
(function (MixedStreamClientMixVideoFormat) {
    MixedStreamClientMixVideoFormat[MixedStreamClientMixVideoFormat["MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_I420"] = 0] = "MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_I420";
    MixedStreamClientMixVideoFormat[MixedStreamClientMixVideoFormat["MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_TEXTURE_2D"] = 1] = "MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_TEXTURE_2D";
    MixedStreamClientMixVideoFormat[MixedStreamClientMixVideoFormat["MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_CVPIXEL_BUFFER_BGRA"] = 2] = "MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_CVPIXEL_BUFFER_BGRA";
    MixedStreamClientMixVideoFormat[MixedStreamClientMixVideoFormat["MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_NV12"] = 3] = "MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_NV12";
})(MixedStreamClientMixVideoFormat || (MixedStreamClientMixVideoFormat = {}));
var VideoRotationMode;
(function (VideoRotationMode) {
    VideoRotationMode[VideoRotationMode["FOLLOW_APP"] = 0] = "FOLLOW_APP";
    VideoRotationMode[VideoRotationMode["FOLLOW_GSENSOR"] = 1] = "FOLLOW_GSENSOR";
})(VideoRotationMode || (VideoRotationMode = {}));
var PlayerState;
(function (PlayerState) {
    PlayerState[PlayerState["IDLE"] = 0] = "IDLE";
    PlayerState[PlayerState["PRELOADED"] = 1] = "PRELOADED";
    PlayerState[PlayerState["OPENED"] = 2] = "OPENED";
    PlayerState[PlayerState["PLAYING"] = 3] = "PLAYING";
    PlayerState[PlayerState["PAUSED"] = 4] = "PAUSED";
    PlayerState[PlayerState["STOPPED"] = 5] = "STOPPED";
    PlayerState[PlayerState["FAILED"] = 6] = "FAILED";
    PlayerState[PlayerState["FINISHED"] = 7] = "FINISHED";
})(PlayerState || (PlayerState = {}));
var MixedStreamVideoType;
(function (MixedStreamVideoType) {
    MixedStreamVideoType[MixedStreamVideoType["MIXED_STREAM_VIDEO_TYPE_MAIN"] = 0] = "MIXED_STREAM_VIDEO_TYPE_MAIN";
    MixedStreamVideoType[MixedStreamVideoType["MIXED_STREAM_VIDEO_TYPE_SCREEN"] = 1] = "MIXED_STREAM_VIDEO_TYPE_SCREEN";
})(MixedStreamVideoType || (MixedStreamVideoType = {}));
var MixedStreamLayoutRegionConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.MixedStreamConfig$MixedStreamLayoutRegionConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setRoomID_decorators;
    var _getRoomID_decorators;
    var _setUserID_decorators;
    var _getUserID_decorators;
    var _setLocationX_decorators;
    var _getLocationX_decorators;
    var _setLocationY_decorators;
    var _getLocationY_decorators;
    var _setWidth_decorators;
    var _getWidth_decorators;
    var _setHeight_decorators;
    var _getHeight_decorators;
    var _setZOrder_decorators;
    var _getZOrder_decorators;
    var _setAlpha_decorators;
    var _getAlpha_decorators;
    var _setCornerRadius_decorators;
    var _getCornerRadius_decorators;
    var _setMediaType_decorators;
    var _getMediaType_decorators;
    var _setRegionContentType_decorators;
    var _getRegionContentType_decorators;
    var _setRenderMode_decorators;
    var _getRenderMode_decorators;
    var _getIsLocalUser_decorators;
    var _setIsLocalUser_decorators;
    var _setStreamType_decorators;
    var _getStreamType_decorators;
    var _setImageWaterMark_decorators;
    var _getImageWaterMark_decorators;
    var _setImageWaterMarkConfig_decorators;
    var _getImageWaterMarkConfig_decorators;
    var _setAlternateImageFillMode_decorators;
    var _getAlternateImageFillMode_decorators;
    var _setAlternateImageURL_decorators;
    var _getAlternateImageURL_decorators;
    var _setSpatialPosition_decorators;
    var _getSpatialPosition_decorators;
    var _setApplySpatialAudio_decorators;
    var _getApplySpatialAudio_decorators;
    _classThis = /** @class */ (function () {
        function MixedStreamLayoutRegionConfig_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        MixedStreamLayoutRegionConfig_1.prototype.setRoomID = function (roomID) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getRoomID = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setUserID = function (userID) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getUserID = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setLocationX = function (locationX) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getLocationX = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setLocationY = function (locationY) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getLocationY = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setWidth = function (width) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getWidth = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setHeight = function (height) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getHeight = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setZOrder = function (zOrder) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getZOrder = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setAlpha = function (alpha) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getAlpha = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setCornerRadius = function (cornerRadius) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getCornerRadius = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setMediaType = function (mediaType) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getMediaType = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setRegionContentType = function (regionContentType) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getRegionContentType = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setRenderMode = function (renderMode) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getRenderMode = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getIsLocalUser = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setIsLocalUser = function (islocalUser) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setStreamType = function (streamType) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getStreamType = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setImageWaterMark = function (imageWaterMark) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getImageWaterMark = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setImageWaterMarkConfig = function (imageWaterMarkConfig) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getImageWaterMarkConfig = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setAlternateImageFillMode = function (alternateImageFillMode) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getAlternateImageFillMode = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setAlternateImageURL = function (alternateImageUrl) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getAlternateImageURL = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setSpatialPosition = function (spatialPosition) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getSpatialPosition = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.setApplySpatialAudio = function (applySpatialAudio) {
            throw new Error('not implement');
        };
        MixedStreamLayoutRegionConfig_1.prototype.getApplySpatialAudio = function () {
            throw new Error('not implement');
        };
        return MixedStreamLayoutRegionConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamLayoutRegionConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setRoomID_decorators = [NativeMethodSync()];
        _getRoomID_decorators = [NativeMethodSync()];
        _setUserID_decorators = [NativeMethodSync()];
        _getUserID_decorators = [NativeMethodSync()];
        _setLocationX_decorators = [NativeMethodSync()];
        _getLocationX_decorators = [NativeMethodSync()];
        _setLocationY_decorators = [NativeMethodSync()];
        _getLocationY_decorators = [NativeMethodSync()];
        _setWidth_decorators = [NativeMethodSync()];
        _getWidth_decorators = [NativeMethodSync()];
        _setHeight_decorators = [NativeMethodSync()];
        _getHeight_decorators = [NativeMethodSync()];
        _setZOrder_decorators = [NativeMethodSync()];
        _getZOrder_decorators = [NativeMethodSync()];
        _setAlpha_decorators = [NativeMethodSync()];
        _getAlpha_decorators = [NativeMethodSync()];
        _setCornerRadius_decorators = [NativeMethodSync()];
        _getCornerRadius_decorators = [NativeMethodSync()];
        _setMediaType_decorators = [NativeMethodSync()];
        _getMediaType_decorators = [NativeMethodSync()];
        _setRegionContentType_decorators = [NativeMethodSync()];
        _getRegionContentType_decorators = [NativeMethodSync()];
        _setRenderMode_decorators = [NativeMethodSync()];
        _getRenderMode_decorators = [NativeMethodSync()];
        _getIsLocalUser_decorators = [NativeMethodSync()];
        _setIsLocalUser_decorators = [NativeMethodSync()];
        _setStreamType_decorators = [NativeMethodSync()];
        _getStreamType_decorators = [NativeMethodSync()];
        _setImageWaterMark_decorators = [NativeMethodSync()];
        _getImageWaterMark_decorators = [NativeMethodSync()];
        _setImageWaterMarkConfig_decorators = [NativeMethodSync()];
        _getImageWaterMarkConfig_decorators = [ReturnClass(function () { return MixedStreamLayoutRegionImageWaterMarkConfig$1; }), NativeMethodSync()];
        _setAlternateImageFillMode_decorators = [NativeMethodSync()];
        _getAlternateImageFillMode_decorators = [NativeMethodSync()];
        _setAlternateImageURL_decorators = [NativeMethodSync()];
        _getAlternateImageURL_decorators = [NativeMethodSync()];
        _setSpatialPosition_decorators = [NativeMethodSync()];
        _getSpatialPosition_decorators = [ReturnClass(function () { return Position$1; }), NativeMethodSync()];
        _setApplySpatialAudio_decorators = [NativeMethodSync()];
        _getApplySpatialAudio_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setRoomID_decorators, { kind: "method", name: "setRoomID", static: false, private: false, access: { has: function (obj) { return "setRoomID" in obj; }, get: function (obj) { return obj.setRoomID; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getRoomID_decorators, { kind: "method", name: "getRoomID", static: false, private: false, access: { has: function (obj) { return "getRoomID" in obj; }, get: function (obj) { return obj.getRoomID; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setUserID_decorators, { kind: "method", name: "setUserID", static: false, private: false, access: { has: function (obj) { return "setUserID" in obj; }, get: function (obj) { return obj.setUserID; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getUserID_decorators, { kind: "method", name: "getUserID", static: false, private: false, access: { has: function (obj) { return "getUserID" in obj; }, get: function (obj) { return obj.getUserID; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocationX_decorators, { kind: "method", name: "setLocationX", static: false, private: false, access: { has: function (obj) { return "setLocationX" in obj; }, get: function (obj) { return obj.setLocationX; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getLocationX_decorators, { kind: "method", name: "getLocationX", static: false, private: false, access: { has: function (obj) { return "getLocationX" in obj; }, get: function (obj) { return obj.getLocationX; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocationY_decorators, { kind: "method", name: "setLocationY", static: false, private: false, access: { has: function (obj) { return "setLocationY" in obj; }, get: function (obj) { return obj.setLocationY; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getLocationY_decorators, { kind: "method", name: "getLocationY", static: false, private: false, access: { has: function (obj) { return "getLocationY" in obj; }, get: function (obj) { return obj.getLocationY; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setWidth_decorators, { kind: "method", name: "setWidth", static: false, private: false, access: { has: function (obj) { return "setWidth" in obj; }, get: function (obj) { return obj.setWidth; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getWidth_decorators, { kind: "method", name: "getWidth", static: false, private: false, access: { has: function (obj) { return "getWidth" in obj; }, get: function (obj) { return obj.getWidth; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setHeight_decorators, { kind: "method", name: "setHeight", static: false, private: false, access: { has: function (obj) { return "setHeight" in obj; }, get: function (obj) { return obj.setHeight; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getHeight_decorators, { kind: "method", name: "getHeight", static: false, private: false, access: { has: function (obj) { return "getHeight" in obj; }, get: function (obj) { return obj.getHeight; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setZOrder_decorators, { kind: "method", name: "setZOrder", static: false, private: false, access: { has: function (obj) { return "setZOrder" in obj; }, get: function (obj) { return obj.setZOrder; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getZOrder_decorators, { kind: "method", name: "getZOrder", static: false, private: false, access: { has: function (obj) { return "getZOrder" in obj; }, get: function (obj) { return obj.getZOrder; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAlpha_decorators, { kind: "method", name: "setAlpha", static: false, private: false, access: { has: function (obj) { return "setAlpha" in obj; }, get: function (obj) { return obj.setAlpha; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAlpha_decorators, { kind: "method", name: "getAlpha", static: false, private: false, access: { has: function (obj) { return "getAlpha" in obj; }, get: function (obj) { return obj.getAlpha; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCornerRadius_decorators, { kind: "method", name: "setCornerRadius", static: false, private: false, access: { has: function (obj) { return "setCornerRadius" in obj; }, get: function (obj) { return obj.setCornerRadius; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getCornerRadius_decorators, { kind: "method", name: "getCornerRadius", static: false, private: false, access: { has: function (obj) { return "getCornerRadius" in obj; }, get: function (obj) { return obj.getCornerRadius; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setMediaType_decorators, { kind: "method", name: "setMediaType", static: false, private: false, access: { has: function (obj) { return "setMediaType" in obj; }, get: function (obj) { return obj.setMediaType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getMediaType_decorators, { kind: "method", name: "getMediaType", static: false, private: false, access: { has: function (obj) { return "getMediaType" in obj; }, get: function (obj) { return obj.getMediaType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRegionContentType_decorators, { kind: "method", name: "setRegionContentType", static: false, private: false, access: { has: function (obj) { return "setRegionContentType" in obj; }, get: function (obj) { return obj.setRegionContentType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getRegionContentType_decorators, { kind: "method", name: "getRegionContentType", static: false, private: false, access: { has: function (obj) { return "getRegionContentType" in obj; }, get: function (obj) { return obj.getRegionContentType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRenderMode_decorators, { kind: "method", name: "setRenderMode", static: false, private: false, access: { has: function (obj) { return "setRenderMode" in obj; }, get: function (obj) { return obj.setRenderMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getRenderMode_decorators, { kind: "method", name: "getRenderMode", static: false, private: false, access: { has: function (obj) { return "getRenderMode" in obj; }, get: function (obj) { return obj.getRenderMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getIsLocalUser_decorators, { kind: "method", name: "getIsLocalUser", static: false, private: false, access: { has: function (obj) { return "getIsLocalUser" in obj; }, get: function (obj) { return obj.getIsLocalUser; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setIsLocalUser_decorators, { kind: "method", name: "setIsLocalUser", static: false, private: false, access: { has: function (obj) { return "setIsLocalUser" in obj; }, get: function (obj) { return obj.setIsLocalUser; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setStreamType_decorators, { kind: "method", name: "setStreamType", static: false, private: false, access: { has: function (obj) { return "setStreamType" in obj; }, get: function (obj) { return obj.setStreamType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getStreamType_decorators, { kind: "method", name: "getStreamType", static: false, private: false, access: { has: function (obj) { return "getStreamType" in obj; }, get: function (obj) { return obj.getStreamType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setImageWaterMark_decorators, { kind: "method", name: "setImageWaterMark", static: false, private: false, access: { has: function (obj) { return "setImageWaterMark" in obj; }, get: function (obj) { return obj.setImageWaterMark; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getImageWaterMark_decorators, { kind: "method", name: "getImageWaterMark", static: false, private: false, access: { has: function (obj) { return "getImageWaterMark" in obj; }, get: function (obj) { return obj.getImageWaterMark; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setImageWaterMarkConfig_decorators, { kind: "method", name: "setImageWaterMarkConfig", static: false, private: false, access: { has: function (obj) { return "setImageWaterMarkConfig" in obj; }, get: function (obj) { return obj.setImageWaterMarkConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getImageWaterMarkConfig_decorators, { kind: "method", name: "getImageWaterMarkConfig", static: false, private: false, access: { has: function (obj) { return "getImageWaterMarkConfig" in obj; }, get: function (obj) { return obj.getImageWaterMarkConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAlternateImageFillMode_decorators, { kind: "method", name: "setAlternateImageFillMode", static: false, private: false, access: { has: function (obj) { return "setAlternateImageFillMode" in obj; }, get: function (obj) { return obj.setAlternateImageFillMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAlternateImageFillMode_decorators, { kind: "method", name: "getAlternateImageFillMode", static: false, private: false, access: { has: function (obj) { return "getAlternateImageFillMode" in obj; }, get: function (obj) { return obj.getAlternateImageFillMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAlternateImageURL_decorators, { kind: "method", name: "setAlternateImageURL", static: false, private: false, access: { has: function (obj) { return "setAlternateImageURL" in obj; }, get: function (obj) { return obj.setAlternateImageURL; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAlternateImageURL_decorators, { kind: "method", name: "getAlternateImageURL", static: false, private: false, access: { has: function (obj) { return "getAlternateImageURL" in obj; }, get: function (obj) { return obj.getAlternateImageURL; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setSpatialPosition_decorators, { kind: "method", name: "setSpatialPosition", static: false, private: false, access: { has: function (obj) { return "setSpatialPosition" in obj; }, get: function (obj) { return obj.setSpatialPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getSpatialPosition_decorators, { kind: "method", name: "getSpatialPosition", static: false, private: false, access: { has: function (obj) { return "getSpatialPosition" in obj; }, get: function (obj) { return obj.getSpatialPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setApplySpatialAudio_decorators, { kind: "method", name: "setApplySpatialAudio", static: false, private: false, access: { has: function (obj) { return "setApplySpatialAudio" in obj; }, get: function (obj) { return obj.setApplySpatialAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getApplySpatialAudio_decorators, { kind: "method", name: "getApplySpatialAudio", static: false, private: false, access: { has: function (obj) { return "getApplySpatialAudio" in obj; }, get: function (obj) { return obj.getApplySpatialAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioScenarioType;
(function (AudioScenarioType) {
    AudioScenarioType[AudioScenarioType["AUDIO_SCENARIO_MUSIC"] = 0] = "AUDIO_SCENARIO_MUSIC";
    AudioScenarioType[AudioScenarioType["AUDIO_SCENARIO_HIGHQUALITY_COMMUNICATION"] = 1] = "AUDIO_SCENARIO_HIGHQUALITY_COMMUNICATION";
    AudioScenarioType[AudioScenarioType["AUDIO_SCENARIO_COMMUNICATION"] = 2] = "AUDIO_SCENARIO_COMMUNICATION";
    AudioScenarioType[AudioScenarioType["AUDIO_SCENARIO_MEDIA"] = 3] = "AUDIO_SCENARIO_MEDIA";
    AudioScenarioType[AudioScenarioType["AUDIO_SCENARIO_GAME_STREAMING"] = 4] = "AUDIO_SCENARIO_GAME_STREAMING";
    AudioScenarioType[AudioScenarioType["AUDIO_SCENARIO_HIGHQUALITY_CHAT"] = 5] = "AUDIO_SCENARIO_HIGHQUALITY_CHAT";
})(AudioScenarioType || (AudioScenarioType = {}));
var AudioPropertiesMode;
(function (AudioPropertiesMode) {
    AudioPropertiesMode[AudioPropertiesMode["AUDIO_PROPERTIES_MODE_MICROPHONE"] = 0] = "AUDIO_PROPERTIES_MODE_MICROPHONE";
    AudioPropertiesMode[AudioPropertiesMode["AUDIO_PROPERTIES_MODE_AUDIOMIXING"] = 1] = "AUDIO_PROPERTIES_MODE_AUDIOMIXING";
})(AudioPropertiesMode || (AudioPropertiesMode = {}));
var ASRAuthorizationType;
(function (ASRAuthorizationType) {
    ASRAuthorizationType[ASRAuthorizationType["ASR_AUTHORIZATION_TYPE_TOKEN"] = 0] = "ASR_AUTHORIZATION_TYPE_TOKEN";
    ASRAuthorizationType[ASRAuthorizationType["ASR_AUTHORIZATION_TYPE_SIGNATURE"] = 1] = "ASR_AUTHORIZATION_TYPE_SIGNATURE";
})(ASRAuthorizationType || (ASRAuthorizationType = {}));
var VoiceEqualizationBandFrequency;
(function (VoiceEqualizationBandFrequency) {
    VoiceEqualizationBandFrequency[VoiceEqualizationBandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_31"] = 0] = "VOICE_EQUALIZATION_BAND_FREQUENCY_31";
    VoiceEqualizationBandFrequency[VoiceEqualizationBandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_62"] = 1] = "VOICE_EQUALIZATION_BAND_FREQUENCY_62";
    VoiceEqualizationBandFrequency[VoiceEqualizationBandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_125"] = 2] = "VOICE_EQUALIZATION_BAND_FREQUENCY_125";
    VoiceEqualizationBandFrequency[VoiceEqualizationBandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_250"] = 3] = "VOICE_EQUALIZATION_BAND_FREQUENCY_250";
    VoiceEqualizationBandFrequency[VoiceEqualizationBandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_500"] = 4] = "VOICE_EQUALIZATION_BAND_FREQUENCY_500";
    VoiceEqualizationBandFrequency[VoiceEqualizationBandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_1K"] = 5] = "VOICE_EQUALIZATION_BAND_FREQUENCY_1K";
    VoiceEqualizationBandFrequency[VoiceEqualizationBandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_2K"] = 6] = "VOICE_EQUALIZATION_BAND_FREQUENCY_2K";
    VoiceEqualizationBandFrequency[VoiceEqualizationBandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_4K"] = 7] = "VOICE_EQUALIZATION_BAND_FREQUENCY_4K";
    VoiceEqualizationBandFrequency[VoiceEqualizationBandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_8K"] = 8] = "VOICE_EQUALIZATION_BAND_FREQUENCY_8K";
    VoiceEqualizationBandFrequency[VoiceEqualizationBandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_16K"] = 9] = "VOICE_EQUALIZATION_BAND_FREQUENCY_16K";
})(VoiceEqualizationBandFrequency || (VoiceEqualizationBandFrequency = {}));
var SysStats$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.SysStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _cpuCores_decorators;
    var _cpuCores_initializers = [];
    var _cpuCores_extraInitializers = [];
    var _cpuAppUsage_decorators;
    var _cpuAppUsage_initializers = [];
    var _cpuAppUsage_extraInitializers = [];
    var _cpuTotalUsage_decorators;
    var _cpuTotalUsage_initializers = [];
    var _cpuTotalUsage_extraInitializers = [];
    var _memoryUsage_decorators;
    var _memoryUsage_initializers = [];
    var _memoryUsage_extraInitializers = [];
    var _fullMemory_decorators;
    var _fullMemory_initializers = [];
    var _fullMemory_extraInitializers = [];
    var _totalMemoryUsage_decorators;
    var _totalMemoryUsage_initializers = [];
    var _totalMemoryUsage_extraInitializers = [];
    var _freeMemory_decorators;
    var _freeMemory_initializers = [];
    var _freeMemory_extraInitializers = [];
    var _memoryRatio_decorators;
    var _memoryRatio_initializers = [];
    var _memoryRatio_extraInitializers = [];
    var _totalMemoryRatio_decorators;
    var _totalMemoryRatio_initializers = [];
    var _totalMemoryRatio_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function SysStats_1() {
            this.cpuCores = __runInitializers(this, _cpuCores_initializers, void 0);
            this.cpuAppUsage = (__runInitializers(this, _cpuCores_extraInitializers), __runInitializers(this, _cpuAppUsage_initializers, void 0));
            this.cpuTotalUsage = (__runInitializers(this, _cpuAppUsage_extraInitializers), __runInitializers(this, _cpuTotalUsage_initializers, void 0));
            this.memoryUsage = (__runInitializers(this, _cpuTotalUsage_extraInitializers), __runInitializers(this, _memoryUsage_initializers, void 0));
            this.fullMemory = (__runInitializers(this, _memoryUsage_extraInitializers), __runInitializers(this, _fullMemory_initializers, void 0));
            this.totalMemoryUsage = (__runInitializers(this, _fullMemory_extraInitializers), __runInitializers(this, _totalMemoryUsage_initializers, void 0));
            this.freeMemory = (__runInitializers(this, _totalMemoryUsage_extraInitializers), __runInitializers(this, _freeMemory_initializers, void 0));
            this.memoryRatio = (__runInitializers(this, _freeMemory_extraInitializers), __runInitializers(this, _memoryRatio_initializers, void 0));
            this.totalMemoryRatio = (__runInitializers(this, _memoryRatio_extraInitializers), __runInitializers(this, _totalMemoryRatio_initializers, void 0));
            __runInitializers(this, _totalMemoryRatio_extraInitializers);
        }
        return SysStats_1;
    }());
    __setFunctionName(_classThis, "SysStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _cpuCores_decorators = [NativeMember()];
        _cpuAppUsage_decorators = [NativeMember()];
        _cpuTotalUsage_decorators = [NativeMember()];
        _memoryUsage_decorators = [NativeMember()];
        _fullMemory_decorators = [NativeMember()];
        _totalMemoryUsage_decorators = [NativeMember()];
        _freeMemory_decorators = [NativeMember()];
        _memoryRatio_decorators = [NativeMember()];
        _totalMemoryRatio_decorators = [NativeMember()];
        __esDecorate(null, null, _cpuCores_decorators, { kind: "field", name: "cpuCores", static: false, private: false, access: { has: function (obj) { return "cpuCores" in obj; }, get: function (obj) { return obj.cpuCores; }, set: function (obj, value) { obj.cpuCores = value; } }, metadata: _metadata }, _cpuCores_initializers, _cpuCores_extraInitializers);
        __esDecorate(null, null, _cpuAppUsage_decorators, { kind: "field", name: "cpuAppUsage", static: false, private: false, access: { has: function (obj) { return "cpuAppUsage" in obj; }, get: function (obj) { return obj.cpuAppUsage; }, set: function (obj, value) { obj.cpuAppUsage = value; } }, metadata: _metadata }, _cpuAppUsage_initializers, _cpuAppUsage_extraInitializers);
        __esDecorate(null, null, _cpuTotalUsage_decorators, { kind: "field", name: "cpuTotalUsage", static: false, private: false, access: { has: function (obj) { return "cpuTotalUsage" in obj; }, get: function (obj) { return obj.cpuTotalUsage; }, set: function (obj, value) { obj.cpuTotalUsage = value; } }, metadata: _metadata }, _cpuTotalUsage_initializers, _cpuTotalUsage_extraInitializers);
        __esDecorate(null, null, _memoryUsage_decorators, { kind: "field", name: "memoryUsage", static: false, private: false, access: { has: function (obj) { return "memoryUsage" in obj; }, get: function (obj) { return obj.memoryUsage; }, set: function (obj, value) { obj.memoryUsage = value; } }, metadata: _metadata }, _memoryUsage_initializers, _memoryUsage_extraInitializers);
        __esDecorate(null, null, _fullMemory_decorators, { kind: "field", name: "fullMemory", static: false, private: false, access: { has: function (obj) { return "fullMemory" in obj; }, get: function (obj) { return obj.fullMemory; }, set: function (obj, value) { obj.fullMemory = value; } }, metadata: _metadata }, _fullMemory_initializers, _fullMemory_extraInitializers);
        __esDecorate(null, null, _totalMemoryUsage_decorators, { kind: "field", name: "totalMemoryUsage", static: false, private: false, access: { has: function (obj) { return "totalMemoryUsage" in obj; }, get: function (obj) { return obj.totalMemoryUsage; }, set: function (obj, value) { obj.totalMemoryUsage = value; } }, metadata: _metadata }, _totalMemoryUsage_initializers, _totalMemoryUsage_extraInitializers);
        __esDecorate(null, null, _freeMemory_decorators, { kind: "field", name: "freeMemory", static: false, private: false, access: { has: function (obj) { return "freeMemory" in obj; }, get: function (obj) { return obj.freeMemory; }, set: function (obj, value) { obj.freeMemory = value; } }, metadata: _metadata }, _freeMemory_initializers, _freeMemory_extraInitializers);
        __esDecorate(null, null, _memoryRatio_decorators, { kind: "field", name: "memoryRatio", static: false, private: false, access: { has: function (obj) { return "memoryRatio" in obj; }, get: function (obj) { return obj.memoryRatio; }, set: function (obj, value) { obj.memoryRatio = value; } }, metadata: _metadata }, _memoryRatio_initializers, _memoryRatio_extraInitializers);
        __esDecorate(null, null, _totalMemoryRatio_decorators, { kind: "field", name: "totalMemoryRatio", static: false, private: false, access: { has: function (obj) { return "totalMemoryRatio" in obj; }, get: function (obj) { return obj.totalMemoryRatio; }, set: function (obj, value) { obj.totalMemoryRatio = value; } }, metadata: _metadata }, _totalMemoryRatio_initializers, _totalMemoryRatio_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoContentType;
(function (VideoContentType) {
    VideoContentType[VideoContentType["NORMAL_FRAME"] = 0] = "NORMAL_FRAME";
    VideoContentType[VideoContentType["BLACK_FRAME"] = 1] = "BLACK_FRAME";
})(VideoContentType || (VideoContentType = {}));
var SubscribeConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.SubscribeConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _static_create_decorators;
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _subVideo_decorators;
    var _subVideo_initializers = [];
    var _subVideo_extraInitializers = [];
    var _subAudio_decorators;
    var _subAudio_initializers = [];
    var _subAudio_extraInitializers = [];
    var _videoIndex_decorators;
    var _videoIndex_initializers = [];
    var _videoIndex_extraInitializers = [];
    var _subWidth_decorators;
    var _subWidth_initializers = [];
    var _subWidth_extraInitializers = [];
    var _subHeight_decorators;
    var _subHeight_initializers = [];
    var _subHeight_extraInitializers = [];
    var _framerate_decorators;
    var _framerate_initializers = [];
    var _framerate_extraInitializers = [];
    var SubscribeConfig = _classThis = /** @class */ (function () {
        function SubscribeConfig_1() {
            this.isScreen = __runInitializers(this, _isScreen_initializers, void 0);
            this.subVideo = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _subVideo_initializers, void 0));
            this.subAudio = (__runInitializers(this, _subVideo_extraInitializers), __runInitializers(this, _subAudio_initializers, void 0));
            this.videoIndex = (__runInitializers(this, _subAudio_extraInitializers), __runInitializers(this, _videoIndex_initializers, void 0));
            this.subWidth = (__runInitializers(this, _videoIndex_extraInitializers), __runInitializers(this, _subWidth_initializers, void 0));
            this.subHeight = (__runInitializers(this, _subWidth_extraInitializers), __runInitializers(this, _subHeight_initializers, void 0));
            this.framerate = (__runInitializers(this, _subHeight_extraInitializers), __runInitializers(this, _framerate_initializers, void 0));
            __runInitializers(this, _framerate_extraInitializers);
        }
        SubscribeConfig_1.create = function (isScreen, subVideo, subAudio, videoIndex, svcLayer, subWidth, subHeight, subVideoIndex) {
            throw new Error('not implement');
        };
        return SubscribeConfig_1;
    }());
    __setFunctionName(_classThis, "SubscribeConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_create_decorators = [ReturnClass(function () { return SubscribeConfig; }), NativeStaticMethodSync()];
        _isScreen_decorators = [NativeMember()];
        _subVideo_decorators = [NativeMember()];
        _subAudio_decorators = [NativeMember()];
        _videoIndex_decorators = [NativeMember()];
        _subWidth_decorators = [NativeMember()];
        _subHeight_decorators = [NativeMember()];
        _framerate_decorators = [NativeMember()];
        __esDecorate(_classThis, null, _static_create_decorators, { kind: "method", name: "create", static: true, private: false, access: { has: function (obj) { return "create" in obj; }, get: function (obj) { return obj.create; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _subVideo_decorators, { kind: "field", name: "subVideo", static: false, private: false, access: { has: function (obj) { return "subVideo" in obj; }, get: function (obj) { return obj.subVideo; }, set: function (obj, value) { obj.subVideo = value; } }, metadata: _metadata }, _subVideo_initializers, _subVideo_extraInitializers);
        __esDecorate(null, null, _subAudio_decorators, { kind: "field", name: "subAudio", static: false, private: false, access: { has: function (obj) { return "subAudio" in obj; }, get: function (obj) { return obj.subAudio; }, set: function (obj, value) { obj.subAudio = value; } }, metadata: _metadata }, _subAudio_initializers, _subAudio_extraInitializers);
        __esDecorate(null, null, _videoIndex_decorators, { kind: "field", name: "videoIndex", static: false, private: false, access: { has: function (obj) { return "videoIndex" in obj; }, get: function (obj) { return obj.videoIndex; }, set: function (obj, value) { obj.videoIndex = value; } }, metadata: _metadata }, _videoIndex_initializers, _videoIndex_extraInitializers);
        __esDecorate(null, null, _subWidth_decorators, { kind: "field", name: "subWidth", static: false, private: false, access: { has: function (obj) { return "subWidth" in obj; }, get: function (obj) { return obj.subWidth; }, set: function (obj, value) { obj.subWidth = value; } }, metadata: _metadata }, _subWidth_initializers, _subWidth_extraInitializers);
        __esDecorate(null, null, _subHeight_decorators, { kind: "field", name: "subHeight", static: false, private: false, access: { has: function (obj) { return "subHeight" in obj; }, get: function (obj) { return obj.subHeight; }, set: function (obj, value) { obj.subHeight = value; } }, metadata: _metadata }, _subHeight_initializers, _subHeight_extraInitializers);
        __esDecorate(null, null, _framerate_decorators, { kind: "field", name: "framerate", static: false, private: false, access: { has: function (obj) { return "framerate" in obj; }, get: function (obj) { return obj.framerate; }, set: function (obj, value) { obj.framerate = value; } }, metadata: _metadata }, _framerate_initializers, _framerate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        SubscribeConfig = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _staticExtraInitializers);
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return SubscribeConfig = _classThis;
}();
var EchoTestConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.EchoTestConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _view_decorators;
    var _view_initializers = [];
    var _view_extraInitializers = [];
    var _uid_decorators;
    var _uid_initializers = [];
    var _uid_extraInitializers = [];
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _token_decorators;
    var _token_initializers = [];
    var _token_extraInitializers = [];
    var _enableAudio_decorators;
    var _enableAudio_initializers = [];
    var _enableAudio_extraInitializers = [];
    var _enableVideo_decorators;
    var _enableVideo_initializers = [];
    var _enableVideo_extraInitializers = [];
    var _audioReportInterval_decorators;
    var _audioReportInterval_initializers = [];
    var _audioReportInterval_extraInitializers = [];
    var _getEchoRenderView_decorators;
    var _getEchoUid_decorators;
    var _getEchoRoomId_decorators;
    var _getEchoToken_decorators;
    var _getEchoEnabledAudio_decorators;
    var _getEchoEnabledVideo_decorators;
    var _getAudioReportInterval_decorators;
    _classThis = /** @class */ (function () {
        function EchoTestConfig_1(view, uid, roomid, token, enableAudio, enableVideo, interval) {
            this.view = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _view_initializers, void 0));
            this.uid = (__runInitializers(this, _view_extraInitializers), __runInitializers(this, _uid_initializers, void 0));
            this.roomId = (__runInitializers(this, _uid_extraInitializers), __runInitializers(this, _roomId_initializers, void 0));
            this.token = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _token_initializers, void 0));
            this.enableAudio = (__runInitializers(this, _token_extraInitializers), __runInitializers(this, _enableAudio_initializers, void 0));
            this.enableVideo = (__runInitializers(this, _enableAudio_extraInitializers), __runInitializers(this, _enableVideo_initializers, void 0));
            this.audioReportInterval = (__runInitializers(this, _enableVideo_extraInitializers), __runInitializers(this, _audioReportInterval_initializers, void 0));
            __runInitializers(this, _audioReportInterval_extraInitializers);
        }
        EchoTestConfig_1.prototype.getEchoRenderView = function () {
            throw new Error('not implement');
        };
        EchoTestConfig_1.prototype.getEchoUid = function () {
            throw new Error('not implement');
        };
        EchoTestConfig_1.prototype.getEchoRoomId = function () {
            throw new Error('not implement');
        };
        EchoTestConfig_1.prototype.getEchoToken = function () {
            throw new Error('not implement');
        };
        EchoTestConfig_1.prototype.getEchoEnabledAudio = function () {
            throw new Error('not implement');
        };
        EchoTestConfig_1.prototype.getEchoEnabledVideo = function () {
            throw new Error('not implement');
        };
        EchoTestConfig_1.prototype.getAudioReportInterval = function () {
            throw new Error('not implement');
        };
        return EchoTestConfig_1;
    }());
    __setFunctionName(_classThis, "EchoTestConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _view_decorators = [NativeMember()];
        _uid_decorators = [NativeMember()];
        _roomId_decorators = [NativeMember()];
        _token_decorators = [NativeMember()];
        _enableAudio_decorators = [NativeMember()];
        _enableVideo_decorators = [NativeMember()];
        _audioReportInterval_decorators = [NativeMember()];
        _getEchoRenderView_decorators = [NativeMethodSync()];
        _getEchoUid_decorators = [NativeMethodSync()];
        _getEchoRoomId_decorators = [NativeMethodSync()];
        _getEchoToken_decorators = [NativeMethodSync()];
        _getEchoEnabledAudio_decorators = [NativeMethodSync()];
        _getEchoEnabledVideo_decorators = [NativeMethodSync()];
        _getAudioReportInterval_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _getEchoRenderView_decorators, { kind: "method", name: "getEchoRenderView", static: false, private: false, access: { has: function (obj) { return "getEchoRenderView" in obj; }, get: function (obj) { return obj.getEchoRenderView; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getEchoUid_decorators, { kind: "method", name: "getEchoUid", static: false, private: false, access: { has: function (obj) { return "getEchoUid" in obj; }, get: function (obj) { return obj.getEchoUid; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getEchoRoomId_decorators, { kind: "method", name: "getEchoRoomId", static: false, private: false, access: { has: function (obj) { return "getEchoRoomId" in obj; }, get: function (obj) { return obj.getEchoRoomId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getEchoToken_decorators, { kind: "method", name: "getEchoToken", static: false, private: false, access: { has: function (obj) { return "getEchoToken" in obj; }, get: function (obj) { return obj.getEchoToken; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getEchoEnabledAudio_decorators, { kind: "method", name: "getEchoEnabledAudio", static: false, private: false, access: { has: function (obj) { return "getEchoEnabledAudio" in obj; }, get: function (obj) { return obj.getEchoEnabledAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getEchoEnabledVideo_decorators, { kind: "method", name: "getEchoEnabledVideo", static: false, private: false, access: { has: function (obj) { return "getEchoEnabledVideo" in obj; }, get: function (obj) { return obj.getEchoEnabledVideo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioReportInterval_decorators, { kind: "method", name: "getAudioReportInterval", static: false, private: false, access: { has: function (obj) { return "getAudioReportInterval" in obj; }, get: function (obj) { return obj.getAudioReportInterval; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _view_decorators, { kind: "field", name: "view", static: false, private: false, access: { has: function (obj) { return "view" in obj; }, get: function (obj) { return obj.view; }, set: function (obj, value) { obj.view = value; } }, metadata: _metadata }, _view_initializers, _view_extraInitializers);
        __esDecorate(null, null, _uid_decorators, { kind: "field", name: "uid", static: false, private: false, access: { has: function (obj) { return "uid" in obj; }, get: function (obj) { return obj.uid; }, set: function (obj, value) { obj.uid = value; } }, metadata: _metadata }, _uid_initializers, _uid_extraInitializers);
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _token_decorators, { kind: "field", name: "token", static: false, private: false, access: { has: function (obj) { return "token" in obj; }, get: function (obj) { return obj.token; }, set: function (obj, value) { obj.token = value; } }, metadata: _metadata }, _token_initializers, _token_extraInitializers);
        __esDecorate(null, null, _enableAudio_decorators, { kind: "field", name: "enableAudio", static: false, private: false, access: { has: function (obj) { return "enableAudio" in obj; }, get: function (obj) { return obj.enableAudio; }, set: function (obj, value) { obj.enableAudio = value; } }, metadata: _metadata }, _enableAudio_initializers, _enableAudio_extraInitializers);
        __esDecorate(null, null, _enableVideo_decorators, { kind: "field", name: "enableVideo", static: false, private: false, access: { has: function (obj) { return "enableVideo" in obj; }, get: function (obj) { return obj.enableVideo; }, set: function (obj, value) { obj.enableVideo = value; } }, metadata: _metadata }, _enableVideo_initializers, _enableVideo_extraInitializers);
        __esDecorate(null, null, _audioReportInterval_decorators, { kind: "field", name: "audioReportInterval", static: false, private: false, access: { has: function (obj) { return "audioReportInterval" in obj; }, get: function (obj) { return obj.audioReportInterval; }, set: function (obj, value) { obj.audioReportInterval = value; } }, metadata: _metadata }, _audioReportInterval_initializers, _audioReportInterval_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioSampleRate;
(function (AudioSampleRate) {
    AudioSampleRate[AudioSampleRate["AUDIO_SAMPLE_RATE_AUTO"] = -1] = "AUDIO_SAMPLE_RATE_AUTO";
    AudioSampleRate[AudioSampleRate["AUDIO_SAMPLE_RATE_8000"] = 8000] = "AUDIO_SAMPLE_RATE_8000";
    AudioSampleRate[AudioSampleRate["AUDIO_SAMPLE_RATE_16000"] = 16000] = "AUDIO_SAMPLE_RATE_16000";
    AudioSampleRate[AudioSampleRate["AUDIO_SAMPLE_RATE_32000"] = 32000] = "AUDIO_SAMPLE_RATE_32000";
    AudioSampleRate[AudioSampleRate["AUDIO_SAMPLE_RATE_44100"] = 44100] = "AUDIO_SAMPLE_RATE_44100";
    AudioSampleRate[AudioSampleRate["AUDIO_SAMPLE_RATE_48000"] = 48000] = "AUDIO_SAMPLE_RATE_48000";
})(AudioSampleRate || (AudioSampleRate = {}));
var MusicInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.ktv.data.MusicInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _musicId_decorators;
    var _musicId_initializers = [];
    var _musicId_extraInitializers = [];
    var _musicName_decorators;
    var _musicName_initializers = [];
    var _musicName_extraInitializers = [];
    var _singer_decorators;
    var _singer_initializers = [];
    var _singer_extraInitializers = [];
    var _vendorId_decorators;
    var _vendorId_initializers = [];
    var _vendorId_extraInitializers = [];
    var _vendorName_decorators;
    var _vendorName_initializers = [];
    var _vendorName_extraInitializers = [];
    var _updateTimestamp_decorators;
    var _updateTimestamp_initializers = [];
    var _updateTimestamp_extraInitializers = [];
    var _posterUrl_decorators;
    var _posterUrl_initializers = [];
    var _posterUrl_extraInitializers = [];
    var _lyricStatus_decorators;
    var _lyricStatus_initializers = [];
    var _lyricStatus_extraInitializers = [];
    var _duration_decorators;
    var _duration_initializers = [];
    var _duration_extraInitializers = [];
    var _enableScore_decorators;
    var _enableScore_initializers = [];
    var _enableScore_extraInitializers = [];
    var _climaxStartTime_decorators;
    var _climaxStartTime_initializers = [];
    var _climaxStartTime_extraInitializers = [];
    var _climaxEndTime_decorators;
    var _climaxEndTime_initializers = [];
    var _climaxEndTime_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function MusicInfo_1(musicId, musicName, singer, vendorId, vendorName, updateTimestamp, posterUrl, lyricType, duration, enableScore, climaxStart, climaxEnd) {
            this.musicId = __runInitializers(this, _musicId_initializers, void 0);
            this.musicName = (__runInitializers(this, _musicId_extraInitializers), __runInitializers(this, _musicName_initializers, void 0));
            this.singer = (__runInitializers(this, _musicName_extraInitializers), __runInitializers(this, _singer_initializers, void 0));
            this.vendorId = (__runInitializers(this, _singer_extraInitializers), __runInitializers(this, _vendorId_initializers, void 0));
            this.vendorName = (__runInitializers(this, _vendorId_extraInitializers), __runInitializers(this, _vendorName_initializers, void 0));
            this.updateTimestamp = (__runInitializers(this, _vendorName_extraInitializers), __runInitializers(this, _updateTimestamp_initializers, void 0));
            this.posterUrl = (__runInitializers(this, _updateTimestamp_extraInitializers), __runInitializers(this, _posterUrl_initializers, void 0));
            this.lyricStatus = (__runInitializers(this, _posterUrl_extraInitializers), __runInitializers(this, _lyricStatus_initializers, void 0));
            this.duration = (__runInitializers(this, _lyricStatus_extraInitializers), __runInitializers(this, _duration_initializers, void 0));
            this.enableScore = (__runInitializers(this, _duration_extraInitializers), __runInitializers(this, _enableScore_initializers, void 0));
            this.climaxStartTime = (__runInitializers(this, _enableScore_extraInitializers), __runInitializers(this, _climaxStartTime_initializers, void 0));
            this.climaxEndTime = (__runInitializers(this, _climaxStartTime_extraInitializers), __runInitializers(this, _climaxEndTime_initializers, void 0));
            __runInitializers(this, _climaxEndTime_extraInitializers);
        }
        return MusicInfo_1;
    }());
    __setFunctionName(_classThis, "MusicInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _musicId_decorators = [NativeMember()];
        _musicName_decorators = [NativeMember()];
        _singer_decorators = [NativeMember()];
        _vendorId_decorators = [NativeMember()];
        _vendorName_decorators = [NativeMember()];
        _updateTimestamp_decorators = [NativeMember()];
        _posterUrl_decorators = [NativeMember()];
        _lyricStatus_decorators = [NativeMember()];
        _duration_decorators = [NativeMember()];
        _enableScore_decorators = [NativeMember()];
        _climaxStartTime_decorators = [NativeMember()];
        _climaxEndTime_decorators = [NativeMember()];
        __esDecorate(null, null, _musicId_decorators, { kind: "field", name: "musicId", static: false, private: false, access: { has: function (obj) { return "musicId" in obj; }, get: function (obj) { return obj.musicId; }, set: function (obj, value) { obj.musicId = value; } }, metadata: _metadata }, _musicId_initializers, _musicId_extraInitializers);
        __esDecorate(null, null, _musicName_decorators, { kind: "field", name: "musicName", static: false, private: false, access: { has: function (obj) { return "musicName" in obj; }, get: function (obj) { return obj.musicName; }, set: function (obj, value) { obj.musicName = value; } }, metadata: _metadata }, _musicName_initializers, _musicName_extraInitializers);
        __esDecorate(null, null, _singer_decorators, { kind: "field", name: "singer", static: false, private: false, access: { has: function (obj) { return "singer" in obj; }, get: function (obj) { return obj.singer; }, set: function (obj, value) { obj.singer = value; } }, metadata: _metadata }, _singer_initializers, _singer_extraInitializers);
        __esDecorate(null, null, _vendorId_decorators, { kind: "field", name: "vendorId", static: false, private: false, access: { has: function (obj) { return "vendorId" in obj; }, get: function (obj) { return obj.vendorId; }, set: function (obj, value) { obj.vendorId = value; } }, metadata: _metadata }, _vendorId_initializers, _vendorId_extraInitializers);
        __esDecorate(null, null, _vendorName_decorators, { kind: "field", name: "vendorName", static: false, private: false, access: { has: function (obj) { return "vendorName" in obj; }, get: function (obj) { return obj.vendorName; }, set: function (obj, value) { obj.vendorName = value; } }, metadata: _metadata }, _vendorName_initializers, _vendorName_extraInitializers);
        __esDecorate(null, null, _updateTimestamp_decorators, { kind: "field", name: "updateTimestamp", static: false, private: false, access: { has: function (obj) { return "updateTimestamp" in obj; }, get: function (obj) { return obj.updateTimestamp; }, set: function (obj, value) { obj.updateTimestamp = value; } }, metadata: _metadata }, _updateTimestamp_initializers, _updateTimestamp_extraInitializers);
        __esDecorate(null, null, _posterUrl_decorators, { kind: "field", name: "posterUrl", static: false, private: false, access: { has: function (obj) { return "posterUrl" in obj; }, get: function (obj) { return obj.posterUrl; }, set: function (obj, value) { obj.posterUrl = value; } }, metadata: _metadata }, _posterUrl_initializers, _posterUrl_extraInitializers);
        __esDecorate(null, null, _lyricStatus_decorators, { kind: "field", name: "lyricStatus", static: false, private: false, access: { has: function (obj) { return "lyricStatus" in obj; }, get: function (obj) { return obj.lyricStatus; }, set: function (obj, value) { obj.lyricStatus = value; } }, metadata: _metadata }, _lyricStatus_initializers, _lyricStatus_extraInitializers);
        __esDecorate(null, null, _duration_decorators, { kind: "field", name: "duration", static: false, private: false, access: { has: function (obj) { return "duration" in obj; }, get: function (obj) { return obj.duration; }, set: function (obj, value) { obj.duration = value; } }, metadata: _metadata }, _duration_initializers, _duration_extraInitializers);
        __esDecorate(null, null, _enableScore_decorators, { kind: "field", name: "enableScore", static: false, private: false, access: { has: function (obj) { return "enableScore" in obj; }, get: function (obj) { return obj.enableScore; }, set: function (obj, value) { obj.enableScore = value; } }, metadata: _metadata }, _enableScore_initializers, _enableScore_extraInitializers);
        __esDecorate(null, null, _climaxStartTime_decorators, { kind: "field", name: "climaxStartTime", static: false, private: false, access: { has: function (obj) { return "climaxStartTime" in obj; }, get: function (obj) { return obj.climaxStartTime; }, set: function (obj, value) { obj.climaxStartTime = value; } }, metadata: _metadata }, _climaxStartTime_initializers, _climaxStartTime_extraInitializers);
        __esDecorate(null, null, _climaxEndTime_decorators, { kind: "field", name: "climaxEndTime", static: false, private: false, access: { has: function (obj) { return "climaxEndTime" in obj; }, get: function (obj) { return obj.climaxEndTime; }, set: function (obj, value) { obj.climaxEndTime = value; } }, metadata: _metadata }, _climaxEndTime_initializers, _climaxEndTime_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MixedStreamVideoCodecType;
(function (MixedStreamVideoCodecType) {
    MixedStreamVideoCodecType["MIXED_STREAM_VIDEO_CODEC_TYPE_H264"] = "H264";
    MixedStreamVideoCodecType["MIXED_STREAM_VIDEO_CODEC_TYPE_BYTEVC1"] = "ByteVC1";
})(MixedStreamVideoCodecType || (MixedStreamVideoCodecType = {}));
var MuteState;
(function (MuteState) {
    MuteState[MuteState["MUTE_STATE_OFF"] = 0] = "MUTE_STATE_OFF";
    MuteState[MuteState["MUTE_STATE_ON"] = 1] = "MUTE_STATE_ON";
})(MuteState || (MuteState = {}));
var ByteRTCStreamMixingType$1;
(function (ByteRTCStreamMixingType) {
    ByteRTCStreamMixingType[ByteRTCStreamMixingType["STREAM_MIXING_BY_SERVER"] = 0] = "STREAM_MIXING_BY_SERVER";
    ByteRTCStreamMixingType[ByteRTCStreamMixingType["STREAM_MIXING_BY_CLIENT"] = 1] = "STREAM_MIXING_BY_CLIENT";
})(ByteRTCStreamMixingType$1 || (ByteRTCStreamMixingType$1 = {}));
var MediaDeviceError;
(function (MediaDeviceError) {
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_OK"] = 0] = "MEDIA_DEVICE_ERROR_OK";
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_NOPERMISSION"] = 1] = "MEDIA_DEVICE_ERROR_NOPERMISSION";
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_DEVICEBUSY"] = 2] = "MEDIA_DEVICE_ERROR_DEVICEBUSY";
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_DEVICEFAILURE"] = 3] = "MEDIA_DEVICE_ERROR_DEVICEFAILURE";
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_DEVICENOTFOUND"] = 4] = "MEDIA_DEVICE_ERROR_DEVICENOTFOUND";
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_DEVICEDISCONNECTED"] = 5] = "MEDIA_DEVICE_ERROR_DEVICEDISCONNECTED";
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_DEVICENOCALLBACK"] = 6] = "MEDIA_DEVICE_ERROR_DEVICENOCALLBACK";
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_UNSUPPORTFORMAT"] = 7] = "MEDIA_DEVICE_ERROR_UNSUPPORTFORMAT";
})(MediaDeviceError || (MediaDeviceError = {}));
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.builder.CpuBufferVideoFrameBuilder')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setTimeStampUs_decorators;
    var _setWidth_decorators;
    var _setHeight_decorators;
    var _setRotation_decorators;
    var _setColorSpace_decorators;
    var _setPlaneData_decorators;
    var _setPlaneStride_decorators;
    var _setExternalDataInfo_decorators;
    var _setSupplementaryInfo_decorators;
    var _setReleaseCallback_decorators;
    var _build_decorators;
    _classThis = /** @class */ (function () {
        function CpuBufferVideoFrameBuilder_1(pixelFormat) {
            __runInitializers(this, _instanceExtraInitializers);
        }
        CpuBufferVideoFrameBuilder_1.prototype.setTimeStampUs = function (timeStampUs) {
            throw new Error('not implement');
        };
        CpuBufferVideoFrameBuilder_1.prototype.setWidth = function (width) {
            throw new Error('not implement');
        };
        CpuBufferVideoFrameBuilder_1.prototype.setHeight = function (height) {
            throw new Error('not implement');
        };
        CpuBufferVideoFrameBuilder_1.prototype.setRotation = function (rotation) {
            throw new Error('not implement');
        };
        CpuBufferVideoFrameBuilder_1.prototype.setColorSpace = function (colorSpace) {
            throw new Error('not implement');
        };
        CpuBufferVideoFrameBuilder_1.prototype.setPlaneData = function (planeIndex, buffer) {
            throw new Error('not implement');
        };
        CpuBufferVideoFrameBuilder_1.prototype.setPlaneStride = function (planeIndex, stride) {
            throw new Error('not implement');
        };
        CpuBufferVideoFrameBuilder_1.prototype.setExternalDataInfo = function (externalDataInfo) {
            throw new Error('not implement');
        };
        CpuBufferVideoFrameBuilder_1.prototype.setSupplementaryInfo = function (supplementaryInfo) {
            throw new Error('not implement');
        };
        CpuBufferVideoFrameBuilder_1.prototype.setReleaseCallback = function (releaseCallback) {
            throw new Error('not implement');
        };
        CpuBufferVideoFrameBuilder_1.prototype.build = function () {
            throw new Error('not implement');
        };
        return CpuBufferVideoFrameBuilder_1;
    }());
    __setFunctionName(_classThis, "CpuBufferVideoFrameBuilder");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setTimeStampUs_decorators = [NativeMethodSync()];
        _setWidth_decorators = [NativeMethodSync()];
        _setHeight_decorators = [NativeMethodSync()];
        _setRotation_decorators = [NativeMethodSync()];
        _setColorSpace_decorators = [NativeMethodSync()];
        _setPlaneData_decorators = [NativeMethodSync()];
        _setPlaneStride_decorators = [NativeMethodSync()];
        _setExternalDataInfo_decorators = [NativeMethodSync()];
        _setSupplementaryInfo_decorators = [NativeMethodSync()];
        _setReleaseCallback_decorators = [NativeMethodSync()];
        _build_decorators = [ReturnClass(function () { return VideoFrame$1; }), NativeMethodSync()];
        __esDecorate(_classThis, null, _setTimeStampUs_decorators, { kind: "method", name: "setTimeStampUs", static: false, private: false, access: { has: function (obj) { return "setTimeStampUs" in obj; }, get: function (obj) { return obj.setTimeStampUs; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setWidth_decorators, { kind: "method", name: "setWidth", static: false, private: false, access: { has: function (obj) { return "setWidth" in obj; }, get: function (obj) { return obj.setWidth; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setHeight_decorators, { kind: "method", name: "setHeight", static: false, private: false, access: { has: function (obj) { return "setHeight" in obj; }, get: function (obj) { return obj.setHeight; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRotation_decorators, { kind: "method", name: "setRotation", static: false, private: false, access: { has: function (obj) { return "setRotation" in obj; }, get: function (obj) { return obj.setRotation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setColorSpace_decorators, { kind: "method", name: "setColorSpace", static: false, private: false, access: { has: function (obj) { return "setColorSpace" in obj; }, get: function (obj) { return obj.setColorSpace; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPlaneData_decorators, { kind: "method", name: "setPlaneData", static: false, private: false, access: { has: function (obj) { return "setPlaneData" in obj; }, get: function (obj) { return obj.setPlaneData; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPlaneStride_decorators, { kind: "method", name: "setPlaneStride", static: false, private: false, access: { has: function (obj) { return "setPlaneStride" in obj; }, get: function (obj) { return obj.setPlaneStride; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setExternalDataInfo_decorators, { kind: "method", name: "setExternalDataInfo", static: false, private: false, access: { has: function (obj) { return "setExternalDataInfo" in obj; }, get: function (obj) { return obj.setExternalDataInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setSupplementaryInfo_decorators, { kind: "method", name: "setSupplementaryInfo", static: false, private: false, access: { has: function (obj) { return "setSupplementaryInfo" in obj; }, get: function (obj) { return obj.setSupplementaryInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setReleaseCallback_decorators, { kind: "method", name: "setReleaseCallback", static: false, private: false, access: { has: function (obj) { return "setReleaseCallback" in obj; }, get: function (obj) { return obj.setReleaseCallback; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _build_decorators, { kind: "method", name: "build", static: false, private: false, access: { has: function (obj) { return "build" in obj; }, get: function (obj) { return obj.build; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var AudioFrameSource;
(function (AudioFrameSource) {
    AudioFrameSource[AudioFrameSource["AUDIO_FRAME_SOURCE_MIC"] = 0] = "AUDIO_FRAME_SOURCE_MIC";
    AudioFrameSource[AudioFrameSource["AUDIO_FRAME_SOURCE_PLAYBACK"] = 1] = "AUDIO_FRAME_SOURCE_PLAYBACK";
    AudioFrameSource[AudioFrameSource["AUDIO_FRAME_SOURCE_MIXED"] = 2] = "AUDIO_FRAME_SOURCE_MIXED";
})(AudioFrameSource || (AudioFrameSource = {}));
var StreamRemoveReason;
(function (StreamRemoveReason) {
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_UNPUBLISH"] = 0] = "STREAM_REMOVE_REASON_UNPUBLISH";
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_PUBLISH_FAILED"] = 1] = "STREAM_REMOVE_REASON_PUBLISH_FAILED";
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_KEEP_LIVE_FAILED"] = 2] = "STREAM_REMOVE_REASON_KEEP_LIVE_FAILED";
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_CLIENT_DISCONNECTED"] = 3] = "STREAM_REMOVE_REASON_CLIENT_DISCONNECTED";
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_REPUBLISH"] = 4] = "STREAM_REMOVE_REASON_REPUBLISH";
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_OTHER"] = 5] = "STREAM_REMOVE_REASON_OTHER";
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_PUBLISH_PRIVILEGE_TOKEN_EXPIRED"] = 6] = "STREAM_REMOVE_REASON_PUBLISH_PRIVILEGE_TOKEN_EXPIRED";
})(StreamRemoveReason || (StreamRemoveReason = {}));
var ForwardStreamError;
(function (ForwardStreamError) {
    ForwardStreamError[ForwardStreamError["FORWARD_STREAM_ERROR_OK"] = 0] = "FORWARD_STREAM_ERROR_OK";
    ForwardStreamError[ForwardStreamError["FORWARD_STREAM_ERROR_INVALID_ARGUMENT"] = 1201] = "FORWARD_STREAM_ERROR_INVALID_ARGUMENT";
    ForwardStreamError[ForwardStreamError["FORWARD_STREAM_ERROR_INVALID_TOKEN"] = 1202] = "FORWARD_STREAM_ERROR_INVALID_TOKEN";
    ForwardStreamError[ForwardStreamError["FORWARD_STREAM_ERROR_RESPONSE"] = 1203] = "FORWARD_STREAM_ERROR_RESPONSE";
    ForwardStreamError[ForwardStreamError["FORWARD_STREAM_ERROR_REMOTE_KICKED"] = 1204] = "FORWARD_STREAM_ERROR_REMOTE_KICKED";
    ForwardStreamError[ForwardStreamError["FORWARD_STREAM_ERROR_NOT_SUPPORT"] = 1205] = "FORWARD_STREAM_ERROR_NOT_SUPPORT";
})(ForwardStreamError || (ForwardStreamError = {}));
var NetworkDetectionStopReason;
(function (NetworkDetectionStopReason) {
    NetworkDetectionStopReason[NetworkDetectionStopReason["USER"] = 0] = "USER";
    NetworkDetectionStopReason[NetworkDetectionStopReason["TIMEOUT"] = 1] = "TIMEOUT";
    NetworkDetectionStopReason[NetworkDetectionStopReason["CONNECTION_LOST"] = 2] = "CONNECTION_LOST";
    NetworkDetectionStopReason[NetworkDetectionStopReason["STREAMING"] = 3] = "STREAMING";
    NetworkDetectionStopReason[NetworkDetectionStopReason["INNER_ERR"] = 4] = "INNER_ERR";
})(NetworkDetectionStopReason || (NetworkDetectionStopReason = {}));
var ReceiveRange$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.ReceiveRange')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _min_decorators;
    var _min_initializers = [];
    var _min_extraInitializers = [];
    var _max_decorators;
    var _max_initializers = [];
    var _max_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function ReceiveRange_1(min, max) {
            this.min = __runInitializers(this, _min_initializers, void 0);
            this.max = (__runInitializers(this, _min_extraInitializers), __runInitializers(this, _max_initializers, void 0));
            __runInitializers(this, _max_extraInitializers);
        }
        return ReceiveRange_1;
    }());
    __setFunctionName(_classThis, "ReceiveRange");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _min_decorators = [NativeMember()];
        _max_decorators = [NativeMember()];
        __esDecorate(null, null, _min_decorators, { kind: "field", name: "min", static: false, private: false, access: { has: function (obj) { return "min" in obj; }, get: function (obj) { return obj.min; }, set: function (obj, value) { obj.min = value; } }, metadata: _metadata }, _min_initializers, _min_extraInitializers);
        __esDecorate(null, null, _max_decorators, { kind: "field", name: "max", static: false, private: false, access: { has: function (obj) { return "max" in obj; }, get: function (obj) { return obj.max; }, set: function (obj, value) { obj.max = value; } }, metadata: _metadata }, _max_initializers, _max_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var NetworkQuality;
(function (NetworkQuality) {
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_UNKNOWN"] = 0] = "NETWORK_QUALITY_UNKNOWN";
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_EXCELLENT"] = 1] = "NETWORK_QUALITY_EXCELLENT";
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_GOOD"] = 2] = "NETWORK_QUALITY_GOOD";
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_POOR"] = 3] = "NETWORK_QUALITY_POOR";
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_BAD"] = 4] = "NETWORK_QUALITY_BAD";
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_VERY_BAD"] = 5] = "NETWORK_QUALITY_VERY_BAD";
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_DOWN"] = 6] = "NETWORK_QUALITY_DOWN";
})(NetworkQuality || (NetworkQuality = {}));
var ZoomConfigType;
(function (ZoomConfigType) {
    ZoomConfigType[ZoomConfigType["ZOOM_FOCUS_OFFSET"] = 0] = "ZOOM_FOCUS_OFFSET";
    ZoomConfigType[ZoomConfigType["ZOOM_MOVE_OFFSET"] = 1] = "ZOOM_MOVE_OFFSET";
})(ZoomConfigType || (ZoomConfigType = {}));
var StreamSycnInfoConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.StreamSycnInfoConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _streamIndex_decorators;
    var _streamIndex_initializers = [];
    var _streamIndex_extraInitializers = [];
    var _repeatCount_decorators;
    var _repeatCount_initializers = [];
    var _repeatCount_extraInitializers = [];
    var _streamType_decorators;
    var _streamType_initializers = [];
    var _streamType_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function StreamSycnInfoConfig_1(streamIndex, repeatCount, streamType) {
            this.streamIndex = __runInitializers(this, _streamIndex_initializers, void 0);
            this.repeatCount = (__runInitializers(this, _streamIndex_extraInitializers), __runInitializers(this, _repeatCount_initializers, void 0));
            this.streamType = (__runInitializers(this, _repeatCount_extraInitializers), __runInitializers(this, _streamType_initializers, void 0));
            __runInitializers(this, _streamType_extraInitializers);
        }
        return StreamSycnInfoConfig_1;
    }());
    __setFunctionName(_classThis, "StreamSycnInfoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _streamIndex_decorators = [NativeMember()];
        _repeatCount_decorators = [NativeMember()];
        _streamType_decorators = [NativeMember()];
        __esDecorate(null, null, _streamIndex_decorators, { kind: "field", name: "streamIndex", static: false, private: false, access: { has: function (obj) { return "streamIndex" in obj; }, get: function (obj) { return obj.streamIndex; }, set: function (obj, value) { obj.streamIndex = value; } }, metadata: _metadata }, _streamIndex_initializers, _streamIndex_extraInitializers);
        __esDecorate(null, null, _repeatCount_decorators, { kind: "field", name: "repeatCount", static: false, private: false, access: { has: function (obj) { return "repeatCount" in obj; }, get: function (obj) { return obj.repeatCount; }, set: function (obj, value) { obj.repeatCount = value; } }, metadata: _metadata }, _repeatCount_initializers, _repeatCount_extraInitializers);
        __esDecorate(null, null, _streamType_decorators, { kind: "field", name: "streamType", static: false, private: false, access: { has: function (obj) { return "streamType" in obj; }, get: function (obj) { return obj.streamType; }, set: function (obj, value) { obj.streamType = value; } }, metadata: _metadata }, _streamType_initializers, _streamType_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var LocalVideoStats$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.LocalVideoStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _sentKBitrate_decorators;
    var _sentKBitrate_initializers = [];
    var _sentKBitrate_extraInitializers = [];
    var _inputFrameRate_decorators;
    var _inputFrameRate_initializers = [];
    var _inputFrameRate_extraInitializers = [];
    var _sentFrameRate_decorators;
    var _sentFrameRate_initializers = [];
    var _sentFrameRate_extraInitializers = [];
    var _encoderOutputFrameRate_decorators;
    var _encoderOutputFrameRate_initializers = [];
    var _encoderOutputFrameRate_extraInitializers = [];
    var _rendererOutputFrameRate_decorators;
    var _rendererOutputFrameRate_initializers = [];
    var _rendererOutputFrameRate_extraInitializers = [];
    var _statsInterval_decorators;
    var _statsInterval_initializers = [];
    var _statsInterval_extraInitializers = [];
    var _videoLossRate_decorators;
    var _videoLossRate_initializers = [];
    var _videoLossRate_extraInitializers = [];
    var _rtt_decorators;
    var _rtt_initializers = [];
    var _rtt_extraInitializers = [];
    var _encodedBitrate_decorators;
    var _encodedBitrate_initializers = [];
    var _encodedBitrate_extraInitializers = [];
    var _encodedFrameWidth_decorators;
    var _encodedFrameWidth_initializers = [];
    var _encodedFrameWidth_extraInitializers = [];
    var _encodedFrameHeight_decorators;
    var _encodedFrameHeight_initializers = [];
    var _encodedFrameHeight_extraInitializers = [];
    var _encodedFrameCount_decorators;
    var _encodedFrameCount_initializers = [];
    var _encodedFrameCount_extraInitializers = [];
    var _codecType_decorators;
    var _codecType_initializers = [];
    var _codecType_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _jitter_decorators;
    var _jitter_initializers = [];
    var _jitter_extraInitializers = [];
    var _videoDenoiseMode_decorators;
    var _videoDenoiseMode_initializers = [];
    var _videoDenoiseMode_extraInitializers = [];
    var _isPSNROn_decorators;
    var _isPSNROn_initializers = [];
    var _isPSNROn_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function LocalVideoStats_1() {
            this.sentKBitrate = __runInitializers(this, _sentKBitrate_initializers, void 0);
            this.inputFrameRate = (__runInitializers(this, _sentKBitrate_extraInitializers), __runInitializers(this, _inputFrameRate_initializers, void 0));
            this.sentFrameRate = (__runInitializers(this, _inputFrameRate_extraInitializers), __runInitializers(this, _sentFrameRate_initializers, void 0));
            this.encoderOutputFrameRate = (__runInitializers(this, _sentFrameRate_extraInitializers), __runInitializers(this, _encoderOutputFrameRate_initializers, void 0));
            this.rendererOutputFrameRate = (__runInitializers(this, _encoderOutputFrameRate_extraInitializers), __runInitializers(this, _rendererOutputFrameRate_initializers, void 0));
            this.statsInterval = (__runInitializers(this, _rendererOutputFrameRate_extraInitializers), __runInitializers(this, _statsInterval_initializers, void 0));
            this.videoLossRate = (__runInitializers(this, _statsInterval_extraInitializers), __runInitializers(this, _videoLossRate_initializers, void 0));
            this.rtt = (__runInitializers(this, _videoLossRate_extraInitializers), __runInitializers(this, _rtt_initializers, void 0));
            this.encodedBitrate = (__runInitializers(this, _rtt_extraInitializers), __runInitializers(this, _encodedBitrate_initializers, void 0));
            this.encodedFrameWidth = (__runInitializers(this, _encodedBitrate_extraInitializers), __runInitializers(this, _encodedFrameWidth_initializers, void 0));
            this.encodedFrameHeight = (__runInitializers(this, _encodedFrameWidth_extraInitializers), __runInitializers(this, _encodedFrameHeight_initializers, void 0));
            this.encodedFrameCount = (__runInitializers(this, _encodedFrameHeight_extraInitializers), __runInitializers(this, _encodedFrameCount_initializers, void 0));
            this.codecType = (__runInitializers(this, _encodedFrameCount_extraInitializers), __runInitializers(this, _codecType_initializers, void 0));
            this.isScreen = (__runInitializers(this, _codecType_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.jitter = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _jitter_initializers, void 0));
            this.videoDenoiseMode = (__runInitializers(this, _jitter_extraInitializers), __runInitializers(this, _videoDenoiseMode_initializers, void 0));
            this.isPSNROn = (__runInitializers(this, _videoDenoiseMode_extraInitializers), __runInitializers(this, _isPSNROn_initializers, void 0));
            __runInitializers(this, _isPSNROn_extraInitializers);
        }
        return LocalVideoStats_1;
    }());
    __setFunctionName(_classThis, "LocalVideoStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _sentKBitrate_decorators = [NativeMember()];
        _inputFrameRate_decorators = [NativeMember()];
        _sentFrameRate_decorators = [NativeMember()];
        _encoderOutputFrameRate_decorators = [NativeMember()];
        _rendererOutputFrameRate_decorators = [NativeMember()];
        _statsInterval_decorators = [NativeMember()];
        _videoLossRate_decorators = [NativeMember()];
        _rtt_decorators = [NativeMember()];
        _encodedBitrate_decorators = [NativeMember()];
        _encodedFrameWidth_decorators = [NativeMember()];
        _encodedFrameHeight_decorators = [NativeMember()];
        _encodedFrameCount_decorators = [NativeMember()];
        _codecType_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _jitter_decorators = [NativeMember()];
        _videoDenoiseMode_decorators = [NativeMember()];
        _isPSNROn_decorators = [NativeMember()];
        __esDecorate(null, null, _sentKBitrate_decorators, { kind: "field", name: "sentKBitrate", static: false, private: false, access: { has: function (obj) { return "sentKBitrate" in obj; }, get: function (obj) { return obj.sentKBitrate; }, set: function (obj, value) { obj.sentKBitrate = value; } }, metadata: _metadata }, _sentKBitrate_initializers, _sentKBitrate_extraInitializers);
        __esDecorate(null, null, _inputFrameRate_decorators, { kind: "field", name: "inputFrameRate", static: false, private: false, access: { has: function (obj) { return "inputFrameRate" in obj; }, get: function (obj) { return obj.inputFrameRate; }, set: function (obj, value) { obj.inputFrameRate = value; } }, metadata: _metadata }, _inputFrameRate_initializers, _inputFrameRate_extraInitializers);
        __esDecorate(null, null, _sentFrameRate_decorators, { kind: "field", name: "sentFrameRate", static: false, private: false, access: { has: function (obj) { return "sentFrameRate" in obj; }, get: function (obj) { return obj.sentFrameRate; }, set: function (obj, value) { obj.sentFrameRate = value; } }, metadata: _metadata }, _sentFrameRate_initializers, _sentFrameRate_extraInitializers);
        __esDecorate(null, null, _encoderOutputFrameRate_decorators, { kind: "field", name: "encoderOutputFrameRate", static: false, private: false, access: { has: function (obj) { return "encoderOutputFrameRate" in obj; }, get: function (obj) { return obj.encoderOutputFrameRate; }, set: function (obj, value) { obj.encoderOutputFrameRate = value; } }, metadata: _metadata }, _encoderOutputFrameRate_initializers, _encoderOutputFrameRate_extraInitializers);
        __esDecorate(null, null, _rendererOutputFrameRate_decorators, { kind: "field", name: "rendererOutputFrameRate", static: false, private: false, access: { has: function (obj) { return "rendererOutputFrameRate" in obj; }, get: function (obj) { return obj.rendererOutputFrameRate; }, set: function (obj, value) { obj.rendererOutputFrameRate = value; } }, metadata: _metadata }, _rendererOutputFrameRate_initializers, _rendererOutputFrameRate_extraInitializers);
        __esDecorate(null, null, _statsInterval_decorators, { kind: "field", name: "statsInterval", static: false, private: false, access: { has: function (obj) { return "statsInterval" in obj; }, get: function (obj) { return obj.statsInterval; }, set: function (obj, value) { obj.statsInterval = value; } }, metadata: _metadata }, _statsInterval_initializers, _statsInterval_extraInitializers);
        __esDecorate(null, null, _videoLossRate_decorators, { kind: "field", name: "videoLossRate", static: false, private: false, access: { has: function (obj) { return "videoLossRate" in obj; }, get: function (obj) { return obj.videoLossRate; }, set: function (obj, value) { obj.videoLossRate = value; } }, metadata: _metadata }, _videoLossRate_initializers, _videoLossRate_extraInitializers);
        __esDecorate(null, null, _rtt_decorators, { kind: "field", name: "rtt", static: false, private: false, access: { has: function (obj) { return "rtt" in obj; }, get: function (obj) { return obj.rtt; }, set: function (obj, value) { obj.rtt = value; } }, metadata: _metadata }, _rtt_initializers, _rtt_extraInitializers);
        __esDecorate(null, null, _encodedBitrate_decorators, { kind: "field", name: "encodedBitrate", static: false, private: false, access: { has: function (obj) { return "encodedBitrate" in obj; }, get: function (obj) { return obj.encodedBitrate; }, set: function (obj, value) { obj.encodedBitrate = value; } }, metadata: _metadata }, _encodedBitrate_initializers, _encodedBitrate_extraInitializers);
        __esDecorate(null, null, _encodedFrameWidth_decorators, { kind: "field", name: "encodedFrameWidth", static: false, private: false, access: { has: function (obj) { return "encodedFrameWidth" in obj; }, get: function (obj) { return obj.encodedFrameWidth; }, set: function (obj, value) { obj.encodedFrameWidth = value; } }, metadata: _metadata }, _encodedFrameWidth_initializers, _encodedFrameWidth_extraInitializers);
        __esDecorate(null, null, _encodedFrameHeight_decorators, { kind: "field", name: "encodedFrameHeight", static: false, private: false, access: { has: function (obj) { return "encodedFrameHeight" in obj; }, get: function (obj) { return obj.encodedFrameHeight; }, set: function (obj, value) { obj.encodedFrameHeight = value; } }, metadata: _metadata }, _encodedFrameHeight_initializers, _encodedFrameHeight_extraInitializers);
        __esDecorate(null, null, _encodedFrameCount_decorators, { kind: "field", name: "encodedFrameCount", static: false, private: false, access: { has: function (obj) { return "encodedFrameCount" in obj; }, get: function (obj) { return obj.encodedFrameCount; }, set: function (obj, value) { obj.encodedFrameCount = value; } }, metadata: _metadata }, _encodedFrameCount_initializers, _encodedFrameCount_extraInitializers);
        __esDecorate(null, null, _codecType_decorators, { kind: "field", name: "codecType", static: false, private: false, access: { has: function (obj) { return "codecType" in obj; }, get: function (obj) { return obj.codecType; }, set: function (obj, value) { obj.codecType = value; } }, metadata: _metadata }, _codecType_initializers, _codecType_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _jitter_decorators, { kind: "field", name: "jitter", static: false, private: false, access: { has: function (obj) { return "jitter" in obj; }, get: function (obj) { return obj.jitter; }, set: function (obj, value) { obj.jitter = value; } }, metadata: _metadata }, _jitter_initializers, _jitter_extraInitializers);
        __esDecorate(null, null, _videoDenoiseMode_decorators, { kind: "field", name: "videoDenoiseMode", static: false, private: false, access: { has: function (obj) { return "videoDenoiseMode" in obj; }, get: function (obj) { return obj.videoDenoiseMode; }, set: function (obj, value) { obj.videoDenoiseMode = value; } }, metadata: _metadata }, _videoDenoiseMode_initializers, _videoDenoiseMode_extraInitializers);
        __esDecorate(null, null, _isPSNROn_decorators, { kind: "field", name: "isPSNROn", static: false, private: false, access: { has: function (obj) { return "isPSNROn" in obj; }, get: function (obj) { return obj.isPSNROn; }, set: function (obj, value) { obj.isPSNROn = value; } }, metadata: _metadata }, _isPSNROn_initializers, _isPSNROn_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioRecordingState;
(function (AudioRecordingState) {
    AudioRecordingState[AudioRecordingState["AUDIO_RECORDING_STATE_ERROR"] = 0] = "AUDIO_RECORDING_STATE_ERROR";
    AudioRecordingState[AudioRecordingState["AUDIO_RECORDING_STATE_PROCESSING"] = 1] = "AUDIO_RECORDING_STATE_PROCESSING";
    AudioRecordingState[AudioRecordingState["AUDIO_RECORDING_STATE_SUCCESS"] = 2] = "AUDIO_RECORDING_STATE_SUCCESS";
})(AudioRecordingState || (AudioRecordingState = {}));
var MulDimSingScoringMode;
(function (MulDimSingScoringMode) {
    MulDimSingScoringMode[MulDimSingScoringMode["MUL_DIM_SING_SCORING_MODE_NOTE"] = 0] = "MUL_DIM_SING_SCORING_MODE_NOTE";
})(MulDimSingScoringMode || (MulDimSingScoringMode = {}));
var AudioPlaybackDevice;
(function (AudioPlaybackDevice) {
    AudioPlaybackDevice[AudioPlaybackDevice["AUDIO_PLAYBACK_DEVICE_HEADSET"] = 1] = "AUDIO_PLAYBACK_DEVICE_HEADSET";
    AudioPlaybackDevice[AudioPlaybackDevice["AUDIO_PLAYBACK_DEVICE_EARPIECE"] = 2] = "AUDIO_PLAYBACK_DEVICE_EARPIECE";
    AudioPlaybackDevice[AudioPlaybackDevice["AUDIO_PLAYBACK_DEVICE_SPEAKERPHONE"] = 3] = "AUDIO_PLAYBACK_DEVICE_SPEAKERPHONE";
    AudioPlaybackDevice[AudioPlaybackDevice["AUDIO_PLAYBACK_DEVICE_HEADSET_BLUETOOTH"] = 4] = "AUDIO_PLAYBACK_DEVICE_HEADSET_BLUETOOTH";
    AudioPlaybackDevice[AudioPlaybackDevice["AUDIO_PLAYBACK_DEVICE_HEADSET_USB"] = 5] = "AUDIO_PLAYBACK_DEVICE_HEADSET_USB";
})(AudioPlaybackDevice || (AudioPlaybackDevice = {}));
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.ForwardStreamInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _token_decorators;
    var _token_initializers = [];
    var _token_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function ForwardStreamInfo_1(roomId, token) {
            this.roomId = __runInitializers(this, _roomId_initializers, void 0);
            this.token = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _token_initializers, void 0));
            __runInitializers(this, _token_extraInitializers);
        }
        return ForwardStreamInfo_1;
    }());
    __setFunctionName(_classThis, "ForwardStreamInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _roomId_decorators = [NativeMember()];
        _token_decorators = [NativeMember()];
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _token_decorators, { kind: "field", name: "token", static: false, private: false, access: { has: function (obj) { return "token" in obj; }, get: function (obj) { return obj.token; }, set: function (obj, value) { obj.token = value; } }, metadata: _metadata }, _token_initializers, _token_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var VideoPreprocessorConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.VideoPreprocessorConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _requiredPixelFormat_decorators;
    var _requiredPixelFormat_initializers = [];
    var _requiredPixelFormat_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function VideoPreprocessorConfig_1() {
            this.requiredPixelFormat = __runInitializers(this, _requiredPixelFormat_initializers, void 0);
            __runInitializers(this, _requiredPixelFormat_extraInitializers);
        }
        return VideoPreprocessorConfig_1;
    }());
    __setFunctionName(_classThis, "VideoPreprocessorConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _requiredPixelFormat_decorators = [NativeMember()];
        __esDecorate(null, null, _requiredPixelFormat_decorators, { kind: "field", name: "requiredPixelFormat", static: false, private: false, access: { has: function (obj) { return "requiredPixelFormat" in obj; }, get: function (obj) { return obj.requiredPixelFormat; }, set: function (obj, value) { obj.requiredPixelFormat = value; } }, metadata: _metadata }, _requiredPixelFormat_initializers, _requiredPixelFormat_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.LocalProxyConfiguration')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _localProxyType_decorators;
    var _localProxyType_initializers = [];
    var _localProxyType_extraInitializers = [];
    var _localProxyIp_decorators;
    var _localProxyIp_initializers = [];
    var _localProxyIp_extraInitializers = [];
    var _localProxyPort_decorators;
    var _localProxyPort_initializers = [];
    var _localProxyPort_extraInitializers = [];
    var _localProxyUsername_decorators;
    var _localProxyUsername_initializers = [];
    var _localProxyUsername_extraInitializers = [];
    var _localProxyPassword_decorators;
    var _localProxyPassword_initializers = [];
    var _localProxyPassword_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function LocalProxyConfiguration_1(localProxyType, localProxyIp, localProxyPort, localProxyUsername, localProxyPassword) {
            this.localProxyType = __runInitializers(this, _localProxyType_initializers, void 0);
            this.localProxyIp = (__runInitializers(this, _localProxyType_extraInitializers), __runInitializers(this, _localProxyIp_initializers, void 0));
            this.localProxyPort = (__runInitializers(this, _localProxyIp_extraInitializers), __runInitializers(this, _localProxyPort_initializers, void 0));
            this.localProxyUsername = (__runInitializers(this, _localProxyPort_extraInitializers), __runInitializers(this, _localProxyUsername_initializers, void 0));
            this.localProxyPassword = (__runInitializers(this, _localProxyUsername_extraInitializers), __runInitializers(this, _localProxyPassword_initializers, void 0));
            __runInitializers(this, _localProxyPassword_extraInitializers);
        }
        return LocalProxyConfiguration_1;
    }());
    __setFunctionName(_classThis, "LocalProxyConfiguration");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _localProxyType_decorators = [NativeMember()];
        _localProxyIp_decorators = [NativeMember()];
        _localProxyPort_decorators = [NativeMember()];
        _localProxyUsername_decorators = [NativeMember()];
        _localProxyPassword_decorators = [NativeMember()];
        __esDecorate(null, null, _localProxyType_decorators, { kind: "field", name: "localProxyType", static: false, private: false, access: { has: function (obj) { return "localProxyType" in obj; }, get: function (obj) { return obj.localProxyType; }, set: function (obj, value) { obj.localProxyType = value; } }, metadata: _metadata }, _localProxyType_initializers, _localProxyType_extraInitializers);
        __esDecorate(null, null, _localProxyIp_decorators, { kind: "field", name: "localProxyIp", static: false, private: false, access: { has: function (obj) { return "localProxyIp" in obj; }, get: function (obj) { return obj.localProxyIp; }, set: function (obj, value) { obj.localProxyIp = value; } }, metadata: _metadata }, _localProxyIp_initializers, _localProxyIp_extraInitializers);
        __esDecorate(null, null, _localProxyPort_decorators, { kind: "field", name: "localProxyPort", static: false, private: false, access: { has: function (obj) { return "localProxyPort" in obj; }, get: function (obj) { return obj.localProxyPort; }, set: function (obj, value) { obj.localProxyPort = value; } }, metadata: _metadata }, _localProxyPort_initializers, _localProxyPort_extraInitializers);
        __esDecorate(null, null, _localProxyUsername_decorators, { kind: "field", name: "localProxyUsername", static: false, private: false, access: { has: function (obj) { return "localProxyUsername" in obj; }, get: function (obj) { return obj.localProxyUsername; }, set: function (obj, value) { obj.localProxyUsername = value; } }, metadata: _metadata }, _localProxyUsername_initializers, _localProxyUsername_extraInitializers);
        __esDecorate(null, null, _localProxyPassword_decorators, { kind: "field", name: "localProxyPassword", static: false, private: false, access: { has: function (obj) { return "localProxyPassword" in obj; }, get: function (obj) { return obj.localProxyPassword; }, set: function (obj, value) { obj.localProxyPassword = value; } }, metadata: _metadata }, _localProxyPassword_initializers, _localProxyPassword_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var AudioFrame$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.utils.AudioFrame')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _buffer_decorators;
    var _buffer_initializers = [];
    var _buffer_extraInitializers = [];
    var _samples_decorators;
    var _samples_initializers = [];
    var _samples_extraInitializers = [];
    var _sampleRate_decorators;
    var _sampleRate_initializers = [];
    var _sampleRate_extraInitializers = [];
    var _channel_decorators;
    var _channel_initializers = [];
    var _channel_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function AudioFrame_1() {
            this.buffer = __runInitializers(this, _buffer_initializers, void 0);
            this.samples = (__runInitializers(this, _buffer_extraInitializers), __runInitializers(this, _samples_initializers, void 0));
            this.sampleRate = (__runInitializers(this, _samples_extraInitializers), __runInitializers(this, _sampleRate_initializers, void 0));
            this.channel = (__runInitializers(this, _sampleRate_extraInitializers), __runInitializers(this, _channel_initializers, void 0));
            __runInitializers(this, _channel_extraInitializers);
        }
        return AudioFrame_1;
    }());
    __setFunctionName(_classThis, "AudioFrame");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _buffer_decorators = [NativeMember()];
        _samples_decorators = [NativeMember()];
        _sampleRate_decorators = [NativeMember()];
        _channel_decorators = [NativeMember()];
        __esDecorate(null, null, _buffer_decorators, { kind: "field", name: "buffer", static: false, private: false, access: { has: function (obj) { return "buffer" in obj; }, get: function (obj) { return obj.buffer; }, set: function (obj, value) { obj.buffer = value; } }, metadata: _metadata }, _buffer_initializers, _buffer_extraInitializers);
        __esDecorate(null, null, _samples_decorators, { kind: "field", name: "samples", static: false, private: false, access: { has: function (obj) { return "samples" in obj; }, get: function (obj) { return obj.samples; }, set: function (obj, value) { obj.samples = value; } }, metadata: _metadata }, _samples_initializers, _samples_extraInitializers);
        __esDecorate(null, null, _sampleRate_decorators, { kind: "field", name: "sampleRate", static: false, private: false, access: { has: function (obj) { return "sampleRate" in obj; }, get: function (obj) { return obj.sampleRate; }, set: function (obj, value) { obj.sampleRate = value; } }, metadata: _metadata }, _sampleRate_initializers, _sampleRate_extraInitializers);
        __esDecorate(null, null, _channel_decorators, { kind: "field", name: "channel", static: false, private: false, access: { has: function (obj) { return "channel" in obj; }, get: function (obj) { return obj.channel; }, set: function (obj, value) { obj.channel = value; } }, metadata: _metadata }, _channel_initializers, _channel_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var EncoderPreference;
(function (EncoderPreference) {
    EncoderPreference[EncoderPreference["DISABLED"] = 0] = "DISABLED";
    EncoderPreference[EncoderPreference["MAINTAIN_FRAMERATE"] = 1] = "MAINTAIN_FRAMERATE";
    EncoderPreference[EncoderPreference["MAINTAIN_QUALITY"] = 2] = "MAINTAIN_QUALITY";
    EncoderPreference[EncoderPreference["BALANCE"] = 3] = "BALANCE";
})(EncoderPreference || (EncoderPreference = {}));
var DownloadResult$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.ktv.data.DownloadResult')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _musicId_decorators;
    var _musicId_initializers = [];
    var _musicId_extraInitializers = [];
    var _fileType_decorators;
    var _fileType_initializers = [];
    var _fileType_extraInitializers = [];
    var _filePath_decorators;
    var _filePath_initializers = [];
    var _filePath_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function DownloadResult_1(musicId, fileType, filePath) {
            this.musicId = __runInitializers(this, _musicId_initializers, void 0);
            this.fileType = (__runInitializers(this, _musicId_extraInitializers), __runInitializers(this, _fileType_initializers, void 0));
            this.filePath = (__runInitializers(this, _fileType_extraInitializers), __runInitializers(this, _filePath_initializers, void 0));
            __runInitializers(this, _filePath_extraInitializers);
        }
        return DownloadResult_1;
    }());
    __setFunctionName(_classThis, "DownloadResult");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _musicId_decorators = [NativeMember()];
        _fileType_decorators = [NativeMember()];
        _filePath_decorators = [NativeMember()];
        __esDecorate(null, null, _musicId_decorators, { kind: "field", name: "musicId", static: false, private: false, access: { has: function (obj) { return "musicId" in obj; }, get: function (obj) { return obj.musicId; }, set: function (obj, value) { obj.musicId = value; } }, metadata: _metadata }, _musicId_initializers, _musicId_extraInitializers);
        __esDecorate(null, null, _fileType_decorators, { kind: "field", name: "fileType", static: false, private: false, access: { has: function (obj) { return "fileType" in obj; }, get: function (obj) { return obj.fileType; }, set: function (obj, value) { obj.fileType = value; } }, metadata: _metadata }, _fileType_initializers, _fileType_extraInitializers);
        __esDecorate(null, null, _filePath_decorators, { kind: "field", name: "filePath", static: false, private: false, access: { has: function (obj) { return "filePath" in obj; }, get: function (obj) { return obj.filePath; }, set: function (obj, value) { obj.filePath = value; } }, metadata: _metadata }, _filePath_initializers, _filePath_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ProblemFeedbackOption;
(function (ProblemFeedbackOption) {
    ProblemFeedbackOption[ProblemFeedbackOption["NONE"] = 0] = "NONE";
    ProblemFeedbackOption["OTHER_MESSAGE"] = "1L";
    ProblemFeedbackOption[ProblemFeedbackOption["DISCONNECTED"] = 2] = "DISCONNECTED";
    ProblemFeedbackOption[ProblemFeedbackOption["EAR_BACK_DELAY"] = 4] = "EAR_BACK_DELAY";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_NOISE"] = 1024] = "LOCAL_NOISE";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_AUDIO_LAGGING"] = 2048] = "LOCAL_AUDIO_LAGGING";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_NO_AUDIO"] = 4096] = "LOCAL_NO_AUDIO";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_AUDIO_STRENGTH"] = 8192] = "LOCAL_AUDIO_STRENGTH";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_ECHO"] = 16384] = "LOCAL_ECHO";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_VIDEO_FUZZY"] = 16777216] = "LOCAL_VIDEO_FUZZY";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_NOT_SYNC"] = 33554432] = "LOCAL_NOT_SYNC";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_VIDEO_LAGGING"] = 67108864] = "LOCAL_VIDEO_LAGGING";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_NO_VIDEO"] = 134217728] = "LOCAL_NO_VIDEO";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_NOISE"] = 32] = "REMOTE_NOISE";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_AUDIO_LAGGING"] = 64] = "REMOTE_AUDIO_LAGGING";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_NO_AUDIO"] = 128] = "REMOTE_NO_AUDIO";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_AUDIO_STRENGTH"] = 256] = "REMOTE_AUDIO_STRENGTH";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_ECHO"] = 512] = "REMOTE_ECHO";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_VIDEO_FUZZY"] = 524288] = "REMOTE_VIDEO_FUZZY";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_NOT_SYNC"] = 1048576] = "REMOTE_NOT_SYNC";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_VIDEO_LAGGING"] = 2097152] = "REMOTE_VIDEO_LAGGING";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_NO_VIDEO"] = 4194304] = "REMOTE_NO_VIDEO";
})(ProblemFeedbackOption || (ProblemFeedbackOption = {}));
var VideoConfig = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.publicstream.PublicStreaming$VideoConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setFps_decorators;
    var _setKBitRate_decorators;
    var _setWidth_decorators;
    var _setHeight_decorators;
    _classThis = /** @class */ (function () {
        function VideoConfig_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        VideoConfig_1.prototype.setFps = function (fps) {
            throw new Error('not implement');
        };
        VideoConfig_1.prototype.setKBitRate = function (kBitRate) {
            throw new Error('not implement');
        };
        VideoConfig_1.prototype.setWidth = function (width) {
            throw new Error('not implement');
        };
        VideoConfig_1.prototype.setHeight = function (height) {
            throw new Error('not implement');
        };
        return VideoConfig_1;
    }());
    __setFunctionName(_classThis, "VideoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setFps_decorators = [NativeMethodSync()];
        _setKBitRate_decorators = [NativeMethodSync()];
        _setWidth_decorators = [NativeMethodSync()];
        _setHeight_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setFps_decorators, { kind: "method", name: "setFps", static: false, private: false, access: { has: function (obj) { return "setFps" in obj; }, get: function (obj) { return obj.setFps; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setKBitRate_decorators, { kind: "method", name: "setKBitRate", static: false, private: false, access: { has: function (obj) { return "setKBitRate" in obj; }, get: function (obj) { return obj.setKBitRate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setWidth_decorators, { kind: "method", name: "setWidth", static: false, private: false, access: { has: function (obj) { return "setWidth" in obj; }, get: function (obj) { return obj.setWidth; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setHeight_decorators, { kind: "method", name: "setHeight", static: false, private: false, access: { has: function (obj) { return "setHeight" in obj; }, get: function (obj) { return obj.setHeight; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.LiveTranscoding$Region')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _uid_decorators;
    var _roomId_decorators;
    var _zorder_decorators;
    var _alpha_decorators;
    var _setCornerRadius_decorators;
    var _contentControl_decorators;
    var _renderMode_decorators;
    var _position_decorators;
    var _size_decorators;
    var _isScreenStream_decorators;
    var _setScreenStream_decorators;
    var _isLocalUser_decorators;
    var _setLocalUser_decorators;
    var _type_decorators;
    var _data_decorators;
    var _dataParam_decorators;
    var _spatialPosition_decorators;
    var _applySpatialAudio_decorators;
    _classThis = /** @class */ (function () {
        function Region_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        Region_1.prototype.uid = function (uid) {
            throw new Error('not implement');
        };
        Region_1.prototype.roomId = function (roomId) {
            throw new Error('not implement');
        };
        Region_1.prototype.zorder = function (zorder) {
            throw new Error('not implement');
        };
        Region_1.prototype.alpha = function (alpha) {
            throw new Error('not implement');
        };
        Region_1.prototype.setCornerRadius = function (radius) {
            throw new Error('not implement');
        };
        Region_1.prototype.contentControl = function (contentControl) {
            throw new Error('not implement');
        };
        Region_1.prototype.renderMode = function (renderMode) {
            throw new Error('not implement');
        };
        Region_1.prototype.position = function (x, y) {
            throw new Error('not implement');
        };
        Region_1.prototype.size = function (width, height) {
            throw new Error('not implement');
        };
        Region_1.prototype.isScreenStream = function () {
            throw new Error('not implement');
        };
        Region_1.prototype.setScreenStream = function (screenStream) {
            throw new Error('not implement');
        };
        Region_1.prototype.isLocalUser = function () {
            throw new Error('not implement');
        };
        Region_1.prototype.setLocalUser = function (localUser) {
            throw new Error('not implement');
        };
        Region_1.prototype.type = function (type) {
            throw new Error('not implement');
        };
        Region_1.prototype.data = function (data) {
            throw new Error('not implement');
        };
        Region_1.prototype.dataParam = function (dataParam) {
            throw new Error('not implement');
        };
        Region_1.prototype.spatialPosition = function (x, y, z) {
            throw new Error('not implement');
        };
        Region_1.prototype.applySpatialAudio = function (applySpatialAudio) {
            throw new Error('not implement');
        };
        return Region_1;
    }());
    __setFunctionName(_classThis, "Region");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _uid_decorators = [NativeMethodSync()];
        _roomId_decorators = [NativeMethodSync()];
        _zorder_decorators = [NativeMethodSync()];
        _alpha_decorators = [NativeMethodSync()];
        _setCornerRadius_decorators = [NativeMethodSync()];
        _contentControl_decorators = [NativeMethodSync()];
        _renderMode_decorators = [NativeMethodSync()];
        _position_decorators = [NativeMethodSync()];
        _size_decorators = [NativeMethodSync()];
        _isScreenStream_decorators = [NativeMethodSync()];
        _setScreenStream_decorators = [NativeMethodSync()];
        _isLocalUser_decorators = [NativeMethodSync()];
        _setLocalUser_decorators = [NativeMethodSync()];
        _type_decorators = [NativeMethodSync()];
        _data_decorators = [NativeMethodSync()];
        _dataParam_decorators = [NativeMethodSync()];
        _spatialPosition_decorators = [NativeMethodSync()];
        _applySpatialAudio_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _uid_decorators, { kind: "method", name: "uid", static: false, private: false, access: { has: function (obj) { return "uid" in obj; }, get: function (obj) { return obj.uid; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _roomId_decorators, { kind: "method", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _zorder_decorators, { kind: "method", name: "zorder", static: false, private: false, access: { has: function (obj) { return "zorder" in obj; }, get: function (obj) { return obj.zorder; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _alpha_decorators, { kind: "method", name: "alpha", static: false, private: false, access: { has: function (obj) { return "alpha" in obj; }, get: function (obj) { return obj.alpha; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCornerRadius_decorators, { kind: "method", name: "setCornerRadius", static: false, private: false, access: { has: function (obj) { return "setCornerRadius" in obj; }, get: function (obj) { return obj.setCornerRadius; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _contentControl_decorators, { kind: "method", name: "contentControl", static: false, private: false, access: { has: function (obj) { return "contentControl" in obj; }, get: function (obj) { return obj.contentControl; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _renderMode_decorators, { kind: "method", name: "renderMode", static: false, private: false, access: { has: function (obj) { return "renderMode" in obj; }, get: function (obj) { return obj.renderMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _position_decorators, { kind: "method", name: "position", static: false, private: false, access: { has: function (obj) { return "position" in obj; }, get: function (obj) { return obj.position; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _size_decorators, { kind: "method", name: "size", static: false, private: false, access: { has: function (obj) { return "size" in obj; }, get: function (obj) { return obj.size; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _isScreenStream_decorators, { kind: "method", name: "isScreenStream", static: false, private: false, access: { has: function (obj) { return "isScreenStream" in obj; }, get: function (obj) { return obj.isScreenStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setScreenStream_decorators, { kind: "method", name: "setScreenStream", static: false, private: false, access: { has: function (obj) { return "setScreenStream" in obj; }, get: function (obj) { return obj.setScreenStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _isLocalUser_decorators, { kind: "method", name: "isLocalUser", static: false, private: false, access: { has: function (obj) { return "isLocalUser" in obj; }, get: function (obj) { return obj.isLocalUser; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalUser_decorators, { kind: "method", name: "setLocalUser", static: false, private: false, access: { has: function (obj) { return "setLocalUser" in obj; }, get: function (obj) { return obj.setLocalUser; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _type_decorators, { kind: "method", name: "type", static: false, private: false, access: { has: function (obj) { return "type" in obj; }, get: function (obj) { return obj.type; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _data_decorators, { kind: "method", name: "data", static: false, private: false, access: { has: function (obj) { return "data" in obj; }, get: function (obj) { return obj.data; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _dataParam_decorators, { kind: "method", name: "dataParam", static: false, private: false, access: { has: function (obj) { return "dataParam" in obj; }, get: function (obj) { return obj.dataParam; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _spatialPosition_decorators, { kind: "method", name: "spatialPosition", static: false, private: false, access: { has: function (obj) { return "spatialPosition" in obj; }, get: function (obj) { return obj.spatialPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _applySpatialAudio_decorators, { kind: "method", name: "applySpatialAudio", static: false, private: false, access: { has: function (obj) { return "applySpatialAudio" in obj; }, get: function (obj) { return obj.applySpatialAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var UserOnlineStatus;
(function (UserOnlineStatus) {
    UserOnlineStatus[UserOnlineStatus["USER_ONLINE_STATUS_OFFLINE"] = 0] = "USER_ONLINE_STATUS_OFFLINE";
    UserOnlineStatus[UserOnlineStatus["USER_ONLINE_STATUS_ONLINE"] = 1] = "USER_ONLINE_STATUS_ONLINE";
    UserOnlineStatus[UserOnlineStatus["USER_ONLINE_STATUS_UNREACHABLE"] = 2] = "USER_ONLINE_STATUS_UNREACHABLE";
})(UserOnlineStatus || (UserOnlineStatus = {}));
var VideoDecoderConfig;
(function (VideoDecoderConfig) {
    VideoDecoderConfig[VideoDecoderConfig["VIDEO_DECODER_CONFIG_RAW"] = 0] = "VIDEO_DECODER_CONFIG_RAW";
    VideoDecoderConfig[VideoDecoderConfig["VIDEO_DECODER_CONFIG_ENCODE"] = 1] = "VIDEO_DECODER_CONFIG_ENCODE";
    VideoDecoderConfig[VideoDecoderConfig["VIDEO_DECODER_CONFIG_BOTH"] = 2] = "VIDEO_DECODER_CONFIG_BOTH";
})(VideoDecoderConfig || (VideoDecoderConfig = {}));
var VideoStreamDescription$EncoderPreference;
(function (VideoStreamDescription$EncoderPreference) {
    VideoStreamDescription$EncoderPreference[VideoStreamDescription$EncoderPreference["Disabled"] = 0] = "Disabled";
    VideoStreamDescription$EncoderPreference[VideoStreamDescription$EncoderPreference["MaintainFramerate"] = 1] = "MaintainFramerate";
    VideoStreamDescription$EncoderPreference[VideoStreamDescription$EncoderPreference["MaintainQuality"] = 2] = "MaintainQuality";
    VideoStreamDescription$EncoderPreference[VideoStreamDescription$EncoderPreference["Balance"] = 3] = "Balance";
})(VideoStreamDescription$EncoderPreference || (VideoStreamDescription$EncoderPreference = {}));
var PositionInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.PositionInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _position_decorators;
    var _position_initializers = [];
    var _position_extraInitializers = [];
    var _orientation_decorators;
    var _orientation_initializers = [];
    var _orientation_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function PositionInfo_1(position, orientation) {
            this.position = __runInitializers(this, _position_initializers, void 0);
            this.orientation = (__runInitializers(this, _position_extraInitializers), __runInitializers(this, _orientation_initializers, void 0));
            __runInitializers(this, _orientation_extraInitializers);
        }
        return PositionInfo_1;
    }());
    __setFunctionName(_classThis, "PositionInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _position_decorators = [NativeMember()];
        _orientation_decorators = [NativeMember()];
        __esDecorate(null, null, _position_decorators, { kind: "field", name: "position", static: false, private: false, access: { has: function (obj) { return "position" in obj; }, get: function (obj) { return obj.position; }, set: function (obj, value) { obj.position = value; } }, metadata: _metadata }, _position_initializers, _position_extraInitializers);
        __esDecorate(null, null, _orientation_decorators, { kind: "field", name: "orientation", static: false, private: false, access: { has: function (obj) { return "orientation" in obj; }, get: function (obj) { return obj.orientation; }, set: function (obj, value) { obj.orientation = value; } }, metadata: _metadata }, _orientation_initializers, _orientation_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var LocalStreamStats$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.LocalStreamStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _audioStats_decorators;
    var _audioStats_initializers = [];
    var _audioStats_extraInitializers = [];
    var _videoStats_decorators;
    var _videoStats_initializers = [];
    var _videoStats_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _txQuality_decorators;
    var _txQuality_initializers = [];
    var _txQuality_extraInitializers = [];
    var _rxQuality_decorators;
    var _rxQuality_initializers = [];
    var _rxQuality_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function LocalStreamStats_1() {
            this.audioStats = __runInitializers(this, _audioStats_initializers, void 0);
            this.videoStats = (__runInitializers(this, _audioStats_extraInitializers), __runInitializers(this, _videoStats_initializers, void 0));
            this.isScreen = (__runInitializers(this, _videoStats_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.txQuality = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _txQuality_initializers, void 0));
            this.rxQuality = (__runInitializers(this, _txQuality_extraInitializers), __runInitializers(this, _rxQuality_initializers, void 0));
            __runInitializers(this, _rxQuality_extraInitializers);
        }
        return LocalStreamStats_1;
    }());
    __setFunctionName(_classThis, "LocalStreamStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _audioStats_decorators = [NativeMember()];
        _videoStats_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _txQuality_decorators = [NativeMember()];
        _rxQuality_decorators = [NativeMember()];
        __esDecorate(null, null, _audioStats_decorators, { kind: "field", name: "audioStats", static: false, private: false, access: { has: function (obj) { return "audioStats" in obj; }, get: function (obj) { return obj.audioStats; }, set: function (obj, value) { obj.audioStats = value; } }, metadata: _metadata }, _audioStats_initializers, _audioStats_extraInitializers);
        __esDecorate(null, null, _videoStats_decorators, { kind: "field", name: "videoStats", static: false, private: false, access: { has: function (obj) { return "videoStats" in obj; }, get: function (obj) { return obj.videoStats; }, set: function (obj, value) { obj.videoStats = value; } }, metadata: _metadata }, _videoStats_initializers, _videoStats_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _txQuality_decorators, { kind: "field", name: "txQuality", static: false, private: false, access: { has: function (obj) { return "txQuality" in obj; }, get: function (obj) { return obj.txQuality; }, set: function (obj, value) { obj.txQuality = value; } }, metadata: _metadata }, _txQuality_initializers, _txQuality_extraInitializers);
        __esDecorate(null, null, _rxQuality_decorators, { kind: "field", name: "rxQuality", static: false, private: false, access: { has: function (obj) { return "rxQuality" in obj; }, get: function (obj) { return obj.rxQuality; }, set: function (obj, value) { obj.rxQuality = value; } }, metadata: _metadata }, _rxQuality_initializers, _rxQuality_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VoiceEqualizationConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.VoiceEqualizationConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _frequency_decorators;
    var _frequency_initializers = [];
    var _frequency_extraInitializers = [];
    var _gain_decorators;
    var _gain_initializers = [];
    var _gain_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function VoiceEqualizationConfig_1(frequency, gain) {
            this.frequency = __runInitializers(this, _frequency_initializers, void 0);
            this.gain = (__runInitializers(this, _frequency_extraInitializers), __runInitializers(this, _gain_initializers, void 0));
            __runInitializers(this, _gain_extraInitializers);
        }
        return VoiceEqualizationConfig_1;
    }());
    __setFunctionName(_classThis, "VoiceEqualizationConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _frequency_decorators = [NativeMember()];
        _gain_decorators = [NativeMember()];
        __esDecorate(null, null, _frequency_decorators, { kind: "field", name: "frequency", static: false, private: false, access: { has: function (obj) { return "frequency" in obj; }, get: function (obj) { return obj.frequency; }, set: function (obj, value) { obj.frequency = value; } }, metadata: _metadata }, _frequency_initializers, _frequency_extraInitializers);
        __esDecorate(null, null, _gain_decorators, { kind: "field", name: "gain", static: false, private: false, access: { has: function (obj) { return "gain" in obj; }, get: function (obj) { return obj.gain; }, set: function (obj, value) { obj.gain = value; } }, metadata: _metadata }, _gain_initializers, _gain_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoFrameType;
(function (VideoFrameType) {
    VideoFrameType[VideoFrameType["RAW_MEMORY"] = 0] = "RAW_MEMORY";
    VideoFrameType[VideoFrameType["GL_TEXTURE"] = 2] = "GL_TEXTURE";
})(VideoFrameType || (VideoFrameType = {}));
var TranscoderContentControlType;
(function (TranscoderContentControlType) {
    TranscoderContentControlType[TranscoderContentControlType["HAS_AUDIO_AND_VIDEO"] = 0] = "HAS_AUDIO_AND_VIDEO";
    TranscoderContentControlType[TranscoderContentControlType["HAS_AUDIO_ONLY"] = 1] = "HAS_AUDIO_ONLY";
    TranscoderContentControlType[TranscoderContentControlType["HAS_VIDEO_ONLY"] = 2] = "HAS_VIDEO_ONLY";
})(TranscoderContentControlType || (TranscoderContentControlType = {}));
var ChannelProfile;
(function (ChannelProfile) {
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_COMMUNICATION"] = 0] = "CHANNEL_PROFILE_COMMUNICATION";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_GAME"] = 2] = "CHANNEL_PROFILE_GAME";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_CLOUD_GAME"] = 3] = "CHANNEL_PROFILE_CLOUD_GAME";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_LOW_LATENCY"] = 4] = "CHANNEL_PROFILE_LOW_LATENCY";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_CHAT"] = 5] = "CHANNEL_PROFILE_CHAT";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_CHAT_ROOM"] = 6] = "CHANNEL_PROFILE_CHAT_ROOM";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_LW_TOGETHER"] = 7] = "CHANNEL_PROFILE_LW_TOGETHER";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_GAME_HD"] = 8] = "CHANNEL_PROFILE_GAME_HD";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_CO_HOST"] = 9] = "CHANNEL_PROFILE_CO_HOST";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_INTERACTIVE_PODCAST"] = 10] = "CHANNEL_PROFILE_INTERACTIVE_PODCAST";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_KTV"] = 11] = "CHANNEL_PROFILE_KTV";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_CHORUS"] = 12] = "CHANNEL_PROFILE_CHORUS";
    ChannelProfile[ChannelProfile["CHANNEL_PROFIEL_VR_CHAT"] = 13] = "CHANNEL_PROFIEL_VR_CHAT";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_GAME_STREAMING"] = 14] = "CHANNEL_PROFILE_GAME_STREAMING";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_LAN_LIVE_STREAMING"] = 15] = "CHANNEL_PROFILE_LAN_LIVE_STREAMING";
    ChannelProfile[ChannelProfile["CHANNEL_PROFIEL_MEETING"] = 16] = "CHANNEL_PROFIEL_MEETING";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_MEETING_ROOM"] = 17] = "CHANNEL_PROFILE_MEETING_ROOM";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_CLASSROOM"] = 18] = "CHANNEL_PROFILE_CLASSROOM";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_LIVE_BROADCASTING"] = 1] = "CHANNEL_PROFILE_LIVE_BROADCASTING";
})(ChannelProfile || (ChannelProfile = {}));
var MixedStreamLayoutConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.MixedStreamConfig$MixedStreamLayoutConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setBackgroundColor_decorators;
    var _getBackgroundColor_decorators;
    var _setBackgroundImageURL_decorators;
    var _getBackgroundImageURL_decorators;
    var _setRegions_decorators;
    var _getRegions_decorators;
    var _setUserConfigExtraInfo_decorators;
    var _getUserConfigExtraInfo_decorators;
    _classThis = /** @class */ (function () {
        function MixedStreamLayoutConfig_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        MixedStreamLayoutConfig_1.prototype.setBackgroundColor = function (backgroundColor) {
            throw new Error('not implement');
        };
        MixedStreamLayoutConfig_1.prototype.getBackgroundColor = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutConfig_1.prototype.setBackgroundImageURL = function (backgroundImageURL) {
            throw new Error('not implement');
        };
        MixedStreamLayoutConfig_1.prototype.getBackgroundImageURL = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutConfig_1.prototype.setRegions = function (regions) {
            throw new Error('not implement');
        };
        MixedStreamLayoutConfig_1.prototype.getRegions = function () {
            throw new Error('not implement');
        };
        MixedStreamLayoutConfig_1.prototype.setUserConfigExtraInfo = function (userConfigExtraInfo) {
            throw new Error('not implement');
        };
        MixedStreamLayoutConfig_1.prototype.getUserConfigExtraInfo = function () {
            throw new Error('not implement');
        };
        return MixedStreamLayoutConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamLayoutConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setBackgroundColor_decorators = [NativeMethodSync()];
        _getBackgroundColor_decorators = [NativeMethodSync()];
        _setBackgroundImageURL_decorators = [NativeMethodSync()];
        _getBackgroundImageURL_decorators = [NativeMethodSync()];
        _setRegions_decorators = [NativeMethodSync()];
        _getRegions_decorators = [NativeMethodSync()];
        _setUserConfigExtraInfo_decorators = [NativeMethodSync()];
        _getUserConfigExtraInfo_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setBackgroundColor_decorators, { kind: "method", name: "setBackgroundColor", static: false, private: false, access: { has: function (obj) { return "setBackgroundColor" in obj; }, get: function (obj) { return obj.setBackgroundColor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getBackgroundColor_decorators, { kind: "method", name: "getBackgroundColor", static: false, private: false, access: { has: function (obj) { return "getBackgroundColor" in obj; }, get: function (obj) { return obj.getBackgroundColor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBackgroundImageURL_decorators, { kind: "method", name: "setBackgroundImageURL", static: false, private: false, access: { has: function (obj) { return "setBackgroundImageURL" in obj; }, get: function (obj) { return obj.setBackgroundImageURL; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getBackgroundImageURL_decorators, { kind: "method", name: "getBackgroundImageURL", static: false, private: false, access: { has: function (obj) { return "getBackgroundImageURL" in obj; }, get: function (obj) { return obj.getBackgroundImageURL; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRegions_decorators, { kind: "method", name: "setRegions", static: false, private: false, access: { has: function (obj) { return "setRegions" in obj; }, get: function (obj) { return obj.setRegions; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getRegions_decorators, { kind: "method", name: "getRegions", static: false, private: false, access: { has: function (obj) { return "getRegions" in obj; }, get: function (obj) { return obj.getRegions; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setUserConfigExtraInfo_decorators, { kind: "method", name: "setUserConfigExtraInfo", static: false, private: false, access: { has: function (obj) { return "setUserConfigExtraInfo" in obj; }, get: function (obj) { return obj.setUserConfigExtraInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getUserConfigExtraInfo_decorators, { kind: "method", name: "getUserConfigExtraInfo", static: false, private: false, access: { has: function (obj) { return "getUserConfigExtraInfo" in obj; }, get: function (obj) { return obj.getUserConfigExtraInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IAudioFrame$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.utils.IAudioFrame')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _timestamp_us_decorators;
    var _sample_rate_decorators;
    var _channel_decorators;
    var _getDataBuffer_decorators;
    var _data_size_decorators;
    var _frame_type_decorators;
    var _release_decorators;
    _classThis = /** @class */ (function () {
        function IAudioFrame_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        IAudioFrame_1.prototype.timestamp_us = function () {
            throw new Error('not implement');
        };
        IAudioFrame_1.prototype.sample_rate = function () {
            throw new Error('not implement');
        };
        IAudioFrame_1.prototype.channel = function () {
            throw new Error('not implement');
        };
        IAudioFrame_1.prototype.getDataBuffer = function () {
            throw new Error('not implement');
        };
        IAudioFrame_1.prototype.data_size = function () {
            throw new Error('not implement');
        };
        IAudioFrame_1.prototype.frame_type = function () {
            throw new Error('not implement');
        };
        IAudioFrame_1.prototype.release = function () {
            throw new Error('not implement');
        };
        return IAudioFrame_1;
    }());
    __setFunctionName(_classThis, "IAudioFrame");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _timestamp_us_decorators = [NativeMethodSync()];
        _sample_rate_decorators = [NativeMethodSync()];
        _channel_decorators = [NativeMethodSync()];
        _getDataBuffer_decorators = [NativeMethodSync()];
        _data_size_decorators = [NativeMethodSync()];
        _frame_type_decorators = [NativeMethodSync()];
        _release_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _timestamp_us_decorators, { kind: "method", name: "timestamp_us", static: false, private: false, access: { has: function (obj) { return "timestamp_us" in obj; }, get: function (obj) { return obj.timestamp_us; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sample_rate_decorators, { kind: "method", name: "sample_rate", static: false, private: false, access: { has: function (obj) { return "sample_rate" in obj; }, get: function (obj) { return obj.sample_rate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _channel_decorators, { kind: "method", name: "channel", static: false, private: false, access: { has: function (obj) { return "channel" in obj; }, get: function (obj) { return obj.channel; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getDataBuffer_decorators, { kind: "method", name: "getDataBuffer", static: false, private: false, access: { has: function (obj) { return "getDataBuffer" in obj; }, get: function (obj) { return obj.getDataBuffer; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _data_size_decorators, { kind: "method", name: "data_size", static: false, private: false, access: { has: function (obj) { return "data_size" in obj; }, get: function (obj) { return obj.data_size; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _frame_type_decorators, { kind: "method", name: "frame_type", static: false, private: false, access: { has: function (obj) { return "frame_type" in obj; }, get: function (obj) { return obj.frame_type; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _release_decorators, { kind: "method", name: "release", static: false, private: false, access: { has: function (obj) { return "release" in obj; }, get: function (obj) { return obj.release; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ForwardStreamStateInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.ForwardStreamStateInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _state_decorators;
    var _state_initializers = [];
    var _state_extraInitializers = [];
    var _error_decorators;
    var _error_initializers = [];
    var _error_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function ForwardStreamStateInfo_1(roomId, state, error) {
            this.roomId = __runInitializers(this, _roomId_initializers, void 0);
            this.state = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _state_initializers, void 0));
            this.error = (__runInitializers(this, _state_extraInitializers), __runInitializers(this, _error_initializers, void 0));
            __runInitializers(this, _error_extraInitializers);
        }
        return ForwardStreamStateInfo_1;
    }());
    __setFunctionName(_classThis, "ForwardStreamStateInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _roomId_decorators = [NativeMember()];
        _state_decorators = [NativeMember()];
        _error_decorators = [NativeMember()];
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _state_decorators, { kind: "field", name: "state", static: false, private: false, access: { has: function (obj) { return "state" in obj; }, get: function (obj) { return obj.state; }, set: function (obj, value) { obj.state = value; } }, metadata: _metadata }, _state_initializers, _state_extraInitializers);
        __esDecorate(null, null, _error_decorators, { kind: "field", name: "error", static: false, private: false, access: { has: function (obj) { return "error" in obj; }, get: function (obj) { return obj.error; }, set: function (obj, value) { obj.error = value; } }, metadata: _metadata }, _error_initializers, _error_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RemoteVideoConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.RemoteVideoConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _framerate_decorators;
    var _framerate_initializers = [];
    var _framerate_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RemoteVideoConfig_1(width, height, framerate) {
            this.width = __runInitializers(this, _width_initializers, void 0);
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.framerate = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _framerate_initializers, void 0));
            __runInitializers(this, _framerate_extraInitializers);
        }
        return RemoteVideoConfig_1;
    }());
    __setFunctionName(_classThis, "RemoteVideoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _framerate_decorators = [NativeMember()];
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _framerate_decorators, { kind: "field", name: "framerate", static: false, private: false, access: { has: function (obj) { return "framerate" in obj; }, get: function (obj) { return obj.framerate; }, set: function (obj, value) { obj.framerate = value; } }, metadata: _metadata }, _framerate_initializers, _framerate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var PauseResumeControlMediaType;
(function (PauseResumeControlMediaType) {
    PauseResumeControlMediaType[PauseResumeControlMediaType["AUDIO"] = 0] = "AUDIO";
    PauseResumeControlMediaType[PauseResumeControlMediaType["VIDEO"] = 1] = "VIDEO";
    PauseResumeControlMediaType[PauseResumeControlMediaType["AUDIO_AND_VIDEO"] = 2] = "AUDIO_AND_VIDEO";
})(PauseResumeControlMediaType || (PauseResumeControlMediaType = {}));
var RTCEncodedVideoFrame$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.mediaio.RTCEncodedVideoFrame')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _buffer_decorators;
    var _buffer_initializers = [];
    var _buffer_extraInitializers = [];
    var _timestampUs_decorators;
    var _timestampUs_initializers = [];
    var _timestampUs_extraInitializers = [];
    var _timestampDtsUs_decorators;
    var _timestampDtsUs_initializers = [];
    var _timestampDtsUs_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _videoCodecType_decorators;
    var _videoCodecType_initializers = [];
    var _videoCodecType_extraInitializers = [];
    var _videoPictureType_decorators;
    var _videoPictureType_initializers = [];
    var _videoPictureType_extraInitializers = [];
    var _videoRotation_decorators;
    var _videoRotation_initializers = [];
    var _videoRotation_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RTCEncodedVideoFrame_1(buffer, timestampUs, timestampDtsUs, width, height, videoCodecType, videoPictureType, videoRotation) {
            this.buffer = __runInitializers(this, _buffer_initializers, void 0);
            this.timestampUs = (__runInitializers(this, _buffer_extraInitializers), __runInitializers(this, _timestampUs_initializers, void 0));
            this.timestampDtsUs = (__runInitializers(this, _timestampUs_extraInitializers), __runInitializers(this, _timestampDtsUs_initializers, void 0));
            this.width = (__runInitializers(this, _timestampDtsUs_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.videoCodecType = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _videoCodecType_initializers, void 0));
            this.videoPictureType = (__runInitializers(this, _videoCodecType_extraInitializers), __runInitializers(this, _videoPictureType_initializers, void 0));
            this.videoRotation = (__runInitializers(this, _videoPictureType_extraInitializers), __runInitializers(this, _videoRotation_initializers, void 0));
            __runInitializers(this, _videoRotation_extraInitializers);
        }
        return RTCEncodedVideoFrame_1;
    }());
    __setFunctionName(_classThis, "RTCEncodedVideoFrame");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _buffer_decorators = [NativeMember()];
        _timestampUs_decorators = [NativeMember()];
        _timestampDtsUs_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _videoCodecType_decorators = [NativeMember()];
        _videoPictureType_decorators = [NativeMember()];
        _videoRotation_decorators = [NativeMember()];
        __esDecorate(null, null, _buffer_decorators, { kind: "field", name: "buffer", static: false, private: false, access: { has: function (obj) { return "buffer" in obj; }, get: function (obj) { return obj.buffer; }, set: function (obj, value) { obj.buffer = value; } }, metadata: _metadata }, _buffer_initializers, _buffer_extraInitializers);
        __esDecorate(null, null, _timestampUs_decorators, { kind: "field", name: "timestampUs", static: false, private: false, access: { has: function (obj) { return "timestampUs" in obj; }, get: function (obj) { return obj.timestampUs; }, set: function (obj, value) { obj.timestampUs = value; } }, metadata: _metadata }, _timestampUs_initializers, _timestampUs_extraInitializers);
        __esDecorate(null, null, _timestampDtsUs_decorators, { kind: "field", name: "timestampDtsUs", static: false, private: false, access: { has: function (obj) { return "timestampDtsUs" in obj; }, get: function (obj) { return obj.timestampDtsUs; }, set: function (obj, value) { obj.timestampDtsUs = value; } }, metadata: _metadata }, _timestampDtsUs_initializers, _timestampDtsUs_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _videoCodecType_decorators, { kind: "field", name: "videoCodecType", static: false, private: false, access: { has: function (obj) { return "videoCodecType" in obj; }, get: function (obj) { return obj.videoCodecType; }, set: function (obj, value) { obj.videoCodecType = value; } }, metadata: _metadata }, _videoCodecType_initializers, _videoCodecType_extraInitializers);
        __esDecorate(null, null, _videoPictureType_decorators, { kind: "field", name: "videoPictureType", static: false, private: false, access: { has: function (obj) { return "videoPictureType" in obj; }, get: function (obj) { return obj.videoPictureType; }, set: function (obj, value) { obj.videoPictureType = value; } }, metadata: _metadata }, _videoPictureType_initializers, _videoPictureType_extraInitializers);
        __esDecorate(null, null, _videoRotation_decorators, { kind: "field", name: "videoRotation", static: false, private: false, access: { has: function (obj) { return "videoRotation" in obj; }, get: function (obj) { return obj.videoRotation; }, set: function (obj, value) { obj.videoRotation = value; } }, metadata: _metadata }, _videoRotation_initializers, _videoRotation_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioMixingState;
(function (AudioMixingState) {
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_PRELOADED"] = 0] = "AUDIO_MIXING_STATE_PRELOADED";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_PLAYING"] = 1] = "AUDIO_MIXING_STATE_PLAYING";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_PAUSED"] = 2] = "AUDIO_MIXING_STATE_PAUSED";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_STOPPED"] = 3] = "AUDIO_MIXING_STATE_STOPPED";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_FAILED"] = 4] = "AUDIO_MIXING_STATE_FAILED";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_FINISHED"] = 5] = "AUDIO_MIXING_STATE_FINISHED";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_PCM_ENABLED"] = 6] = "AUDIO_MIXING_STATE_PCM_ENABLED";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_PCM_DISABLED"] = 7] = "AUDIO_MIXING_STATE_PCM_DISABLED";
})(AudioMixingState || (AudioMixingState = {}));
var DownloadLyricType;
(function (DownloadLyricType) {
    DownloadLyricType[DownloadLyricType["KRC"] = 0] = "KRC";
    DownloadLyricType[DownloadLyricType["LRC"] = 1] = "LRC";
})(DownloadLyricType || (DownloadLyricType = {}));
var MixedStreamType;
(function (MixedStreamType) {
    MixedStreamType[MixedStreamType["MIXED_STREAM_TYPE_BY_SERVER"] = 0] = "MIXED_STREAM_TYPE_BY_SERVER";
    MixedStreamType[MixedStreamType["MIXED_STREAM_TYPE_BY_CLIENT"] = 1] = "MIXED_STREAM_TYPE_BY_CLIENT";
})(MixedStreamType || (MixedStreamType = {}));
var RemoteAudioStats$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.RemoteAudioStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _audioLossRate_decorators;
    var _audioLossRate_initializers = [];
    var _audioLossRate_extraInitializers = [];
    var _receivedKBitrate_decorators;
    var _receivedKBitrate_initializers = [];
    var _receivedKBitrate_extraInitializers = [];
    var _stallCount_decorators;
    var _stallCount_initializers = [];
    var _stallCount_extraInitializers = [];
    var _stallDuration_decorators;
    var _stallDuration_initializers = [];
    var _stallDuration_extraInitializers = [];
    var _e2eDelay_decorators;
    var _e2eDelay_initializers = [];
    var _e2eDelay_extraInitializers = [];
    var _playoutSampleRate_decorators;
    var _playoutSampleRate_initializers = [];
    var _playoutSampleRate_extraInitializers = [];
    var _statsInterval_decorators;
    var _statsInterval_initializers = [];
    var _statsInterval_extraInitializers = [];
    var _rtt_decorators;
    var _rtt_initializers = [];
    var _rtt_extraInitializers = [];
    var _totalRtt_decorators;
    var _totalRtt_initializers = [];
    var _totalRtt_extraInitializers = [];
    var _quality_decorators;
    var _quality_initializers = [];
    var _quality_extraInitializers = [];
    var _jitterBufferDelay_decorators;
    var _jitterBufferDelay_initializers = [];
    var _jitterBufferDelay_extraInitializers = [];
    var _numChannels_decorators;
    var _numChannels_initializers = [];
    var _numChannels_extraInitializers = [];
    var _receivedSampleRate_decorators;
    var _receivedSampleRate_initializers = [];
    var _receivedSampleRate_extraInitializers = [];
    var _frozenRate_decorators;
    var _frozenRate_initializers = [];
    var _frozenRate_extraInitializers = [];
    var _concealedSamples_decorators;
    var _concealedSamples_initializers = [];
    var _concealedSamples_extraInitializers = [];
    var _concealmentEvent_decorators;
    var _concealmentEvent_initializers = [];
    var _concealmentEvent_extraInitializers = [];
    var _decSampleRate_decorators;
    var _decSampleRate_initializers = [];
    var _decSampleRate_extraInitializers = [];
    var _decDuration_decorators;
    var _decDuration_initializers = [];
    var _decDuration_extraInitializers = [];
    var _jitter_decorators;
    var _jitter_initializers = [];
    var _jitter_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RemoteAudioStats_1() {
            this.audioLossRate = __runInitializers(this, _audioLossRate_initializers, void 0);
            this.receivedKBitrate = (__runInitializers(this, _audioLossRate_extraInitializers), __runInitializers(this, _receivedKBitrate_initializers, void 0));
            this.stallCount = (__runInitializers(this, _receivedKBitrate_extraInitializers), __runInitializers(this, _stallCount_initializers, void 0));
            this.stallDuration = (__runInitializers(this, _stallCount_extraInitializers), __runInitializers(this, _stallDuration_initializers, void 0));
            this.e2eDelay = (__runInitializers(this, _stallDuration_extraInitializers), __runInitializers(this, _e2eDelay_initializers, void 0));
            this.playoutSampleRate = (__runInitializers(this, _e2eDelay_extraInitializers), __runInitializers(this, _playoutSampleRate_initializers, void 0));
            this.statsInterval = (__runInitializers(this, _playoutSampleRate_extraInitializers), __runInitializers(this, _statsInterval_initializers, void 0));
            this.rtt = (__runInitializers(this, _statsInterval_extraInitializers), __runInitializers(this, _rtt_initializers, void 0));
            this.totalRtt = (__runInitializers(this, _rtt_extraInitializers), __runInitializers(this, _totalRtt_initializers, void 0));
            this.quality = (__runInitializers(this, _totalRtt_extraInitializers), __runInitializers(this, _quality_initializers, void 0));
            this.jitterBufferDelay = (__runInitializers(this, _quality_extraInitializers), __runInitializers(this, _jitterBufferDelay_initializers, void 0));
            this.numChannels = (__runInitializers(this, _jitterBufferDelay_extraInitializers), __runInitializers(this, _numChannels_initializers, void 0));
            this.receivedSampleRate = (__runInitializers(this, _numChannels_extraInitializers), __runInitializers(this, _receivedSampleRate_initializers, void 0));
            this.frozenRate = (__runInitializers(this, _receivedSampleRate_extraInitializers), __runInitializers(this, _frozenRate_initializers, void 0));
            this.concealedSamples = (__runInitializers(this, _frozenRate_extraInitializers), __runInitializers(this, _concealedSamples_initializers, void 0));
            this.concealmentEvent = (__runInitializers(this, _concealedSamples_extraInitializers), __runInitializers(this, _concealmentEvent_initializers, void 0));
            this.decSampleRate = (__runInitializers(this, _concealmentEvent_extraInitializers), __runInitializers(this, _decSampleRate_initializers, void 0));
            this.decDuration = (__runInitializers(this, _decSampleRate_extraInitializers), __runInitializers(this, _decDuration_initializers, void 0));
            this.jitter = (__runInitializers(this, _decDuration_extraInitializers), __runInitializers(this, _jitter_initializers, void 0));
            __runInitializers(this, _jitter_extraInitializers);
        }
        return RemoteAudioStats_1;
    }());
    __setFunctionName(_classThis, "RemoteAudioStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _audioLossRate_decorators = [NativeMember()];
        _receivedKBitrate_decorators = [NativeMember()];
        _stallCount_decorators = [NativeMember()];
        _stallDuration_decorators = [NativeMember()];
        _e2eDelay_decorators = [NativeMember()];
        _playoutSampleRate_decorators = [NativeMember()];
        _statsInterval_decorators = [NativeMember()];
        _rtt_decorators = [NativeMember()];
        _totalRtt_decorators = [NativeMember()];
        _quality_decorators = [NativeMember()];
        _jitterBufferDelay_decorators = [NativeMember()];
        _numChannels_decorators = [NativeMember()];
        _receivedSampleRate_decorators = [NativeMember()];
        _frozenRate_decorators = [NativeMember()];
        _concealedSamples_decorators = [NativeMember()];
        _concealmentEvent_decorators = [NativeMember()];
        _decSampleRate_decorators = [NativeMember()];
        _decDuration_decorators = [NativeMember()];
        _jitter_decorators = [NativeMember()];
        __esDecorate(null, null, _audioLossRate_decorators, { kind: "field", name: "audioLossRate", static: false, private: false, access: { has: function (obj) { return "audioLossRate" in obj; }, get: function (obj) { return obj.audioLossRate; }, set: function (obj, value) { obj.audioLossRate = value; } }, metadata: _metadata }, _audioLossRate_initializers, _audioLossRate_extraInitializers);
        __esDecorate(null, null, _receivedKBitrate_decorators, { kind: "field", name: "receivedKBitrate", static: false, private: false, access: { has: function (obj) { return "receivedKBitrate" in obj; }, get: function (obj) { return obj.receivedKBitrate; }, set: function (obj, value) { obj.receivedKBitrate = value; } }, metadata: _metadata }, _receivedKBitrate_initializers, _receivedKBitrate_extraInitializers);
        __esDecorate(null, null, _stallCount_decorators, { kind: "field", name: "stallCount", static: false, private: false, access: { has: function (obj) { return "stallCount" in obj; }, get: function (obj) { return obj.stallCount; }, set: function (obj, value) { obj.stallCount = value; } }, metadata: _metadata }, _stallCount_initializers, _stallCount_extraInitializers);
        __esDecorate(null, null, _stallDuration_decorators, { kind: "field", name: "stallDuration", static: false, private: false, access: { has: function (obj) { return "stallDuration" in obj; }, get: function (obj) { return obj.stallDuration; }, set: function (obj, value) { obj.stallDuration = value; } }, metadata: _metadata }, _stallDuration_initializers, _stallDuration_extraInitializers);
        __esDecorate(null, null, _e2eDelay_decorators, { kind: "field", name: "e2eDelay", static: false, private: false, access: { has: function (obj) { return "e2eDelay" in obj; }, get: function (obj) { return obj.e2eDelay; }, set: function (obj, value) { obj.e2eDelay = value; } }, metadata: _metadata }, _e2eDelay_initializers, _e2eDelay_extraInitializers);
        __esDecorate(null, null, _playoutSampleRate_decorators, { kind: "field", name: "playoutSampleRate", static: false, private: false, access: { has: function (obj) { return "playoutSampleRate" in obj; }, get: function (obj) { return obj.playoutSampleRate; }, set: function (obj, value) { obj.playoutSampleRate = value; } }, metadata: _metadata }, _playoutSampleRate_initializers, _playoutSampleRate_extraInitializers);
        __esDecorate(null, null, _statsInterval_decorators, { kind: "field", name: "statsInterval", static: false, private: false, access: { has: function (obj) { return "statsInterval" in obj; }, get: function (obj) { return obj.statsInterval; }, set: function (obj, value) { obj.statsInterval = value; } }, metadata: _metadata }, _statsInterval_initializers, _statsInterval_extraInitializers);
        __esDecorate(null, null, _rtt_decorators, { kind: "field", name: "rtt", static: false, private: false, access: { has: function (obj) { return "rtt" in obj; }, get: function (obj) { return obj.rtt; }, set: function (obj, value) { obj.rtt = value; } }, metadata: _metadata }, _rtt_initializers, _rtt_extraInitializers);
        __esDecorate(null, null, _totalRtt_decorators, { kind: "field", name: "totalRtt", static: false, private: false, access: { has: function (obj) { return "totalRtt" in obj; }, get: function (obj) { return obj.totalRtt; }, set: function (obj, value) { obj.totalRtt = value; } }, metadata: _metadata }, _totalRtt_initializers, _totalRtt_extraInitializers);
        __esDecorate(null, null, _quality_decorators, { kind: "field", name: "quality", static: false, private: false, access: { has: function (obj) { return "quality" in obj; }, get: function (obj) { return obj.quality; }, set: function (obj, value) { obj.quality = value; } }, metadata: _metadata }, _quality_initializers, _quality_extraInitializers);
        __esDecorate(null, null, _jitterBufferDelay_decorators, { kind: "field", name: "jitterBufferDelay", static: false, private: false, access: { has: function (obj) { return "jitterBufferDelay" in obj; }, get: function (obj) { return obj.jitterBufferDelay; }, set: function (obj, value) { obj.jitterBufferDelay = value; } }, metadata: _metadata }, _jitterBufferDelay_initializers, _jitterBufferDelay_extraInitializers);
        __esDecorate(null, null, _numChannels_decorators, { kind: "field", name: "numChannels", static: false, private: false, access: { has: function (obj) { return "numChannels" in obj; }, get: function (obj) { return obj.numChannels; }, set: function (obj, value) { obj.numChannels = value; } }, metadata: _metadata }, _numChannels_initializers, _numChannels_extraInitializers);
        __esDecorate(null, null, _receivedSampleRate_decorators, { kind: "field", name: "receivedSampleRate", static: false, private: false, access: { has: function (obj) { return "receivedSampleRate" in obj; }, get: function (obj) { return obj.receivedSampleRate; }, set: function (obj, value) { obj.receivedSampleRate = value; } }, metadata: _metadata }, _receivedSampleRate_initializers, _receivedSampleRate_extraInitializers);
        __esDecorate(null, null, _frozenRate_decorators, { kind: "field", name: "frozenRate", static: false, private: false, access: { has: function (obj) { return "frozenRate" in obj; }, get: function (obj) { return obj.frozenRate; }, set: function (obj, value) { obj.frozenRate = value; } }, metadata: _metadata }, _frozenRate_initializers, _frozenRate_extraInitializers);
        __esDecorate(null, null, _concealedSamples_decorators, { kind: "field", name: "concealedSamples", static: false, private: false, access: { has: function (obj) { return "concealedSamples" in obj; }, get: function (obj) { return obj.concealedSamples; }, set: function (obj, value) { obj.concealedSamples = value; } }, metadata: _metadata }, _concealedSamples_initializers, _concealedSamples_extraInitializers);
        __esDecorate(null, null, _concealmentEvent_decorators, { kind: "field", name: "concealmentEvent", static: false, private: false, access: { has: function (obj) { return "concealmentEvent" in obj; }, get: function (obj) { return obj.concealmentEvent; }, set: function (obj, value) { obj.concealmentEvent = value; } }, metadata: _metadata }, _concealmentEvent_initializers, _concealmentEvent_extraInitializers);
        __esDecorate(null, null, _decSampleRate_decorators, { kind: "field", name: "decSampleRate", static: false, private: false, access: { has: function (obj) { return "decSampleRate" in obj; }, get: function (obj) { return obj.decSampleRate; }, set: function (obj, value) { obj.decSampleRate = value; } }, metadata: _metadata }, _decSampleRate_initializers, _decSampleRate_extraInitializers);
        __esDecorate(null, null, _decDuration_decorators, { kind: "field", name: "decDuration", static: false, private: false, access: { has: function (obj) { return "decDuration" in obj; }, get: function (obj) { return obj.decDuration; }, set: function (obj, value) { obj.decDuration = value; } }, metadata: _metadata }, _decDuration_initializers, _decDuration_extraInitializers);
        __esDecorate(null, null, _jitter_decorators, { kind: "field", name: "jitter", static: false, private: false, access: { has: function (obj) { return "jitter" in obj; }, get: function (obj) { return obj.jitter; }, set: function (obj, value) { obj.jitter = value; } }, metadata: _metadata }, _jitter_initializers, _jitter_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.ScreenSharingParameters')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _maxWidth_decorators;
    var _maxWidth_initializers = [];
    var _maxWidth_extraInitializers = [];
    var _maxHeight_decorators;
    var _maxHeight_initializers = [];
    var _maxHeight_extraInitializers = [];
    var _frameRate_decorators;
    var _frameRate_initializers = [];
    var _frameRate_extraInitializers = [];
    var _bitrate_decorators;
    var _bitrate_initializers = [];
    var _bitrate_extraInitializers = [];
    var _minBitrate_decorators;
    var _minBitrate_initializers = [];
    var _minBitrate_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function ScreenSharingParameters_1() {
            this.maxWidth = __runInitializers(this, _maxWidth_initializers, void 0);
            this.maxHeight = (__runInitializers(this, _maxWidth_extraInitializers), __runInitializers(this, _maxHeight_initializers, void 0));
            this.frameRate = (__runInitializers(this, _maxHeight_extraInitializers), __runInitializers(this, _frameRate_initializers, void 0));
            this.bitrate = (__runInitializers(this, _frameRate_extraInitializers), __runInitializers(this, _bitrate_initializers, void 0));
            this.minBitrate = (__runInitializers(this, _bitrate_extraInitializers), __runInitializers(this, _minBitrate_initializers, void 0));
            __runInitializers(this, _minBitrate_extraInitializers);
        }
        return ScreenSharingParameters_1;
    }());
    __setFunctionName(_classThis, "ScreenSharingParameters");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _maxWidth_decorators = [NativeMember()];
        _maxHeight_decorators = [NativeMember()];
        _frameRate_decorators = [NativeMember()];
        _bitrate_decorators = [NativeMember()];
        _minBitrate_decorators = [NativeMember()];
        __esDecorate(null, null, _maxWidth_decorators, { kind: "field", name: "maxWidth", static: false, private: false, access: { has: function (obj) { return "maxWidth" in obj; }, get: function (obj) { return obj.maxWidth; }, set: function (obj, value) { obj.maxWidth = value; } }, metadata: _metadata }, _maxWidth_initializers, _maxWidth_extraInitializers);
        __esDecorate(null, null, _maxHeight_decorators, { kind: "field", name: "maxHeight", static: false, private: false, access: { has: function (obj) { return "maxHeight" in obj; }, get: function (obj) { return obj.maxHeight; }, set: function (obj, value) { obj.maxHeight = value; } }, metadata: _metadata }, _maxHeight_initializers, _maxHeight_extraInitializers);
        __esDecorate(null, null, _frameRate_decorators, { kind: "field", name: "frameRate", static: false, private: false, access: { has: function (obj) { return "frameRate" in obj; }, get: function (obj) { return obj.frameRate; }, set: function (obj, value) { obj.frameRate = value; } }, metadata: _metadata }, _frameRate_initializers, _frameRate_extraInitializers);
        __esDecorate(null, null, _bitrate_decorators, { kind: "field", name: "bitrate", static: false, private: false, access: { has: function (obj) { return "bitrate" in obj; }, get: function (obj) { return obj.bitrate; }, set: function (obj, value) { obj.bitrate = value; } }, metadata: _metadata }, _bitrate_initializers, _bitrate_extraInitializers);
        __esDecorate(null, null, _minBitrate_decorators, { kind: "field", name: "minBitrate", static: false, private: false, access: { has: function (obj) { return "minBitrate" in obj; }, get: function (obj) { return obj.minBitrate; }, set: function (obj, value) { obj.minBitrate = value; } }, metadata: _metadata }, _minBitrate_initializers, _minBitrate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var VideoOrientation;
(function (VideoOrientation) {
    VideoOrientation[VideoOrientation["ADAPTIVE"] = 0] = "ADAPTIVE";
    VideoOrientation[VideoOrientation["PORTRAIT"] = 1] = "PORTRAIT";
    VideoOrientation[VideoOrientation["LANDSCAPE"] = 2] = "LANDSCAPE";
})(VideoOrientation || (VideoOrientation = {}));
var AudioRecordingConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.AudioRecordingConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _absoluteFileName_decorators;
    var _absoluteFileName_initializers = [];
    var _absoluteFileName_extraInitializers = [];
    var _sampleRate_decorators;
    var _sampleRate_initializers = [];
    var _sampleRate_extraInitializers = [];
    var _channel_decorators;
    var _channel_initializers = [];
    var _channel_extraInitializers = [];
    var _frameSource_decorators;
    var _frameSource_initializers = [];
    var _frameSource_extraInitializers = [];
    var _quality_decorators;
    var _quality_initializers = [];
    var _quality_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function AudioRecordingConfig_1() {
            this.absoluteFileName = __runInitializers(this, _absoluteFileName_initializers, void 0);
            this.sampleRate = (__runInitializers(this, _absoluteFileName_extraInitializers), __runInitializers(this, _sampleRate_initializers, void 0));
            this.channel = (__runInitializers(this, _sampleRate_extraInitializers), __runInitializers(this, _channel_initializers, void 0));
            this.frameSource = (__runInitializers(this, _channel_extraInitializers), __runInitializers(this, _frameSource_initializers, void 0));
            this.quality = (__runInitializers(this, _frameSource_extraInitializers), __runInitializers(this, _quality_initializers, void 0));
            __runInitializers(this, _quality_extraInitializers);
        }
        return AudioRecordingConfig_1;
    }());
    __setFunctionName(_classThis, "AudioRecordingConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _absoluteFileName_decorators = [NativeMember()];
        _sampleRate_decorators = [NativeMember()];
        _channel_decorators = [NativeMember()];
        _frameSource_decorators = [NativeMember()];
        _quality_decorators = [NativeMember()];
        __esDecorate(null, null, _absoluteFileName_decorators, { kind: "field", name: "absoluteFileName", static: false, private: false, access: { has: function (obj) { return "absoluteFileName" in obj; }, get: function (obj) { return obj.absoluteFileName; }, set: function (obj, value) { obj.absoluteFileName = value; } }, metadata: _metadata }, _absoluteFileName_initializers, _absoluteFileName_extraInitializers);
        __esDecorate(null, null, _sampleRate_decorators, { kind: "field", name: "sampleRate", static: false, private: false, access: { has: function (obj) { return "sampleRate" in obj; }, get: function (obj) { return obj.sampleRate; }, set: function (obj, value) { obj.sampleRate = value; } }, metadata: _metadata }, _sampleRate_initializers, _sampleRate_extraInitializers);
        __esDecorate(null, null, _channel_decorators, { kind: "field", name: "channel", static: false, private: false, access: { has: function (obj) { return "channel" in obj; }, get: function (obj) { return obj.channel; }, set: function (obj, value) { obj.channel = value; } }, metadata: _metadata }, _channel_initializers, _channel_extraInitializers);
        __esDecorate(null, null, _frameSource_decorators, { kind: "field", name: "frameSource", static: false, private: false, access: { has: function (obj) { return "frameSource" in obj; }, get: function (obj) { return obj.frameSource; }, set: function (obj, value) { obj.frameSource = value; } }, metadata: _metadata }, _frameSource_initializers, _frameSource_extraInitializers);
        __esDecorate(null, null, _quality_decorators, { kind: "field", name: "quality", static: false, private: false, access: { has: function (obj) { return "quality" in obj; }, get: function (obj) { return obj.quality; }, set: function (obj, value) { obj.quality = value; } }, metadata: _metadata }, _quality_initializers, _quality_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioRoute;
(function (AudioRoute) {
    AudioRoute[AudioRoute["AUDIO_ROUTE_DEFAULT"] = -1] = "AUDIO_ROUTE_DEFAULT";
    AudioRoute[AudioRoute["AUDIO_ROUTE_HEADSET"] = 1] = "AUDIO_ROUTE_HEADSET";
    AudioRoute[AudioRoute["AUDIO_ROUTE_EARPIECE"] = 2] = "AUDIO_ROUTE_EARPIECE";
    AudioRoute[AudioRoute["AUDIO_ROUTE_SPEAKERPHONE"] = 3] = "AUDIO_ROUTE_SPEAKERPHONE";
    AudioRoute[AudioRoute["AUDIO_ROUTE_HEADSET_BLUETOOTH"] = 4] = "AUDIO_ROUTE_HEADSET_BLUETOOTH";
    AudioRoute[AudioRoute["AUDIO_ROUTE_HEADSET_USB"] = 5] = "AUDIO_ROUTE_HEADSET_USB";
})(AudioRoute || (AudioRoute = {}));
var Position$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.Position')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _x_decorators;
    var _x_initializers = [];
    var _x_extraInitializers = [];
    var _y_decorators;
    var _y_initializers = [];
    var _y_extraInitializers = [];
    var _z_decorators;
    var _z_initializers = [];
    var _z_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function Position_1() {
            this.x = __runInitializers(this, _x_initializers, void 0);
            this.y = (__runInitializers(this, _x_extraInitializers), __runInitializers(this, _y_initializers, void 0));
            this.z = (__runInitializers(this, _y_extraInitializers), __runInitializers(this, _z_initializers, void 0));
            __runInitializers(this, _z_extraInitializers);
        }
        return Position_1;
    }());
    __setFunctionName(_classThis, "Position");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _x_decorators = [NativeMember()];
        _y_decorators = [NativeMember()];
        _z_decorators = [NativeMember()];
        __esDecorate(null, null, _x_decorators, { kind: "field", name: "x", static: false, private: false, access: { has: function (obj) { return "x" in obj; }, get: function (obj) { return obj.x; }, set: function (obj, value) { obj.x = value; } }, metadata: _metadata }, _x_initializers, _x_extraInitializers);
        __esDecorate(null, null, _y_decorators, { kind: "field", name: "y", static: false, private: false, access: { has: function (obj) { return "y" in obj; }, get: function (obj) { return obj.y; }, set: function (obj, value) { obj.y = value; } }, metadata: _metadata }, _y_initializers, _y_extraInitializers);
        __esDecorate(null, null, _z_decorators, { kind: "field", name: "z", static: false, private: false, access: { has: function (obj) { return "z" in obj; }, get: function (obj) { return obj.z; }, set: function (obj, value) { obj.z = value; } }, metadata: _metadata }, _z_initializers, _z_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MediaInputType;
(function (MediaInputType) {
    MediaInputType[MediaInputType["MEDIA_INPUT_TYPE_EXTERNAL"] = 0] = "MEDIA_INPUT_TYPE_EXTERNAL";
    MediaInputType[MediaInputType["MEDIA_INPUT_TYPE_INTERNAL"] = 1] = "MEDIA_INPUT_TYPE_INTERNAL";
})(MediaInputType || (MediaInputType = {}));
var AudioPlayType;
(function (AudioPlayType) {
    AudioPlayType[AudioPlayType["LOCAL"] = 0] = "LOCAL";
    AudioPlayType[AudioPlayType["REMOTE"] = 1] = "REMOTE";
    AudioPlayType[AudioPlayType["LOCAL_AND_REMOTE"] = 2] = "LOCAL_AND_REMOTE";
})(AudioPlayType || (AudioPlayType = {}));
var DownloadFileType;
(function (DownloadFileType) {
    DownloadFileType[DownloadFileType["MUSIC"] = 1] = "MUSIC";
    DownloadFileType[DownloadFileType["KRC"] = 2] = "KRC";
    DownloadFileType[DownloadFileType["LRC"] = 3] = "LRC";
    DownloadFileType[DownloadFileType["MIDI"] = 4] = "MIDI";
})(DownloadFileType || (DownloadFileType = {}));
var MediaPlayerCustomSourceSeekWhence;
(function (MediaPlayerCustomSourceSeekWhence) {
    MediaPlayerCustomSourceSeekWhence[MediaPlayerCustomSourceSeekWhence["SET"] = 0] = "SET";
    MediaPlayerCustomSourceSeekWhence[MediaPlayerCustomSourceSeekWhence["CUR"] = 1] = "CUR";
    MediaPlayerCustomSourceSeekWhence[MediaPlayerCustomSourceSeekWhence["END"] = 2] = "END";
    MediaPlayerCustomSourceSeekWhence[MediaPlayerCustomSourceSeekWhence["SIZE"] = 3] = "SIZE";
})(MediaPlayerCustomSourceSeekWhence || (MediaPlayerCustomSourceSeekWhence = {}));
var AudioCodecType;
(function (AudioCodecType) {
    AudioCodecType["AUDIO_CODEC_TYPE_AAC"] = "AAC";
})(AudioCodecType || (AudioCodecType = {}));
var SingScoringConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.SingScoringConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _sampleRate_decorators;
    var _sampleRate_initializers = [];
    var _sampleRate_extraInitializers = [];
    var _mode_decorators;
    var _mode_initializers = [];
    var _mode_extraInitializers = [];
    var _lyricsFilepath_decorators;
    var _lyricsFilepath_initializers = [];
    var _lyricsFilepath_extraInitializers = [];
    var _midiFilepath_decorators;
    var _midiFilepath_initializers = [];
    var _midiFilepath_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function SingScoringConfig_1(sampleRate, mode, lyricsFilepath, midiFilepath) {
            this.sampleRate = __runInitializers(this, _sampleRate_initializers, void 0);
            this.mode = (__runInitializers(this, _sampleRate_extraInitializers), __runInitializers(this, _mode_initializers, void 0));
            this.lyricsFilepath = (__runInitializers(this, _mode_extraInitializers), __runInitializers(this, _lyricsFilepath_initializers, void 0));
            this.midiFilepath = (__runInitializers(this, _lyricsFilepath_extraInitializers), __runInitializers(this, _midiFilepath_initializers, void 0));
            __runInitializers(this, _midiFilepath_extraInitializers);
        }
        return SingScoringConfig_1;
    }());
    __setFunctionName(_classThis, "SingScoringConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _sampleRate_decorators = [NativeMember()];
        _mode_decorators = [NativeMember()];
        _lyricsFilepath_decorators = [NativeMember()];
        _midiFilepath_decorators = [NativeMember()];
        __esDecorate(null, null, _sampleRate_decorators, { kind: "field", name: "sampleRate", static: false, private: false, access: { has: function (obj) { return "sampleRate" in obj; }, get: function (obj) { return obj.sampleRate; }, set: function (obj, value) { obj.sampleRate = value; } }, metadata: _metadata }, _sampleRate_initializers, _sampleRate_extraInitializers);
        __esDecorate(null, null, _mode_decorators, { kind: "field", name: "mode", static: false, private: false, access: { has: function (obj) { return "mode" in obj; }, get: function (obj) { return obj.mode; }, set: function (obj, value) { obj.mode = value; } }, metadata: _metadata }, _mode_initializers, _mode_extraInitializers);
        __esDecorate(null, null, _lyricsFilepath_decorators, { kind: "field", name: "lyricsFilepath", static: false, private: false, access: { has: function (obj) { return "lyricsFilepath" in obj; }, get: function (obj) { return obj.lyricsFilepath; }, set: function (obj, value) { obj.lyricsFilepath = value; } }, metadata: _metadata }, _lyricsFilepath_initializers, _lyricsFilepath_extraInitializers);
        __esDecorate(null, null, _midiFilepath_decorators, { kind: "field", name: "midiFilepath", static: false, private: false, access: { has: function (obj) { return "midiFilepath" in obj; }, get: function (obj) { return obj.midiFilepath; }, set: function (obj, value) { obj.midiFilepath = value; } }, metadata: _metadata }, _midiFilepath_initializers, _midiFilepath_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var LyricStatus;
(function (LyricStatus) {
    LyricStatus[LyricStatus["NONE"] = 0] = "NONE";
    LyricStatus[LyricStatus["KRC"] = 1] = "KRC";
    LyricStatus[LyricStatus["LRC"] = 2] = "LRC";
    LyricStatus[LyricStatus["KRC_AND_LRC"] = 4] = "KRC_AND_LRC";
})(LyricStatus || (LyricStatus = {}));
var AudioQuality;
(function (AudioQuality) {
    AudioQuality[AudioQuality["AUDIO_QUALITY_LOW"] = 0] = "AUDIO_QUALITY_LOW";
    AudioQuality[AudioQuality["AUDIO_QUALITY_MEDIUM"] = 1] = "AUDIO_QUALITY_MEDIUM";
    AudioQuality[AudioQuality["AUDIO_QUALITY_HIGH"] = 2] = "AUDIO_QUALITY_HIGH";
    AudioQuality[AudioQuality["AUDIO_QUALITY_ULTRA_HIGH"] = 3] = "AUDIO_QUALITY_ULTRA_HIGH";
})(AudioQuality || (AudioQuality = {}));
var MixedStreamLayoutRegionType;
(function (MixedStreamLayoutRegionType) {
    MixedStreamLayoutRegionType[MixedStreamLayoutRegionType["MIXED_STREAM_LAYOUT_REGION_TYPE_VIDEO_STREAM"] = 0] = "MIXED_STREAM_LAYOUT_REGION_TYPE_VIDEO_STREAM";
    MixedStreamLayoutRegionType[MixedStreamLayoutRegionType["MIXED_STREAM_LAYOUT_REGION_TYPE_IMAGE"] = 1] = "MIXED_STREAM_LAYOUT_REGION_TYPE_IMAGE";
})(MixedStreamLayoutRegionType || (MixedStreamLayoutRegionType = {}));
var AudioFrameCallbackMethod;
(function (AudioFrameCallbackMethod) {
    AudioFrameCallbackMethod[AudioFrameCallbackMethod["AUDIO_FRAME_CALLBACK_RECORD"] = 0] = "AUDIO_FRAME_CALLBACK_RECORD";
    AudioFrameCallbackMethod[AudioFrameCallbackMethod["AUDIO_FRAME_CALLBACK_PLAYBACK"] = 1] = "AUDIO_FRAME_CALLBACK_PLAYBACK";
    AudioFrameCallbackMethod[AudioFrameCallbackMethod["AUDIO_FRAME_CALLBACK_MIXED"] = 2] = "AUDIO_FRAME_CALLBACK_MIXED";
    AudioFrameCallbackMethod[AudioFrameCallbackMethod["AUDIO_FRAME_CALLBACK_REMOTE_USER"] = 3] = "AUDIO_FRAME_CALLBACK_REMOTE_USER";
})(AudioFrameCallbackMethod || (AudioFrameCallbackMethod = {}));
var RtcUser = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.RtcUser')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _metaData_decorators;
    var _metaData_initializers = [];
    var _metaData_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RtcUser_1() {
            this.userId = __runInitializers(this, _userId_initializers, void 0);
            this.metaData = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _metaData_initializers, void 0));
            __runInitializers(this, _metaData_extraInitializers);
        }
        return RtcUser_1;
    }());
    __setFunctionName(_classThis, "RtcUser");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _userId_decorators = [NativeMember()];
        _metaData_decorators = [NativeMember()];
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _metaData_decorators, { kind: "field", name: "metaData", static: false, private: false, access: { has: function (obj) { return "metaData" in obj; }, get: function (obj) { return obj.metaData; }, set: function (obj, value) { obj.metaData = value; } }, metadata: _metadata }, _metaData_initializers, _metaData_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var LogoutReason;
(function (LogoutReason) {
    LogoutReason[LogoutReason["LOGOUT_REASON_LOGOUT"] = 0] = "LOGOUT_REASON_LOGOUT";
    LogoutReason[LogoutReason["LOGOUT_REASON_DUPLICATE_LOGIN"] = 1] = "LOGOUT_REASON_DUPLICATE_LOGIN";
})(LogoutReason || (LogoutReason = {}));
var VideoRenderMirrorType;
(function (VideoRenderMirrorType) {
    VideoRenderMirrorType[VideoRenderMirrorType["ON"] = 1] = "ON";
    VideoRenderMirrorType[VideoRenderMirrorType["OFF"] = 2] = "OFF";
})(VideoRenderMirrorType || (VideoRenderMirrorType = {}));
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.publicstream.PublicStreaming$SourceCrop')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _locationX_decorators;
    var _locationX_initializers = [];
    var _locationX_extraInitializers = [];
    var _locationY_decorators;
    var _locationY_initializers = [];
    var _locationY_extraInitializers = [];
    var _widthProportion_decorators;
    var _widthProportion_initializers = [];
    var _widthProportion_extraInitializers = [];
    var _heightProportion_decorators;
    var _heightProportion_initializers = [];
    var _heightProportion_extraInitializers = [];
    var _setLocationX_decorators;
    var _setLocationY_decorators;
    var _setWidthProportion_decorators;
    var _setHeightProportion_decorators;
    _classThis = /** @class */ (function () {
        function SourceCrop_1() {
            this.locationX = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _locationX_initializers, void 0));
            this.locationY = (__runInitializers(this, _locationX_extraInitializers), __runInitializers(this, _locationY_initializers, void 0));
            this.widthProportion = (__runInitializers(this, _locationY_extraInitializers), __runInitializers(this, _widthProportion_initializers, void 0));
            this.heightProportion = (__runInitializers(this, _widthProportion_extraInitializers), __runInitializers(this, _heightProportion_initializers, void 0));
            __runInitializers(this, _heightProportion_extraInitializers);
        }
        SourceCrop_1.prototype.setLocationX = function (x) {
            throw new Error('not implement');
        };
        SourceCrop_1.prototype.setLocationY = function (y) {
            throw new Error('not implement');
        };
        SourceCrop_1.prototype.setWidthProportion = function (w) {
            throw new Error('not implement');
        };
        SourceCrop_1.prototype.setHeightProportion = function (h) {
            throw new Error('not implement');
        };
        return SourceCrop_1;
    }());
    __setFunctionName(_classThis, "SourceCrop");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _locationX_decorators = [NativeMember()];
        _locationY_decorators = [NativeMember()];
        _widthProportion_decorators = [NativeMember()];
        _heightProportion_decorators = [NativeMember()];
        _setLocationX_decorators = [NativeMethodSync()];
        _setLocationY_decorators = [NativeMethodSync()];
        _setWidthProportion_decorators = [NativeMethodSync()];
        _setHeightProportion_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setLocationX_decorators, { kind: "method", name: "setLocationX", static: false, private: false, access: { has: function (obj) { return "setLocationX" in obj; }, get: function (obj) { return obj.setLocationX; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocationY_decorators, { kind: "method", name: "setLocationY", static: false, private: false, access: { has: function (obj) { return "setLocationY" in obj; }, get: function (obj) { return obj.setLocationY; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setWidthProportion_decorators, { kind: "method", name: "setWidthProportion", static: false, private: false, access: { has: function (obj) { return "setWidthProportion" in obj; }, get: function (obj) { return obj.setWidthProportion; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setHeightProportion_decorators, { kind: "method", name: "setHeightProportion", static: false, private: false, access: { has: function (obj) { return "setHeightProportion" in obj; }, get: function (obj) { return obj.setHeightProportion; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _locationX_decorators, { kind: "field", name: "locationX", static: false, private: false, access: { has: function (obj) { return "locationX" in obj; }, get: function (obj) { return obj.locationX; }, set: function (obj, value) { obj.locationX = value; } }, metadata: _metadata }, _locationX_initializers, _locationX_extraInitializers);
        __esDecorate(null, null, _locationY_decorators, { kind: "field", name: "locationY", static: false, private: false, access: { has: function (obj) { return "locationY" in obj; }, get: function (obj) { return obj.locationY; }, set: function (obj, value) { obj.locationY = value; } }, metadata: _metadata }, _locationY_initializers, _locationY_extraInitializers);
        __esDecorate(null, null, _widthProportion_decorators, { kind: "field", name: "widthProportion", static: false, private: false, access: { has: function (obj) { return "widthProportion" in obj; }, get: function (obj) { return obj.widthProportion; }, set: function (obj, value) { obj.widthProportion = value; } }, metadata: _metadata }, _widthProportion_initializers, _widthProportion_extraInitializers);
        __esDecorate(null, null, _heightProportion_decorators, { kind: "field", name: "heightProportion", static: false, private: false, access: { has: function (obj) { return "heightProportion" in obj; }, get: function (obj) { return obj.heightProportion; }, set: function (obj, value) { obj.heightProportion = value; } }, metadata: _metadata }, _heightProportion_initializers, _heightProportion_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var LiveTranscoding$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.LiveTranscoding')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _instanceExtraInitializers = [];
    var _static_getDefualtLiveTranscode_decorators;
    var _getFieldVideoConfigBFrame_decorators;
    var _setUrl_decorators;
    var _setRoomId_decorators;
    var _setUserId_decorators;
    var _setVideo_decorators;
    var _setAudio_decorators;
    var _setSpatialConfig_decorators;
    var _setClientMixParam_decorators;
    var _setLayout_decorators;
    var _getMixType_decorators;
    var _setMixType_decorators;
    var _getUrl_decorators;
    var _getVideo_decorators;
    var _getAudio_decorators;
    var _getSpatialConfig_decorators;
    var _getClientMixParam_decorators;
    var _getLayout_decorators;
    var _setAction_decorators;
    var LiveTranscoding = _classThis = /** @class */ (function () {
        function LiveTranscoding_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        LiveTranscoding_1.getDefualtLiveTranscode = function () {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.getFieldVideoConfigBFrame = function () {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.setUrl = function (url) {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.setRoomId = function (roomId) {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.setUserId = function (userId) {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.setVideo = function (video) {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.setAudio = function (audio) {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.setSpatialConfig = function (spatialConfig) {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.setClientMixParam = function (param) {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.setLayout = function (layout) {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.getMixType = function () {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.setMixType = function (mixType) {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.getUrl = function () {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.getVideo = function () {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.getAudio = function () {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.getSpatialConfig = function () {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.getClientMixParam = function () {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.getLayout = function () {
            throw new Error('not implement');
        };
        LiveTranscoding_1.prototype.setAction = function (action) {
            throw new Error('not implement');
        };
        return LiveTranscoding_1;
    }());
    __setFunctionName(_classThis, "LiveTranscoding");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_getDefualtLiveTranscode_decorators = [ReturnClass(function () { return LiveTranscoding; }), NativeStaticMethodSync()];
        _getFieldVideoConfigBFrame_decorators = [NativeMethodSync()];
        _setUrl_decorators = [NativeMethodSync()];
        _setRoomId_decorators = [NativeMethodSync()];
        _setUserId_decorators = [NativeMethodSync()];
        _setVideo_decorators = [NativeMethodSync()];
        _setAudio_decorators = [NativeMethodSync()];
        _setSpatialConfig_decorators = [NativeMethodSync()];
        _setClientMixParam_decorators = [NativeMethodSync()];
        _setLayout_decorators = [NativeMethodSync()];
        _getMixType_decorators = [NativeMethodSync()];
        _setMixType_decorators = [NativeMethodSync()];
        _getUrl_decorators = [NativeMethodSync()];
        _getVideo_decorators = [ReturnClass(function () { return VideoConfig; }), NativeMethodSync()];
        _getAudio_decorators = [ReturnClass(function () { return AudioConfig; }), NativeMethodSync()];
        _getSpatialConfig_decorators = [ReturnClass(function () { return SpatialConfig; }), NativeMethodSync()];
        _getClientMixParam_decorators = [ReturnClass(function () { return ClientMixParam; }), NativeMethodSync()];
        _getLayout_decorators = [ReturnClass(function () { return Layout; }), NativeMethodSync()];
        _setAction_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _static_getDefualtLiveTranscode_decorators, { kind: "method", name: "getDefualtLiveTranscode", static: true, private: false, access: { has: function (obj) { return "getDefualtLiveTranscode" in obj; }, get: function (obj) { return obj.getDefualtLiveTranscode; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _getFieldVideoConfigBFrame_decorators, { kind: "method", name: "getFieldVideoConfigBFrame", static: false, private: false, access: { has: function (obj) { return "getFieldVideoConfigBFrame" in obj; }, get: function (obj) { return obj.getFieldVideoConfigBFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setUrl_decorators, { kind: "method", name: "setUrl", static: false, private: false, access: { has: function (obj) { return "setUrl" in obj; }, get: function (obj) { return obj.setUrl; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRoomId_decorators, { kind: "method", name: "setRoomId", static: false, private: false, access: { has: function (obj) { return "setRoomId" in obj; }, get: function (obj) { return obj.setRoomId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setUserId_decorators, { kind: "method", name: "setUserId", static: false, private: false, access: { has: function (obj) { return "setUserId" in obj; }, get: function (obj) { return obj.setUserId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideo_decorators, { kind: "method", name: "setVideo", static: false, private: false, access: { has: function (obj) { return "setVideo" in obj; }, get: function (obj) { return obj.setVideo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudio_decorators, { kind: "method", name: "setAudio", static: false, private: false, access: { has: function (obj) { return "setAudio" in obj; }, get: function (obj) { return obj.setAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setSpatialConfig_decorators, { kind: "method", name: "setSpatialConfig", static: false, private: false, access: { has: function (obj) { return "setSpatialConfig" in obj; }, get: function (obj) { return obj.setSpatialConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setClientMixParam_decorators, { kind: "method", name: "setClientMixParam", static: false, private: false, access: { has: function (obj) { return "setClientMixParam" in obj; }, get: function (obj) { return obj.setClientMixParam; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLayout_decorators, { kind: "method", name: "setLayout", static: false, private: false, access: { has: function (obj) { return "setLayout" in obj; }, get: function (obj) { return obj.setLayout; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getMixType_decorators, { kind: "method", name: "getMixType", static: false, private: false, access: { has: function (obj) { return "getMixType" in obj; }, get: function (obj) { return obj.getMixType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setMixType_decorators, { kind: "method", name: "setMixType", static: false, private: false, access: { has: function (obj) { return "setMixType" in obj; }, get: function (obj) { return obj.setMixType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getUrl_decorators, { kind: "method", name: "getUrl", static: false, private: false, access: { has: function (obj) { return "getUrl" in obj; }, get: function (obj) { return obj.getUrl; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getVideo_decorators, { kind: "method", name: "getVideo", static: false, private: false, access: { has: function (obj) { return "getVideo" in obj; }, get: function (obj) { return obj.getVideo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudio_decorators, { kind: "method", name: "getAudio", static: false, private: false, access: { has: function (obj) { return "getAudio" in obj; }, get: function (obj) { return obj.getAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getSpatialConfig_decorators, { kind: "method", name: "getSpatialConfig", static: false, private: false, access: { has: function (obj) { return "getSpatialConfig" in obj; }, get: function (obj) { return obj.getSpatialConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getClientMixParam_decorators, { kind: "method", name: "getClientMixParam", static: false, private: false, access: { has: function (obj) { return "getClientMixParam" in obj; }, get: function (obj) { return obj.getClientMixParam; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getLayout_decorators, { kind: "method", name: "getLayout", static: false, private: false, access: { has: function (obj) { return "getLayout" in obj; }, get: function (obj) { return obj.getLayout; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAction_decorators, { kind: "method", name: "setAction", static: false, private: false, access: { has: function (obj) { return "setAction" in obj; }, get: function (obj) { return obj.setAction; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        LiveTranscoding = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
    })();
    _classThis.ACTION_START = (__runInitializers(_classThis, _staticExtraInitializers), 'started');
    _classThis.ACTION_CHANGED = 'layoutChanged';
    _classThis.ACTION_STOPPED = 'stopped';
    (function () {
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return LiveTranscoding = _classThis;
}();
var VideoDenoiseMode;
(function (VideoDenoiseMode) {
    VideoDenoiseMode[VideoDenoiseMode["VIDEO_DENOISE_MODE_OFF"] = 0] = "VIDEO_DENOISE_MODE_OFF";
    VideoDenoiseMode[VideoDenoiseMode["VIDEO_DENOISE_MODE_AUTO"] = 1] = "VIDEO_DENOISE_MODE_AUTO";
})(VideoDenoiseMode || (VideoDenoiseMode = {}));
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.VideoDimensions')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function VideoDimensions_1() {
            this.width = __runInitializers(this, _width_initializers, void 0);
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            __runInitializers(this, _height_extraInitializers);
        }
        return VideoDimensions_1;
    }());
    __setFunctionName(_classThis, "VideoDimensions");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var SpatialConfig = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.LiveTranscoding$SpatialConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setAudienceSpatialPosition_decorators;
    var _setAudienceSpatialOrientation_decorators;
    var _setEnableSpatialRender_decorators;
    _classThis = /** @class */ (function () {
        function SpatialConfig_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        SpatialConfig_1.prototype.setAudienceSpatialPosition = function (pos) {
            throw new Error('not implement');
        };
        SpatialConfig_1.prototype.setAudienceSpatialOrientation = function (orientation) {
            throw new Error('not implement');
        };
        SpatialConfig_1.prototype.setEnableSpatialRender = function (enableSpatialRender) {
            throw new Error('not implement');
        };
        return SpatialConfig_1;
    }());
    __setFunctionName(_classThis, "SpatialConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setAudienceSpatialPosition_decorators = [NativeMethodSync()];
        _setAudienceSpatialOrientation_decorators = [NativeMethodSync()];
        _setEnableSpatialRender_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setAudienceSpatialPosition_decorators, { kind: "method", name: "setAudienceSpatialPosition", static: false, private: false, access: { has: function (obj) { return "setAudienceSpatialPosition" in obj; }, get: function (obj) { return obj.setAudienceSpatialPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudienceSpatialOrientation_decorators, { kind: "method", name: "setAudienceSpatialOrientation", static: false, private: false, access: { has: function (obj) { return "setAudienceSpatialOrientation" in obj; }, get: function (obj) { return obj.setAudienceSpatialOrientation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEnableSpatialRender_decorators, { kind: "method", name: "setEnableSpatialRender", static: false, private: false, access: { has: function (obj) { return "setEnableSpatialRender" in obj; }, get: function (obj) { return obj.setEnableSpatialRender; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MixedStreamSEIContentMode;
(function (MixedStreamSEIContentMode) {
    MixedStreamSEIContentMode[MixedStreamSEIContentMode["MIXED_STREAM_SEI_CONTENT_MODE_DEFAULT"] = 0] = "MIXED_STREAM_SEI_CONTENT_MODE_DEFAULT";
    MixedStreamSEIContentMode[MixedStreamSEIContentMode["MIXED_STREAM_SEI_CONTENT_MODE_ENABLE_VOLUME_INDICATION"] = 1] = "MIXED_STREAM_SEI_CONTENT_MODE_ENABLE_VOLUME_INDICATION";
})(MixedStreamSEIContentMode || (MixedStreamSEIContentMode = {}));
var AudioMixingError;
(function (AudioMixingError) {
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_OK"] = 0] = "AUDIO_MIXING_ERROR_OK";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_PRELOAD_FAILED"] = 1] = "AUDIO_MIXING_ERROR_PRELOAD_FAILED";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_START_FAILED"] = 2] = "AUDIO_MIXING_ERROR_START_FAILED";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_ID_NOT_FOUND"] = 3] = "AUDIO_MIXING_ERROR_ID_NOT_FOUND";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_SET_POSITION_FAILED"] = 4] = "AUDIO_MIXING_ERROR_SET_POSITION_FAILED";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_INVALID_VOLUME"] = 5] = "AUDIO_MIXING_ERROR_INVALID_VOLUME";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_LOAD_CONFLICT"] = 6] = "AUDIO_MIXING_ERROR_LOAD_CONFLICT";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_ID_TYPE_NOT_MATCH"] = 7] = "AUDIO_MIXING_ERROR_ID_TYPE_NOT_MATCH";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_ID_TYPE_INVALID_PITCH"] = 8] = "AUDIO_MIXING_ERROR_ID_TYPE_INVALID_PITCH";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_INVALID_AUDIO_TRACK"] = 9] = "AUDIO_MIXING_ERROR_INVALID_AUDIO_TRACK";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_IS_STARTING"] = 10] = "AUDIO_MIXING_ERROR_IS_STARTING";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_INVALID_PLAYBACK_SPEED"] = 11] = "AUDIO_MIXING_ERROR_INVALID_PLAYBACK_SPEED";
})(AudioMixingError || (AudioMixingError = {}));
var AACProfile;
(function (AACProfile) {
    AACProfile["AAC_PROFILE_LC"] = "LC";
    AACProfile["AAC_PROFILE_HEV1"] = "HEv1";
    AACProfile["AAC_PROFILE_HEV2"] = "HEv2";
})(AACProfile || (AACProfile = {}));
var AudioSelectionPriority;
(function (AudioSelectionPriority) {
    AudioSelectionPriority[AudioSelectionPriority["AUDIO_SELECTION_PRIORITY_NORMAL"] = 0] = "AUDIO_SELECTION_PRIORITY_NORMAL";
    AudioSelectionPriority[AudioSelectionPriority["AUDIO_SELECTION_PRIORITY_HIGIH"] = 1] = "AUDIO_SELECTION_PRIORITY_HIGIH";
})(AudioSelectionPriority || (AudioSelectionPriority = {}));
var DataMessageSourceType;
(function (DataMessageSourceType) {
    DataMessageSourceType[DataMessageSourceType["DATA_MESSAGE_SOURCE_TYPE_DEFAULT"] = 0] = "DATA_MESSAGE_SOURCE_TYPE_DEFAULT";
    DataMessageSourceType[DataMessageSourceType["DATA_MESSAGE_SOURCE_TYPE_SYSTEM"] = 1] = "DATA_MESSAGE_SOURCE_TYPE_SYSTEM";
})(DataMessageSourceType || (DataMessageSourceType = {}));
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.publicstream.PublicStreaming.Layout')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _getRegions_decorators;
    var _setRegions_decorators;
    var _getInterpolationMode_decorators;
    var _setInterpolationMode_decorators;
    var _getLayoutMode_decorators;
    var _setLayoutMode_decorators;
    var _getBackgroundImage_decorators;
    var _setBackgroundImage_decorators;
    var _getBackgroundColor_decorators;
    var _setBackgroundColor_decorators;
    _classThis = /** @class */ (function () {
        function PublicStreaming$Layout_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        PublicStreaming$Layout_1.prototype.getRegions = function () {
            throw new Error('not implement');
        };
        PublicStreaming$Layout_1.prototype.setRegions = function (regions) {
            throw new Error('not implement');
        };
        PublicStreaming$Layout_1.prototype.getInterpolationMode = function () {
            throw new Error('not implement');
        };
        PublicStreaming$Layout_1.prototype.setInterpolationMode = function (interMode) {
            throw new Error('not implement');
        };
        PublicStreaming$Layout_1.prototype.getLayoutMode = function () {
            throw new Error('not implement');
        };
        PublicStreaming$Layout_1.prototype.setLayoutMode = function (layoutMode) {
            throw new Error('not implement');
        };
        PublicStreaming$Layout_1.prototype.getBackgroundImage = function () {
            throw new Error('not implement');
        };
        PublicStreaming$Layout_1.prototype.setBackgroundImage = function (bgImage) {
            throw new Error('not implement');
        };
        PublicStreaming$Layout_1.prototype.getBackgroundColor = function () {
            throw new Error('not implement');
        };
        PublicStreaming$Layout_1.prototype.setBackgroundColor = function (backgroundColor) {
            throw new Error('not implement');
        };
        return PublicStreaming$Layout_1;
    }());
    __setFunctionName(_classThis, "PublicStreaming$Layout");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _getRegions_decorators = [NativeMethodSync()];
        _setRegions_decorators = [NativeMethodSync()];
        _getInterpolationMode_decorators = [NativeMethodSync()];
        _setInterpolationMode_decorators = [NativeMethodSync()];
        _getLayoutMode_decorators = [NativeMethodSync()];
        _setLayoutMode_decorators = [NativeMethodSync()];
        _getBackgroundImage_decorators = [NativeMethodSync()];
        _setBackgroundImage_decorators = [NativeMethodSync()];
        _getBackgroundColor_decorators = [NativeMethodSync()];
        _setBackgroundColor_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _getRegions_decorators, { kind: "method", name: "getRegions", static: false, private: false, access: { has: function (obj) { return "getRegions" in obj; }, get: function (obj) { return obj.getRegions; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRegions_decorators, { kind: "method", name: "setRegions", static: false, private: false, access: { has: function (obj) { return "setRegions" in obj; }, get: function (obj) { return obj.setRegions; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getInterpolationMode_decorators, { kind: "method", name: "getInterpolationMode", static: false, private: false, access: { has: function (obj) { return "getInterpolationMode" in obj; }, get: function (obj) { return obj.getInterpolationMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setInterpolationMode_decorators, { kind: "method", name: "setInterpolationMode", static: false, private: false, access: { has: function (obj) { return "setInterpolationMode" in obj; }, get: function (obj) { return obj.setInterpolationMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getLayoutMode_decorators, { kind: "method", name: "getLayoutMode", static: false, private: false, access: { has: function (obj) { return "getLayoutMode" in obj; }, get: function (obj) { return obj.getLayoutMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLayoutMode_decorators, { kind: "method", name: "setLayoutMode", static: false, private: false, access: { has: function (obj) { return "setLayoutMode" in obj; }, get: function (obj) { return obj.setLayoutMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getBackgroundImage_decorators, { kind: "method", name: "getBackgroundImage", static: false, private: false, access: { has: function (obj) { return "getBackgroundImage" in obj; }, get: function (obj) { return obj.getBackgroundImage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBackgroundImage_decorators, { kind: "method", name: "setBackgroundImage", static: false, private: false, access: { has: function (obj) { return "setBackgroundImage" in obj; }, get: function (obj) { return obj.setBackgroundImage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getBackgroundColor_decorators, { kind: "method", name: "getBackgroundColor", static: false, private: false, access: { has: function (obj) { return "getBackgroundColor" in obj; }, get: function (obj) { return obj.getBackgroundColor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBackgroundColor_decorators, { kind: "method", name: "setBackgroundColor", static: false, private: false, access: { has: function (obj) { return "setBackgroundColor" in obj; }, get: function (obj) { return obj.setBackgroundColor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.VideoEffectExpressionConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _enableAgeDetect_decorators;
    var _enableAgeDetect_initializers = [];
    var _enableAgeDetect_extraInitializers = [];
    var _enableGenderDetect_decorators;
    var _enableGenderDetect_initializers = [];
    var _enableGenderDetect_extraInitializers = [];
    var _enableEmotionDetect_decorators;
    var _enableEmotionDetect_initializers = [];
    var _enableEmotionDetect_extraInitializers = [];
    var _enableAttractivenessDetect_decorators;
    var _enableAttractivenessDetect_initializers = [];
    var _enableAttractivenessDetect_extraInitializers = [];
    var _enableHappinessDetect_decorators;
    var _enableHappinessDetect_initializers = [];
    var _enableHappinessDetect_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function VideoEffectExpressionConfig_1() {
            this.enableAgeDetect = __runInitializers(this, _enableAgeDetect_initializers, void 0);
            this.enableGenderDetect = (__runInitializers(this, _enableAgeDetect_extraInitializers), __runInitializers(this, _enableGenderDetect_initializers, void 0));
            this.enableEmotionDetect = (__runInitializers(this, _enableGenderDetect_extraInitializers), __runInitializers(this, _enableEmotionDetect_initializers, void 0));
            this.enableAttractivenessDetect = (__runInitializers(this, _enableEmotionDetect_extraInitializers), __runInitializers(this, _enableAttractivenessDetect_initializers, void 0));
            this.enableHappinessDetect = (__runInitializers(this, _enableAttractivenessDetect_extraInitializers), __runInitializers(this, _enableHappinessDetect_initializers, void 0));
            __runInitializers(this, _enableHappinessDetect_extraInitializers);
        }
        return VideoEffectExpressionConfig_1;
    }());
    __setFunctionName(_classThis, "VideoEffectExpressionConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enableAgeDetect_decorators = [NativeMember()];
        _enableGenderDetect_decorators = [NativeMember()];
        _enableEmotionDetect_decorators = [NativeMember()];
        _enableAttractivenessDetect_decorators = [NativeMember()];
        _enableHappinessDetect_decorators = [NativeMember()];
        __esDecorate(null, null, _enableAgeDetect_decorators, { kind: "field", name: "enableAgeDetect", static: false, private: false, access: { has: function (obj) { return "enableAgeDetect" in obj; }, get: function (obj) { return obj.enableAgeDetect; }, set: function (obj, value) { obj.enableAgeDetect = value; } }, metadata: _metadata }, _enableAgeDetect_initializers, _enableAgeDetect_extraInitializers);
        __esDecorate(null, null, _enableGenderDetect_decorators, { kind: "field", name: "enableGenderDetect", static: false, private: false, access: { has: function (obj) { return "enableGenderDetect" in obj; }, get: function (obj) { return obj.enableGenderDetect; }, set: function (obj, value) { obj.enableGenderDetect = value; } }, metadata: _metadata }, _enableGenderDetect_initializers, _enableGenderDetect_extraInitializers);
        __esDecorate(null, null, _enableEmotionDetect_decorators, { kind: "field", name: "enableEmotionDetect", static: false, private: false, access: { has: function (obj) { return "enableEmotionDetect" in obj; }, get: function (obj) { return obj.enableEmotionDetect; }, set: function (obj, value) { obj.enableEmotionDetect = value; } }, metadata: _metadata }, _enableEmotionDetect_initializers, _enableEmotionDetect_extraInitializers);
        __esDecorate(null, null, _enableAttractivenessDetect_decorators, { kind: "field", name: "enableAttractivenessDetect", static: false, private: false, access: { has: function (obj) { return "enableAttractivenessDetect" in obj; }, get: function (obj) { return obj.enableAttractivenessDetect; }, set: function (obj, value) { obj.enableAttractivenessDetect = value; } }, metadata: _metadata }, _enableAttractivenessDetect_initializers, _enableAttractivenessDetect_extraInitializers);
        __esDecorate(null, null, _enableHappinessDetect_decorators, { kind: "field", name: "enableHappinessDetect", static: false, private: false, access: { has: function (obj) { return "enableHappinessDetect" in obj; }, get: function (obj) { return obj.enableHappinessDetect; }, set: function (obj, value) { obj.enableHappinessDetect = value; } }, metadata: _metadata }, _enableHappinessDetect_initializers, _enableHappinessDetect_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var FaceDetectionResult$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.FaceDetectionResult')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _detectResult_decorators;
    var _detectResult_initializers = [];
    var _detectResult_extraInitializers = [];
    var _imageWidth_decorators;
    var _imageWidth_initializers = [];
    var _imageWidth_extraInitializers = [];
    var _imageHeight_decorators;
    var _imageHeight_initializers = [];
    var _imageHeight_extraInitializers = [];
    var _faces_decorators;
    var _faces_initializers = [];
    var _faces_extraInitializers = [];
    var _frameTimestampUs_decorators;
    var _frameTimestampUs_initializers = [];
    var _frameTimestampUs_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function FaceDetectionResult_1() {
            this.detectResult = __runInitializers(this, _detectResult_initializers, void 0);
            this.imageWidth = (__runInitializers(this, _detectResult_extraInitializers), __runInitializers(this, _imageWidth_initializers, void 0));
            this.imageHeight = (__runInitializers(this, _imageWidth_extraInitializers), __runInitializers(this, _imageHeight_initializers, void 0));
            this.faces = (__runInitializers(this, _imageHeight_extraInitializers), __runInitializers(this, _faces_initializers, void 0));
            this.frameTimestampUs = (__runInitializers(this, _faces_extraInitializers), __runInitializers(this, _frameTimestampUs_initializers, void 0));
            __runInitializers(this, _frameTimestampUs_extraInitializers);
        }
        return FaceDetectionResult_1;
    }());
    __setFunctionName(_classThis, "FaceDetectionResult");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _detectResult_decorators = [NativeMember()];
        _imageWidth_decorators = [NativeMember()];
        _imageHeight_decorators = [NativeMember()];
        _faces_decorators = [NativeMember()];
        _frameTimestampUs_decorators = [NativeMember()];
        __esDecorate(null, null, _detectResult_decorators, { kind: "field", name: "detectResult", static: false, private: false, access: { has: function (obj) { return "detectResult" in obj; }, get: function (obj) { return obj.detectResult; }, set: function (obj, value) { obj.detectResult = value; } }, metadata: _metadata }, _detectResult_initializers, _detectResult_extraInitializers);
        __esDecorate(null, null, _imageWidth_decorators, { kind: "field", name: "imageWidth", static: false, private: false, access: { has: function (obj) { return "imageWidth" in obj; }, get: function (obj) { return obj.imageWidth; }, set: function (obj, value) { obj.imageWidth = value; } }, metadata: _metadata }, _imageWidth_initializers, _imageWidth_extraInitializers);
        __esDecorate(null, null, _imageHeight_decorators, { kind: "field", name: "imageHeight", static: false, private: false, access: { has: function (obj) { return "imageHeight" in obj; }, get: function (obj) { return obj.imageHeight; }, set: function (obj, value) { obj.imageHeight = value; } }, metadata: _metadata }, _imageHeight_initializers, _imageHeight_extraInitializers);
        __esDecorate(null, null, _faces_decorators, { kind: "field", name: "faces", static: false, private: false, access: { has: function (obj) { return "faces" in obj; }, get: function (obj) { return obj.faces; }, set: function (obj, value) { obj.faces = value; } }, metadata: _metadata }, _faces_initializers, _faces_extraInitializers);
        __esDecorate(null, null, _frameTimestampUs_decorators, { kind: "field", name: "frameTimestampUs", static: false, private: false, access: { has: function (obj) { return "frameTimestampUs" in obj; }, get: function (obj) { return obj.frameTimestampUs; }, set: function (obj, value) { obj.frameTimestampUs = value; } }, metadata: _metadata }, _frameTimestampUs_initializers, _frameTimestampUs_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoFrame$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.VideoFrame')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setReleaseCallback_decorators;
    var _hasReleaseCallback_decorators;
    var _getFrameType_decorators;
    var _getPixelFormat_decorators;
    var _getContentType_decorators;
    var _getTimeStampUs_decorators;
    var _getWidth_decorators;
    var _getHeight_decorators;
    var _getRotation_decorators;
    var _getColorSpace_decorators;
    var _getCameraId_decorators;
    var _getNumberOfPlanes_decorators;
    var _getPlaneData_decorators;
    var _getPlaneStride_decorators;
    var _getExternalDataInfo_decorators;
    var _getSupplementaryInfo_decorators;
    var _getTextureID_decorators;
    var _getGLSync_decorators;
    var _getTextureMatrix_decorators;
    var _getEGLContext_decorators;
    var _retain_decorators;
    var _release_decorators;
    _classThis = /** @class */ (function () {
        function VideoFrame_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        VideoFrame_1.prototype.setReleaseCallback = function (releaseCallback) {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.hasReleaseCallback = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getFrameType = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getPixelFormat = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getContentType = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getTimeStampUs = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getWidth = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getHeight = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getRotation = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getColorSpace = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getCameraId = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getNumberOfPlanes = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getPlaneData = function (planeIndex) {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getPlaneStride = function (planeIndex) {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getExternalDataInfo = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getSupplementaryInfo = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getTextureID = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getGLSync = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getTextureMatrix = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.getEGLContext = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.retain = function () {
            throw new Error('not implement');
        };
        VideoFrame_1.prototype.release = function () {
            throw new Error('not implement');
        };
        return VideoFrame_1;
    }());
    __setFunctionName(_classThis, "VideoFrame");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setReleaseCallback_decorators = [NativeMethodSync()];
        _hasReleaseCallback_decorators = [NativeMethodSync()];
        _getFrameType_decorators = [NativeMethodSync()];
        _getPixelFormat_decorators = [NativeMethodSync()];
        _getContentType_decorators = [NativeMethodSync()];
        _getTimeStampUs_decorators = [NativeMethodSync()];
        _getWidth_decorators = [NativeMethodSync()];
        _getHeight_decorators = [NativeMethodSync()];
        _getRotation_decorators = [NativeMethodSync()];
        _getColorSpace_decorators = [NativeMethodSync()];
        _getCameraId_decorators = [NativeMethodSync()];
        _getNumberOfPlanes_decorators = [NativeMethodSync()];
        _getPlaneData_decorators = [NativeMethodSync()];
        _getPlaneStride_decorators = [NativeMethodSync()];
        _getExternalDataInfo_decorators = [NativeMethodSync()];
        _getSupplementaryInfo_decorators = [NativeMethodSync()];
        _getTextureID_decorators = [NativeMethodSync()];
        _getGLSync_decorators = [NativeMethodSync()];
        _getTextureMatrix_decorators = [NativeMethodSync()];
        _getEGLContext_decorators = [NativeMethodSync()];
        _retain_decorators = [NativeMethodSync()];
        _release_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setReleaseCallback_decorators, { kind: "method", name: "setReleaseCallback", static: false, private: false, access: { has: function (obj) { return "setReleaseCallback" in obj; }, get: function (obj) { return obj.setReleaseCallback; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _hasReleaseCallback_decorators, { kind: "method", name: "hasReleaseCallback", static: false, private: false, access: { has: function (obj) { return "hasReleaseCallback" in obj; }, get: function (obj) { return obj.hasReleaseCallback; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getFrameType_decorators, { kind: "method", name: "getFrameType", static: false, private: false, access: { has: function (obj) { return "getFrameType" in obj; }, get: function (obj) { return obj.getFrameType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getPixelFormat_decorators, { kind: "method", name: "getPixelFormat", static: false, private: false, access: { has: function (obj) { return "getPixelFormat" in obj; }, get: function (obj) { return obj.getPixelFormat; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getContentType_decorators, { kind: "method", name: "getContentType", static: false, private: false, access: { has: function (obj) { return "getContentType" in obj; }, get: function (obj) { return obj.getContentType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getTimeStampUs_decorators, { kind: "method", name: "getTimeStampUs", static: false, private: false, access: { has: function (obj) { return "getTimeStampUs" in obj; }, get: function (obj) { return obj.getTimeStampUs; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getWidth_decorators, { kind: "method", name: "getWidth", static: false, private: false, access: { has: function (obj) { return "getWidth" in obj; }, get: function (obj) { return obj.getWidth; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getHeight_decorators, { kind: "method", name: "getHeight", static: false, private: false, access: { has: function (obj) { return "getHeight" in obj; }, get: function (obj) { return obj.getHeight; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getRotation_decorators, { kind: "method", name: "getRotation", static: false, private: false, access: { has: function (obj) { return "getRotation" in obj; }, get: function (obj) { return obj.getRotation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getColorSpace_decorators, { kind: "method", name: "getColorSpace", static: false, private: false, access: { has: function (obj) { return "getColorSpace" in obj; }, get: function (obj) { return obj.getColorSpace; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getCameraId_decorators, { kind: "method", name: "getCameraId", static: false, private: false, access: { has: function (obj) { return "getCameraId" in obj; }, get: function (obj) { return obj.getCameraId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getNumberOfPlanes_decorators, { kind: "method", name: "getNumberOfPlanes", static: false, private: false, access: { has: function (obj) { return "getNumberOfPlanes" in obj; }, get: function (obj) { return obj.getNumberOfPlanes; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getPlaneData_decorators, { kind: "method", name: "getPlaneData", static: false, private: false, access: { has: function (obj) { return "getPlaneData" in obj; }, get: function (obj) { return obj.getPlaneData; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getPlaneStride_decorators, { kind: "method", name: "getPlaneStride", static: false, private: false, access: { has: function (obj) { return "getPlaneStride" in obj; }, get: function (obj) { return obj.getPlaneStride; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getExternalDataInfo_decorators, { kind: "method", name: "getExternalDataInfo", static: false, private: false, access: { has: function (obj) { return "getExternalDataInfo" in obj; }, get: function (obj) { return obj.getExternalDataInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getSupplementaryInfo_decorators, { kind: "method", name: "getSupplementaryInfo", static: false, private: false, access: { has: function (obj) { return "getSupplementaryInfo" in obj; }, get: function (obj) { return obj.getSupplementaryInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getTextureID_decorators, { kind: "method", name: "getTextureID", static: false, private: false, access: { has: function (obj) { return "getTextureID" in obj; }, get: function (obj) { return obj.getTextureID; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getGLSync_decorators, { kind: "method", name: "getGLSync", static: false, private: false, access: { has: function (obj) { return "getGLSync" in obj; }, get: function (obj) { return obj.getGLSync; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getTextureMatrix_decorators, { kind: "method", name: "getTextureMatrix", static: false, private: false, access: { has: function (obj) { return "getTextureMatrix" in obj; }, get: function (obj) { return obj.getTextureMatrix; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getEGLContext_decorators, { kind: "method", name: "getEGLContext", static: false, private: false, access: { has: function (obj) { return "getEGLContext" in obj; }, get: function (obj) { return obj.getEGLContext; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _retain_decorators, { kind: "method", name: "retain", static: false, private: false, access: { has: function (obj) { return "retain" in obj; }, get: function (obj) { return obj.retain; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _release_decorators, { kind: "method", name: "release", static: false, private: false, access: { has: function (obj) { return "release" in obj; }, get: function (obj) { return obj.release; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RemoteStreamKey$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.RemoteStreamKey')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _streamIndex_decorators;
    var _streamIndex_initializers = [];
    var _streamIndex_extraInitializers = [];
    var _getRoomId_decorators;
    var _getUserId_decorators;
    var _getStreamIndex_decorators;
    var _hasNullProperty_decorators;
    _classThis = /** @class */ (function () {
        function RemoteStreamKey_1(roomId, userId, streamIndex) {
            this.roomId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _roomId_initializers, void 0));
            this.userId = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _userId_initializers, void 0));
            this.streamIndex = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _streamIndex_initializers, void 0));
            __runInitializers(this, _streamIndex_extraInitializers);
        }
        RemoteStreamKey_1.prototype.getRoomId = function () {
            throw new Error('not implement');
        };
        RemoteStreamKey_1.prototype.getUserId = function () {
            throw new Error('not implement');
        };
        RemoteStreamKey_1.prototype.getStreamIndex = function () {
            throw new Error('not implement');
        };
        RemoteStreamKey_1.prototype.hasNullProperty = function () {
            throw new Error('not implement');
        };
        return RemoteStreamKey_1;
    }());
    __setFunctionName(_classThis, "RemoteStreamKey");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _roomId_decorators = [NativeMember()];
        _userId_decorators = [NativeMember()];
        _streamIndex_decorators = [NativeMember()];
        _getRoomId_decorators = [NativeMethodSync()];
        _getUserId_decorators = [NativeMethodSync()];
        _getStreamIndex_decorators = [NativeMethodSync()];
        _hasNullProperty_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _getRoomId_decorators, { kind: "method", name: "getRoomId", static: false, private: false, access: { has: function (obj) { return "getRoomId" in obj; }, get: function (obj) { return obj.getRoomId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getUserId_decorators, { kind: "method", name: "getUserId", static: false, private: false, access: { has: function (obj) { return "getUserId" in obj; }, get: function (obj) { return obj.getUserId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getStreamIndex_decorators, { kind: "method", name: "getStreamIndex", static: false, private: false, access: { has: function (obj) { return "getStreamIndex" in obj; }, get: function (obj) { return obj.getStreamIndex; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _hasNullProperty_decorators, { kind: "method", name: "hasNullProperty", static: false, private: false, access: { has: function (obj) { return "hasNullProperty" in obj; }, get: function (obj) { return obj.hasNullProperty; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _streamIndex_decorators, { kind: "field", name: "streamIndex", static: false, private: false, access: { has: function (obj) { return "streamIndex" in obj; }, get: function (obj) { return obj.streamIndex; }, set: function (obj, value) { obj.streamIndex = value; } }, metadata: _metadata }, _streamIndex_initializers, _streamIndex_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VoiceReverbType;
(function (VoiceReverbType) {
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_ORIGINAL"] = 0] = "VOICE_REVERB_ORIGINAL";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_ECHO"] = 1] = "VOICE_REVERB_ECHO";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_CONCERT"] = 2] = "VOICE_REVERB_CONCERT";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_ETHEREAL"] = 3] = "VOICE_REVERB_ETHEREAL";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_KTV"] = 4] = "VOICE_REVERB_KTV";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_STUDIO"] = 5] = "VOICE_REVERB_STUDIO";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_VIRTUAL_STEREO"] = 6] = "VOICE_REVERB_VIRTUAL_STEREO";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_SPACIOUS"] = 7] = "VOICE_REVERB_SPACIOUS";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_3D"] = 8] = "VOICE_REVERB_3D";
})(VoiceReverbType || (VoiceReverbType = {}));
var MediaPlayerCustomSourceMode;
(function (MediaPlayerCustomSourceMode) {
    MediaPlayerCustomSourceMode[MediaPlayerCustomSourceMode["PUSH"] = 0] = "PUSH";
    MediaPlayerCustomSourceMode[MediaPlayerCustomSourceMode["PULL"] = 1] = "PULL";
})(MediaPlayerCustomSourceMode || (MediaPlayerCustomSourceMode = {}));
var KTVPlayerErrorCode;
(function (KTVPlayerErrorCode) {
    KTVPlayerErrorCode[KTVPlayerErrorCode["OK"] = 0] = "OK";
    KTVPlayerErrorCode[KTVPlayerErrorCode["FILE_NOT_EXIST"] = -3020] = "FILE_NOT_EXIST";
    KTVPlayerErrorCode[KTVPlayerErrorCode["FILE_ERROR"] = -3021] = "FILE_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["NOT_JOIN_ROOM"] = -3022] = "NOT_JOIN_ROOM";
    KTVPlayerErrorCode[KTVPlayerErrorCode["PARAM"] = -3023] = "PARAM";
    KTVPlayerErrorCode[KTVPlayerErrorCode["START_ERROR"] = -3024] = "START_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["MIX_ID_ERROR"] = -3025] = "MIX_ID_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["POSITION_ERROR"] = -3026] = "POSITION_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["AUDIO_VOLUME_ERROR"] = -3027] = "AUDIO_VOLUME_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["TYPE_ERROR"] = -3028] = "TYPE_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["PITCH_ERROR"] = -3029] = "PITCH_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["AUDIO_TRACK_ERROR"] = -3030] = "AUDIO_TRACK_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["STARTING_ERROR"] = -3031] = "STARTING_ERROR";
})(KTVPlayerErrorCode || (KTVPlayerErrorCode = {}));
var AudioChannel;
(function (AudioChannel) {
    AudioChannel[AudioChannel["AUDIO_CHANNEL_AUTO"] = -1] = "AUDIO_CHANNEL_AUTO";
    AudioChannel[AudioChannel["AUDIO_CHANNEL_MONO"] = 1] = "AUDIO_CHANNEL_MONO";
    AudioChannel[AudioChannel["AUDIO_CHANNEL_STEREO"] = 2] = "AUDIO_CHANNEL_STEREO";
})(AudioChannel || (AudioChannel = {}));
var RemoteVideoStateChangeReason;
(function (RemoteVideoStateChangeReason) {
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_INTERNAL"] = 0] = "REMOTE_VIDEO_STATE_CHANGE_REASON_INTERNAL";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_CONGESTION"] = 1] = "REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_CONGESTION";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_RECOVERY"] = 2] = "REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_RECOVERY";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_MUTED"] = 3] = "REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_MUTED";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_UNMUTED"] = 4] = "REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_UNMUTED";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_MUTED"] = 5] = "REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_MUTED";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_UNMUTED"] = 6] = "REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_UNMUTED";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_OFFLINE"] = 7] = "REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_OFFLINE";
})(RemoteVideoStateChangeReason || (RemoteVideoStateChangeReason = {}));
var PerformanceAlarmReason;
(function (PerformanceAlarmReason) {
    PerformanceAlarmReason[PerformanceAlarmReason["BANDWIDTH_FALLBACKED"] = 0] = "BANDWIDTH_FALLBACKED";
    PerformanceAlarmReason[PerformanceAlarmReason["BANDWIDTH_RESUMED"] = 1] = "BANDWIDTH_RESUMED";
    PerformanceAlarmReason[PerformanceAlarmReason["PERFORMANCE_FALLBACKED"] = 2] = "PERFORMANCE_FALLBACKED";
    PerformanceAlarmReason[PerformanceAlarmReason["PERFORMANCE_RESUMED"] = 3] = "PERFORMANCE_RESUMED";
})(PerformanceAlarmReason || (PerformanceAlarmReason = {}));
var VideoDeviceType;
(function (VideoDeviceType) {
    VideoDeviceType[VideoDeviceType["VIDEO_DEVICE_TYPE_UNKNOWN"] = -1] = "VIDEO_DEVICE_TYPE_UNKNOWN";
    VideoDeviceType[VideoDeviceType["VIDEO_DEVICE_TYPE_RENDER_DEVICE"] = 0] = "VIDEO_DEVICE_TYPE_RENDER_DEVICE";
    VideoDeviceType[VideoDeviceType["VIDEO_DEVICE_TYPE_CAPTURE_DEVICE"] = 1] = "VIDEO_DEVICE_TYPE_CAPTURE_DEVICE";
    VideoDeviceType[VideoDeviceType["VIDEO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE"] = 2] = "VIDEO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE";
})(VideoDeviceType || (VideoDeviceType = {}));
var HotMusicInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.ktv.data.HotMusicInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _hotType_decorators;
    var _hotType_initializers = [];
    var _hotType_extraInitializers = [];
    var _hotName_decorators;
    var _hotName_initializers = [];
    var _hotName_extraInitializers = [];
    var _musicInfos_decorators;
    var _musicInfos_initializers = [];
    var _musicInfos_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function HotMusicInfo_1(hotType, hotName, musicInfos) {
            this.hotType = __runInitializers(this, _hotType_initializers, void 0);
            this.hotName = (__runInitializers(this, _hotType_extraInitializers), __runInitializers(this, _hotName_initializers, void 0));
            this.musicInfos = (__runInitializers(this, _hotName_extraInitializers), __runInitializers(this, _musicInfos_initializers, void 0));
            __runInitializers(this, _musicInfos_extraInitializers);
        }
        return HotMusicInfo_1;
    }());
    __setFunctionName(_classThis, "HotMusicInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _hotType_decorators = [NativeMember()];
        _hotName_decorators = [NativeMember()];
        _musicInfos_decorators = [NativeMember()];
        __esDecorate(null, null, _hotType_decorators, { kind: "field", name: "hotType", static: false, private: false, access: { has: function (obj) { return "hotType" in obj; }, get: function (obj) { return obj.hotType; }, set: function (obj, value) { obj.hotType = value; } }, metadata: _metadata }, _hotType_initializers, _hotType_extraInitializers);
        __esDecorate(null, null, _hotName_decorators, { kind: "field", name: "hotName", static: false, private: false, access: { has: function (obj) { return "hotName" in obj; }, get: function (obj) { return obj.hotName; }, set: function (obj, value) { obj.hotName = value; } }, metadata: _metadata }, _hotName_initializers, _hotName_extraInitializers);
        __esDecorate(null, null, _musicInfos_decorators, { kind: "field", name: "musicInfos", static: false, private: false, access: { has: function (obj) { return "musicInfos" in obj; }, get: function (obj) { return obj.musicInfos; }, set: function (obj, value) { obj.musicInfos = value; } }, metadata: _metadata }, _musicInfos_initializers, _musicInfos_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var TranscoderRenderMode;
(function (TranscoderRenderMode) {
    TranscoderRenderMode[TranscoderRenderMode["RENDER_HIDDEN"] = 1] = "RENDER_HIDDEN";
    TranscoderRenderMode[TranscoderRenderMode["RENDER_FIT"] = 2] = "RENDER_FIT";
    TranscoderRenderMode[TranscoderRenderMode["RENDER_ADAPTIVE"] = 3] = "RENDER_ADAPTIVE";
    TranscoderRenderMode[TranscoderRenderMode["RENDER_UNKNOWN"] = 0] = "RENDER_UNKNOWN";
})(TranscoderRenderMode || (TranscoderRenderMode = {}));
var MixedStreamServerControlConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.MixedStreamConfig$MixedStreamServerControlConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setSeiPayloadType_decorators;
    var _getSeiPayloadType_decorators;
    var _setSeiPayloadUuid_decorators;
    var _getSeiPayloadUuid_decorators;
    var _setVolumeIndicationInterval_decorators;
    var _getVolumeIndicationInterval_decorators;
    var _setEnableVolumeIndication_decorators;
    var _getEnableVolumeIndication_decorators;
    var _setIsAddVolumeValue_decorators;
    var _getIsAddVolumeValue_decorators;
    var _setSeiContentMode_decorators;
    var _getSeiContentMode_decorators;
    var _setTalkVolume_decorators;
    var _getTalkVolume_decorators;
    var _setPushStreamMode_decorators;
    var _getPushStreamMode_decorators;
    var _setMediaType_decorators;
    var _getMediaType_decorators;
    _classThis = /** @class */ (function () {
        function MixedStreamServerControlConfig_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        MixedStreamServerControlConfig_1.prototype.setSeiPayloadType = function (seiPayloadType) {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.getSeiPayloadType = function () {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.setSeiPayloadUuid = function (seiPayloadUuid) {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.getSeiPayloadUuid = function () {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.setVolumeIndicationInterval = function (volumeIndicationInterval) {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.getVolumeIndicationInterval = function () {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.setEnableVolumeIndication = function (enableVolumeIndication) {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.getEnableVolumeIndication = function () {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.setIsAddVolumeValue = function (addVolumeValue) {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.getIsAddVolumeValue = function () {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.setSeiContentMode = function (seiContentMode) {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.getSeiContentMode = function () {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.setTalkVolume = function (talkVolume) {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.getTalkVolume = function () {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.setPushStreamMode = function (pushStreamMode) {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.getPushStreamMode = function () {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.setMediaType = function (mediaType) {
            throw new Error('not implement');
        };
        MixedStreamServerControlConfig_1.prototype.getMediaType = function () {
            throw new Error('not implement');
        };
        return MixedStreamServerControlConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamServerControlConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setSeiPayloadType_decorators = [NativeMethodSync()];
        _getSeiPayloadType_decorators = [NativeMethodSync()];
        _setSeiPayloadUuid_decorators = [NativeMethodSync()];
        _getSeiPayloadUuid_decorators = [NativeMethodSync()];
        _setVolumeIndicationInterval_decorators = [NativeMethodSync()];
        _getVolumeIndicationInterval_decorators = [NativeMethodSync()];
        _setEnableVolumeIndication_decorators = [NativeMethodSync()];
        _getEnableVolumeIndication_decorators = [NativeMethodSync()];
        _setIsAddVolumeValue_decorators = [NativeMethodSync()];
        _getIsAddVolumeValue_decorators = [NativeMethodSync()];
        _setSeiContentMode_decorators = [NativeMethodSync()];
        _getSeiContentMode_decorators = [NativeMethodSync()];
        _setTalkVolume_decorators = [NativeMethodSync()];
        _getTalkVolume_decorators = [NativeMethodSync()];
        _setPushStreamMode_decorators = [NativeMethodSync()];
        _getPushStreamMode_decorators = [NativeMethodSync()];
        _setMediaType_decorators = [NativeMethodSync()];
        _getMediaType_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setSeiPayloadType_decorators, { kind: "method", name: "setSeiPayloadType", static: false, private: false, access: { has: function (obj) { return "setSeiPayloadType" in obj; }, get: function (obj) { return obj.setSeiPayloadType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getSeiPayloadType_decorators, { kind: "method", name: "getSeiPayloadType", static: false, private: false, access: { has: function (obj) { return "getSeiPayloadType" in obj; }, get: function (obj) { return obj.getSeiPayloadType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setSeiPayloadUuid_decorators, { kind: "method", name: "setSeiPayloadUuid", static: false, private: false, access: { has: function (obj) { return "setSeiPayloadUuid" in obj; }, get: function (obj) { return obj.setSeiPayloadUuid; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getSeiPayloadUuid_decorators, { kind: "method", name: "getSeiPayloadUuid", static: false, private: false, access: { has: function (obj) { return "getSeiPayloadUuid" in obj; }, get: function (obj) { return obj.getSeiPayloadUuid; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVolumeIndicationInterval_decorators, { kind: "method", name: "setVolumeIndicationInterval", static: false, private: false, access: { has: function (obj) { return "setVolumeIndicationInterval" in obj; }, get: function (obj) { return obj.setVolumeIndicationInterval; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getVolumeIndicationInterval_decorators, { kind: "method", name: "getVolumeIndicationInterval", static: false, private: false, access: { has: function (obj) { return "getVolumeIndicationInterval" in obj; }, get: function (obj) { return obj.getVolumeIndicationInterval; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEnableVolumeIndication_decorators, { kind: "method", name: "setEnableVolumeIndication", static: false, private: false, access: { has: function (obj) { return "setEnableVolumeIndication" in obj; }, get: function (obj) { return obj.setEnableVolumeIndication; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getEnableVolumeIndication_decorators, { kind: "method", name: "getEnableVolumeIndication", static: false, private: false, access: { has: function (obj) { return "getEnableVolumeIndication" in obj; }, get: function (obj) { return obj.getEnableVolumeIndication; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setIsAddVolumeValue_decorators, { kind: "method", name: "setIsAddVolumeValue", static: false, private: false, access: { has: function (obj) { return "setIsAddVolumeValue" in obj; }, get: function (obj) { return obj.setIsAddVolumeValue; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getIsAddVolumeValue_decorators, { kind: "method", name: "getIsAddVolumeValue", static: false, private: false, access: { has: function (obj) { return "getIsAddVolumeValue" in obj; }, get: function (obj) { return obj.getIsAddVolumeValue; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setSeiContentMode_decorators, { kind: "method", name: "setSeiContentMode", static: false, private: false, access: { has: function (obj) { return "setSeiContentMode" in obj; }, get: function (obj) { return obj.setSeiContentMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getSeiContentMode_decorators, { kind: "method", name: "getSeiContentMode", static: false, private: false, access: { has: function (obj) { return "getSeiContentMode" in obj; }, get: function (obj) { return obj.getSeiContentMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setTalkVolume_decorators, { kind: "method", name: "setTalkVolume", static: false, private: false, access: { has: function (obj) { return "setTalkVolume" in obj; }, get: function (obj) { return obj.setTalkVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getTalkVolume_decorators, { kind: "method", name: "getTalkVolume", static: false, private: false, access: { has: function (obj) { return "getTalkVolume" in obj; }, get: function (obj) { return obj.getTalkVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPushStreamMode_decorators, { kind: "method", name: "setPushStreamMode", static: false, private: false, access: { has: function (obj) { return "setPushStreamMode" in obj; }, get: function (obj) { return obj.setPushStreamMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getPushStreamMode_decorators, { kind: "method", name: "getPushStreamMode", static: false, private: false, access: { has: function (obj) { return "getPushStreamMode" in obj; }, get: function (obj) { return obj.getPushStreamMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setMediaType_decorators, { kind: "method", name: "setMediaType", static: false, private: false, access: { has: function (obj) { return "setMediaType" in obj; }, get: function (obj) { return obj.setMediaType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getMediaType_decorators, { kind: "method", name: "getMediaType", static: false, private: false, access: { has: function (obj) { return "getMediaType" in obj; }, get: function (obj) { return obj.getMediaType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioMixingDualMonoMode;
(function (AudioMixingDualMonoMode) {
    AudioMixingDualMonoMode[AudioMixingDualMonoMode["AUDIO_MIXING_DUAL_MONO_MODE_AUTO"] = 0] = "AUDIO_MIXING_DUAL_MONO_MODE_AUTO";
    AudioMixingDualMonoMode[AudioMixingDualMonoMode["AUDIO_MIXING_DUAL_MONO_MODE_L"] = 1] = "AUDIO_MIXING_DUAL_MONO_MODE_L";
    AudioMixingDualMonoMode[AudioMixingDualMonoMode["AUDIO_MIXING_DUAL_MONO_MODE_R"] = 2] = "AUDIO_MIXING_DUAL_MONO_MODE_R";
    AudioMixingDualMonoMode[AudioMixingDualMonoMode["AUDIO_MIXING_DUAL_MONO_MODE_MIX"] = 3] = "AUDIO_MIXING_DUAL_MONO_MODE_MIX";
})(AudioMixingDualMonoMode || (AudioMixingDualMonoMode = {}));
var LocalAudioStats$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.LocalAudioStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _audioLossRate_decorators;
    var _audioLossRate_initializers = [];
    var _audioLossRate_extraInitializers = [];
    var _sendKBitrate_decorators;
    var _sendKBitrate_initializers = [];
    var _sendKBitrate_extraInitializers = [];
    var _recordSampleRate_decorators;
    var _recordSampleRate_initializers = [];
    var _recordSampleRate_extraInitializers = [];
    var _statsInterval_decorators;
    var _statsInterval_initializers = [];
    var _statsInterval_extraInitializers = [];
    var _rtt_decorators;
    var _rtt_initializers = [];
    var _rtt_extraInitializers = [];
    var _numChannels_decorators;
    var _numChannels_initializers = [];
    var _numChannels_extraInitializers = [];
    var _sentSampleRate_decorators;
    var _sentSampleRate_initializers = [];
    var _sentSampleRate_extraInitializers = [];
    var _jitter_decorators;
    var _jitter_initializers = [];
    var _jitter_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function LocalAudioStats_1() {
            this.audioLossRate = __runInitializers(this, _audioLossRate_initializers, void 0);
            this.sendKBitrate = (__runInitializers(this, _audioLossRate_extraInitializers), __runInitializers(this, _sendKBitrate_initializers, void 0));
            this.recordSampleRate = (__runInitializers(this, _sendKBitrate_extraInitializers), __runInitializers(this, _recordSampleRate_initializers, void 0));
            this.statsInterval = (__runInitializers(this, _recordSampleRate_extraInitializers), __runInitializers(this, _statsInterval_initializers, void 0));
            this.rtt = (__runInitializers(this, _statsInterval_extraInitializers), __runInitializers(this, _rtt_initializers, void 0));
            this.numChannels = (__runInitializers(this, _rtt_extraInitializers), __runInitializers(this, _numChannels_initializers, void 0));
            this.sentSampleRate = (__runInitializers(this, _numChannels_extraInitializers), __runInitializers(this, _sentSampleRate_initializers, void 0));
            this.jitter = (__runInitializers(this, _sentSampleRate_extraInitializers), __runInitializers(this, _jitter_initializers, void 0));
            __runInitializers(this, _jitter_extraInitializers);
        }
        return LocalAudioStats_1;
    }());
    __setFunctionName(_classThis, "LocalAudioStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _audioLossRate_decorators = [NativeMember()];
        _sendKBitrate_decorators = [NativeMember()];
        _recordSampleRate_decorators = [NativeMember()];
        _statsInterval_decorators = [NativeMember()];
        _rtt_decorators = [NativeMember()];
        _numChannels_decorators = [NativeMember()];
        _sentSampleRate_decorators = [NativeMember()];
        _jitter_decorators = [NativeMember()];
        __esDecorate(null, null, _audioLossRate_decorators, { kind: "field", name: "audioLossRate", static: false, private: false, access: { has: function (obj) { return "audioLossRate" in obj; }, get: function (obj) { return obj.audioLossRate; }, set: function (obj, value) { obj.audioLossRate = value; } }, metadata: _metadata }, _audioLossRate_initializers, _audioLossRate_extraInitializers);
        __esDecorate(null, null, _sendKBitrate_decorators, { kind: "field", name: "sendKBitrate", static: false, private: false, access: { has: function (obj) { return "sendKBitrate" in obj; }, get: function (obj) { return obj.sendKBitrate; }, set: function (obj, value) { obj.sendKBitrate = value; } }, metadata: _metadata }, _sendKBitrate_initializers, _sendKBitrate_extraInitializers);
        __esDecorate(null, null, _recordSampleRate_decorators, { kind: "field", name: "recordSampleRate", static: false, private: false, access: { has: function (obj) { return "recordSampleRate" in obj; }, get: function (obj) { return obj.recordSampleRate; }, set: function (obj, value) { obj.recordSampleRate = value; } }, metadata: _metadata }, _recordSampleRate_initializers, _recordSampleRate_extraInitializers);
        __esDecorate(null, null, _statsInterval_decorators, { kind: "field", name: "statsInterval", static: false, private: false, access: { has: function (obj) { return "statsInterval" in obj; }, get: function (obj) { return obj.statsInterval; }, set: function (obj, value) { obj.statsInterval = value; } }, metadata: _metadata }, _statsInterval_initializers, _statsInterval_extraInitializers);
        __esDecorate(null, null, _rtt_decorators, { kind: "field", name: "rtt", static: false, private: false, access: { has: function (obj) { return "rtt" in obj; }, get: function (obj) { return obj.rtt; }, set: function (obj, value) { obj.rtt = value; } }, metadata: _metadata }, _rtt_initializers, _rtt_extraInitializers);
        __esDecorate(null, null, _numChannels_decorators, { kind: "field", name: "numChannels", static: false, private: false, access: { has: function (obj) { return "numChannels" in obj; }, get: function (obj) { return obj.numChannels; }, set: function (obj, value) { obj.numChannels = value; } }, metadata: _metadata }, _numChannels_initializers, _numChannels_extraInitializers);
        __esDecorate(null, null, _sentSampleRate_decorators, { kind: "field", name: "sentSampleRate", static: false, private: false, access: { has: function (obj) { return "sentSampleRate" in obj; }, get: function (obj) { return obj.sentSampleRate; }, set: function (obj, value) { obj.sentSampleRate = value; } }, metadata: _metadata }, _sentSampleRate_initializers, _sentSampleRate_extraInitializers);
        __esDecorate(null, null, _jitter_decorators, { kind: "field", name: "jitter", static: false, private: false, access: { has: function (obj) { return "jitter" in obj; }, get: function (obj) { return obj.jitter; }, set: function (obj, value) { obj.jitter = value; } }, metadata: _metadata }, _jitter_initializers, _jitter_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MixedStreamVideoConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.MixedStreamConfig$MixedStreamVideoConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setFps_decorators;
    var _getFps_decorators;
    var _setGop_decorators;
    var _getGop_decorators;
    var _setBitrate_decorators;
    var _getBitrate_decorators;
    var _setWidth_decorators;
    var _getWidth_decorators;
    var _setHeight_decorators;
    var _getHeight_decorators;
    var _setEnableBframe_decorators;
    var _getEnableBframe_decorators;
    var _setVideoCodec_decorators;
    var _getVideoCodec_decorators;
    _classThis = /** @class */ (function () {
        function MixedStreamVideoConfig_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        MixedStreamVideoConfig_1.prototype.setFps = function (fps) {
            throw new Error('not implement');
        };
        MixedStreamVideoConfig_1.prototype.getFps = function () {
            throw new Error('not implement');
        };
        MixedStreamVideoConfig_1.prototype.setGop = function (gop) {
            throw new Error('not implement');
        };
        MixedStreamVideoConfig_1.prototype.getGop = function () {
            throw new Error('not implement');
        };
        MixedStreamVideoConfig_1.prototype.setBitrate = function (bitrate) {
            throw new Error('not implement');
        };
        MixedStreamVideoConfig_1.prototype.getBitrate = function () {
            throw new Error('not implement');
        };
        MixedStreamVideoConfig_1.prototype.setWidth = function (width) {
            throw new Error('not implement');
        };
        MixedStreamVideoConfig_1.prototype.getWidth = function () {
            throw new Error('not implement');
        };
        MixedStreamVideoConfig_1.prototype.setHeight = function (height) {
            throw new Error('not implement');
        };
        MixedStreamVideoConfig_1.prototype.getHeight = function () {
            throw new Error('not implement');
        };
        MixedStreamVideoConfig_1.prototype.setEnableBframe = function (enableBframe) {
            throw new Error('not implement');
        };
        MixedStreamVideoConfig_1.prototype.getEnableBframe = function () {
            throw new Error('not implement');
        };
        MixedStreamVideoConfig_1.prototype.setVideoCodec = function (videoCodec) {
            throw new Error('not implement');
        };
        MixedStreamVideoConfig_1.prototype.getVideoCodec = function () {
            throw new Error('not implement');
        };
        return MixedStreamVideoConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamVideoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setFps_decorators = [NativeMethodSync()];
        _getFps_decorators = [NativeMethodSync()];
        _setGop_decorators = [NativeMethodSync()];
        _getGop_decorators = [NativeMethodSync()];
        _setBitrate_decorators = [NativeMethodSync()];
        _getBitrate_decorators = [NativeMethodSync()];
        _setWidth_decorators = [NativeMethodSync()];
        _getWidth_decorators = [NativeMethodSync()];
        _setHeight_decorators = [NativeMethodSync()];
        _getHeight_decorators = [NativeMethodSync()];
        _setEnableBframe_decorators = [NativeMethodSync()];
        _getEnableBframe_decorators = [NativeMethodSync()];
        _setVideoCodec_decorators = [NativeMethodSync()];
        _getVideoCodec_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setFps_decorators, { kind: "method", name: "setFps", static: false, private: false, access: { has: function (obj) { return "setFps" in obj; }, get: function (obj) { return obj.setFps; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getFps_decorators, { kind: "method", name: "getFps", static: false, private: false, access: { has: function (obj) { return "getFps" in obj; }, get: function (obj) { return obj.getFps; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setGop_decorators, { kind: "method", name: "setGop", static: false, private: false, access: { has: function (obj) { return "setGop" in obj; }, get: function (obj) { return obj.setGop; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getGop_decorators, { kind: "method", name: "getGop", static: false, private: false, access: { has: function (obj) { return "getGop" in obj; }, get: function (obj) { return obj.getGop; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBitrate_decorators, { kind: "method", name: "setBitrate", static: false, private: false, access: { has: function (obj) { return "setBitrate" in obj; }, get: function (obj) { return obj.setBitrate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getBitrate_decorators, { kind: "method", name: "getBitrate", static: false, private: false, access: { has: function (obj) { return "getBitrate" in obj; }, get: function (obj) { return obj.getBitrate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setWidth_decorators, { kind: "method", name: "setWidth", static: false, private: false, access: { has: function (obj) { return "setWidth" in obj; }, get: function (obj) { return obj.setWidth; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getWidth_decorators, { kind: "method", name: "getWidth", static: false, private: false, access: { has: function (obj) { return "getWidth" in obj; }, get: function (obj) { return obj.getWidth; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setHeight_decorators, { kind: "method", name: "setHeight", static: false, private: false, access: { has: function (obj) { return "setHeight" in obj; }, get: function (obj) { return obj.setHeight; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getHeight_decorators, { kind: "method", name: "getHeight", static: false, private: false, access: { has: function (obj) { return "getHeight" in obj; }, get: function (obj) { return obj.getHeight; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEnableBframe_decorators, { kind: "method", name: "setEnableBframe", static: false, private: false, access: { has: function (obj) { return "setEnableBframe" in obj; }, get: function (obj) { return obj.setEnableBframe; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getEnableBframe_decorators, { kind: "method", name: "getEnableBframe", static: false, private: false, access: { has: function (obj) { return "getEnableBframe" in obj; }, get: function (obj) { return obj.getEnableBframe; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoCodec_decorators, { kind: "method", name: "setVideoCodec", static: false, private: false, access: { has: function (obj) { return "setVideoCodec" in obj; }, get: function (obj) { return obj.setVideoCodec; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getVideoCodec_decorators, { kind: "method", name: "getVideoCodec", static: false, private: false, access: { has: function (obj) { return "getVideoCodec" in obj; }, get: function (obj) { return obj.getVideoCodec; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MediaPlayerCustomSource$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.MediaPlayerCustomSource')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _mode_decorators;
    var _mode_initializers = [];
    var _mode_extraInitializers = [];
    var _type_decorators;
    var _type_initializers = [];
    var _type_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function MediaPlayerCustomSource_1() {
            this.mode = __runInitializers(this, _mode_initializers, void 0);
            this.type = (__runInitializers(this, _mode_extraInitializers), __runInitializers(this, _type_initializers, void 0));
            __runInitializers(this, _type_extraInitializers);
        }
        return MediaPlayerCustomSource_1;
    }());
    __setFunctionName(_classThis, "MediaPlayerCustomSource");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _mode_decorators = [NativeMember()];
        _type_decorators = [NativeMember()];
        __esDecorate(null, null, _mode_decorators, { kind: "field", name: "mode", static: false, private: false, access: { has: function (obj) { return "mode" in obj; }, get: function (obj) { return obj.mode; }, set: function (obj, value) { obj.mode = value; } }, metadata: _metadata }, _mode_initializers, _mode_extraInitializers);
        __esDecorate(null, null, _type_decorators, { kind: "field", name: "type", static: false, private: false, access: { has: function (obj) { return "type" in obj; }, get: function (obj) { return obj.type; }, set: function (obj, value) { obj.type = value; } }, metadata: _metadata }, _type_initializers, _type_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MusicFilterType;
(function (MusicFilterType) {
    MusicFilterType[MusicFilterType["NONE"] = 0] = "NONE";
    MusicFilterType[MusicFilterType["WITHOUT_LYRIC"] = 1] = "WITHOUT_LYRIC";
    MusicFilterType[MusicFilterType["UNSUPPORTED_SCORE"] = 2] = "UNSUPPORTED_SCORE";
    MusicFilterType[MusicFilterType["UNSUPPORTED_ACCOMPANY"] = 4] = "UNSUPPORTED_ACCOMPANY";
    MusicFilterType[MusicFilterType["UNSUPPORTED_CLIMAX"] = 8] = "UNSUPPORTED_CLIMAX";
})(MusicFilterType || (MusicFilterType = {}));
var RemoteAudioPropertiesInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.RemoteAudioPropertiesInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _streamKey_decorators;
    var _streamKey_initializers = [];
    var _streamKey_extraInitializers = [];
    var _audioPropertiesInfo_decorators;
    var _audioPropertiesInfo_initializers = [];
    var _audioPropertiesInfo_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RemoteAudioPropertiesInfo_1(streamKey, audioPropertiesInfo) {
            this.streamKey = __runInitializers(this, _streamKey_initializers, void 0);
            this.audioPropertiesInfo = (__runInitializers(this, _streamKey_extraInitializers), __runInitializers(this, _audioPropertiesInfo_initializers, void 0));
            __runInitializers(this, _audioPropertiesInfo_extraInitializers);
        }
        return RemoteAudioPropertiesInfo_1;
    }());
    __setFunctionName(_classThis, "RemoteAudioPropertiesInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _streamKey_decorators = [NativeMember()];
        _audioPropertiesInfo_decorators = [NativeMember()];
        __esDecorate(null, null, _streamKey_decorators, { kind: "field", name: "streamKey", static: false, private: false, access: { has: function (obj) { return "streamKey" in obj; }, get: function (obj) { return obj.streamKey; }, set: function (obj, value) { obj.streamKey = value; } }, metadata: _metadata }, _streamKey_initializers, _streamKey_extraInitializers);
        __esDecorate(null, null, _audioPropertiesInfo_decorators, { kind: "field", name: "audioPropertiesInfo", static: false, private: false, access: { has: function (obj) { return "audioPropertiesInfo" in obj; }, get: function (obj) { return obj.audioPropertiesInfo; }, set: function (obj, value) { obj.audioPropertiesInfo = value; } }, metadata: _metadata }, _audioPropertiesInfo_initializers, _audioPropertiesInfo_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var LocalVideoRenderPosition;
(function (LocalVideoRenderPosition) {
    LocalVideoRenderPosition[LocalVideoRenderPosition["AFTER_CAPTURE"] = 0] = "AFTER_CAPTURE";
    LocalVideoRenderPosition[LocalVideoRenderPosition["AFTER_PREPROCESS"] = 1] = "AFTER_PREPROCESS";
})(LocalVideoRenderPosition || (LocalVideoRenderPosition = {}));
var RTCLogConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.RTCLogConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _logPath_decorators;
    var _logPath_initializers = [];
    var _logPath_extraInitializers = [];
    var _logFileSize_decorators;
    var _logFileSize_initializers = [];
    var _logFileSize_extraInitializers = [];
    var _logLevel_decorators;
    var _logLevel_initializers = [];
    var _logLevel_extraInitializers = [];
    var _logFilenamePrefix_decorators;
    var _logFilenamePrefix_initializers = [];
    var _logFilenamePrefix_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RTCLogConfig_1(logLevel, logPath, logFileSize, logFilenamePrefix) {
            this.logPath = __runInitializers(this, _logPath_initializers, void 0);
            this.logFileSize = (__runInitializers(this, _logPath_extraInitializers), __runInitializers(this, _logFileSize_initializers, void 0));
            this.logLevel = (__runInitializers(this, _logFileSize_extraInitializers), __runInitializers(this, _logLevel_initializers, void 0));
            this.logFilenamePrefix = (__runInitializers(this, _logLevel_extraInitializers), __runInitializers(this, _logFilenamePrefix_initializers, void 0));
            __runInitializers(this, _logFilenamePrefix_extraInitializers);
        }
        return RTCLogConfig_1;
    }());
    __setFunctionName(_classThis, "RTCLogConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _logPath_decorators = [NativeMember()];
        _logFileSize_decorators = [NativeMember()];
        _logLevel_decorators = [NativeMember()];
        _logFilenamePrefix_decorators = [NativeMember()];
        __esDecorate(null, null, _logPath_decorators, { kind: "field", name: "logPath", static: false, private: false, access: { has: function (obj) { return "logPath" in obj; }, get: function (obj) { return obj.logPath; }, set: function (obj, value) { obj.logPath = value; } }, metadata: _metadata }, _logPath_initializers, _logPath_extraInitializers);
        __esDecorate(null, null, _logFileSize_decorators, { kind: "field", name: "logFileSize", static: false, private: false, access: { has: function (obj) { return "logFileSize" in obj; }, get: function (obj) { return obj.logFileSize; }, set: function (obj, value) { obj.logFileSize = value; } }, metadata: _metadata }, _logFileSize_initializers, _logFileSize_extraInitializers);
        __esDecorate(null, null, _logLevel_decorators, { kind: "field", name: "logLevel", static: false, private: false, access: { has: function (obj) { return "logLevel" in obj; }, get: function (obj) { return obj.logLevel; }, set: function (obj, value) { obj.logLevel = value; } }, metadata: _metadata }, _logLevel_initializers, _logLevel_extraInitializers);
        __esDecorate(null, null, _logFilenamePrefix_decorators, { kind: "field", name: "logFilenamePrefix", static: false, private: false, access: { has: function (obj) { return "logFilenamePrefix" in obj; }, get: function (obj) { return obj.logFilenamePrefix; }, set: function (obj, value) { obj.logFilenamePrefix = value; } }, metadata: _metadata }, _logFilenamePrefix_initializers, _logFilenamePrefix_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioReportMode;
(function (AudioReportMode) {
    AudioReportMode[AudioReportMode["AUDIO_REPORT_MODE_NORMAL"] = 0] = "AUDIO_REPORT_MODE_NORMAL";
    AudioReportMode[AudioReportMode["AUDIO_REPORT_MODE_DISCONNECT"] = 1] = "AUDIO_REPORT_MODE_DISCONNECT";
    AudioReportMode[AudioReportMode["AUDIO_REPORT_MODE_RESET"] = 2] = "AUDIO_REPORT_MODE_RESET";
})(AudioReportMode || (AudioReportMode = {}));
var AudioFormat$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.AudioFormat')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _sampleRate_decorators;
    var _sampleRate_initializers = [];
    var _sampleRate_extraInitializers = [];
    var _channel_decorators;
    var _channel_initializers = [];
    var _channel_extraInitializers = [];
    var _samplesPerCall_decorators;
    var _samplesPerCall_initializers = [];
    var _samplesPerCall_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function AudioFormat_1() {
            this.sampleRate = __runInitializers(this, _sampleRate_initializers, void 0);
            this.channel = (__runInitializers(this, _sampleRate_extraInitializers), __runInitializers(this, _channel_initializers, void 0));
            this.samplesPerCall = (__runInitializers(this, _channel_extraInitializers), __runInitializers(this, _samplesPerCall_initializers, void 0));
            __runInitializers(this, _samplesPerCall_extraInitializers);
        }
        return AudioFormat_1;
    }());
    __setFunctionName(_classThis, "AudioFormat");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _sampleRate_decorators = [NativeMember()];
        _channel_decorators = [NativeMember()];
        _samplesPerCall_decorators = [NativeMember()];
        __esDecorate(null, null, _sampleRate_decorators, { kind: "field", name: "sampleRate", static: false, private: false, access: { has: function (obj) { return "sampleRate" in obj; }, get: function (obj) { return obj.sampleRate; }, set: function (obj, value) { obj.sampleRate = value; } }, metadata: _metadata }, _sampleRate_initializers, _sampleRate_extraInitializers);
        __esDecorate(null, null, _channel_decorators, { kind: "field", name: "channel", static: false, private: false, access: { has: function (obj) { return "channel" in obj; }, get: function (obj) { return obj.channel; }, set: function (obj, value) { obj.channel = value; } }, metadata: _metadata }, _channel_initializers, _channel_extraInitializers);
        __esDecorate(null, null, _samplesPerCall_decorators, { kind: "field", name: "samplesPerCall", static: false, private: false, access: { has: function (obj) { return "samplesPerCall" in obj; }, get: function (obj) { return obj.samplesPerCall; }, set: function (obj, value) { obj.samplesPerCall = value; } }, metadata: _metadata }, _samplesPerCall_initializers, _samplesPerCall_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MediaTypeEnhancementConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.MediaTypeEnhancementConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _enhanceSignaling_decorators;
    var _enhanceSignaling_initializers = [];
    var _enhanceSignaling_extraInitializers = [];
    var _enhanceAudio_decorators;
    var _enhanceAudio_initializers = [];
    var _enhanceAudio_extraInitializers = [];
    var _enhanceVideo_decorators;
    var _enhanceVideo_initializers = [];
    var _enhanceVideo_extraInitializers = [];
    var _enhanceScreenAudio_decorators;
    var _enhanceScreenAudio_initializers = [];
    var _enhanceScreenAudio_extraInitializers = [];
    var _enhanceScreenVideo_decorators;
    var _enhanceScreenVideo_initializers = [];
    var _enhanceScreenVideo_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function MediaTypeEnhancementConfig_1() {
            this.enhanceSignaling = __runInitializers(this, _enhanceSignaling_initializers, void 0);
            this.enhanceAudio = (__runInitializers(this, _enhanceSignaling_extraInitializers), __runInitializers(this, _enhanceAudio_initializers, void 0));
            this.enhanceVideo = (__runInitializers(this, _enhanceAudio_extraInitializers), __runInitializers(this, _enhanceVideo_initializers, void 0));
            this.enhanceScreenAudio = (__runInitializers(this, _enhanceVideo_extraInitializers), __runInitializers(this, _enhanceScreenAudio_initializers, void 0));
            this.enhanceScreenVideo = (__runInitializers(this, _enhanceScreenAudio_extraInitializers), __runInitializers(this, _enhanceScreenVideo_initializers, void 0));
            __runInitializers(this, _enhanceScreenVideo_extraInitializers);
        }
        return MediaTypeEnhancementConfig_1;
    }());
    __setFunctionName(_classThis, "MediaTypeEnhancementConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enhanceSignaling_decorators = [NativeMember()];
        _enhanceAudio_decorators = [NativeMember()];
        _enhanceVideo_decorators = [NativeMember()];
        _enhanceScreenAudio_decorators = [NativeMember()];
        _enhanceScreenVideo_decorators = [NativeMember()];
        __esDecorate(null, null, _enhanceSignaling_decorators, { kind: "field", name: "enhanceSignaling", static: false, private: false, access: { has: function (obj) { return "enhanceSignaling" in obj; }, get: function (obj) { return obj.enhanceSignaling; }, set: function (obj, value) { obj.enhanceSignaling = value; } }, metadata: _metadata }, _enhanceSignaling_initializers, _enhanceSignaling_extraInitializers);
        __esDecorate(null, null, _enhanceAudio_decorators, { kind: "field", name: "enhanceAudio", static: false, private: false, access: { has: function (obj) { return "enhanceAudio" in obj; }, get: function (obj) { return obj.enhanceAudio; }, set: function (obj, value) { obj.enhanceAudio = value; } }, metadata: _metadata }, _enhanceAudio_initializers, _enhanceAudio_extraInitializers);
        __esDecorate(null, null, _enhanceVideo_decorators, { kind: "field", name: "enhanceVideo", static: false, private: false, access: { has: function (obj) { return "enhanceVideo" in obj; }, get: function (obj) { return obj.enhanceVideo; }, set: function (obj, value) { obj.enhanceVideo = value; } }, metadata: _metadata }, _enhanceVideo_initializers, _enhanceVideo_extraInitializers);
        __esDecorate(null, null, _enhanceScreenAudio_decorators, { kind: "field", name: "enhanceScreenAudio", static: false, private: false, access: { has: function (obj) { return "enhanceScreenAudio" in obj; }, get: function (obj) { return obj.enhanceScreenAudio; }, set: function (obj, value) { obj.enhanceScreenAudio = value; } }, metadata: _metadata }, _enhanceScreenAudio_initializers, _enhanceScreenAudio_extraInitializers);
        __esDecorate(null, null, _enhanceScreenVideo_decorators, { kind: "field", name: "enhanceScreenVideo", static: false, private: false, access: { has: function (obj) { return "enhanceScreenVideo" in obj; }, get: function (obj) { return obj.enhanceScreenVideo; }, set: function (obj, value) { obj.enhanceScreenVideo = value; } }, metadata: _metadata }, _enhanceScreenVideo_initializers, _enhanceScreenVideo_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MirrorType;
(function (MirrorType) {
    MirrorType[MirrorType["MIRROR_TYPE_NONE"] = 0] = "MIRROR_TYPE_NONE";
    MirrorType[MirrorType["MIRROR_TYPE_RENDER"] = 1] = "MIRROR_TYPE_RENDER";
    MirrorType[MirrorType["MIRROR_TYPE_RENDER_AND_ENCODER"] = 3] = "MIRROR_TYPE_RENDER_AND_ENCODER";
})(MirrorType || (MirrorType = {}));
var CloudProxyInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.CloudProxyInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _cloudProxyIp_decorators;
    var _cloudProxyIp_initializers = [];
    var _cloudProxyIp_extraInitializers = [];
    var _cloudProxyPort_decorators;
    var _cloudProxyPort_initializers = [];
    var _cloudProxyPort_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function CloudProxyInfo_1(cloudProxyIp, cloudProxyPort) {
            this.cloudProxyIp = __runInitializers(this, _cloudProxyIp_initializers, void 0);
            this.cloudProxyPort = (__runInitializers(this, _cloudProxyIp_extraInitializers), __runInitializers(this, _cloudProxyPort_initializers, void 0));
            __runInitializers(this, _cloudProxyPort_extraInitializers);
        }
        return CloudProxyInfo_1;
    }());
    __setFunctionName(_classThis, "CloudProxyInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _cloudProxyIp_decorators = [NativeMember()];
        _cloudProxyPort_decorators = [NativeMember()];
        __esDecorate(null, null, _cloudProxyIp_decorators, { kind: "field", name: "cloudProxyIp", static: false, private: false, access: { has: function (obj) { return "cloudProxyIp" in obj; }, get: function (obj) { return obj.cloudProxyIp; }, set: function (obj, value) { obj.cloudProxyIp = value; } }, metadata: _metadata }, _cloudProxyIp_initializers, _cloudProxyIp_extraInitializers);
        __esDecorate(null, null, _cloudProxyPort_decorators, { kind: "field", name: "cloudProxyPort", static: false, private: false, access: { has: function (obj) { return "cloudProxyPort" in obj; }, get: function (obj) { return obj.cloudProxyPort; }, set: function (obj, value) { obj.cloudProxyPort = value; } }, metadata: _metadata }, _cloudProxyPort_initializers, _cloudProxyPort_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoEncoderConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.VideoEncoderConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _frameRate_decorators;
    var _frameRate_initializers = [];
    var _frameRate_extraInitializers = [];
    var _maxBitrate_decorators;
    var _maxBitrate_initializers = [];
    var _maxBitrate_extraInitializers = [];
    var _minBitrate_decorators;
    var _minBitrate_initializers = [];
    var _minBitrate_extraInitializers = [];
    var _encodePreference_decorators;
    var _encodePreference_initializers = [];
    var _encodePreference_extraInitializers = [];
    var _maxQp_decorators;
    var _maxQp_initializers = [];
    var _maxQp_extraInitializers = [];
    var _minQp_decorators;
    var _minQp_initializers = [];
    var _minQp_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function VideoEncoderConfig_1() {
            this.width = __runInitializers(this, _width_initializers, void 0);
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.frameRate = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _frameRate_initializers, void 0));
            this.maxBitrate = (__runInitializers(this, _frameRate_extraInitializers), __runInitializers(this, _maxBitrate_initializers, void 0));
            this.minBitrate = (__runInitializers(this, _maxBitrate_extraInitializers), __runInitializers(this, _minBitrate_initializers, void 0));
            this.encodePreference = (__runInitializers(this, _minBitrate_extraInitializers), __runInitializers(this, _encodePreference_initializers, void 0));
            this.maxQp = (__runInitializers(this, _encodePreference_extraInitializers), __runInitializers(this, _maxQp_initializers, void 0));
            this.minQp = (__runInitializers(this, _maxQp_extraInitializers), __runInitializers(this, _minQp_initializers, void 0));
            __runInitializers(this, _minQp_extraInitializers);
        }
        return VideoEncoderConfig_1;
    }());
    __setFunctionName(_classThis, "VideoEncoderConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _frameRate_decorators = [NativeMember()];
        _maxBitrate_decorators = [NativeMember()];
        _minBitrate_decorators = [NativeMember()];
        _encodePreference_decorators = [NativeMember()];
        _maxQp_decorators = [NativeMember()];
        _minQp_decorators = [NativeMember()];
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _frameRate_decorators, { kind: "field", name: "frameRate", static: false, private: false, access: { has: function (obj) { return "frameRate" in obj; }, get: function (obj) { return obj.frameRate; }, set: function (obj, value) { obj.frameRate = value; } }, metadata: _metadata }, _frameRate_initializers, _frameRate_extraInitializers);
        __esDecorate(null, null, _maxBitrate_decorators, { kind: "field", name: "maxBitrate", static: false, private: false, access: { has: function (obj) { return "maxBitrate" in obj; }, get: function (obj) { return obj.maxBitrate; }, set: function (obj, value) { obj.maxBitrate = value; } }, metadata: _metadata }, _maxBitrate_initializers, _maxBitrate_extraInitializers);
        __esDecorate(null, null, _minBitrate_decorators, { kind: "field", name: "minBitrate", static: false, private: false, access: { has: function (obj) { return "minBitrate" in obj; }, get: function (obj) { return obj.minBitrate; }, set: function (obj, value) { obj.minBitrate = value; } }, metadata: _metadata }, _minBitrate_initializers, _minBitrate_extraInitializers);
        __esDecorate(null, null, _encodePreference_decorators, { kind: "field", name: "encodePreference", static: false, private: false, access: { has: function (obj) { return "encodePreference" in obj; }, get: function (obj) { return obj.encodePreference; }, set: function (obj, value) { obj.encodePreference = value; } }, metadata: _metadata }, _encodePreference_initializers, _encodePreference_extraInitializers);
        __esDecorate(null, null, _maxQp_decorators, { kind: "field", name: "maxQp", static: false, private: false, access: { has: function (obj) { return "maxQp" in obj; }, get: function (obj) { return obj.maxQp; }, set: function (obj, value) { obj.maxQp = value; } }, metadata: _metadata }, _maxQp_initializers, _maxQp_extraInitializers);
        __esDecorate(null, null, _minQp_decorators, { kind: "field", name: "minQp", static: false, private: false, access: { has: function (obj) { return "minQp" in obj; }, get: function (obj) { return obj.minQp; }, set: function (obj, value) { obj.minQp = value; } }, metadata: _metadata }, _minQp_initializers, _minQp_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var FirstFramePlayState;
(function (FirstFramePlayState) {
    FirstFramePlayState[FirstFramePlayState["FIRST_FRAME_PLAY_STATE_PLAYING"] = 0] = "FIRST_FRAME_PLAY_STATE_PLAYING";
    FirstFramePlayState[FirstFramePlayState["FIRST_FRAME_PLAY_STATE_PLAYED"] = 1] = "FIRST_FRAME_PLAY_STATE_PLAYED";
    FirstFramePlayState[FirstFramePlayState["FIRST_FRAME_PLAY_STATE_END"] = 2] = "FIRST_FRAME_PLAY_STATE_END";
})(FirstFramePlayState || (FirstFramePlayState = {}));
var RemoteVideoSinkConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.RemoteVideoSinkConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _position_decorators;
    var _position_initializers = [];
    var _position_extraInitializers = [];
    var _pixelFormat_decorators;
    var _pixelFormat_initializers = [];
    var _pixelFormat_extraInitializers = [];
    var _applyRotation_decorators;
    var _applyRotation_initializers = [];
    var _applyRotation_extraInitializers = [];
    var _mirrorType_decorators;
    var _mirrorType_initializers = [];
    var _mirrorType_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RemoteVideoSinkConfig_1() {
            this.position = __runInitializers(this, _position_initializers, void 0);
            this.pixelFormat = (__runInitializers(this, _position_extraInitializers), __runInitializers(this, _pixelFormat_initializers, void 0));
            this.applyRotation = (__runInitializers(this, _pixelFormat_extraInitializers), __runInitializers(this, _applyRotation_initializers, void 0));
            this.mirrorType = (__runInitializers(this, _applyRotation_extraInitializers), __runInitializers(this, _mirrorType_initializers, void 0));
            __runInitializers(this, _mirrorType_extraInitializers);
        }
        return RemoteVideoSinkConfig_1;
    }());
    __setFunctionName(_classThis, "RemoteVideoSinkConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _position_decorators = [NativeMember()];
        _pixelFormat_decorators = [NativeMember()];
        _applyRotation_decorators = [NativeMember()];
        _mirrorType_decorators = [NativeMember()];
        __esDecorate(null, null, _position_decorators, { kind: "field", name: "position", static: false, private: false, access: { has: function (obj) { return "position" in obj; }, get: function (obj) { return obj.position; }, set: function (obj, value) { obj.position = value; } }, metadata: _metadata }, _position_initializers, _position_extraInitializers);
        __esDecorate(null, null, _pixelFormat_decorators, { kind: "field", name: "pixelFormat", static: false, private: false, access: { has: function (obj) { return "pixelFormat" in obj; }, get: function (obj) { return obj.pixelFormat; }, set: function (obj, value) { obj.pixelFormat = value; } }, metadata: _metadata }, _pixelFormat_initializers, _pixelFormat_extraInitializers);
        __esDecorate(null, null, _applyRotation_decorators, { kind: "field", name: "applyRotation", static: false, private: false, access: { has: function (obj) { return "applyRotation" in obj; }, get: function (obj) { return obj.applyRotation; }, set: function (obj, value) { obj.applyRotation = value; } }, metadata: _metadata }, _applyRotation_initializers, _applyRotation_extraInitializers);
        __esDecorate(null, null, _mirrorType_decorators, { kind: "field", name: "mirrorType", static: false, private: false, access: { has: function (obj) { return "mirrorType" in obj; }, get: function (obj) { return obj.mirrorType; }, set: function (obj, value) { obj.mirrorType = value; } }, metadata: _metadata }, _mirrorType_initializers, _mirrorType_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoSuperResolutionModeChangedReason;
(function (VideoSuperResolutionModeChangedReason) {
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_OFF"] = 0] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_OFF";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_ON"] = 1] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_ON";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_RESOLUTION_EXCEED"] = 2] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_RESOLUTION_EXCEED";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OVER_USE"] = 3] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OVER_USE";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DEVICE_NOT_SUPPORT"] = 4] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DEVICE_NOT_SUPPORT";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DYNAMIC_CLOSE"] = 5] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DYNAMIC_CLOSE";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_DISABLED"] = 6] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_DISABLED";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_ENABLED"] = 7] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_ENABLED";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_NO_COMPONENT"] = 8] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_NO_COMPONENT";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_STREAM_NOT_EXIST"] = 9] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_STREAM_NOT_EXIST";
})(VideoSuperResolutionModeChangedReason || (VideoSuperResolutionModeChangedReason = {}));
var AnsMode;
(function (AnsMode) {
    AnsMode[AnsMode["ANS_MODE_DISABLE"] = 0] = "ANS_MODE_DISABLE";
    AnsMode[AnsMode["ANS_MODE_LOW"] = 1] = "ANS_MODE_LOW";
    AnsMode[AnsMode["ANS_MODE_MEDIUM"] = 2] = "ANS_MODE_MEDIUM";
    AnsMode[AnsMode["ANS_MODE_HIGH"] = 3] = "ANS_MODE_HIGH";
    AnsMode[AnsMode["ANS_MODE_AUTOMATIC"] = 4] = "ANS_MODE_AUTOMATIC";
})(AnsMode || (AnsMode = {}));
var LocalAudioStreamState;
(function (LocalAudioStreamState) {
    LocalAudioStreamState[LocalAudioStreamState["LOCAL_AUDIO_STREAM_STATE_STOPPED"] = 0] = "LOCAL_AUDIO_STREAM_STATE_STOPPED";
    LocalAudioStreamState[LocalAudioStreamState["LOCAL_AUDIO_STREAM_STATE_RECORDING"] = 1] = "LOCAL_AUDIO_STREAM_STATE_RECORDING";
    LocalAudioStreamState[LocalAudioStreamState["LOCAL_AUDIO_STREAM_STATE_ENCODING"] = 2] = "LOCAL_AUDIO_STREAM_STATE_ENCODING";
    LocalAudioStreamState[LocalAudioStreamState["LOCAL_AUDIO_STREAM_STATE_FAILED"] = 3] = "LOCAL_AUDIO_STREAM_STATE_FAILED";
})(LocalAudioStreamState || (LocalAudioStreamState = {}));
var VideoFrameInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.VideoFrameInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _rotation_decorators;
    var _rotation_initializers = [];
    var _rotation_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function VideoFrameInfo_1(width, height, rotation) {
            this.width = __runInitializers(this, _width_initializers, void 0);
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.rotation = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _rotation_initializers, void 0));
            __runInitializers(this, _rotation_extraInitializers);
        }
        return VideoFrameInfo_1;
    }());
    __setFunctionName(_classThis, "VideoFrameInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _rotation_decorators = [NativeMember()];
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _rotation_decorators, { kind: "field", name: "rotation", static: false, private: false, access: { has: function (obj) { return "rotation" in obj; }, get: function (obj) { return obj.rotation; }, set: function (obj, value) { obj.rotation = value; } }, metadata: _metadata }, _rotation_initializers, _rotation_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var EngineConfig = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.EngineConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _appID_decorators;
    var _appID_initializers = [];
    var _appID_extraInitializers = [];
    var _eglContext_decorators;
    var _eglContext_initializers = [];
    var _eglContext_extraInitializers = [];
    var _parameters_decorators;
    var _parameters_initializers = [];
    var _parameters_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function EngineConfig_1(appID) {
            this.appID = __runInitializers(this, _appID_initializers, void 0);
            this.eglContext = (__runInitializers(this, _appID_extraInitializers), __runInitializers(this, _eglContext_initializers, void 0));
            this.parameters = (__runInitializers(this, _eglContext_extraInitializers), __runInitializers(this, _parameters_initializers, void 0));
            __runInitializers(this, _parameters_extraInitializers);
        }
        return EngineConfig_1;
    }());
    __setFunctionName(_classThis, "EngineConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _appID_decorators = [NativeMember()];
        _eglContext_decorators = [NativeMember()];
        _parameters_decorators = [NativeMember()];
        __esDecorate(null, null, _appID_decorators, { kind: "field", name: "appID", static: false, private: false, access: { has: function (obj) { return "appID" in obj; }, get: function (obj) { return obj.appID; }, set: function (obj, value) { obj.appID = value; } }, metadata: _metadata }, _appID_initializers, _appID_extraInitializers);
        __esDecorate(null, null, _eglContext_decorators, { kind: "field", name: "eglContext", static: false, private: false, access: { has: function (obj) { return "eglContext" in obj; }, get: function (obj) { return obj.eglContext; }, set: function (obj, value) { obj.eglContext = value; } }, metadata: _metadata }, _eglContext_initializers, _eglContext_extraInitializers);
        __esDecorate(null, null, _parameters_decorators, { kind: "field", name: "parameters", static: false, private: false, access: { has: function (obj) { return "parameters" in obj; }, get: function (obj) { return obj.parameters; }, set: function (obj, value) { obj.parameters = value; } }, metadata: _metadata }, _parameters_initializers, _parameters_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
    })();
    _classThis.TAG = 'EngineConfig';
    _classThis.ENGINE_CONFIG_VALID = 0;
    _classThis.ENGINE_CONFIG_INVALID_APP_ID = 1;
    _classThis.ENGINE_CONFIG_INVALID_NATIVE_LIB_PATH = 2;
    (function () {
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var TranscoderClientMixVideoFormat;
(function (TranscoderClientMixVideoFormat) {
    TranscoderClientMixVideoFormat[TranscoderClientMixVideoFormat["YUV_I420"] = 0] = "YUV_I420";
    TranscoderClientMixVideoFormat[TranscoderClientMixVideoFormat["TEXTURE_2D"] = 1] = "TEXTURE_2D";
    TranscoderClientMixVideoFormat[TranscoderClientMixVideoFormat["CVPIXEL_BUFFER_BGRA"] = 2] = "CVPIXEL_BUFFER_BGRA";
    TranscoderClientMixVideoFormat[TranscoderClientMixVideoFormat["YUV_NV12"] = 3] = "YUV_NV12";
})(TranscoderClientMixVideoFormat || (TranscoderClientMixVideoFormat = {}));
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.LiveTranscoding$VideoConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setCodec_decorators;
    var _setFps_decorators;
    var _setGop_decorators;
    var _setBFrame_decorators;
    var _setKBitRate_decorators;
    var _setWidth_decorators;
    var _setHeight_decorators;
    _classThis = /** @class */ (function () {
        function LiveTranscoding$VideoConfig_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        LiveTranscoding$VideoConfig_1.prototype.setCodec = function (codec) {
            throw new Error('not implement');
        };
        LiveTranscoding$VideoConfig_1.prototype.setFps = function (fps) {
            throw new Error('not implement');
        };
        LiveTranscoding$VideoConfig_1.prototype.setGop = function (gop) {
            throw new Error('not implement');
        };
        LiveTranscoding$VideoConfig_1.prototype.setBFrame = function (useBFrame) {
            throw new Error('not implement');
        };
        LiveTranscoding$VideoConfig_1.prototype.setKBitRate = function (kBitRate) {
            throw new Error('not implement');
        };
        LiveTranscoding$VideoConfig_1.prototype.setWidth = function (width) {
            throw new Error('not implement');
        };
        LiveTranscoding$VideoConfig_1.prototype.setHeight = function (height) {
            throw new Error('not implement');
        };
        return LiveTranscoding$VideoConfig_1;
    }());
    __setFunctionName(_classThis, "LiveTranscoding$VideoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setCodec_decorators = [NativeMethodSync()];
        _setFps_decorators = [NativeMethodSync()];
        _setGop_decorators = [NativeMethodSync()];
        _setBFrame_decorators = [NativeMethodSync()];
        _setKBitRate_decorators = [NativeMethodSync()];
        _setWidth_decorators = [NativeMethodSync()];
        _setHeight_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setCodec_decorators, { kind: "method", name: "setCodec", static: false, private: false, access: { has: function (obj) { return "setCodec" in obj; }, get: function (obj) { return obj.setCodec; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setFps_decorators, { kind: "method", name: "setFps", static: false, private: false, access: { has: function (obj) { return "setFps" in obj; }, get: function (obj) { return obj.setFps; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setGop_decorators, { kind: "method", name: "setGop", static: false, private: false, access: { has: function (obj) { return "setGop" in obj; }, get: function (obj) { return obj.setGop; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBFrame_decorators, { kind: "method", name: "setBFrame", static: false, private: false, access: { has: function (obj) { return "setBFrame" in obj; }, get: function (obj) { return obj.setBFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setKBitRate_decorators, { kind: "method", name: "setKBitRate", static: false, private: false, access: { has: function (obj) { return "setKBitRate" in obj; }, get: function (obj) { return obj.setKBitRate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setWidth_decorators, { kind: "method", name: "setWidth", static: false, private: false, access: { has: function (obj) { return "setWidth" in obj; }, get: function (obj) { return obj.setWidth; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setHeight_decorators, { kind: "method", name: "setHeight", static: false, private: false, access: { has: function (obj) { return "setHeight" in obj; }, get: function (obj) { return obj.setHeight; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var RemoteStreamSwitch = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.RemoteStreamSwitch')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _uid_decorators;
    var _uid_initializers = [];
    var _uid_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _beforeVideoIndex_decorators;
    var _beforeVideoIndex_initializers = [];
    var _beforeVideoIndex_extraInitializers = [];
    var _afterVideoIndex_decorators;
    var _afterVideoIndex_initializers = [];
    var _afterVideoIndex_extraInitializers = [];
    var _beforeEnable_decorators;
    var _beforeEnable_initializers = [];
    var _beforeEnable_extraInitializers = [];
    var _afterEnable_decorators;
    var _afterEnable_initializers = [];
    var _afterEnable_extraInitializers = [];
    var _reason_decorators;
    var _reason_initializers = [];
    var _reason_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RemoteStreamSwitch_1() {
            this.uid = __runInitializers(this, _uid_initializers, void 0);
            this.isScreen = (__runInitializers(this, _uid_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.beforeVideoIndex = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _beforeVideoIndex_initializers, void 0));
            this.afterVideoIndex = (__runInitializers(this, _beforeVideoIndex_extraInitializers), __runInitializers(this, _afterVideoIndex_initializers, void 0));
            this.beforeEnable = (__runInitializers(this, _afterVideoIndex_extraInitializers), __runInitializers(this, _beforeEnable_initializers, void 0));
            this.afterEnable = (__runInitializers(this, _beforeEnable_extraInitializers), __runInitializers(this, _afterEnable_initializers, void 0));
            this.reason = (__runInitializers(this, _afterEnable_extraInitializers), __runInitializers(this, _reason_initializers, void 0));
            __runInitializers(this, _reason_extraInitializers);
        }
        return RemoteStreamSwitch_1;
    }());
    __setFunctionName(_classThis, "RemoteStreamSwitch");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _uid_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _beforeVideoIndex_decorators = [NativeMember()];
        _afterVideoIndex_decorators = [NativeMember()];
        _beforeEnable_decorators = [NativeMember()];
        _afterEnable_decorators = [NativeMember()];
        _reason_decorators = [NativeMember()];
        __esDecorate(null, null, _uid_decorators, { kind: "field", name: "uid", static: false, private: false, access: { has: function (obj) { return "uid" in obj; }, get: function (obj) { return obj.uid; }, set: function (obj, value) { obj.uid = value; } }, metadata: _metadata }, _uid_initializers, _uid_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _beforeVideoIndex_decorators, { kind: "field", name: "beforeVideoIndex", static: false, private: false, access: { has: function (obj) { return "beforeVideoIndex" in obj; }, get: function (obj) { return obj.beforeVideoIndex; }, set: function (obj, value) { obj.beforeVideoIndex = value; } }, metadata: _metadata }, _beforeVideoIndex_initializers, _beforeVideoIndex_extraInitializers);
        __esDecorate(null, null, _afterVideoIndex_decorators, { kind: "field", name: "afterVideoIndex", static: false, private: false, access: { has: function (obj) { return "afterVideoIndex" in obj; }, get: function (obj) { return obj.afterVideoIndex; }, set: function (obj, value) { obj.afterVideoIndex = value; } }, metadata: _metadata }, _afterVideoIndex_initializers, _afterVideoIndex_extraInitializers);
        __esDecorate(null, null, _beforeEnable_decorators, { kind: "field", name: "beforeEnable", static: false, private: false, access: { has: function (obj) { return "beforeEnable" in obj; }, get: function (obj) { return obj.beforeEnable; }, set: function (obj, value) { obj.beforeEnable = value; } }, metadata: _metadata }, _beforeEnable_initializers, _beforeEnable_extraInitializers);
        __esDecorate(null, null, _afterEnable_decorators, { kind: "field", name: "afterEnable", static: false, private: false, access: { has: function (obj) { return "afterEnable" in obj; }, get: function (obj) { return obj.afterEnable; }, set: function (obj, value) { obj.afterEnable = value; } }, metadata: _metadata }, _afterEnable_initializers, _afterEnable_extraInitializers);
        __esDecorate(null, null, _reason_decorators, { kind: "field", name: "reason", static: false, private: false, access: { has: function (obj) { return "reason" in obj; }, get: function (obj) { return obj.reason; }, set: function (obj, value) { obj.reason = value; } }, metadata: _metadata }, _reason_initializers, _reason_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MixedStreamSpatialConfig = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.MixedStreamConfig$MixedStreamSpatialConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setAudienceSpatialPosition_decorators;
    var _getAudienceSpatialPosition_decorators;
    var _setAudienceSpatialOrientation_decorators;
    var _getAudienceSpatialOrientation_decorators;
    var _setEnableSpatialRender_decorators;
    var _getEnableSpatialRender_decorators;
    _classThis = /** @class */ (function () {
        function MixedStreamSpatialConfig_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        MixedStreamSpatialConfig_1.prototype.setAudienceSpatialPosition = function (pos) {
            throw new Error('not implement');
        };
        MixedStreamSpatialConfig_1.prototype.getAudienceSpatialPosition = function () {
            throw new Error('not implement');
        };
        MixedStreamSpatialConfig_1.prototype.setAudienceSpatialOrientation = function (orientation) {
            throw new Error('not implement');
        };
        MixedStreamSpatialConfig_1.prototype.getAudienceSpatialOrientation = function () {
            throw new Error('not implement');
        };
        MixedStreamSpatialConfig_1.prototype.setEnableSpatialRender = function (enableSpatialRender) {
            throw new Error('not implement');
        };
        MixedStreamSpatialConfig_1.prototype.getEnableSpatialRender = function () {
            throw new Error('not implement');
        };
        return MixedStreamSpatialConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamSpatialConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setAudienceSpatialPosition_decorators = [NativeMethodSync()];
        _getAudienceSpatialPosition_decorators = [ReturnClass(function () { return Position$1; }), NativeMethodSync()];
        _setAudienceSpatialOrientation_decorators = [NativeMethodSync()];
        _getAudienceSpatialOrientation_decorators = [ReturnClass(function () { return HumanOrientation$1; }), NativeMethodSync()];
        _setEnableSpatialRender_decorators = [NativeMethodSync()];
        _getEnableSpatialRender_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setAudienceSpatialPosition_decorators, { kind: "method", name: "setAudienceSpatialPosition", static: false, private: false, access: { has: function (obj) { return "setAudienceSpatialPosition" in obj; }, get: function (obj) { return obj.setAudienceSpatialPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudienceSpatialPosition_decorators, { kind: "method", name: "getAudienceSpatialPosition", static: false, private: false, access: { has: function (obj) { return "getAudienceSpatialPosition" in obj; }, get: function (obj) { return obj.getAudienceSpatialPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudienceSpatialOrientation_decorators, { kind: "method", name: "setAudienceSpatialOrientation", static: false, private: false, access: { has: function (obj) { return "setAudienceSpatialOrientation" in obj; }, get: function (obj) { return obj.setAudienceSpatialOrientation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudienceSpatialOrientation_decorators, { kind: "method", name: "getAudienceSpatialOrientation", static: false, private: false, access: { has: function (obj) { return "getAudienceSpatialOrientation" in obj; }, get: function (obj) { return obj.getAudienceSpatialOrientation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEnableSpatialRender_decorators, { kind: "method", name: "setEnableSpatialRender", static: false, private: false, access: { has: function (obj) { return "setEnableSpatialRender" in obj; }, get: function (obj) { return obj.setEnableSpatialRender; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getEnableSpatialRender_decorators, { kind: "method", name: "getEnableSpatialRender", static: false, private: false, access: { has: function (obj) { return "getEnableSpatialRender" in obj; }, get: function (obj) { return obj.getEnableSpatialRender; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoCanvas$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.VideoCanvas')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _renderView_decorators;
    var _renderView_initializers = [];
    var _renderView_extraInitializers = [];
    var _renderSurface_decorators;
    var _renderSurface_initializers = [];
    var _renderSurface_extraInitializers = [];
    var _renderMode_decorators;
    var _renderMode_initializers = [];
    var _renderMode_extraInitializers = [];
    var _backgroundColor_decorators;
    var _backgroundColor_initializers = [];
    var _backgroundColor_extraInitializers = [];
    var _renderRotation_decorators;
    var _renderRotation_initializers = [];
    var _renderRotation_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function VideoCanvas_1() {
            this.renderView = __runInitializers(this, _renderView_initializers, void 0);
            this.renderSurface = (__runInitializers(this, _renderView_extraInitializers), __runInitializers(this, _renderSurface_initializers, void 0));
            this.renderMode = (__runInitializers(this, _renderSurface_extraInitializers), __runInitializers(this, _renderMode_initializers, void 0));
            this.backgroundColor = (__runInitializers(this, _renderMode_extraInitializers), __runInitializers(this, _backgroundColor_initializers, void 0));
            this.renderRotation = (__runInitializers(this, _backgroundColor_extraInitializers), __runInitializers(this, _renderRotation_initializers, void 0));
            __runInitializers(this, _renderRotation_extraInitializers);
        }
        return VideoCanvas_1;
    }());
    __setFunctionName(_classThis, "VideoCanvas");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _renderView_decorators = [NativeMember()];
        _renderSurface_decorators = [NativeMember()];
        _renderMode_decorators = [NativeMember()];
        _backgroundColor_decorators = [NativeMember()];
        _renderRotation_decorators = [NativeMember()];
        __esDecorate(null, null, _renderView_decorators, { kind: "field", name: "renderView", static: false, private: false, access: { has: function (obj) { return "renderView" in obj; }, get: function (obj) { return obj.renderView; }, set: function (obj, value) { obj.renderView = value; } }, metadata: _metadata }, _renderView_initializers, _renderView_extraInitializers);
        __esDecorate(null, null, _renderSurface_decorators, { kind: "field", name: "renderSurface", static: false, private: false, access: { has: function (obj) { return "renderSurface" in obj; }, get: function (obj) { return obj.renderSurface; }, set: function (obj, value) { obj.renderSurface = value; } }, metadata: _metadata }, _renderSurface_initializers, _renderSurface_extraInitializers);
        __esDecorate(null, null, _renderMode_decorators, { kind: "field", name: "renderMode", static: false, private: false, access: { has: function (obj) { return "renderMode" in obj; }, get: function (obj) { return obj.renderMode; }, set: function (obj, value) { obj.renderMode = value; } }, metadata: _metadata }, _renderMode_initializers, _renderMode_extraInitializers);
        __esDecorate(null, null, _backgroundColor_decorators, { kind: "field", name: "backgroundColor", static: false, private: false, access: { has: function (obj) { return "backgroundColor" in obj; }, get: function (obj) { return obj.backgroundColor; }, set: function (obj, value) { obj.backgroundColor = value; } }, metadata: _metadata }, _backgroundColor_initializers, _backgroundColor_extraInitializers);
        __esDecorate(null, null, _renderRotation_decorators, { kind: "field", name: "renderRotation", static: false, private: false, access: { has: function (obj) { return "renderRotation" in obj; }, get: function (obj) { return obj.renderRotation; }, set: function (obj, value) { obj.renderRotation = value; } }, metadata: _metadata }, _renderRotation_initializers, _renderRotation_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
    })();
    _classThis.RENDER_MODE_HIDDEN = 1;
    _classThis.RENDER_MODE_FIT = 2;
    _classThis.RENDER_MODE_FILL = 3;
    (function () {
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RemoteVideoStats$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.RemoteVideoStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _videoLossRate_decorators;
    var _videoLossRate_initializers = [];
    var _videoLossRate_extraInitializers = [];
    var _receivedKBitrate_decorators;
    var _receivedKBitrate_initializers = [];
    var _receivedKBitrate_extraInitializers = [];
    var _decoderOutputFrameRate_decorators;
    var _decoderOutputFrameRate_initializers = [];
    var _decoderOutputFrameRate_extraInitializers = [];
    var _rendererOutputFrameRate_decorators;
    var _rendererOutputFrameRate_initializers = [];
    var _rendererOutputFrameRate_extraInitializers = [];
    var _stallCount_decorators;
    var _stallCount_initializers = [];
    var _stallCount_extraInitializers = [];
    var _stallDuration_decorators;
    var _stallDuration_initializers = [];
    var _stallDuration_extraInitializers = [];
    var _e2eDelay_decorators;
    var _e2eDelay_initializers = [];
    var _e2eDelay_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _statsInterval_decorators;
    var _statsInterval_initializers = [];
    var _statsInterval_extraInitializers = [];
    var _rtt_decorators;
    var _rtt_initializers = [];
    var _rtt_extraInitializers = [];
    var _frozenRate_decorators;
    var _frozenRate_initializers = [];
    var _frozenRate_extraInitializers = [];
    var _codecType_decorators;
    var _codecType_initializers = [];
    var _codecType_extraInitializers = [];
    var _videoIndex_decorators;
    var _videoIndex_initializers = [];
    var _videoIndex_extraInitializers = [];
    var _jitter_decorators;
    var _jitter_initializers = [];
    var _jitter_extraInitializers = [];
    var _superResolutionMode_decorators;
    var _superResolutionMode_initializers = [];
    var _superResolutionMode_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RemoteVideoStats_1() {
            this.width = __runInitializers(this, _width_initializers, void 0);
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.videoLossRate = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _videoLossRate_initializers, void 0));
            this.receivedKBitrate = (__runInitializers(this, _videoLossRate_extraInitializers), __runInitializers(this, _receivedKBitrate_initializers, void 0));
            this.decoderOutputFrameRate = (__runInitializers(this, _receivedKBitrate_extraInitializers), __runInitializers(this, _decoderOutputFrameRate_initializers, void 0));
            this.rendererOutputFrameRate = (__runInitializers(this, _decoderOutputFrameRate_extraInitializers), __runInitializers(this, _rendererOutputFrameRate_initializers, void 0));
            this.stallCount = (__runInitializers(this, _rendererOutputFrameRate_extraInitializers), __runInitializers(this, _stallCount_initializers, void 0));
            this.stallDuration = (__runInitializers(this, _stallCount_extraInitializers), __runInitializers(this, _stallDuration_initializers, void 0));
            this.e2eDelay = (__runInitializers(this, _stallDuration_extraInitializers), __runInitializers(this, _e2eDelay_initializers, void 0));
            this.isScreen = (__runInitializers(this, _e2eDelay_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.statsInterval = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _statsInterval_initializers, void 0));
            this.rtt = (__runInitializers(this, _statsInterval_extraInitializers), __runInitializers(this, _rtt_initializers, void 0));
            this.frozenRate = (__runInitializers(this, _rtt_extraInitializers), __runInitializers(this, _frozenRate_initializers, void 0));
            this.codecType = (__runInitializers(this, _frozenRate_extraInitializers), __runInitializers(this, _codecType_initializers, void 0));
            this.videoIndex = (__runInitializers(this, _codecType_extraInitializers), __runInitializers(this, _videoIndex_initializers, void 0));
            this.jitter = (__runInitializers(this, _videoIndex_extraInitializers), __runInitializers(this, _jitter_initializers, void 0));
            this.superResolutionMode = (__runInitializers(this, _jitter_extraInitializers), __runInitializers(this, _superResolutionMode_initializers, void 0));
            __runInitializers(this, _superResolutionMode_extraInitializers);
        }
        return RemoteVideoStats_1;
    }());
    __setFunctionName(_classThis, "RemoteVideoStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _videoLossRate_decorators = [NativeMember()];
        _receivedKBitrate_decorators = [NativeMember()];
        _decoderOutputFrameRate_decorators = [NativeMember()];
        _rendererOutputFrameRate_decorators = [NativeMember()];
        _stallCount_decorators = [NativeMember()];
        _stallDuration_decorators = [NativeMember()];
        _e2eDelay_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _statsInterval_decorators = [NativeMember()];
        _rtt_decorators = [NativeMember()];
        _frozenRate_decorators = [NativeMember()];
        _codecType_decorators = [NativeMember()];
        _videoIndex_decorators = [NativeMember()];
        _jitter_decorators = [NativeMember()];
        _superResolutionMode_decorators = [NativeMember()];
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _videoLossRate_decorators, { kind: "field", name: "videoLossRate", static: false, private: false, access: { has: function (obj) { return "videoLossRate" in obj; }, get: function (obj) { return obj.videoLossRate; }, set: function (obj, value) { obj.videoLossRate = value; } }, metadata: _metadata }, _videoLossRate_initializers, _videoLossRate_extraInitializers);
        __esDecorate(null, null, _receivedKBitrate_decorators, { kind: "field", name: "receivedKBitrate", static: false, private: false, access: { has: function (obj) { return "receivedKBitrate" in obj; }, get: function (obj) { return obj.receivedKBitrate; }, set: function (obj, value) { obj.receivedKBitrate = value; } }, metadata: _metadata }, _receivedKBitrate_initializers, _receivedKBitrate_extraInitializers);
        __esDecorate(null, null, _decoderOutputFrameRate_decorators, { kind: "field", name: "decoderOutputFrameRate", static: false, private: false, access: { has: function (obj) { return "decoderOutputFrameRate" in obj; }, get: function (obj) { return obj.decoderOutputFrameRate; }, set: function (obj, value) { obj.decoderOutputFrameRate = value; } }, metadata: _metadata }, _decoderOutputFrameRate_initializers, _decoderOutputFrameRate_extraInitializers);
        __esDecorate(null, null, _rendererOutputFrameRate_decorators, { kind: "field", name: "rendererOutputFrameRate", static: false, private: false, access: { has: function (obj) { return "rendererOutputFrameRate" in obj; }, get: function (obj) { return obj.rendererOutputFrameRate; }, set: function (obj, value) { obj.rendererOutputFrameRate = value; } }, metadata: _metadata }, _rendererOutputFrameRate_initializers, _rendererOutputFrameRate_extraInitializers);
        __esDecorate(null, null, _stallCount_decorators, { kind: "field", name: "stallCount", static: false, private: false, access: { has: function (obj) { return "stallCount" in obj; }, get: function (obj) { return obj.stallCount; }, set: function (obj, value) { obj.stallCount = value; } }, metadata: _metadata }, _stallCount_initializers, _stallCount_extraInitializers);
        __esDecorate(null, null, _stallDuration_decorators, { kind: "field", name: "stallDuration", static: false, private: false, access: { has: function (obj) { return "stallDuration" in obj; }, get: function (obj) { return obj.stallDuration; }, set: function (obj, value) { obj.stallDuration = value; } }, metadata: _metadata }, _stallDuration_initializers, _stallDuration_extraInitializers);
        __esDecorate(null, null, _e2eDelay_decorators, { kind: "field", name: "e2eDelay", static: false, private: false, access: { has: function (obj) { return "e2eDelay" in obj; }, get: function (obj) { return obj.e2eDelay; }, set: function (obj, value) { obj.e2eDelay = value; } }, metadata: _metadata }, _e2eDelay_initializers, _e2eDelay_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _statsInterval_decorators, { kind: "field", name: "statsInterval", static: false, private: false, access: { has: function (obj) { return "statsInterval" in obj; }, get: function (obj) { return obj.statsInterval; }, set: function (obj, value) { obj.statsInterval = value; } }, metadata: _metadata }, _statsInterval_initializers, _statsInterval_extraInitializers);
        __esDecorate(null, null, _rtt_decorators, { kind: "field", name: "rtt", static: false, private: false, access: { has: function (obj) { return "rtt" in obj; }, get: function (obj) { return obj.rtt; }, set: function (obj, value) { obj.rtt = value; } }, metadata: _metadata }, _rtt_initializers, _rtt_extraInitializers);
        __esDecorate(null, null, _frozenRate_decorators, { kind: "field", name: "frozenRate", static: false, private: false, access: { has: function (obj) { return "frozenRate" in obj; }, get: function (obj) { return obj.frozenRate; }, set: function (obj, value) { obj.frozenRate = value; } }, metadata: _metadata }, _frozenRate_initializers, _frozenRate_extraInitializers);
        __esDecorate(null, null, _codecType_decorators, { kind: "field", name: "codecType", static: false, private: false, access: { has: function (obj) { return "codecType" in obj; }, get: function (obj) { return obj.codecType; }, set: function (obj, value) { obj.codecType = value; } }, metadata: _metadata }, _codecType_initializers, _codecType_extraInitializers);
        __esDecorate(null, null, _videoIndex_decorators, { kind: "field", name: "videoIndex", static: false, private: false, access: { has: function (obj) { return "videoIndex" in obj; }, get: function (obj) { return obj.videoIndex; }, set: function (obj, value) { obj.videoIndex = value; } }, metadata: _metadata }, _videoIndex_initializers, _videoIndex_extraInitializers);
        __esDecorate(null, null, _jitter_decorators, { kind: "field", name: "jitter", static: false, private: false, access: { has: function (obj) { return "jitter" in obj; }, get: function (obj) { return obj.jitter; }, set: function (obj, value) { obj.jitter = value; } }, metadata: _metadata }, _jitter_initializers, _jitter_extraInitializers);
        __esDecorate(null, null, _superResolutionMode_decorators, { kind: "field", name: "superResolutionMode", static: false, private: false, access: { has: function (obj) { return "superResolutionMode" in obj; }, get: function (obj) { return obj.superResolutionMode; }, set: function (obj, value) { obj.superResolutionMode = value; } }, metadata: _metadata }, _superResolutionMode_initializers, _superResolutionMode_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoApplyRotation;
(function (VideoApplyRotation) {
    VideoApplyRotation[VideoApplyRotation["DEFAULT"] = -1] = "DEFAULT";
    VideoApplyRotation[VideoApplyRotation["DEGREE_0"] = 0] = "DEGREE_0";
})(VideoApplyRotation || (VideoApplyRotation = {}));
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.VideoDeviceInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _deviceId_decorators;
    var _deviceId_initializers = [];
    var _deviceId_extraInitializers = [];
    var _deviceName_decorators;
    var _deviceName_initializers = [];
    var _deviceName_extraInitializers = [];
    var _deviceFacing_decorators;
    var _deviceFacing_initializers = [];
    var _deviceFacing_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function VideoDeviceInfo_1() {
            this.deviceId = __runInitializers(this, _deviceId_initializers, void 0);
            this.deviceName = (__runInitializers(this, _deviceId_extraInitializers), __runInitializers(this, _deviceName_initializers, void 0));
            this.deviceFacing = (__runInitializers(this, _deviceName_extraInitializers), __runInitializers(this, _deviceFacing_initializers, void 0));
            __runInitializers(this, _deviceFacing_extraInitializers);
        }
        return VideoDeviceInfo_1;
    }());
    __setFunctionName(_classThis, "VideoDeviceInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _deviceId_decorators = [NativeMember()];
        _deviceName_decorators = [NativeMember()];
        _deviceFacing_decorators = [NativeMember()];
        __esDecorate(null, null, _deviceId_decorators, { kind: "field", name: "deviceId", static: false, private: false, access: { has: function (obj) { return "deviceId" in obj; }, get: function (obj) { return obj.deviceId; }, set: function (obj, value) { obj.deviceId = value; } }, metadata: _metadata }, _deviceId_initializers, _deviceId_extraInitializers);
        __esDecorate(null, null, _deviceName_decorators, { kind: "field", name: "deviceName", static: false, private: false, access: { has: function (obj) { return "deviceName" in obj; }, get: function (obj) { return obj.deviceName; }, set: function (obj, value) { obj.deviceName = value; } }, metadata: _metadata }, _deviceName_initializers, _deviceName_extraInitializers);
        __esDecorate(null, null, _deviceFacing_decorators, { kind: "field", name: "deviceFacing", static: false, private: false, access: { has: function (obj) { return "deviceFacing" in obj; }, get: function (obj) { return obj.deviceFacing; }, set: function (obj, value) { obj.deviceFacing = value; } }, metadata: _metadata }, _deviceFacing_initializers, _deviceFacing_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.IVideoSink')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _onFrame_decorators;
    var _getRenderElapse_decorators;
    _classThis = /** @class */ (function () {
        function IVideoSink_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        IVideoSink_1.prototype.onFrame = function (frame) {
            throw new Error('not implement');
        };
        IVideoSink_1.prototype.getRenderElapse = function () {
            throw new Error('not implement');
        };
        return IVideoSink_1;
    }());
    __setFunctionName(_classThis, "IVideoSink");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _onFrame_decorators = [NativeMethodSync()];
        _getRenderElapse_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _onFrame_decorators, { kind: "method", name: "onFrame", static: false, private: false, access: { has: function (obj) { return "onFrame" in obj; }, get: function (obj) { return obj.onFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getRenderElapse_decorators, { kind: "method", name: "getRenderElapse", static: false, private: false, access: { has: function (obj) { return "getRenderElapse" in obj; }, get: function (obj) { return obj.getRenderElapse; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var VideoRotation;
(function (VideoRotation) {
    VideoRotation[VideoRotation["VIDEO_ROTATION_0"] = 0] = "VIDEO_ROTATION_0";
    VideoRotation[VideoRotation["VIDEO_ROTATION_90"] = 90] = "VIDEO_ROTATION_90";
    VideoRotation[VideoRotation["VIDEO_ROTATION_180"] = 180] = "VIDEO_ROTATION_180";
    VideoRotation[VideoRotation["VIDEO_ROTATION_270"] = 270] = "VIDEO_ROTATION_270";
})(VideoRotation || (VideoRotation = {}));
var OrientationMode;
(function (OrientationMode) {
    OrientationMode[OrientationMode["ORIENTATION_MODE_ADAPTIVE"] = 0] = "ORIENTATION_MODE_ADAPTIVE";
    OrientationMode[OrientationMode["ORIENTATION_MODE_FIXED_LANDSCAPE"] = 1] = "ORIENTATION_MODE_FIXED_LANDSCAPE";
    OrientationMode[OrientationMode["ORIENTATION_MODE_FIXED_PORTRAIT"] = 2] = "ORIENTATION_MODE_FIXED_PORTRAIT";
})(OrientationMode || (OrientationMode = {}));
var LocalVideoSinkConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.LocalVideoSinkConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _position_decorators;
    var _position_initializers = [];
    var _position_extraInitializers = [];
    var _pixelFormat_decorators;
    var _pixelFormat_initializers = [];
    var _pixelFormat_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function LocalVideoSinkConfig_1() {
            this.position = __runInitializers(this, _position_initializers, void 0);
            this.pixelFormat = (__runInitializers(this, _position_extraInitializers), __runInitializers(this, _pixelFormat_initializers, void 0));
            __runInitializers(this, _pixelFormat_extraInitializers);
        }
        return LocalVideoSinkConfig_1;
    }());
    __setFunctionName(_classThis, "LocalVideoSinkConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _position_decorators = [NativeMember()];
        _pixelFormat_decorators = [NativeMember()];
        __esDecorate(null, null, _position_decorators, { kind: "field", name: "position", static: false, private: false, access: { has: function (obj) { return "position" in obj; }, get: function (obj) { return obj.position; }, set: function (obj, value) { obj.position = value; } }, metadata: _metadata }, _position_initializers, _position_extraInitializers);
        __esDecorate(null, null, _pixelFormat_decorators, { kind: "field", name: "pixelFormat", static: false, private: false, access: { has: function (obj) { return "pixelFormat" in obj; }, get: function (obj) { return obj.pixelFormat; }, set: function (obj, value) { obj.pixelFormat = value; } }, metadata: _metadata }, _pixelFormat_initializers, _pixelFormat_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RecordingProgress$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.RecordingProgress')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _duration_decorators;
    var _duration_initializers = [];
    var _duration_extraInitializers = [];
    var _fileSize_decorators;
    var _fileSize_initializers = [];
    var _fileSize_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RecordingProgress_1(duration, fileSize) {
            this.duration = __runInitializers(this, _duration_initializers, void 0);
            this.fileSize = (__runInitializers(this, _duration_extraInitializers), __runInitializers(this, _fileSize_initializers, void 0));
            __runInitializers(this, _fileSize_extraInitializers);
        }
        return RecordingProgress_1;
    }());
    __setFunctionName(_classThis, "RecordingProgress");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _duration_decorators = [NativeMember()];
        _fileSize_decorators = [NativeMember()];
        __esDecorate(null, null, _duration_decorators, { kind: "field", name: "duration", static: false, private: false, access: { has: function (obj) { return "duration" in obj; }, get: function (obj) { return obj.duration; }, set: function (obj, value) { obj.duration = value; } }, metadata: _metadata }, _duration_initializers, _duration_extraInitializers);
        __esDecorate(null, null, _fileSize_decorators, { kind: "field", name: "fileSize", static: false, private: false, access: { has: function (obj) { return "fileSize" in obj; }, get: function (obj) { return obj.fileSize; }, set: function (obj, value) { obj.fileSize = value; } }, metadata: _metadata }, _fileSize_initializers, _fileSize_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RemoteUserPriority;
(function (RemoteUserPriority) {
    RemoteUserPriority[RemoteUserPriority["REMOTE_USER_PRIORITY_LOW"] = 0] = "REMOTE_USER_PRIORITY_LOW";
    RemoteUserPriority[RemoteUserPriority["REMOTE_USER_PRIORITY_MEDIUM"] = 100] = "REMOTE_USER_PRIORITY_MEDIUM";
    RemoteUserPriority[RemoteUserPriority["REMOTE_USER_PRIORITY_HIGH"] = 200] = "REMOTE_USER_PRIORITY_HIGH";
})(RemoteUserPriority || (RemoteUserPriority = {}));
var LocalVideoStreamState;
(function (LocalVideoStreamState) {
    LocalVideoStreamState[LocalVideoStreamState["LOCAL_VIDEO_STREAM_STATE_STOPPED"] = 0] = "LOCAL_VIDEO_STREAM_STATE_STOPPED";
    LocalVideoStreamState[LocalVideoStreamState["LOCAL_VIDEO_STREAM_STATE_RECORDING"] = 1] = "LOCAL_VIDEO_STREAM_STATE_RECORDING";
    LocalVideoStreamState[LocalVideoStreamState["LOCAL_VIDEO_STREAM_STATE_ENCODING"] = 2] = "LOCAL_VIDEO_STREAM_STATE_ENCODING";
    LocalVideoStreamState[LocalVideoStreamState["LOCAL_VIDEO_STREAM_STATE_FAILED"] = 3] = "LOCAL_VIDEO_STREAM_STATE_FAILED";
})(LocalVideoStreamState || (LocalVideoStreamState = {}));
var RemoteAudioState;
(function (RemoteAudioState) {
    RemoteAudioState[RemoteAudioState["REMOTE_AUDIO_STATE_STOPPED"] = 0] = "REMOTE_AUDIO_STATE_STOPPED";
    RemoteAudioState[RemoteAudioState["REMOTE_AUDIO_STATE_STARTING"] = 1] = "REMOTE_AUDIO_STATE_STARTING";
    RemoteAudioState[RemoteAudioState["REMOTE_AUDIO_STATE_DECODING"] = 2] = "REMOTE_AUDIO_STATE_DECODING";
    RemoteAudioState[RemoteAudioState["REMOTE_AUDIO_STATE_FROZEN"] = 3] = "REMOTE_AUDIO_STATE_FROZEN";
})(RemoteAudioState || (RemoteAudioState = {}));
var AudioPropertiesConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.AudioPropertiesConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _interval_decorators;
    var _interval_initializers = [];
    var _interval_extraInitializers = [];
    var _enableSpectrum_decorators;
    var _enableSpectrum_initializers = [];
    var _enableSpectrum_extraInitializers = [];
    var _enableVad_decorators;
    var _enableVad_initializers = [];
    var _enableVad_extraInitializers = [];
    var _localMainReportMode_decorators;
    var _localMainReportMode_initializers = [];
    var _localMainReportMode_extraInitializers = [];
    var _audioReportMode_decorators;
    var _audioReportMode_initializers = [];
    var _audioReportMode_extraInitializers = [];
    var _smooth_decorators;
    var _smooth_initializers = [];
    var _smooth_extraInitializers = [];
    var _enableVoicePitch_decorators;
    var _enableVoicePitch_initializers = [];
    var _enableVoicePitch_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function AudioPropertiesConfig_1() {
            this.interval = __runInitializers(this, _interval_initializers, void 0);
            this.enableSpectrum = (__runInitializers(this, _interval_extraInitializers), __runInitializers(this, _enableSpectrum_initializers, void 0));
            this.enableVad = (__runInitializers(this, _enableSpectrum_extraInitializers), __runInitializers(this, _enableVad_initializers, void 0));
            this.localMainReportMode = (__runInitializers(this, _enableVad_extraInitializers), __runInitializers(this, _localMainReportMode_initializers, void 0));
            this.audioReportMode = (__runInitializers(this, _localMainReportMode_extraInitializers), __runInitializers(this, _audioReportMode_initializers, void 0));
            this.smooth = (__runInitializers(this, _audioReportMode_extraInitializers), __runInitializers(this, _smooth_initializers, void 0));
            this.enableVoicePitch = (__runInitializers(this, _smooth_extraInitializers), __runInitializers(this, _enableVoicePitch_initializers, void 0));
            __runInitializers(this, _enableVoicePitch_extraInitializers);
        }
        return AudioPropertiesConfig_1;
    }());
    __setFunctionName(_classThis, "AudioPropertiesConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _interval_decorators = [NativeMember()];
        _enableSpectrum_decorators = [NativeMember()];
        _enableVad_decorators = [NativeMember()];
        _localMainReportMode_decorators = [NativeMember()];
        _audioReportMode_decorators = [NativeMember()];
        _smooth_decorators = [NativeMember()];
        _enableVoicePitch_decorators = [NativeMember()];
        __esDecorate(null, null, _interval_decorators, { kind: "field", name: "interval", static: false, private: false, access: { has: function (obj) { return "interval" in obj; }, get: function (obj) { return obj.interval; }, set: function (obj, value) { obj.interval = value; } }, metadata: _metadata }, _interval_initializers, _interval_extraInitializers);
        __esDecorate(null, null, _enableSpectrum_decorators, { kind: "field", name: "enableSpectrum", static: false, private: false, access: { has: function (obj) { return "enableSpectrum" in obj; }, get: function (obj) { return obj.enableSpectrum; }, set: function (obj, value) { obj.enableSpectrum = value; } }, metadata: _metadata }, _enableSpectrum_initializers, _enableSpectrum_extraInitializers);
        __esDecorate(null, null, _enableVad_decorators, { kind: "field", name: "enableVad", static: false, private: false, access: { has: function (obj) { return "enableVad" in obj; }, get: function (obj) { return obj.enableVad; }, set: function (obj, value) { obj.enableVad = value; } }, metadata: _metadata }, _enableVad_initializers, _enableVad_extraInitializers);
        __esDecorate(null, null, _localMainReportMode_decorators, { kind: "field", name: "localMainReportMode", static: false, private: false, access: { has: function (obj) { return "localMainReportMode" in obj; }, get: function (obj) { return obj.localMainReportMode; }, set: function (obj, value) { obj.localMainReportMode = value; } }, metadata: _metadata }, _localMainReportMode_initializers, _localMainReportMode_extraInitializers);
        __esDecorate(null, null, _audioReportMode_decorators, { kind: "field", name: "audioReportMode", static: false, private: false, access: { has: function (obj) { return "audioReportMode" in obj; }, get: function (obj) { return obj.audioReportMode; }, set: function (obj, value) { obj.audioReportMode = value; } }, metadata: _metadata }, _audioReportMode_initializers, _audioReportMode_extraInitializers);
        __esDecorate(null, null, _smooth_decorators, { kind: "field", name: "smooth", static: false, private: false, access: { has: function (obj) { return "smooth" in obj; }, get: function (obj) { return obj.smooth; }, set: function (obj, value) { obj.smooth = value; } }, metadata: _metadata }, _smooth_initializers, _smooth_extraInitializers);
        __esDecorate(null, null, _enableVoicePitch_decorators, { kind: "field", name: "enableVoicePitch", static: false, private: false, access: { has: function (obj) { return "enableVoicePitch" in obj; }, get: function (obj) { return obj.enableVoicePitch; }, set: function (obj, value) { obj.enableVoicePitch = value; } }, metadata: _metadata }, _enableVoicePitch_initializers, _enableVoicePitch_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoPixelFormat;
(function (VideoPixelFormat) {
    VideoPixelFormat[VideoPixelFormat["UNKNOWN"] = 0] = "UNKNOWN";
    VideoPixelFormat[VideoPixelFormat["I420"] = 1] = "I420";
    VideoPixelFormat[VideoPixelFormat["NV12"] = 2] = "NV12";
    VideoPixelFormat[VideoPixelFormat["NV21"] = 3] = "NV21";
    VideoPixelFormat[VideoPixelFormat["RGBA"] = 5] = "RGBA";
    VideoPixelFormat[VideoPixelFormat["TEXTURE_2D"] = 3553] = "TEXTURE_2D";
    VideoPixelFormat[VideoPixelFormat["TEXTURE_OES"] = 36197] = "TEXTURE_OES";
})(VideoPixelFormat || (VideoPixelFormat = {}));
var LocalProxyError;
(function (LocalProxyError) {
    LocalProxyError[LocalProxyError["OK"] = 0] = "OK";
    LocalProxyError[LocalProxyError["SOCKS5_VERSION_ERROR"] = 1] = "SOCKS5_VERSION_ERROR";
    LocalProxyError[LocalProxyError["SOCKS5_FORMAT_ERROR"] = 2] = "SOCKS5_FORMAT_ERROR";
    LocalProxyError[LocalProxyError["SOCKS5_INVALID_VALUE"] = 3] = "SOCKS5_INVALID_VALUE";
    LocalProxyError[LocalProxyError["SOCKS5_USER_PASS_NOT_GIVEN"] = 4] = "SOCKS5_USER_PASS_NOT_GIVEN";
    LocalProxyError[LocalProxyError["SOCKS5_TCP_CLOSED"] = 5] = "SOCKS5_TCP_CLOSED";
    LocalProxyError[LocalProxyError["HTTP_TUNNEL_FAILED"] = 6] = "HTTP_TUNNEL_FAILED";
})(LocalProxyError || (LocalProxyError = {}));
var MediaStreamType;
(function (MediaStreamType) {
    MediaStreamType[MediaStreamType["RTC_MEDIA_STREAM_TYPE_AUDIO"] = 1] = "RTC_MEDIA_STREAM_TYPE_AUDIO";
    MediaStreamType[MediaStreamType["RTC_MEDIA_STREAM_TYPE_VIDEO"] = 2] = "RTC_MEDIA_STREAM_TYPE_VIDEO";
    MediaStreamType[MediaStreamType["RTC_MEDIA_STREAM_TYPE_BOTH"] = 3] = "RTC_MEDIA_STREAM_TYPE_BOTH";
})(MediaStreamType || (MediaStreamType = {}));
var MediaDeviceState;
(function (MediaDeviceState) {
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_STARTED"] = 1] = "MEDIA_DEVICE_STATE_STARTED";
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_STOPPED"] = 2] = "MEDIA_DEVICE_STATE_STOPPED";
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_RUNTIMEERROR"] = 3] = "MEDIA_DEVICE_STATE_RUNTIMEERROR";
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_ADDED"] = 10] = "MEDIA_DEVICE_STATE_ADDED";
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_REMOVED"] = 11] = "MEDIA_DEVICE_STATE_REMOVED";
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_INTERRUPTION_BEGAN"] = 12] = "MEDIA_DEVICE_STATE_INTERRUPTION_BEGAN";
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_INTERRUPTION_ENDED"] = 13] = "MEDIA_DEVICE_STATE_INTERRUPTION_ENDED";
})(MediaDeviceState || (MediaDeviceState = {}));
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.publicstream.PublicStreaming.Layout.Region')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _userId_decorators;
    var _roomId_decorators;
    var _zorder_decorators;
    var _alpha_decorators;
    var _mediaType_decorators;
    var _streamType_decorators;
    var _renderMode_decorators;
    var _position_decorators;
    var _size_decorators;
    var _sourceCropPosition_decorators;
    var _sourceCropSize_decorators;
    _classThis = /** @class */ (function () {
        function Layout$Region_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        Layout$Region_1.prototype.userId = function (uid) {
            throw new Error('not implement');
        };
        Layout$Region_1.prototype.roomId = function (roomId) {
            throw new Error('not implement');
        };
        Layout$Region_1.prototype.zorder = function (zorder) {
            throw new Error('not implement');
        };
        Layout$Region_1.prototype.alpha = function (alpha) {
            throw new Error('not implement');
        };
        Layout$Region_1.prototype.mediaType = function (mediaType) {
            throw new Error('not implement');
        };
        Layout$Region_1.prototype.streamType = function (streamType) {
            throw new Error('not implement');
        };
        Layout$Region_1.prototype.renderMode = function (renderMode) {
            throw new Error('not implement');
        };
        Layout$Region_1.prototype.position = function (x, y) {
            throw new Error('not implement');
        };
        Layout$Region_1.prototype.size = function (width, height) {
            throw new Error('not implement');
        };
        Layout$Region_1.prototype.sourceCropPosition = function (x, y) {
            throw new Error('not implement');
        };
        Layout$Region_1.prototype.sourceCropSize = function (width, height) {
            throw new Error('not implement');
        };
        return Layout$Region_1;
    }());
    __setFunctionName(_classThis, "Layout$Region");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _userId_decorators = [NativeMethodSync()];
        _roomId_decorators = [NativeMethodSync()];
        _zorder_decorators = [NativeMethodSync()];
        _alpha_decorators = [NativeMethodSync()];
        _mediaType_decorators = [NativeMethodSync()];
        _streamType_decorators = [NativeMethodSync()];
        _renderMode_decorators = [NativeMethodSync()];
        _position_decorators = [NativeMethodSync()];
        _size_decorators = [NativeMethodSync()];
        _sourceCropPosition_decorators = [NativeMethodSync()];
        _sourceCropSize_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _userId_decorators, { kind: "method", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _roomId_decorators, { kind: "method", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _zorder_decorators, { kind: "method", name: "zorder", static: false, private: false, access: { has: function (obj) { return "zorder" in obj; }, get: function (obj) { return obj.zorder; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _alpha_decorators, { kind: "method", name: "alpha", static: false, private: false, access: { has: function (obj) { return "alpha" in obj; }, get: function (obj) { return obj.alpha; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _mediaType_decorators, { kind: "method", name: "mediaType", static: false, private: false, access: { has: function (obj) { return "mediaType" in obj; }, get: function (obj) { return obj.mediaType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _streamType_decorators, { kind: "method", name: "streamType", static: false, private: false, access: { has: function (obj) { return "streamType" in obj; }, get: function (obj) { return obj.streamType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _renderMode_decorators, { kind: "method", name: "renderMode", static: false, private: false, access: { has: function (obj) { return "renderMode" in obj; }, get: function (obj) { return obj.renderMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _position_decorators, { kind: "method", name: "position", static: false, private: false, access: { has: function (obj) { return "position" in obj; }, get: function (obj) { return obj.position; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _size_decorators, { kind: "method", name: "size", static: false, private: false, access: { has: function (obj) { return "size" in obj; }, get: function (obj) { return obj.size; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sourceCropPosition_decorators, { kind: "method", name: "sourceCropPosition", static: false, private: false, access: { has: function (obj) { return "sourceCropPosition" in obj; }, get: function (obj) { return obj.sourceCropPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sourceCropSize_decorators, { kind: "method", name: "sourceCropSize", static: false, private: false, access: { has: function (obj) { return "sourceCropSize" in obj; }, get: function (obj) { return obj.sourceCropSize; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var LocalProxyType;
(function (LocalProxyType) {
    LocalProxyType[LocalProxyType["SOCKS5"] = 1] = "SOCKS5";
    LocalProxyType[LocalProxyType["HTTP_TUNNEL"] = 2] = "HTTP_TUNNEL";
})(LocalProxyType || (LocalProxyType = {}));
var DivideModel;
(function (DivideModel) {
    DivideModel[DivideModel["EFFECT"] = 0] = "EFFECT";
    DivideModel[DivideModel["DEFAULT"] = 1] = "DEFAULT";
    DivideModel[DivideModel["value"] = 0] = "value";
})(DivideModel || (DivideModel = {}));
var PlayState;
(function (PlayState) {
    PlayState[PlayState["PLAYING"] = 1] = "PLAYING";
    PlayState[PlayState["PAUSED"] = 2] = "PAUSED";
    PlayState[PlayState["STOPPED"] = 3] = "STOPPED";
    PlayState[PlayState["FAILED"] = 4] = "FAILED";
    PlayState[PlayState["FINISHED"] = 5] = "FINISHED";
})(PlayState || (PlayState = {}));
var VoiceReverbConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.VoiceReverbConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _roomSize_decorators;
    var _roomSize_initializers = [];
    var _roomSize_extraInitializers = [];
    var _decayTime_decorators;
    var _decayTime_initializers = [];
    var _decayTime_extraInitializers = [];
    var _damping_decorators;
    var _damping_initializers = [];
    var _damping_extraInitializers = [];
    var _wetGain_decorators;
    var _wetGain_initializers = [];
    var _wetGain_extraInitializers = [];
    var _dryGain_decorators;
    var _dryGain_initializers = [];
    var _dryGain_extraInitializers = [];
    var _preDelay_decorators;
    var _preDelay_initializers = [];
    var _preDelay_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function VoiceReverbConfig_1(roomSize, decayTime, damping, wetGain, dryGain, preDelay) {
            this.roomSize = __runInitializers(this, _roomSize_initializers, void 0);
            this.decayTime = (__runInitializers(this, _roomSize_extraInitializers), __runInitializers(this, _decayTime_initializers, void 0));
            this.damping = (__runInitializers(this, _decayTime_extraInitializers), __runInitializers(this, _damping_initializers, void 0));
            this.wetGain = (__runInitializers(this, _damping_extraInitializers), __runInitializers(this, _wetGain_initializers, void 0));
            this.dryGain = (__runInitializers(this, _wetGain_extraInitializers), __runInitializers(this, _dryGain_initializers, void 0));
            this.preDelay = (__runInitializers(this, _dryGain_extraInitializers), __runInitializers(this, _preDelay_initializers, void 0));
            __runInitializers(this, _preDelay_extraInitializers);
        }
        return VoiceReverbConfig_1;
    }());
    __setFunctionName(_classThis, "VoiceReverbConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _roomSize_decorators = [NativeMember()];
        _decayTime_decorators = [NativeMember()];
        _damping_decorators = [NativeMember()];
        _wetGain_decorators = [NativeMember()];
        _dryGain_decorators = [NativeMember()];
        _preDelay_decorators = [NativeMember()];
        __esDecorate(null, null, _roomSize_decorators, { kind: "field", name: "roomSize", static: false, private: false, access: { has: function (obj) { return "roomSize" in obj; }, get: function (obj) { return obj.roomSize; }, set: function (obj, value) { obj.roomSize = value; } }, metadata: _metadata }, _roomSize_initializers, _roomSize_extraInitializers);
        __esDecorate(null, null, _decayTime_decorators, { kind: "field", name: "decayTime", static: false, private: false, access: { has: function (obj) { return "decayTime" in obj; }, get: function (obj) { return obj.decayTime; }, set: function (obj, value) { obj.decayTime = value; } }, metadata: _metadata }, _decayTime_initializers, _decayTime_extraInitializers);
        __esDecorate(null, null, _damping_decorators, { kind: "field", name: "damping", static: false, private: false, access: { has: function (obj) { return "damping" in obj; }, get: function (obj) { return obj.damping; }, set: function (obj, value) { obj.damping = value; } }, metadata: _metadata }, _damping_initializers, _damping_extraInitializers);
        __esDecorate(null, null, _wetGain_decorators, { kind: "field", name: "wetGain", static: false, private: false, access: { has: function (obj) { return "wetGain" in obj; }, get: function (obj) { return obj.wetGain; }, set: function (obj, value) { obj.wetGain = value; } }, metadata: _metadata }, _wetGain_initializers, _wetGain_extraInitializers);
        __esDecorate(null, null, _dryGain_decorators, { kind: "field", name: "dryGain", static: false, private: false, access: { has: function (obj) { return "dryGain" in obj; }, get: function (obj) { return obj.dryGain; }, set: function (obj, value) { obj.dryGain = value; } }, metadata: _metadata }, _dryGain_initializers, _dryGain_extraInitializers);
        __esDecorate(null, null, _preDelay_decorators, { kind: "field", name: "preDelay", static: false, private: false, access: { has: function (obj) { return "preDelay" in obj; }, get: function (obj) { return obj.preDelay; }, set: function (obj, value) { obj.preDelay = value; } }, metadata: _metadata }, _preDelay_initializers, _preDelay_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioFrameType;
(function (AudioFrameType) {
    AudioFrameType[AudioFrameType["FRAME_TYPE_PCM16"] = 0] = "FRAME_TYPE_PCM16";
})(AudioFrameType || (AudioFrameType = {}));
var VideoSuperResolutionMode;
(function (VideoSuperResolutionMode) {
    VideoSuperResolutionMode[VideoSuperResolutionMode["VIDEO_SUPER_RESOLUTION_MODE_OFF"] = 0] = "VIDEO_SUPER_RESOLUTION_MODE_OFF";
    VideoSuperResolutionMode[VideoSuperResolutionMode["VIDEO_SUPER_RESOLUTION_MODE_ON"] = 1] = "VIDEO_SUPER_RESOLUTION_MODE_ON";
})(VideoSuperResolutionMode || (VideoSuperResolutionMode = {}));
var PushSingleStreamParam$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.PushSingleStreamParam')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _url_decorators;
    var _url_initializers = [];
    var _url_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function PushSingleStreamParam_1() {
            this.roomId = __runInitializers(this, _roomId_initializers, void 0);
            this.userId = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _userId_initializers, void 0));
            this.url = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _url_initializers, void 0));
            this.isScreen = (__runInitializers(this, _url_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            __runInitializers(this, _isScreen_extraInitializers);
        }
        return PushSingleStreamParam_1;
    }());
    __setFunctionName(_classThis, "PushSingleStreamParam");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _roomId_decorators = [NativeMember()];
        _userId_decorators = [NativeMember()];
        _url_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _url_decorators, { kind: "field", name: "url", static: false, private: false, access: { has: function (obj) { return "url" in obj; }, get: function (obj) { return obj.url; }, set: function (obj, value) { obj.url = value; } }, metadata: _metadata }, _url_initializers, _url_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var SubtitleState;
(function (SubtitleState) {
    SubtitleState[SubtitleState["SUBTITLE_STATE_STARTED"] = 0] = "SUBTITLE_STATE_STARTED";
    SubtitleState[SubtitleState["SUBTITLE_STATE_STOPED"] = 1] = "SUBTITLE_STATE_STOPED";
    SubtitleState[SubtitleState["SUBTITLE_STATE_ERROR"] = 2] = "SUBTITLE_STATE_ERROR";
})(SubtitleState || (SubtitleState = {}));
var RecordingFileType;
(function (RecordingFileType) {
    RecordingFileType[RecordingFileType["AAC"] = 0] = "AAC";
    RecordingFileType[RecordingFileType["MP4"] = 1] = "MP4";
})(RecordingFileType || (RecordingFileType = {}));
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.loader.RTCNativeLibraryLoader')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _load_decorators;
    _classThis = /** @class */ (function () {
        function RTCNativeLibraryLoader_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        RTCNativeLibraryLoader_1.prototype.load = function (libraryName) {
            throw new Error('not implement');
        };
        return RTCNativeLibraryLoader_1;
    }());
    __setFunctionName(_classThis, "RTCNativeLibraryLoader");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _load_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _load_decorators, { kind: "method", name: "load", static: false, private: false, access: { has: function (obj) { return "load" in obj; }, get: function (obj) { return obj.load; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ScreenMediaType;
(function (ScreenMediaType) {
    ScreenMediaType[ScreenMediaType["SCREEN_MEDIA_TYPE_VIDEO_ONLY"] = 0] = "SCREEN_MEDIA_TYPE_VIDEO_ONLY";
    ScreenMediaType[ScreenMediaType["SCREEN_MEDIA_TYPE_AUDIO_ONLY"] = 1] = "SCREEN_MEDIA_TYPE_AUDIO_ONLY";
    ScreenMediaType[ScreenMediaType["SCREEN_MEDIA_TYPE_VIDEO_AND_AUDIO"] = 2] = "SCREEN_MEDIA_TYPE_VIDEO_AND_AUDIO";
})(ScreenMediaType || (ScreenMediaType = {}));
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.RTCWatermarkConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _visibleInPreview_decorators;
    var _visibleInPreview_initializers = [];
    var _visibleInPreview_extraInitializers = [];
    var _positionInLandscapeMode_decorators;
    var _positionInLandscapeMode_initializers = [];
    var _positionInLandscapeMode_extraInitializers = [];
    var _positionInPortraitMode_decorators;
    var _positionInPortraitMode_initializers = [];
    var _positionInPortraitMode_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function RTCWatermarkConfig_1() {
            this.visibleInPreview = __runInitializers(this, _visibleInPreview_initializers, void 0);
            this.positionInLandscapeMode = (__runInitializers(this, _visibleInPreview_extraInitializers), __runInitializers(this, _positionInLandscapeMode_initializers, void 0));
            this.positionInPortraitMode = (__runInitializers(this, _positionInLandscapeMode_extraInitializers), __runInitializers(this, _positionInPortraitMode_initializers, void 0));
            __runInitializers(this, _positionInPortraitMode_extraInitializers);
        }
        return RTCWatermarkConfig_1;
    }());
    __setFunctionName(_classThis, "RTCWatermarkConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _visibleInPreview_decorators = [NativeMember()];
        _positionInLandscapeMode_decorators = [NativeMember()];
        _positionInPortraitMode_decorators = [NativeMember()];
        __esDecorate(null, null, _visibleInPreview_decorators, { kind: "field", name: "visibleInPreview", static: false, private: false, access: { has: function (obj) { return "visibleInPreview" in obj; }, get: function (obj) { return obj.visibleInPreview; }, set: function (obj, value) { obj.visibleInPreview = value; } }, metadata: _metadata }, _visibleInPreview_initializers, _visibleInPreview_extraInitializers);
        __esDecorate(null, null, _positionInLandscapeMode_decorators, { kind: "field", name: "positionInLandscapeMode", static: false, private: false, access: { has: function (obj) { return "positionInLandscapeMode" in obj; }, get: function (obj) { return obj.positionInLandscapeMode; }, set: function (obj, value) { obj.positionInLandscapeMode = value; } }, metadata: _metadata }, _positionInLandscapeMode_initializers, _positionInLandscapeMode_extraInitializers);
        __esDecorate(null, null, _positionInPortraitMode_decorators, { kind: "field", name: "positionInPortraitMode", static: false, private: false, access: { has: function (obj) { return "positionInPortraitMode" in obj; }, get: function (obj) { return obj.positionInPortraitMode; }, set: function (obj, value) { obj.positionInPortraitMode = value; } }, metadata: _metadata }, _positionInPortraitMode_initializers, _positionInPortraitMode_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var MixedStreamRenderMode;
(function (MixedStreamRenderMode) {
    MixedStreamRenderMode[MixedStreamRenderMode["MIXED_STREAM_RENDER_MODE_HIDDEN"] = 1] = "MIXED_STREAM_RENDER_MODE_HIDDEN";
    MixedStreamRenderMode[MixedStreamRenderMode["MIXED_STREAM_RENDER_MODE_FIT"] = 2] = "MIXED_STREAM_RENDER_MODE_FIT";
    MixedStreamRenderMode[MixedStreamRenderMode["MIXED_STREAM_RENDER_MODE_ADAPTIVE"] = 3] = "MIXED_STREAM_RENDER_MODE_ADAPTIVE";
})(MixedStreamRenderMode || (MixedStreamRenderMode = {}));
var SubtitleConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.type.SubtitleConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _mode_decorators;
    var _mode_initializers = [];
    var _mode_extraInitializers = [];
    var _targetLanguage_decorators;
    var _targetLanguage_initializers = [];
    var _targetLanguage_extraInitializers = [];
    _classThis = /** @class */ (function () {
        function SubtitleConfig_1(mode, targetLanguage) {
            this.mode = __runInitializers(this, _mode_initializers, void 0);
            this.targetLanguage = (__runInitializers(this, _mode_extraInitializers), __runInitializers(this, _targetLanguage_initializers, void 0));
            __runInitializers(this, _targetLanguage_extraInitializers);
        }
        return SubtitleConfig_1;
    }());
    __setFunctionName(_classThis, "SubtitleConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _mode_decorators = [NativeMember()];
        _targetLanguage_decorators = [NativeMember()];
        __esDecorate(null, null, _mode_decorators, { kind: "field", name: "mode", static: false, private: false, access: { has: function (obj) { return "mode" in obj; }, get: function (obj) { return obj.mode; }, set: function (obj, value) { obj.mode = value; } }, metadata: _metadata }, _mode_initializers, _mode_extraInitializers);
        __esDecorate(null, null, _targetLanguage_decorators, { kind: "field", name: "targetLanguage", static: false, private: false, access: { has: function (obj) { return "targetLanguage" in obj; }, get: function (obj) { return obj.targetLanguage; }, set: function (obj, value) { obj.targetLanguage = value; } }, metadata: _metadata }, _targetLanguage_initializers, _targetLanguage_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ClientMixParam = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.LiveTranscoding$ClientMixParam')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setClientMixUseAudioMixer_decorators;
    var _setClientMixUseOriginalFrame_decorators;
    var _setClientMixVideoFormat_decorators;
    _classThis = /** @class */ (function () {
        function ClientMixParam_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        ClientMixParam_1.prototype.setClientMixUseAudioMixer = function (enable) {
            throw new Error('not implement');
        };
        ClientMixParam_1.prototype.setClientMixUseOriginalFrame = function (enable) {
            throw new Error('not implement');
        };
        ClientMixParam_1.prototype.setClientMixVideoFormat = function (format) {
            throw new Error('not implement');
        };
        return ClientMixParam_1;
    }());
    __setFunctionName(_classThis, "ClientMixParam");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setClientMixUseAudioMixer_decorators = [NativeMethodSync()];
        _setClientMixUseOriginalFrame_decorators = [NativeMethodSync()];
        _setClientMixVideoFormat_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setClientMixUseAudioMixer_decorators, { kind: "method", name: "setClientMixUseAudioMixer", static: false, private: false, access: { has: function (obj) { return "setClientMixUseAudioMixer" in obj; }, get: function (obj) { return obj.setClientMixUseAudioMixer; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setClientMixUseOriginalFrame_decorators, { kind: "method", name: "setClientMixUseOriginalFrame", static: false, private: false, access: { has: function (obj) { return "setClientMixUseOriginalFrame" in obj; }, get: function (obj) { return obj.setClientMixUseOriginalFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setClientMixVideoFormat_decorators, { kind: "method", name: "setClientMixVideoFormat", static: false, private: false, access: { has: function (obj) { return "setClientMixVideoFormat" in obj; }, get: function (obj) { return obj.setClientMixVideoFormat; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VirtualBackgroundSourceType;
(function (VirtualBackgroundSourceType) {
    VirtualBackgroundSourceType[VirtualBackgroundSourceType["COLOR"] = 0] = "COLOR";
    VirtualBackgroundSourceType[VirtualBackgroundSourceType["IMAGE"] = 1] = "IMAGE";
})(VirtualBackgroundSourceType || (VirtualBackgroundSourceType = {}));
var AudioRenderType;
(function (AudioRenderType) {
    AudioRenderType[AudioRenderType["AUDIO_RENDER_TYPE_EXTERNAL"] = 0] = "AUDIO_RENDER_TYPE_EXTERNAL";
    AudioRenderType[AudioRenderType["AUDIO_RENDER_TYPE_INTERNAL"] = 1] = "AUDIO_RENDER_TYPE_INTERNAL";
})(AudioRenderType || (AudioRenderType = {}));
var VideoDeviceFacing;
(function (VideoDeviceFacing) {
    VideoDeviceFacing[VideoDeviceFacing["FRONT"] = 0] = "FRONT";
    VideoDeviceFacing[VideoDeviceFacing["BACK"] = 1] = "BACK";
    VideoDeviceFacing[VideoDeviceFacing["UNKNOWN"] = 2] = "UNKNOWN";
})(VideoDeviceFacing || (VideoDeviceFacing = {}));
var SubscribeFallbackOptions;
(function (SubscribeFallbackOptions) {
    SubscribeFallbackOptions[SubscribeFallbackOptions["SUBSCRIBE_FALLBACK_OPTIONS_DISABLED"] = 0] = "SUBSCRIBE_FALLBACK_OPTIONS_DISABLED";
    SubscribeFallbackOptions[SubscribeFallbackOptions["SUBSCRIBE_FALLBACK_OPTIONS_STREAM_LOW"] = 1] = "SUBSCRIBE_FALLBACK_OPTIONS_STREAM_LOW";
    SubscribeFallbackOptions[SubscribeFallbackOptions["SUBSCRIBE_FALLBACK_OPTIONS_AUDIO_ONLY"] = 2] = "SUBSCRIBE_FALLBACK_OPTIONS_AUDIO_ONLY";
})(SubscribeFallbackOptions || (SubscribeFallbackOptions = {}));
var MixedStreamAudioConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.MixedStreamConfig$MixedStreamAudioConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setChannels_decorators;
    var _getChannels_decorators;
    var _setSampleRate_decorators;
    var _getSampleRate_decorators;
    var _setBitrate_decorators;
    var _getBitrate_decorators;
    var _setAudioCodec_decorators;
    var _getAudioCodec_decorators;
    var _setAudioProfile_decorators;
    var _getAudioProfile_decorators;
    _classThis = /** @class */ (function () {
        function MixedStreamAudioConfig_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        MixedStreamAudioConfig_1.prototype.setChannels = function (channels) {
            throw new Error('not implement');
        };
        MixedStreamAudioConfig_1.prototype.getChannels = function () {
            throw new Error('not implement');
        };
        MixedStreamAudioConfig_1.prototype.setSampleRate = function (sampleRate) {
            throw new Error('not implement');
        };
        MixedStreamAudioConfig_1.prototype.getSampleRate = function () {
            throw new Error('not implement');
        };
        MixedStreamAudioConfig_1.prototype.setBitrate = function (bitrate) {
            throw new Error('not implement');
        };
        MixedStreamAudioConfig_1.prototype.getBitrate = function () {
            throw new Error('not implement');
        };
        MixedStreamAudioConfig_1.prototype.setAudioCodec = function (audioCodec) {
            throw new Error('not implement');
        };
        MixedStreamAudioConfig_1.prototype.getAudioCodec = function () {
            throw new Error('not implement');
        };
        MixedStreamAudioConfig_1.prototype.setAudioProfile = function (audioProfile) {
            throw new Error('not implement');
        };
        MixedStreamAudioConfig_1.prototype.getAudioProfile = function () {
            throw new Error('not implement');
        };
        return MixedStreamAudioConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamAudioConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setChannels_decorators = [NativeMethodSync()];
        _getChannels_decorators = [NativeMethodSync()];
        _setSampleRate_decorators = [NativeMethodSync()];
        _getSampleRate_decorators = [NativeMethodSync()];
        _setBitrate_decorators = [NativeMethodSync()];
        _getBitrate_decorators = [NativeMethodSync()];
        _setAudioCodec_decorators = [NativeMethodSync()];
        _getAudioCodec_decorators = [NativeMethodSync()];
        _setAudioProfile_decorators = [NativeMethodSync()];
        _getAudioProfile_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setChannels_decorators, { kind: "method", name: "setChannels", static: false, private: false, access: { has: function (obj) { return "setChannels" in obj; }, get: function (obj) { return obj.setChannels; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getChannels_decorators, { kind: "method", name: "getChannels", static: false, private: false, access: { has: function (obj) { return "getChannels" in obj; }, get: function (obj) { return obj.getChannels; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setSampleRate_decorators, { kind: "method", name: "setSampleRate", static: false, private: false, access: { has: function (obj) { return "setSampleRate" in obj; }, get: function (obj) { return obj.setSampleRate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getSampleRate_decorators, { kind: "method", name: "getSampleRate", static: false, private: false, access: { has: function (obj) { return "getSampleRate" in obj; }, get: function (obj) { return obj.getSampleRate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBitrate_decorators, { kind: "method", name: "setBitrate", static: false, private: false, access: { has: function (obj) { return "setBitrate" in obj; }, get: function (obj) { return obj.setBitrate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getBitrate_decorators, { kind: "method", name: "getBitrate", static: false, private: false, access: { has: function (obj) { return "getBitrate" in obj; }, get: function (obj) { return obj.getBitrate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioCodec_decorators, { kind: "method", name: "setAudioCodec", static: false, private: false, access: { has: function (obj) { return "setAudioCodec" in obj; }, get: function (obj) { return obj.setAudioCodec; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioCodec_decorators, { kind: "method", name: "getAudioCodec", static: false, private: false, access: { has: function (obj) { return "getAudioCodec" in obj; }, get: function (obj) { return obj.getAudioCodec; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioProfile_decorators, { kind: "method", name: "setAudioProfile", static: false, private: false, access: { has: function (obj) { return "setAudioProfile" in obj; }, get: function (obj) { return obj.setAudioProfile; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioProfile_decorators, { kind: "method", name: "getAudioProfile", static: false, private: false, access: { has: function (obj) { return "getAudioProfile" in obj; }, get: function (obj) { return obj.getAudioProfile; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var BackgroundMode;
(function (BackgroundMode) {
    BackgroundMode[BackgroundMode["BACKGROUND_A"] = 0] = "BACKGROUND_A";
    BackgroundMode[BackgroundMode["BACKGROUND_B"] = 1] = "BACKGROUND_B";
    BackgroundMode[BackgroundMode["BLUR"] = 2] = "BLUR";
    BackgroundMode[BackgroundMode["NONE"] = 3] = "NONE";
    BackgroundMode[BackgroundMode["value"] = 0] = "value";
})(BackgroundMode || (BackgroundMode = {}));
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.builder.GLTextureVideoFrameBuilder')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setTimeStampUs_decorators;
    var _setWidth_decorators;
    var _setHeight_decorators;
    var _setRotation_decorators;
    var _setColorSpace_decorators;
    var _setExternalDataInfo_decorators;
    var _setSupplementaryInfo_decorators;
    var _setTextureID_decorators;
    var _setGLSync_decorators;
    var _setTextureMatrix_decorators;
    var _setEGLContext_decorators;
    var _setReleaseCallback_decorators;
    var _build_decorators;
    _classThis = /** @class */ (function () {
        function GLTextureVideoFrameBuilder_1(pixelFormat) {
            __runInitializers(this, _instanceExtraInitializers);
        }
        GLTextureVideoFrameBuilder_1.prototype.setTimeStampUs = function (timeStampUs) {
            throw new Error('not implement');
        };
        GLTextureVideoFrameBuilder_1.prototype.setWidth = function (width) {
            throw new Error('not implement');
        };
        GLTextureVideoFrameBuilder_1.prototype.setHeight = function (height) {
            throw new Error('not implement');
        };
        GLTextureVideoFrameBuilder_1.prototype.setRotation = function (rotation) {
            throw new Error('not implement');
        };
        GLTextureVideoFrameBuilder_1.prototype.setColorSpace = function (colorSpace) {
            throw new Error('not implement');
        };
        GLTextureVideoFrameBuilder_1.prototype.setExternalDataInfo = function (externalDataInfo) {
            throw new Error('not implement');
        };
        GLTextureVideoFrameBuilder_1.prototype.setSupplementaryInfo = function (supplementaryInfo) {
            throw new Error('not implement');
        };
        GLTextureVideoFrameBuilder_1.prototype.setTextureID = function (textureID) {
            throw new Error('not implement');
        };
        /**
         * Set the texture ID of the video frame
         */
        GLTextureVideoFrameBuilder_1.prototype.setGLSync = function (glSyncObj) {
            throw new Error('not implement');
        };
        GLTextureVideoFrameBuilder_1.prototype.setTextureMatrix = function (textureMatrix) {
            throw new Error('not implement');
        };
        GLTextureVideoFrameBuilder_1.prototype.setEGLContext = function (eglContext) {
            throw new Error('not implement');
        };
        GLTextureVideoFrameBuilder_1.prototype.setReleaseCallback = function (releaseCallback) {
            throw new Error('not implement');
        };
        GLTextureVideoFrameBuilder_1.prototype.build = function () {
            throw new Error('not implement');
        };
        return GLTextureVideoFrameBuilder_1;
    }());
    __setFunctionName(_classThis, "GLTextureVideoFrameBuilder");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setTimeStampUs_decorators = [NativeMethodSync()];
        _setWidth_decorators = [NativeMethodSync()];
        _setHeight_decorators = [NativeMethodSync()];
        _setRotation_decorators = [NativeMethodSync()];
        _setColorSpace_decorators = [NativeMethodSync()];
        _setExternalDataInfo_decorators = [NativeMethodSync()];
        _setSupplementaryInfo_decorators = [NativeMethodSync()];
        _setTextureID_decorators = [NativeMethodSync()];
        _setGLSync_decorators = [NativeMethodSync()];
        _setTextureMatrix_decorators = [NativeMethodSync()];
        _setEGLContext_decorators = [NativeMethodSync()];
        _setReleaseCallback_decorators = [NativeMethodSync()];
        _build_decorators = [ReturnClass(function () { return VideoFrame$1; }), NativeMethodSync()];
        __esDecorate(_classThis, null, _setTimeStampUs_decorators, { kind: "method", name: "setTimeStampUs", static: false, private: false, access: { has: function (obj) { return "setTimeStampUs" in obj; }, get: function (obj) { return obj.setTimeStampUs; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setWidth_decorators, { kind: "method", name: "setWidth", static: false, private: false, access: { has: function (obj) { return "setWidth" in obj; }, get: function (obj) { return obj.setWidth; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setHeight_decorators, { kind: "method", name: "setHeight", static: false, private: false, access: { has: function (obj) { return "setHeight" in obj; }, get: function (obj) { return obj.setHeight; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRotation_decorators, { kind: "method", name: "setRotation", static: false, private: false, access: { has: function (obj) { return "setRotation" in obj; }, get: function (obj) { return obj.setRotation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setColorSpace_decorators, { kind: "method", name: "setColorSpace", static: false, private: false, access: { has: function (obj) { return "setColorSpace" in obj; }, get: function (obj) { return obj.setColorSpace; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setExternalDataInfo_decorators, { kind: "method", name: "setExternalDataInfo", static: false, private: false, access: { has: function (obj) { return "setExternalDataInfo" in obj; }, get: function (obj) { return obj.setExternalDataInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setSupplementaryInfo_decorators, { kind: "method", name: "setSupplementaryInfo", static: false, private: false, access: { has: function (obj) { return "setSupplementaryInfo" in obj; }, get: function (obj) { return obj.setSupplementaryInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setTextureID_decorators, { kind: "method", name: "setTextureID", static: false, private: false, access: { has: function (obj) { return "setTextureID" in obj; }, get: function (obj) { return obj.setTextureID; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setGLSync_decorators, { kind: "method", name: "setGLSync", static: false, private: false, access: { has: function (obj) { return "setGLSync" in obj; }, get: function (obj) { return obj.setGLSync; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setTextureMatrix_decorators, { kind: "method", name: "setTextureMatrix", static: false, private: false, access: { has: function (obj) { return "setTextureMatrix" in obj; }, get: function (obj) { return obj.setTextureMatrix; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEGLContext_decorators, { kind: "method", name: "setEGLContext", static: false, private: false, access: { has: function (obj) { return "setEGLContext" in obj; }, get: function (obj) { return obj.setEGLContext; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setReleaseCallback_decorators, { kind: "method", name: "setReleaseCallback", static: false, private: false, access: { has: function (obj) { return "setReleaseCallback" in obj; }, get: function (obj) { return obj.setReleaseCallback; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _build_decorators, { kind: "method", name: "build", static: false, private: false, access: { has: function (obj) { return "build" in obj; }, get: function (obj) { return obj.build; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ZoomDirectionType;
(function (ZoomDirectionType) {
    ZoomDirectionType[ZoomDirectionType["CAMERA_MOVE_LEFT"] = 0] = "CAMERA_MOVE_LEFT";
    ZoomDirectionType[ZoomDirectionType["CAMERA_MOVE_RIGHT"] = 1] = "CAMERA_MOVE_RIGHT";
    ZoomDirectionType[ZoomDirectionType["CAMERA_MOVE_UP"] = 2] = "CAMERA_MOVE_UP";
    ZoomDirectionType[ZoomDirectionType["CAMERA_MOVE_DOWN"] = 3] = "CAMERA_MOVE_DOWN";
    ZoomDirectionType[ZoomDirectionType["CAMERA_ZOOM_OUT"] = 4] = "CAMERA_ZOOM_OUT";
    ZoomDirectionType[ZoomDirectionType["CAMERA_ZOOM_IN"] = 5] = "CAMERA_ZOOM_IN";
    ZoomDirectionType[ZoomDirectionType["CAMERA_RESET"] = 6] = "CAMERA_RESET";
})(ZoomDirectionType || (ZoomDirectionType = {}));
var StandardPitchInfo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.data.StandardPitchInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _static_create_decorators;
    var _startTime_decorators;
    var _startTime_initializers = [];
    var _startTime_extraInitializers = [];
    var _duration_decorators;
    var _duration_initializers = [];
    var _duration_extraInitializers = [];
    var _pitch_decorators;
    var _pitch_initializers = [];
    var _pitch_extraInitializers = [];
    var StandardPitchInfo = _classThis = /** @class */ (function () {
        function StandardPitchInfo_1(startTime, duration, pitch) {
            this.startTime = __runInitializers(this, _startTime_initializers, void 0);
            this.duration = (__runInitializers(this, _startTime_extraInitializers), __runInitializers(this, _duration_initializers, void 0));
            this.pitch = (__runInitializers(this, _duration_extraInitializers), __runInitializers(this, _pitch_initializers, void 0));
            __runInitializers(this, _pitch_extraInitializers);
        }
        StandardPitchInfo_1.create = function (startTime, duration, pitch) {
            throw new Error('not implement');
        };
        return StandardPitchInfo_1;
    }());
    __setFunctionName(_classThis, "StandardPitchInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_create_decorators = [ReturnClass(function () { return StandardPitchInfo; }), NativeStaticMethodSync()];
        _startTime_decorators = [NativeMember()];
        _duration_decorators = [NativeMember()];
        _pitch_decorators = [NativeMember()];
        __esDecorate(_classThis, null, _static_create_decorators, { kind: "method", name: "create", static: true, private: false, access: { has: function (obj) { return "create" in obj; }, get: function (obj) { return obj.create; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(null, null, _startTime_decorators, { kind: "field", name: "startTime", static: false, private: false, access: { has: function (obj) { return "startTime" in obj; }, get: function (obj) { return obj.startTime; }, set: function (obj, value) { obj.startTime = value; } }, metadata: _metadata }, _startTime_initializers, _startTime_extraInitializers);
        __esDecorate(null, null, _duration_decorators, { kind: "field", name: "duration", static: false, private: false, access: { has: function (obj) { return "duration" in obj; }, get: function (obj) { return obj.duration; }, set: function (obj, value) { obj.duration = value; } }, metadata: _metadata }, _duration_initializers, _duration_extraInitializers);
        __esDecorate(null, null, _pitch_decorators, { kind: "field", name: "pitch", static: false, private: false, access: { has: function (obj) { return "pitch" in obj; }, get: function (obj) { return obj.pitch; }, set: function (obj, value) { obj.pitch = value; } }, metadata: _metadata }, _pitch_initializers, _pitch_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        StandardPitchInfo = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _staticExtraInitializers);
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return StandardPitchInfo = _classThis;
}();
var AudioMixingType;
(function (AudioMixingType) {
    AudioMixingType[AudioMixingType["AUDIO_MIXING_TYPE_PLAYOUT"] = 0] = "AUDIO_MIXING_TYPE_PLAYOUT";
    AudioMixingType[AudioMixingType["AUDIO_MIXING_TYPE_PUBLISH"] = 1] = "AUDIO_MIXING_TYPE_PUBLISH";
    AudioMixingType[AudioMixingType["AUDIO_MIXING_TYPE_PLAYOUT_AND_PUBLISH"] = 2] = "AUDIO_MIXING_TYPE_PLAYOUT_AND_PUBLISH";
})(AudioMixingType || (AudioMixingType = {}));
var AttenuationType;
(function (AttenuationType) {
    AttenuationType[AttenuationType["ATTENUATION_TYPE_NONE"] = 0] = "ATTENUATION_TYPE_NONE";
    AttenuationType[AttenuationType["ATTENUATION_TYPE_LINEAR"] = 1] = "ATTENUATION_TYPE_LINEAR";
    AttenuationType[AttenuationType["ATTENUATION_TYPE_EXPONENTIAL"] = 2] = "ATTENUATION_TYPE_EXPONENTIAL";
})(AttenuationType || (AttenuationType = {}));
var MediaPlayerCustomSourceStreamType;
(function (MediaPlayerCustomSourceStreamType) {
    MediaPlayerCustomSourceStreamType[MediaPlayerCustomSourceStreamType["RAW"] = 0] = "RAW";
    MediaPlayerCustomSourceStreamType[MediaPlayerCustomSourceStreamType["ENCODED"] = 1] = "ENCODED";
})(MediaPlayerCustomSourceStreamType || (MediaPlayerCustomSourceStreamType = {}));
var AlphaLayout;
(function (AlphaLayout) {
    AlphaLayout[AlphaLayout["TOP"] = 0] = "TOP";
})(AlphaLayout || (AlphaLayout = {}));
var MixedStreamConfig$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.live.MixedStreamConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _instanceExtraInitializers = [];
    var _static_defaultMixedStreamConfig_decorators;
    var _setUserID_decorators;
    var _getUserID_decorators;
    var _setRoomID_decorators;
    var _getRoomID_decorators;
    var _setPushURL_decorators;
    var _getPushURL_decorators;
    var _setExpectedMixingType_decorators;
    var _getExpectedMixingType_decorators;
    var _setAudioConfig_decorators;
    var _getAudioConfig_decorators;
    var _setServerControlConfig_decorators;
    var _getServerControlConfig_decorators;
    var _setVideoConfig_decorators;
    var _getVideoConfig_decorators;
    var _setClientMixConfig_decorators;
    var _setSpatialConfig_decorators;
    var _getSpatialConfig_decorators;
    var _setLayout_decorators;
    var _getLayout_decorators;
    var _getMixedStreamVideoConfigBFrame_decorators;
    var MixedStreamConfig = _classThis = /** @class */ (function () {
        function MixedStreamConfig_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        MixedStreamConfig_1.defaultMixedStreamConfig = function () {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.setUserID = function (userID) {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.getUserID = function () {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.setRoomID = function (roomID) {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.getRoomID = function () {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.setPushURL = function (pushURL) {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.getPushURL = function () {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.setExpectedMixingType = function (expectedMixingType) {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.getExpectedMixingType = function () {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.setAudioConfig = function (audioConfig) {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.getAudioConfig = function () {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.setServerControlConfig = function (serverControlConfig) {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.getServerControlConfig = function () {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.setVideoConfig = function (videoConfig) {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.getVideoConfig = function () {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.setClientMixConfig = function (clientMixConfig) {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.setSpatialConfig = function (spatialConfig) {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.getSpatialConfig = function () {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.setLayout = function (layout) {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.getLayout = function () {
            throw new Error('not implement');
        };
        MixedStreamConfig_1.prototype.getMixedStreamVideoConfigBFrame = function () {
            throw new Error('not implement');
        };
        return MixedStreamConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_defaultMixedStreamConfig_decorators = [ReturnClass(function () { return MixedStreamConfig; }), NativeStaticMethodSync()];
        _setUserID_decorators = [NativeMethodSync()];
        _getUserID_decorators = [NativeMethodSync()];
        _setRoomID_decorators = [NativeMethodSync()];
        _getRoomID_decorators = [NativeMethodSync()];
        _setPushURL_decorators = [NativeMethodSync()];
        _getPushURL_decorators = [NativeMethodSync()];
        _setExpectedMixingType_decorators = [NativeMethodSync()];
        _getExpectedMixingType_decorators = [NativeMethodSync()];
        _setAudioConfig_decorators = [NativeMethodSync()];
        _getAudioConfig_decorators = [ReturnClass(function () { return MixedStreamAudioConfig$1; }), NativeMethodSync()];
        _setServerControlConfig_decorators = [NativeMethodSync()];
        _getServerControlConfig_decorators = [ReturnClass(function () { return MixedStreamServerControlConfig$1; }), NativeMethodSync()];
        _setVideoConfig_decorators = [NativeMethodSync()];
        _getVideoConfig_decorators = [ReturnClass(function () { return MixedStreamVideoConfig$1; }), NativeMethodSync()];
        _setClientMixConfig_decorators = [NativeMethodSync()];
        _setSpatialConfig_decorators = [NativeMethodSync()];
        _getSpatialConfig_decorators = [ReturnClass(function () { return MixedStreamSpatialConfig; }), NativeMethodSync()];
        _setLayout_decorators = [NativeMethodSync()];
        _getLayout_decorators = [ReturnClass(function () { return MixedStreamLayoutConfig$1; }), NativeMethodSync()];
        _getMixedStreamVideoConfigBFrame_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _static_defaultMixedStreamConfig_decorators, { kind: "method", name: "defaultMixedStreamConfig", static: true, private: false, access: { has: function (obj) { return "defaultMixedStreamConfig" in obj; }, get: function (obj) { return obj.defaultMixedStreamConfig; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _setUserID_decorators, { kind: "method", name: "setUserID", static: false, private: false, access: { has: function (obj) { return "setUserID" in obj; }, get: function (obj) { return obj.setUserID; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getUserID_decorators, { kind: "method", name: "getUserID", static: false, private: false, access: { has: function (obj) { return "getUserID" in obj; }, get: function (obj) { return obj.getUserID; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRoomID_decorators, { kind: "method", name: "setRoomID", static: false, private: false, access: { has: function (obj) { return "setRoomID" in obj; }, get: function (obj) { return obj.setRoomID; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getRoomID_decorators, { kind: "method", name: "getRoomID", static: false, private: false, access: { has: function (obj) { return "getRoomID" in obj; }, get: function (obj) { return obj.getRoomID; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPushURL_decorators, { kind: "method", name: "setPushURL", static: false, private: false, access: { has: function (obj) { return "setPushURL" in obj; }, get: function (obj) { return obj.setPushURL; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getPushURL_decorators, { kind: "method", name: "getPushURL", static: false, private: false, access: { has: function (obj) { return "getPushURL" in obj; }, get: function (obj) { return obj.getPushURL; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setExpectedMixingType_decorators, { kind: "method", name: "setExpectedMixingType", static: false, private: false, access: { has: function (obj) { return "setExpectedMixingType" in obj; }, get: function (obj) { return obj.setExpectedMixingType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getExpectedMixingType_decorators, { kind: "method", name: "getExpectedMixingType", static: false, private: false, access: { has: function (obj) { return "getExpectedMixingType" in obj; }, get: function (obj) { return obj.getExpectedMixingType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioConfig_decorators, { kind: "method", name: "setAudioConfig", static: false, private: false, access: { has: function (obj) { return "setAudioConfig" in obj; }, get: function (obj) { return obj.setAudioConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioConfig_decorators, { kind: "method", name: "getAudioConfig", static: false, private: false, access: { has: function (obj) { return "getAudioConfig" in obj; }, get: function (obj) { return obj.getAudioConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setServerControlConfig_decorators, { kind: "method", name: "setServerControlConfig", static: false, private: false, access: { has: function (obj) { return "setServerControlConfig" in obj; }, get: function (obj) { return obj.setServerControlConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getServerControlConfig_decorators, { kind: "method", name: "getServerControlConfig", static: false, private: false, access: { has: function (obj) { return "getServerControlConfig" in obj; }, get: function (obj) { return obj.getServerControlConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoConfig_decorators, { kind: "method", name: "setVideoConfig", static: false, private: false, access: { has: function (obj) { return "setVideoConfig" in obj; }, get: function (obj) { return obj.setVideoConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getVideoConfig_decorators, { kind: "method", name: "getVideoConfig", static: false, private: false, access: { has: function (obj) { return "getVideoConfig" in obj; }, get: function (obj) { return obj.getVideoConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setClientMixConfig_decorators, { kind: "method", name: "setClientMixConfig", static: false, private: false, access: { has: function (obj) { return "setClientMixConfig" in obj; }, get: function (obj) { return obj.setClientMixConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setSpatialConfig_decorators, { kind: "method", name: "setSpatialConfig", static: false, private: false, access: { has: function (obj) { return "setSpatialConfig" in obj; }, get: function (obj) { return obj.setSpatialConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getSpatialConfig_decorators, { kind: "method", name: "getSpatialConfig", static: false, private: false, access: { has: function (obj) { return "getSpatialConfig" in obj; }, get: function (obj) { return obj.getSpatialConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLayout_decorators, { kind: "method", name: "setLayout", static: false, private: false, access: { has: function (obj) { return "setLayout" in obj; }, get: function (obj) { return obj.setLayout; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getLayout_decorators, { kind: "method", name: "getLayout", static: false, private: false, access: { has: function (obj) { return "getLayout" in obj; }, get: function (obj) { return obj.getLayout; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getMixedStreamVideoConfigBFrame_decorators, { kind: "method", name: "getMixedStreamVideoConfigBFrame", static: false, private: false, access: { has: function (obj) { return "getMixedStreamVideoConfigBFrame" in obj; }, get: function (obj) { return obj.getMixedStreamVideoConfigBFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        MixedStreamConfig = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _staticExtraInitializers);
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return MixedStreamConfig = _classThis;
}();
var SEICountPerFrame;
(function (SEICountPerFrame) {
    SEICountPerFrame[SEICountPerFrame["SEI_COUNT_PER_FRAME_SINGLE"] = 0] = "SEI_COUNT_PER_FRAME_SINGLE";
    SEICountPerFrame[SEICountPerFrame["SEI_COUNT_PER_FRAME_MULTI"] = 1] = "SEI_COUNT_PER_FRAME_MULTI";
})(SEICountPerFrame || (SEICountPerFrame = {}));
var RenderMode;
(function (RenderMode) {
    RenderMode[RenderMode["ByteRTCRenderModeHidden"] = 1] = "ByteRTCRenderModeHidden";
    RenderMode[RenderMode["ByteRTCRenderModeFit"] = 2] = "ByteRTCRenderModeFit";
    RenderMode[RenderMode["ByteRTCRenderModeFill"] = 3] = "ByteRTCRenderModeFill";
})(RenderMode || (RenderMode = {}));
var NetworkType;
(function (NetworkType) {
    NetworkType[NetworkType["UNKNOWN"] = -1] = "UNKNOWN";
    NetworkType[NetworkType["NONE"] = 0] = "NONE";
    NetworkType[NetworkType["MOBILE"] = 1] = "MOBILE";
    NetworkType[NetworkType["MOBILE_2G"] = 2] = "MOBILE_2G";
    NetworkType[NetworkType["MOBILE_3G"] = 3] = "MOBILE_3G";
    NetworkType[NetworkType["WIFI"] = 4] = "WIFI";
    NetworkType[NetworkType["MOBILE_4G"] = 5] = "MOBILE_4G";
    NetworkType[NetworkType["MOBILE_5G"] = 6] = "MOBILE_5G";
})(NetworkType || (NetworkType = {}));
var UserOfflineReason;
(function (UserOfflineReason) {
    UserOfflineReason[UserOfflineReason["ByteRTCUserOfflineReasonQuit"] = 0] = "ByteRTCUserOfflineReasonQuit";
    UserOfflineReason[UserOfflineReason["ByteRTCUserOfflineReasonDropped"] = 1] = "ByteRTCUserOfflineReasonDropped";
    UserOfflineReason[UserOfflineReason["ByteRTCUserOfflineReasonSwitchToInvisible"] = 2] = "ByteRTCUserOfflineReasonSwitchToInvisible";
    UserOfflineReason[UserOfflineReason["ByteRTCUserOfflineReasonKickedByAdmin"] = 3] = "ByteRTCUserOfflineReasonKickedByAdmin";
})(UserOfflineReason || (UserOfflineReason = {}));

var ISpatialAudio$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.audio.ISpatialAudio')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _enableSpatialAudio_decorators;
    var _disableRemoteOrientation_decorators;
    var _updateSelfPosition_decorators;
    var _updateRemotePosition_decorators;
    var _removeRemotePosition_decorators;
    var _removeAllRemotePosition_decorators;
    var _updatePosition_decorators;
    var _updateSelfOrientation_decorators;
    var _updateListenerPosition_decorators;
    var _updateListenerOrientation_decorators;
    _classThis = /** @class */ (function () {
        function ISpatialAudio_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        ISpatialAudio_1.prototype.enableSpatialAudio = function (enable) {
            throw new Error('not implement');
        };
        ISpatialAudio_1.prototype.disableRemoteOrientation = function () {
            throw new Error('not implement');
        };
        ISpatialAudio_1.prototype.updateSelfPosition = function (positionInfo) {
            throw new Error('not implement');
        };
        ISpatialAudio_1.prototype.updateRemotePosition = function (uid, positionInfo) {
            throw new Error('not implement');
        };
        ISpatialAudio_1.prototype.removeRemotePosition = function (uid) {
            throw new Error('not implement');
        };
        ISpatialAudio_1.prototype.removeAllRemotePosition = function () {
            throw new Error('not implement');
        };
        ISpatialAudio_1.prototype.updatePosition = function (pos) {
            throw new Error('not implement');
        };
        ISpatialAudio_1.prototype.updateSelfOrientation = function (orientation) {
            throw new Error('not implement');
        };
        ISpatialAudio_1.prototype.updateListenerPosition = function (pos) {
            throw new Error('not implement');
        };
        ISpatialAudio_1.prototype.updateListenerOrientation = function (orientation) {
            throw new Error('not implement');
        };
        return ISpatialAudio_1;
    }());
    __setFunctionName(_classThis, "ISpatialAudio");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enableSpatialAudio_decorators = [NativeMethodSync()];
        _disableRemoteOrientation_decorators = [NativeMethodSync()];
        _updateSelfPosition_decorators = [NativeMethodSync()];
        _updateRemotePosition_decorators = [NativeMethodSync()];
        _removeRemotePosition_decorators = [NativeMethodSync()];
        _removeAllRemotePosition_decorators = [NativeMethodSync()];
        _updatePosition_decorators = [NativeMethodSync()];
        _updateSelfOrientation_decorators = [NativeMethodSync()];
        _updateListenerPosition_decorators = [NativeMethodSync()];
        _updateListenerOrientation_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _enableSpatialAudio_decorators, { kind: "method", name: "enableSpatialAudio", static: false, private: false, access: { has: function (obj) { return "enableSpatialAudio" in obj; }, get: function (obj) { return obj.enableSpatialAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableRemoteOrientation_decorators, { kind: "method", name: "disableRemoteOrientation", static: false, private: false, access: { has: function (obj) { return "disableRemoteOrientation" in obj; }, get: function (obj) { return obj.disableRemoteOrientation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateSelfPosition_decorators, { kind: "method", name: "updateSelfPosition", static: false, private: false, access: { has: function (obj) { return "updateSelfPosition" in obj; }, get: function (obj) { return obj.updateSelfPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateRemotePosition_decorators, { kind: "method", name: "updateRemotePosition", static: false, private: false, access: { has: function (obj) { return "updateRemotePosition" in obj; }, get: function (obj) { return obj.updateRemotePosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _removeRemotePosition_decorators, { kind: "method", name: "removeRemotePosition", static: false, private: false, access: { has: function (obj) { return "removeRemotePosition" in obj; }, get: function (obj) { return obj.removeRemotePosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _removeAllRemotePosition_decorators, { kind: "method", name: "removeAllRemotePosition", static: false, private: false, access: { has: function (obj) { return "removeAllRemotePosition" in obj; }, get: function (obj) { return obj.removeAllRemotePosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updatePosition_decorators, { kind: "method", name: "updatePosition", static: false, private: false, access: { has: function (obj) { return "updatePosition" in obj; }, get: function (obj) { return obj.updatePosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateSelfOrientation_decorators, { kind: "method", name: "updateSelfOrientation", static: false, private: false, access: { has: function (obj) { return "updateSelfOrientation" in obj; }, get: function (obj) { return obj.updateSelfOrientation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateListenerPosition_decorators, { kind: "method", name: "updateListenerPosition", static: false, private: false, access: { has: function (obj) { return "updateListenerPosition" in obj; }, get: function (obj) { return obj.updateListenerPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateListenerOrientation_decorators, { kind: "method", name: "updateListenerOrientation", static: false, private: false, access: { has: function (obj) { return "updateListenerOrientation" in obj; }, get: function (obj) { return obj.updateListenerOrientation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IVideoDeviceManager$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.IVideoDeviceManager')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _enumerateVideoCaptureDevices_decorators;
    var _setVideoCaptureDevice_decorators;
    _classThis = /** @class */ (function () {
        function IVideoDeviceManager_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        IVideoDeviceManager_1.prototype.enumerateVideoCaptureDevices = function () {
            throw new Error('not implement');
        };
        IVideoDeviceManager_1.prototype.setVideoCaptureDevice = function (deviceId) {
            throw new Error('not implement');
        };
        return IVideoDeviceManager_1;
    }());
    __setFunctionName(_classThis, "IVideoDeviceManager");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enumerateVideoCaptureDevices_decorators = [NativeMethodSync()];
        _setVideoCaptureDevice_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _enumerateVideoCaptureDevices_decorators, { kind: "method", name: "enumerateVideoCaptureDevices", static: false, private: false, access: { has: function (obj) { return "enumerateVideoCaptureDevices" in obj; }, get: function (obj) { return obj.enumerateVideoCaptureDevices; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoCaptureDevice_decorators, { kind: "method", name: "setVideoCaptureDevice", static: false, private: false, access: { has: function (obj) { return "setVideoCaptureDevice" in obj; }, get: function (obj) { return obj.setVideoCaptureDevice; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IKTVPlayer$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.ktv.IKTVPlayer')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setPlayerEventHandler_decorators;
    var _playMusic_decorators;
    var _pauseMusic_decorators;
    var _resumeMusic_decorators;
    var _stopMusic_decorators;
    var _seekMusic_decorators;
    var _setMusicVolume_decorators;
    var _switchAudioTrackType_decorators;
    var _setMusicPitch_decorators;
    _classThis = /** @class */ (function () {
        function IKTVPlayer_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        IKTVPlayer_1.prototype.setPlayerEventHandler = function (playerEventHandler) {
            throw new Error('not implement');
        };
        IKTVPlayer_1.prototype.playMusic = function (musicId, trackType, playType) {
            throw new Error('not implement');
        };
        IKTVPlayer_1.prototype.pauseMusic = function (musicId) {
            throw new Error('not implement');
        };
        IKTVPlayer_1.prototype.resumeMusic = function (musicId) {
            throw new Error('not implement');
        };
        IKTVPlayer_1.prototype.stopMusic = function (musicId) {
            throw new Error('not implement');
        };
        IKTVPlayer_1.prototype.seekMusic = function (musicId, position) {
            throw new Error('not implement');
        };
        IKTVPlayer_1.prototype.setMusicVolume = function (musicId, volume) {
            throw new Error('not implement');
        };
        IKTVPlayer_1.prototype.switchAudioTrackType = function (musicId) {
            throw new Error('not implement');
        };
        IKTVPlayer_1.prototype.setMusicPitch = function (musicId, pitch) {
            throw new Error('not implement');
        };
        return IKTVPlayer_1;
    }());
    __setFunctionName(_classThis, "IKTVPlayer");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setPlayerEventHandler_decorators = [NativeMethodSync()];
        _playMusic_decorators = [NativeMethodSync()];
        _pauseMusic_decorators = [NativeMethodSync()];
        _resumeMusic_decorators = [NativeMethodSync()];
        _stopMusic_decorators = [NativeMethodSync()];
        _seekMusic_decorators = [NativeMethodSync()];
        _setMusicVolume_decorators = [NativeMethodSync()];
        _switchAudioTrackType_decorators = [NativeMethodSync()];
        _setMusicPitch_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _setPlayerEventHandler_decorators, { kind: "method", name: "setPlayerEventHandler", static: false, private: false, access: { has: function (obj) { return "setPlayerEventHandler" in obj; }, get: function (obj) { return obj.setPlayerEventHandler; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _playMusic_decorators, { kind: "method", name: "playMusic", static: false, private: false, access: { has: function (obj) { return "playMusic" in obj; }, get: function (obj) { return obj.playMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pauseMusic_decorators, { kind: "method", name: "pauseMusic", static: false, private: false, access: { has: function (obj) { return "pauseMusic" in obj; }, get: function (obj) { return obj.pauseMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resumeMusic_decorators, { kind: "method", name: "resumeMusic", static: false, private: false, access: { has: function (obj) { return "resumeMusic" in obj; }, get: function (obj) { return obj.resumeMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopMusic_decorators, { kind: "method", name: "stopMusic", static: false, private: false, access: { has: function (obj) { return "stopMusic" in obj; }, get: function (obj) { return obj.stopMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _seekMusic_decorators, { kind: "method", name: "seekMusic", static: false, private: false, access: { has: function (obj) { return "seekMusic" in obj; }, get: function (obj) { return obj.seekMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setMusicVolume_decorators, { kind: "method", name: "setMusicVolume", static: false, private: false, access: { has: function (obj) { return "setMusicVolume" in obj; }, get: function (obj) { return obj.setMusicVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _switchAudioTrackType_decorators, { kind: "method", name: "switchAudioTrackType", static: false, private: false, access: { has: function (obj) { return "switchAudioTrackType" in obj; }, get: function (obj) { return obj.switchAudioTrackType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setMusicPitch_decorators, { kind: "method", name: "setMusicPitch", static: false, private: false, access: { has: function (obj) { return "setMusicPitch" in obj; }, get: function (obj) { return obj.setMusicPitch; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IVideoEffect$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.IVideoEffect')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _initCVResource_decorators;
    var _enableVideoEffect_decorators;
    var _disableVideoEffect_decorators;
    var _setEffectNodes_decorators;
    var _updateEffectNode_decorators;
    var _setColorFilter_decorators;
    var _setColorFilterIntensity_decorators;
    var _enableVirtualBackground_decorators;
    var _disableVirtualBackground_decorators;
    var _enableFaceDetection_decorators;
    var _disableFaceDetection_decorators;
    var _registerFaceDetectionObserver_decorators;
    _classThis = /** @class */ (function () {
        function IVideoEffect_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        IVideoEffect_1.prototype.initCVResource = function (licenseFile, algoModelDir) {
            throw new Error('not implement');
        };
        IVideoEffect_1.prototype.enableVideoEffect = function () {
            throw new Error('not implement');
        };
        IVideoEffect_1.prototype.disableVideoEffect = function () {
            throw new Error('not implement');
        };
        IVideoEffect_1.prototype.setEffectNodes = function (effectNodes) {
            throw new Error('not implement');
        };
        IVideoEffect_1.prototype.updateEffectNode = function (effectNode, key, value) {
            throw new Error('not implement');
        };
        IVideoEffect_1.prototype.setColorFilter = function (filterRes) {
            throw new Error('not implement');
        };
        IVideoEffect_1.prototype.setColorFilterIntensity = function (intensity) {
            throw new Error('not implement');
        };
        IVideoEffect_1.prototype.enableVirtualBackground = function (backgroundStickerRes, source) {
            throw new Error('not implement');
        };
        IVideoEffect_1.prototype.disableVirtualBackground = function () {
            throw new Error('not implement');
        };
        IVideoEffect_1.prototype.enableFaceDetection = function (observer, intervalMs, faceModelPath) {
            throw new Error('not implement');
        };
        IVideoEffect_1.prototype.disableFaceDetection = function () {
            throw new Error('not implement');
        };
        IVideoEffect_1.prototype.registerFaceDetectionObserver = function (observer, intervalMs) {
            throw new Error('not implement');
        };
        return IVideoEffect_1;
    }());
    __setFunctionName(_classThis, "IVideoEffect");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _initCVResource_decorators = [NativeMethodSync()];
        _enableVideoEffect_decorators = [NativeMethodSync()];
        _disableVideoEffect_decorators = [NativeMethodSync()];
        _setEffectNodes_decorators = [NativeMethodSync()];
        _updateEffectNode_decorators = [NativeMethodSync()];
        _setColorFilter_decorators = [NativeMethodSync()];
        _setColorFilterIntensity_decorators = [NativeMethodSync()];
        _enableVirtualBackground_decorators = [NativeMethodSync()];
        _disableVirtualBackground_decorators = [NativeMethodSync()];
        _enableFaceDetection_decorators = [NativeMethodSync()];
        _disableFaceDetection_decorators = [NativeMethodSync()];
        _registerFaceDetectionObserver_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _initCVResource_decorators, { kind: "method", name: "initCVResource", static: false, private: false, access: { has: function (obj) { return "initCVResource" in obj; }, get: function (obj) { return obj.initCVResource; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableVideoEffect_decorators, { kind: "method", name: "enableVideoEffect", static: false, private: false, access: { has: function (obj) { return "enableVideoEffect" in obj; }, get: function (obj) { return obj.enableVideoEffect; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableVideoEffect_decorators, { kind: "method", name: "disableVideoEffect", static: false, private: false, access: { has: function (obj) { return "disableVideoEffect" in obj; }, get: function (obj) { return obj.disableVideoEffect; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEffectNodes_decorators, { kind: "method", name: "setEffectNodes", static: false, private: false, access: { has: function (obj) { return "setEffectNodes" in obj; }, get: function (obj) { return obj.setEffectNodes; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateEffectNode_decorators, { kind: "method", name: "updateEffectNode", static: false, private: false, access: { has: function (obj) { return "updateEffectNode" in obj; }, get: function (obj) { return obj.updateEffectNode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setColorFilter_decorators, { kind: "method", name: "setColorFilter", static: false, private: false, access: { has: function (obj) { return "setColorFilter" in obj; }, get: function (obj) { return obj.setColorFilter; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setColorFilterIntensity_decorators, { kind: "method", name: "setColorFilterIntensity", static: false, private: false, access: { has: function (obj) { return "setColorFilterIntensity" in obj; }, get: function (obj) { return obj.setColorFilterIntensity; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableVirtualBackground_decorators, { kind: "method", name: "enableVirtualBackground", static: false, private: false, access: { has: function (obj) { return "enableVirtualBackground" in obj; }, get: function (obj) { return obj.enableVirtualBackground; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableVirtualBackground_decorators, { kind: "method", name: "disableVirtualBackground", static: false, private: false, access: { has: function (obj) { return "disableVirtualBackground" in obj; }, get: function (obj) { return obj.disableVirtualBackground; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableFaceDetection_decorators, { kind: "method", name: "enableFaceDetection", static: false, private: false, access: { has: function (obj) { return "enableFaceDetection" in obj; }, get: function (obj) { return obj.enableFaceDetection; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableFaceDetection_decorators, { kind: "method", name: "disableFaceDetection", static: false, private: false, access: { has: function (obj) { return "disableFaceDetection" in obj; }, get: function (obj) { return obj.disableFaceDetection; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerFaceDetectionObserver_decorators, { kind: "method", name: "registerFaceDetectionObserver", static: false, private: false, access: { has: function (obj) { return "registerFaceDetectionObserver" in obj; }, get: function (obj) { return obj.registerFaceDetectionObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IRTCAudioDeviceManager = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.IRTCAudioDeviceManager')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _startAudioPlaybackDeviceTest_decorators;
    var _stopAudioPlaybackDeviceTest_decorators;
    _classThis = /** @class */ (function () {
        function IRTCAudioDeviceManager_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        IRTCAudioDeviceManager_1.prototype.startAudioPlaybackDeviceTest = function (testAudioFilePath, interval) {
            throw new Error('not implement');
        };
        IRTCAudioDeviceManager_1.prototype.stopAudioPlaybackDeviceTest = function () {
            throw new Error('not implement');
        };
        return IRTCAudioDeviceManager_1;
    }());
    __setFunctionName(_classThis, "IRTCAudioDeviceManager");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _startAudioPlaybackDeviceTest_decorators = [NativeMethodSync()];
        _stopAudioPlaybackDeviceTest_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _startAudioPlaybackDeviceTest_decorators, { kind: "method", name: "startAudioPlaybackDeviceTest", static: false, private: false, access: { has: function (obj) { return "startAudioPlaybackDeviceTest" in obj; }, get: function (obj) { return obj.startAudioPlaybackDeviceTest; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopAudioPlaybackDeviceTest_decorators, { kind: "method", name: "stopAudioPlaybackDeviceTest", static: false, private: false, access: { has: function (obj) { return "stopAudioPlaybackDeviceTest" in obj; }, get: function (obj) { return obj.stopAudioPlaybackDeviceTest; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RTCVideo$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.RTCVideo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _instanceExtraInitializers = [];
    var _static_mInstance_decorators;
    var _static_mInstance_initializers = [];
    var _static_mInstance_extraInitializers = [];
    var _static_mInstanceEx_decorators;
    var _static_mInstanceEx_initializers = [];
    var _static_mInstanceEx_extraInitializers = [];
    var _static_mRtcNativeLibraryLoader_decorators;
    var _static_mRtcNativeLibraryLoader_initializers = [];
    var _static_mRtcNativeLibraryLoader_extraInitializers = [];
    var _static_createRTCVideo_decorators;
    var _static_createRTCVideo_context$appId$handler$eglContext$parameters_decorators;
    var _static_destroyRTCVideo_decorators;
    var _static_getSDKVersion_decorators;
    var _static_setLogConfig_decorators;
    var _static_getErrorDescription_decorators;
    var _static_setDeviceId_decorators;
    var _setRtcVideoEventHandler_decorators;
    var _getAudioDeviceManager_decorators;
    var _startVideoCapture_decorators;
    var _stopVideoCapture_decorators;
    var _startAudioCapture_decorators;
    var _stopAudioCapture_decorators;
    var _setAudioScenario_decorators;
    var _setAudioProfile_decorators;
    var _setAnsMode_decorators;
    var _setVoiceChangerType_decorators;
    var _setVoiceReverbType_decorators;
    var _setLocalVoiceEqualization_decorators;
    var _setLocalVoiceReverbParam_decorators;
    var _enableLocalVoiceReverb_decorators;
    var _setLocalVideoCanvas_decorators;
    var _updateLocalVideoCanvas_decorators;
    var _setLocalVideoRender_decorators;
    var _setRemoteVideoRender_decorators;
    var _updateRemoteStreamVideoCanvas_decorators;
    var _setRemoteVideoCanvas_decorators;
    var _setRemoteVideoSuperResolution_decorators;
    var _setVideoDenoiser_decorators;
    var _setLocalVideoMirrorType_decorators;
    var _setRemoteVideoMirrorType_decorators;
    var _setVideoRotationMode_decorators;
    var _switchCamera_decorators;
    var _setAudioRoute_decorators;
    var _getAudioRoute_decorators;
    var _setDefaultAudioRoute_decorators;
    var _enableExternalSoundCard_decorators;
    var _muteAudioCapture_decorators;
    var _setCaptureVolume_decorators;
    var _setPlaybackVolume_decorators;
    var _setLocalVoicePitch_decorators;
    var _enableVocalInstrumentBalance_decorators;
    var _enablePlaybackDucking_decorators;
    var _login_decorators;
    var _logout_decorators;
    var _updateLoginToken_decorators;
    var _setServerParams_decorators;
    var _getPeerOnlineStatus_decorators;
    var _sendUserMessageOutsideRoom_decorators;
    var _sendUserBinaryMessageOutsideRoom_decorators;
    var _sendServerMessage_decorators;
    var _sendServerBinaryMessage_decorators;
    var _startNetworkDetection_decorators;
    var _stopNetworkDetection_decorators;
    var _enableAudioFrameCallback_decorators;
    var _disableAudioFrameCallback_decorators;
    var _registerAudioFrameObserver_decorators;
    var _registerAudioProcessor_decorators;
    var _enableAudioProcessor_decorators;
    var _disableAudioProcessor_decorators;
    var _registerLocalVideoProcessor_decorators;
    var _setVideoDigitalZoomConfig_decorators;
    var _setVideoDigitalZoomControl_decorators;
    var _startVideoDigitalZoomControl_decorators;
    var _stopVideoDigitalZoomControl_decorators;
    var _registerLocalEncodedVideoFrameObserver_decorators;
    var _registerRemoteEncodedVideoFrameObserver_decorators;
    var _setVideoSourceType_decorators;
    var _pushExternalVideoFrame_decorators;
    var _startPushMixedStreamToCDN_decorators;
    var _updatePushMixedStreamToCDN_decorators;
    var _startPushSingleStreamToCDN_decorators;
    var _stopPushStreamToCDN_decorators;
    var _setVideoCaptureConfig_decorators;
    var _enableSimulcastMode_decorators;
    var _setVideoEncoderConfig_decorators;
    var _setScreenVideoEncoderConfig_decorators;
    var _enableAlphaChannelVideoEncode_decorators;
    var _disableAlphaChannelVideoEncode_decorators;
    var _setAudioSourceType_decorators;
    var _setAudioRenderType_decorators;
    var _pushExternalAudioFrame_decorators;
    var _pullExternalAudioFrame_decorators;
    var _pushScreenVideoFrame_decorators;
    var _setRemoteAudioPlaybackVolume_decorators;
    var _createRTCRoom_decorators;
    var _setPublishFallbackOption_decorators;
    var _setSubscribeFallbackOption_decorators;
    var _setRemoteUserPriority_decorators;
    var _sendSEIMessage_decorators;
    var _setBusinessId_decorators;
    var _setEncryptInfo_decorators;
    var _getVideoEffectInterface_decorators;
    var _enableEffectBeauty_decorators;
    var _setBeautyIntensity_decorators;
    var _setVideoOrientation_decorators;
    var _setRuntimeParameters_decorators;
    var _feedback_decorators;
    var _getNativeHandle_decorators;
    var _startASR_decorators;
    var _stopASR_decorators;
    var _startFileRecording_decorators;
    var _stopFileRecording_decorators;
    var _startAudioRecording_decorators;
    var _stopAudioRecording_decorators;
    var _getAudioEffectPlayer_decorators;
    var _getMediaPlayer_decorators;
    var _setScreenAudioSourceType_decorators;
    var _setScreenAudioStreamIndex_decorators;
    var _pushScreenAudioFrame_decorators;
    var _startScreenCapture_decorators;
    var _updateScreenCapture_decorators;
    var _stopScreenCapture_decorators;
    var _setExternalVideoEncoderEventHandler_decorators;
    var _pushExternalEncodedVideoFrame_decorators;
    var _setVideoDecoderConfig_decorators;
    var _requestRemoteVideoKeyFrame_decorators;
    var _setEarMonitorMode_decorators;
    var _setEarMonitorVolume_decorators;
    var _enableAudioPropertiesReport_decorators;
    var _sendStreamSyncInfo_decorators;
    var _isCameraTorchSupported_decorators;
    var _isCameraZoomSupported_decorators;
    var _setCameraZoomRatio_decorators;
    var _getCameraZoomMaxRatio_decorators;
    var _setCameraTorch_decorators;
    var _isCameraFocusPositionSupported_decorators;
    var _setCameraFocusPosition_decorators;
    var _isCameraExposurePositionSupported_decorators;
    var _setCameraExposurePosition_decorators;
    var _setCameraExposureCompensation_decorators;
    var _enableCameraAutoExposureFaceMode_decorators;
    var _setCameraAdaptiveMinimumFrameRate_decorators;
    var _startPushPublicStream_decorators;
    var _stopPushPublicStream_decorators;
    var _updatePublicStreamParam_decorators;
    var _startPlayPublicStream_decorators;
    var _stopPlayPublicStream_decorators;
    var _setPublicStreamVideoCanvas_decorators;
    var _setPublicStreamVideoSink_decorators;
    var _setPublicStreamAudioPlaybackVolume_decorators;
    var _startEchoTest_decorators;
    var _stopEchoTest_decorators;
    var _setVideoWatermark_decorators;
    var _clearVideoWatermark_decorators;
    var _setDummyCaptureImagePath_decorators;
    var _takeLocalSnapshot_decorators;
    var _takeRemoteSnapshot_decorators;
    var _startCloudProxy_decorators;
    var _stopCloudProxy_decorators;
    var _getSingScoringManager_decorators;
    var _getNetworkTimeInfo_decorators;
    var _getKTVManager_decorators;
    var _startHardwareEchoDetection_decorators;
    var _stopHardwareEchoDetection_decorators;
    var _setCellularEnhancement_decorators;
    var _setLocalProxy_decorators;
    var _getVideoDeviceManager_decorators;
    var _setVideoCaptureRotation_decorators;
    var _setLocalVideoSink_decorators;
    var _setRemoteVideoSink_decorators;
    var _updateRemoteStreamVideoCanvas_streamKey$renderMode$backgroundColor_decorators;
    var _replaceBackground_decorators;
    var _setAudioPlaybackDevice_decorators;
    var _startLiveTranscoding_decorators;
    var _stopLiveTranscoding_decorators;
    var _updateLiveTranscoding_decorators;
    var _setVideoEncoderConfig_videoStreamDescriptions$orientationMode_decorators;
    var _setVideoEncoderConfig_streamIndex$videoStreamDescriptions_decorators;
    var _setOnDestroyCompletedCallback_decorators;
    var _sendSEIMessage_streamIndex$message$repeatCount_decorators;
    var _checkVideoEffectLicense_decorators;
    var _setVideoEffectAlgoModelPath_decorators;
    var _enableVideoEffect_decorators;
    var _setVideoEffectNodes_decorators;
    var _updateVideoEffectNode_decorators;
    var _setBackgroundSticker_decorators;
    var _setVideoEffectColorFilter_decorators;
    var _setVideoEffectColorFilterIntensity_decorators;
    var _registerFaceDetectionObserver_decorators;
    var _getAudioMixingManager_decorators;
    var _muteAudioPlayback_decorators;
    var RTCVideo = _classThis = /** @class */ (function () {
        function RTCVideo_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        RTCVideo_1.createRTCVideo = function (context, handler, config) {
            throw new Error('not implement');
        };
        RTCVideo_1.createRTCVideo_context$appId$handler$eglContext$parameters = function (context, appId, handler, eglContext, parameters) {
            throw new Error('not implement');
        };
        RTCVideo_1.destroyRTCVideo = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.getSDKVersion = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.setLogConfig = function (logConfig) {
            throw new Error('not implement');
        };
        RTCVideo_1.getErrorDescription = function (code) {
            throw new Error('not implement');
        };
        RTCVideo_1.setDeviceId = function (deviceId) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setRtcVideoEventHandler = function (engineEventHandler) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.getAudioDeviceManager = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startVideoCapture = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopVideoCapture = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startAudioCapture = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopAudioCapture = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setAudioScenario = function (audioScenario) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setAudioProfile = function (audioProfile) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setAnsMode = function (ansMode) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVoiceChangerType = function (voiceChanger) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVoiceReverbType = function (voiceReverb) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setLocalVoiceEqualization = function (voiceEqualizationConfig) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setLocalVoiceReverbParam = function (config) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.enableLocalVoiceReverb = function (enable) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setLocalVideoCanvas = function (streamIndex, videoCanvas) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.updateLocalVideoCanvas = function (streamIndex, renderMode, backgroundColor) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setLocalVideoRender = function (index, videoSink, config) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setRemoteVideoRender = function (streamKey, videoSink, config) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.updateRemoteStreamVideoCanvas = function (streamKey, remoteVideoRenderConfig) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setRemoteVideoCanvas = function (streamKey, videoCanvas) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setRemoteVideoSuperResolution = function (streamKey, mode) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoDenoiser = function (mode) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setLocalVideoMirrorType = function (mirrorType) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setRemoteVideoMirrorType = function (remoteStreamKey, mirrorType) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoRotationMode = function (rotationMode) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.switchCamera = function (cameraId) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setAudioRoute = function (audioRoute) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.getAudioRoute = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setDefaultAudioRoute = function (route) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.enableExternalSoundCard = function (enable) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.muteAudioCapture = function (index, mute) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setCaptureVolume = function (index, volume) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setPlaybackVolume = function (volume) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setLocalVoicePitch = function (pitch) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.enableVocalInstrumentBalance = function (enable) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.enablePlaybackDucking = function (enable) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.login = function (token, uid) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.logout = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.updateLoginToken = function (token) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setServerParams = function (signature, url) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.getPeerOnlineStatus = function (peerUserID) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.sendUserMessageOutsideRoom = function (uid, message, config) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.sendUserBinaryMessageOutsideRoom = function (uid, buffer, config) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.sendServerMessage = function (message) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.sendServerBinaryMessage = function (buffer) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startNetworkDetection = function (isTestUplink, expectedUplinkBitrate, isTestDownlink, expectedDownlinkBitrate) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopNetworkDetection = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.enableAudioFrameCallback = function (method, format) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.disableAudioFrameCallback = function (method) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.registerAudioFrameObserver = function (observer) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.registerAudioProcessor = function (processor) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.enableAudioProcessor = function (method, format) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.disableAudioProcessor = function (method) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.registerLocalVideoProcessor = function (processor, config) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoDigitalZoomConfig = function (type, size) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoDigitalZoomControl = function (direction) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startVideoDigitalZoomControl = function (direction) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopVideoDigitalZoomControl = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.registerLocalEncodedVideoFrameObserver = function (observer) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.registerRemoteEncodedVideoFrameObserver = function (observer) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoSourceType = function (index, type) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.pushExternalVideoFrame = function (frame) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startPushMixedStreamToCDN = function (taskId, mixedConfig, observer) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.updatePushMixedStreamToCDN = function (taskId, mixedConfig) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startPushSingleStreamToCDN = function (taskId, param, observer) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopPushStreamToCDN = function (taskId) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoCaptureConfig = function (videoCaptureConfig) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.enableSimulcastMode = function (enabled) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoEncoderConfig = function (channelSolutions) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setScreenVideoEncoderConfig = function (screenSolution) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.enableAlphaChannelVideoEncode = function (streamIndex, alphaLayout) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.disableAlphaChannelVideoEncode = function (streamIndex) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setAudioSourceType = function (type) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setAudioRenderType = function (type) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.pushExternalAudioFrame = function (audioFrame) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.pullExternalAudioFrame = function (audioFrame) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.pushScreenVideoFrame = function (videoFrame) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setRemoteAudioPlaybackVolume = function (roomId, uid, volume) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.createRTCRoom = function (roomId) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setPublishFallbackOption = function (option) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setSubscribeFallbackOption = function (option) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setRemoteUserPriority = function (roomid, uid, priority) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.sendSEIMessage = function (streamIndex, message, repeatCount, mode) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setBusinessId = function (businessId) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setEncryptInfo = function (aesType, key) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.getVideoEffectInterface = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.enableEffectBeauty = function (enable) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setBeautyIntensity = function (beautyMode, intensity) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoOrientation = function (orientation) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setRuntimeParameters = function (params) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.feedback = function (types, info) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.getNativeHandle = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startASR = function (asrConfig, handler) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopASR = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startFileRecording = function (type, config, recordingType) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopFileRecording = function (type) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startAudioRecording = function (config) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopAudioRecording = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.getAudioEffectPlayer = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.getMediaPlayer = function (playerId) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setScreenAudioSourceType = function (sourceType) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setScreenAudioStreamIndex = function (index) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.pushScreenAudioFrame = function (audioFrame) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startScreenCapture = function (type, mediaProjectionResultData) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.updateScreenCapture = function (type) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopScreenCapture = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setExternalVideoEncoderEventHandler = function (handler) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.pushExternalEncodedVideoFrame = function (streamIndex, videoIndex, encodedVideoFrame) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoDecoderConfig = function (key, config) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.requestRemoteVideoKeyFrame = function (streamKey) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setEarMonitorMode = function (mode) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setEarMonitorVolume = function (volume) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.enableAudioPropertiesReport = function (config) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.sendStreamSyncInfo = function (data, config) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.isCameraTorchSupported = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.isCameraZoomSupported = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setCameraZoomRatio = function (zoom) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.getCameraZoomMaxRatio = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setCameraTorch = function (torchState) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.isCameraFocusPositionSupported = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setCameraFocusPosition = function (x, y) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.isCameraExposurePositionSupported = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setCameraExposurePosition = function (x, y) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setCameraExposureCompensation = function (val) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.enableCameraAutoExposureFaceMode = function (enable) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setCameraAdaptiveMinimumFrameRate = function (framerate) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startPushPublicStream = function (publicStreamId, publicStream) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopPushPublicStream = function (publicStreamId) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.updatePublicStreamParam = function (publicStreamId, transcoding) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startPlayPublicStream = function (publicStreamId) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopPlayPublicStream = function (publicStreamId) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setPublicStreamVideoCanvas = function (publicStreamId, canvas) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setPublicStreamVideoSink = function (publicStreamId, videoSink, requiredFormat) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setPublicStreamAudioPlaybackVolume = function (publicStreamId, volume) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startEchoTest = function (config, delayTime) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopEchoTest = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoWatermark = function (streamIndex, imagePath, watermarkConfig) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.clearVideoWatermark = function (streamIndex) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setDummyCaptureImagePath = function (filePath) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.takeLocalSnapshot = function (streamIndex, callback) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.takeRemoteSnapshot = function (streamKey, callback) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startCloudProxy = function (cloudProxiesInfo) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopCloudProxy = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.getSingScoringManager = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.getNetworkTimeInfo = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.getKTVManager = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startHardwareEchoDetection = function (testAudioFilePath) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopHardwareEchoDetection = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setCellularEnhancement = function (config) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setLocalProxy = function (configurations) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.getVideoDeviceManager = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoCaptureRotation = function (rotation) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setLocalVideoSink = function (index, videoSink, requiredFormat) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setRemoteVideoSink = function (streamKey, videoSink, requiredFormat) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.updateRemoteStreamVideoCanvas_streamKey$renderMode$backgroundColor = function (streamKey, renderMode, backgroundColor) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.replaceBackground = function (mode, divideModel) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setAudioPlaybackDevice = function (audioPlaybackDevice) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.startLiveTranscoding = function (taskId, liveTranscode, observer) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.stopLiveTranscoding = function (taskId) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.updateLiveTranscoding = function (taskId, transcoding) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoEncoderConfig_videoStreamDescriptions$orientationMode = function (videoStreamDescriptions, orientationMode) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoEncoderConfig_streamIndex$videoStreamDescriptions = function (streamIndex, videoStreamDescriptions) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setOnDestroyCompletedCallback = function (callback) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.sendSEIMessage_streamIndex$message$repeatCount = function (streamIndex, message, repeatCount) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.checkVideoEffectLicense = function (context, licenseFile) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoEffectAlgoModelPath = function (modelPath) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.enableVideoEffect = function (enable) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoEffectNodes = function (effectNodes) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.updateVideoEffectNode = function (effectNode, key, value) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setBackgroundSticker = function (modelPath, source) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoEffectColorFilter = function (resFile) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.setVideoEffectColorFilterIntensity = function (intensity) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.registerFaceDetectionObserver = function (observer, interval) {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.getAudioMixingManager = function () {
            throw new Error('not implement');
        };
        RTCVideo_1.prototype.muteAudioPlayback = function (muteState) {
            throw new Error('not implement');
        };
        return RTCVideo_1;
    }());
    __setFunctionName(_classThis, "RTCVideo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_mInstance_decorators = [NativeMember()];
        _static_mInstanceEx_decorators = [NativeMember()];
        _static_mRtcNativeLibraryLoader_decorators = [NativeMember()];
        _static_createRTCVideo_decorators = [ReturnClass(function () { return RTCVideo; }), NativeStaticMethodSync()];
        _static_createRTCVideo_context$appId$handler$eglContext$parameters_decorators = [ReturnClass(function () { return RTCVideo; }), NativeStaticMethodSync()];
        _static_destroyRTCVideo_decorators = [NativeStaticMethodSync()];
        _static_getSDKVersion_decorators = [NativeStaticMethodSync()];
        _static_setLogConfig_decorators = [NativeStaticMethodSync()];
        _static_getErrorDescription_decorators = [NativeStaticMethodSync()];
        _static_setDeviceId_decorators = [NativeStaticMethodSync()];
        _setRtcVideoEventHandler_decorators = [NativeMethodSync()];
        _getAudioDeviceManager_decorators = [ReturnClass(function () { return IRTCAudioDeviceManager; }), NativeMethodSync()];
        _startVideoCapture_decorators = [NativeMethodSync()];
        _stopVideoCapture_decorators = [NativeMethodSync()];
        _startAudioCapture_decorators = [NativeMethodSync()];
        _stopAudioCapture_decorators = [NativeMethodSync()];
        _setAudioScenario_decorators = [NativeMethodSync()];
        _setAudioProfile_decorators = [NativeMethodSync()];
        _setAnsMode_decorators = [NativeMethodSync()];
        _setVoiceChangerType_decorators = [NativeMethodSync()];
        _setVoiceReverbType_decorators = [NativeMethodSync()];
        _setLocalVoiceEqualization_decorators = [NativeMethodSync()];
        _setLocalVoiceReverbParam_decorators = [NativeMethodSync()];
        _enableLocalVoiceReverb_decorators = [NativeMethodSync()];
        _setLocalVideoCanvas_decorators = [NativeMethodSync()];
        _updateLocalVideoCanvas_decorators = [NativeMethodSync()];
        _setLocalVideoRender_decorators = [NativeMethodSync()];
        _setRemoteVideoRender_decorators = [NativeMethodSync()];
        _updateRemoteStreamVideoCanvas_decorators = [NativeMethodSync()];
        _setRemoteVideoCanvas_decorators = [NativeMethodSync()];
        _setRemoteVideoSuperResolution_decorators = [NativeMethodSync()];
        _setVideoDenoiser_decorators = [NativeMethodSync()];
        _setLocalVideoMirrorType_decorators = [NativeMethodSync()];
        _setRemoteVideoMirrorType_decorators = [NativeMethodSync()];
        _setVideoRotationMode_decorators = [NativeMethodSync()];
        _switchCamera_decorators = [NativeMethodSync()];
        _setAudioRoute_decorators = [NativeMethodSync()];
        _getAudioRoute_decorators = [NativeMethodSync()];
        _setDefaultAudioRoute_decorators = [NativeMethodSync()];
        _enableExternalSoundCard_decorators = [NativeMethodSync()];
        _muteAudioCapture_decorators = [NativeMethodSync()];
        _setCaptureVolume_decorators = [NativeMethodSync()];
        _setPlaybackVolume_decorators = [NativeMethodSync()];
        _setLocalVoicePitch_decorators = [NativeMethodSync()];
        _enableVocalInstrumentBalance_decorators = [NativeMethodSync()];
        _enablePlaybackDucking_decorators = [NativeMethodSync()];
        _login_decorators = [NativeMethodSync()];
        _logout_decorators = [NativeMethodSync()];
        _updateLoginToken_decorators = [NativeMethodSync()];
        _setServerParams_decorators = [NativeMethodSync()];
        _getPeerOnlineStatus_decorators = [NativeMethodSync()];
        _sendUserMessageOutsideRoom_decorators = [NativeMethodSync()];
        _sendUserBinaryMessageOutsideRoom_decorators = [NativeMethodSync()];
        _sendServerMessage_decorators = [NativeMethodSync()];
        _sendServerBinaryMessage_decorators = [NativeMethodSync()];
        _startNetworkDetection_decorators = [NativeMethodSync()];
        _stopNetworkDetection_decorators = [NativeMethodSync()];
        _enableAudioFrameCallback_decorators = [NativeMethodSync()];
        _disableAudioFrameCallback_decorators = [NativeMethodSync()];
        _registerAudioFrameObserver_decorators = [NativeMethodSync()];
        _registerAudioProcessor_decorators = [NativeMethodSync()];
        _enableAudioProcessor_decorators = [NativeMethodSync()];
        _disableAudioProcessor_decorators = [NativeMethodSync()];
        _registerLocalVideoProcessor_decorators = [NativeMethodSync()];
        _setVideoDigitalZoomConfig_decorators = [NativeMethodSync()];
        _setVideoDigitalZoomControl_decorators = [NativeMethodSync()];
        _startVideoDigitalZoomControl_decorators = [NativeMethodSync()];
        _stopVideoDigitalZoomControl_decorators = [NativeMethodSync()];
        _registerLocalEncodedVideoFrameObserver_decorators = [NativeMethodSync()];
        _registerRemoteEncodedVideoFrameObserver_decorators = [NativeMethodSync()];
        _setVideoSourceType_decorators = [NativeMethodSync()];
        _pushExternalVideoFrame_decorators = [NativeMethodSync()];
        _startPushMixedStreamToCDN_decorators = [NativeMethodSync()];
        _updatePushMixedStreamToCDN_decorators = [NativeMethodSync()];
        _startPushSingleStreamToCDN_decorators = [NativeMethodSync()];
        _stopPushStreamToCDN_decorators = [NativeMethodSync()];
        _setVideoCaptureConfig_decorators = [NativeMethodSync()];
        _enableSimulcastMode_decorators = [NativeMethodSync()];
        _setVideoEncoderConfig_decorators = [NativeMethodSync()];
        _setScreenVideoEncoderConfig_decorators = [NativeMethodSync()];
        _enableAlphaChannelVideoEncode_decorators = [NativeMethodSync()];
        _disableAlphaChannelVideoEncode_decorators = [NativeMethodSync()];
        _setAudioSourceType_decorators = [NativeMethodSync()];
        _setAudioRenderType_decorators = [NativeMethodSync()];
        _pushExternalAudioFrame_decorators = [NativeMethodSync()];
        _pullExternalAudioFrame_decorators = [NativeMethodSync()];
        _pushScreenVideoFrame_decorators = [NativeMethodSync()];
        _setRemoteAudioPlaybackVolume_decorators = [NativeMethodSync()];
        _createRTCRoom_decorators = [ReturnClass(function () { return RTCRoom$1; }), NativeMethodSync()];
        _setPublishFallbackOption_decorators = [NativeMethodSync()];
        _setSubscribeFallbackOption_decorators = [NativeMethodSync()];
        _setRemoteUserPriority_decorators = [NativeMethodSync()];
        _sendSEIMessage_decorators = [NativeMethodSync()];
        _setBusinessId_decorators = [NativeMethodSync()];
        _setEncryptInfo_decorators = [NativeMethodSync()];
        _getVideoEffectInterface_decorators = [ReturnClass(function () { return IVideoEffect$1; }), NativeMethodSync()];
        _enableEffectBeauty_decorators = [NativeMethodSync()];
        _setBeautyIntensity_decorators = [NativeMethodSync()];
        _setVideoOrientation_decorators = [NativeMethodSync()];
        _setRuntimeParameters_decorators = [NativeMethodSync()];
        _feedback_decorators = [NativeMethodSync()];
        _getNativeHandle_decorators = [NativeMethodSync()];
        _startASR_decorators = [NativeMethodSync()];
        _stopASR_decorators = [NativeMethodSync()];
        _startFileRecording_decorators = [NativeMethodSync()];
        _stopFileRecording_decorators = [NativeMethodSync()];
        _startAudioRecording_decorators = [NativeMethodSync()];
        _stopAudioRecording_decorators = [NativeMethodSync()];
        _getAudioEffectPlayer_decorators = [ReturnClass(function () { return IAudioEffectPlayer$1; }), NativeMethodSync()];
        _getMediaPlayer_decorators = [ReturnClass(function () { return IMediaPlayer$1; }), NativeMethodSync()];
        _setScreenAudioSourceType_decorators = [NativeMethodSync()];
        _setScreenAudioStreamIndex_decorators = [NativeMethodSync()];
        _pushScreenAudioFrame_decorators = [NativeMethodSync()];
        _startScreenCapture_decorators = [NativeMethodSync()];
        _updateScreenCapture_decorators = [NativeMethodSync()];
        _stopScreenCapture_decorators = [NativeMethodSync()];
        _setExternalVideoEncoderEventHandler_decorators = [NativeMethodSync()];
        _pushExternalEncodedVideoFrame_decorators = [NativeMethodSync()];
        _setVideoDecoderConfig_decorators = [NativeMethodSync()];
        _requestRemoteVideoKeyFrame_decorators = [NativeMethodSync()];
        _setEarMonitorMode_decorators = [NativeMethodSync()];
        _setEarMonitorVolume_decorators = [NativeMethodSync()];
        _enableAudioPropertiesReport_decorators = [NativeMethodSync()];
        _sendStreamSyncInfo_decorators = [NativeMethodSync()];
        _isCameraTorchSupported_decorators = [NativeMethodSync()];
        _isCameraZoomSupported_decorators = [NativeMethodSync()];
        _setCameraZoomRatio_decorators = [NativeMethodSync()];
        _getCameraZoomMaxRatio_decorators = [NativeMethodSync()];
        _setCameraTorch_decorators = [NativeMethodSync()];
        _isCameraFocusPositionSupported_decorators = [NativeMethodSync()];
        _setCameraFocusPosition_decorators = [NativeMethodSync()];
        _isCameraExposurePositionSupported_decorators = [NativeMethodSync()];
        _setCameraExposurePosition_decorators = [NativeMethodSync()];
        _setCameraExposureCompensation_decorators = [NativeMethodSync()];
        _enableCameraAutoExposureFaceMode_decorators = [NativeMethodSync()];
        _setCameraAdaptiveMinimumFrameRate_decorators = [NativeMethodSync()];
        _startPushPublicStream_decorators = [NativeMethodSync()];
        _stopPushPublicStream_decorators = [NativeMethodSync()];
        _updatePublicStreamParam_decorators = [NativeMethodSync()];
        _startPlayPublicStream_decorators = [NativeMethodSync()];
        _stopPlayPublicStream_decorators = [NativeMethodSync()];
        _setPublicStreamVideoCanvas_decorators = [NativeMethodSync()];
        _setPublicStreamVideoSink_decorators = [NativeMethodSync()];
        _setPublicStreamAudioPlaybackVolume_decorators = [NativeMethodSync()];
        _startEchoTest_decorators = [NativeMethodSync()];
        _stopEchoTest_decorators = [NativeMethodSync()];
        _setVideoWatermark_decorators = [NativeMethodSync()];
        _clearVideoWatermark_decorators = [NativeMethodSync()];
        _setDummyCaptureImagePath_decorators = [NativeMethodSync()];
        _takeLocalSnapshot_decorators = [NativeMethodSync()];
        _takeRemoteSnapshot_decorators = [NativeMethodSync()];
        _startCloudProxy_decorators = [NativeMethodSync()];
        _stopCloudProxy_decorators = [NativeMethodSync()];
        _getSingScoringManager_decorators = [ReturnClass(function () { return ISingScoringManager$1; }), NativeMethodSync()];
        _getNetworkTimeInfo_decorators = [ReturnClass(function () { return NetworkTimeInfo$1; }), NativeMethodSync()];
        _getKTVManager_decorators = [ReturnClass(function () { return IKTVManager$1; }), NativeMethodSync()];
        _startHardwareEchoDetection_decorators = [NativeMethodSync()];
        _stopHardwareEchoDetection_decorators = [NativeMethodSync()];
        _setCellularEnhancement_decorators = [NativeMethodSync()];
        _setLocalProxy_decorators = [NativeMethodSync()];
        _getVideoDeviceManager_decorators = [ReturnClass(function () { return IVideoDeviceManager$1; }), NativeMethodSync()];
        _setVideoCaptureRotation_decorators = [NativeMethodSync()];
        _setLocalVideoSink_decorators = [NativeMethodSync()];
        _setRemoteVideoSink_decorators = [NativeMethodSync()];
        _updateRemoteStreamVideoCanvas_streamKey$renderMode$backgroundColor_decorators = [NativeMethodSync('updateRemoteStreamVideoCanvas')];
        _replaceBackground_decorators = [NativeMethodSync()];
        _setAudioPlaybackDevice_decorators = [NativeMethodSync()];
        _startLiveTranscoding_decorators = [NativeMethodSync()];
        _stopLiveTranscoding_decorators = [NativeMethodSync()];
        _updateLiveTranscoding_decorators = [NativeMethodSync()];
        _setVideoEncoderConfig_videoStreamDescriptions$orientationMode_decorators = [NativeMethodSync('setVideoEncoderConfig')];
        _setVideoEncoderConfig_streamIndex$videoStreamDescriptions_decorators = [NativeMethodSync('setVideoEncoderConfig')];
        _setOnDestroyCompletedCallback_decorators = [NativeMethodSync()];
        _sendSEIMessage_streamIndex$message$repeatCount_decorators = [NativeMethodSync('sendSEIMessage')];
        _checkVideoEffectLicense_decorators = [NativeMethodSync()];
        _setVideoEffectAlgoModelPath_decorators = [NativeMethodSync()];
        _enableVideoEffect_decorators = [NativeMethodSync()];
        _setVideoEffectNodes_decorators = [NativeMethodSync()];
        _updateVideoEffectNode_decorators = [NativeMethodSync()];
        _setBackgroundSticker_decorators = [NativeMethodSync()];
        _setVideoEffectColorFilter_decorators = [NativeMethodSync()];
        _setVideoEffectColorFilterIntensity_decorators = [NativeMethodSync()];
        _registerFaceDetectionObserver_decorators = [NativeMethodSync()];
        _getAudioMixingManager_decorators = [ReturnClass(function () { return IAudioMixingManager$1; }), NativeMethodSync()];
        _muteAudioPlayback_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _static_createRTCVideo_decorators, { kind: "method", name: "createRTCVideo", static: true, private: false, access: { has: function (obj) { return "createRTCVideo" in obj; }, get: function (obj) { return obj.createRTCVideo; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _static_createRTCVideo_context$appId$handler$eglContext$parameters_decorators, { kind: "method", name: "createRTCVideo_context$appId$handler$eglContext$parameters", static: true, private: false, access: { has: function (obj) { return "createRTCVideo_context$appId$handler$eglContext$parameters" in obj; }, get: function (obj) { return obj.createRTCVideo_context$appId$handler$eglContext$parameters; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _static_destroyRTCVideo_decorators, { kind: "method", name: "destroyRTCVideo", static: true, private: false, access: { has: function (obj) { return "destroyRTCVideo" in obj; }, get: function (obj) { return obj.destroyRTCVideo; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _static_getSDKVersion_decorators, { kind: "method", name: "getSDKVersion", static: true, private: false, access: { has: function (obj) { return "getSDKVersion" in obj; }, get: function (obj) { return obj.getSDKVersion; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _static_setLogConfig_decorators, { kind: "method", name: "setLogConfig", static: true, private: false, access: { has: function (obj) { return "setLogConfig" in obj; }, get: function (obj) { return obj.setLogConfig; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _static_getErrorDescription_decorators, { kind: "method", name: "getErrorDescription", static: true, private: false, access: { has: function (obj) { return "getErrorDescription" in obj; }, get: function (obj) { return obj.getErrorDescription; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _static_setDeviceId_decorators, { kind: "method", name: "setDeviceId", static: true, private: false, access: { has: function (obj) { return "setDeviceId" in obj; }, get: function (obj) { return obj.setDeviceId; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _setRtcVideoEventHandler_decorators, { kind: "method", name: "setRtcVideoEventHandler", static: false, private: false, access: { has: function (obj) { return "setRtcVideoEventHandler" in obj; }, get: function (obj) { return obj.setRtcVideoEventHandler; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioDeviceManager_decorators, { kind: "method", name: "getAudioDeviceManager", static: false, private: false, access: { has: function (obj) { return "getAudioDeviceManager" in obj; }, get: function (obj) { return obj.getAudioDeviceManager; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startVideoCapture_decorators, { kind: "method", name: "startVideoCapture", static: false, private: false, access: { has: function (obj) { return "startVideoCapture" in obj; }, get: function (obj) { return obj.startVideoCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopVideoCapture_decorators, { kind: "method", name: "stopVideoCapture", static: false, private: false, access: { has: function (obj) { return "stopVideoCapture" in obj; }, get: function (obj) { return obj.stopVideoCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startAudioCapture_decorators, { kind: "method", name: "startAudioCapture", static: false, private: false, access: { has: function (obj) { return "startAudioCapture" in obj; }, get: function (obj) { return obj.startAudioCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopAudioCapture_decorators, { kind: "method", name: "stopAudioCapture", static: false, private: false, access: { has: function (obj) { return "stopAudioCapture" in obj; }, get: function (obj) { return obj.stopAudioCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioScenario_decorators, { kind: "method", name: "setAudioScenario", static: false, private: false, access: { has: function (obj) { return "setAudioScenario" in obj; }, get: function (obj) { return obj.setAudioScenario; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioProfile_decorators, { kind: "method", name: "setAudioProfile", static: false, private: false, access: { has: function (obj) { return "setAudioProfile" in obj; }, get: function (obj) { return obj.setAudioProfile; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAnsMode_decorators, { kind: "method", name: "setAnsMode", static: false, private: false, access: { has: function (obj) { return "setAnsMode" in obj; }, get: function (obj) { return obj.setAnsMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVoiceChangerType_decorators, { kind: "method", name: "setVoiceChangerType", static: false, private: false, access: { has: function (obj) { return "setVoiceChangerType" in obj; }, get: function (obj) { return obj.setVoiceChangerType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVoiceReverbType_decorators, { kind: "method", name: "setVoiceReverbType", static: false, private: false, access: { has: function (obj) { return "setVoiceReverbType" in obj; }, get: function (obj) { return obj.setVoiceReverbType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVoiceEqualization_decorators, { kind: "method", name: "setLocalVoiceEqualization", static: false, private: false, access: { has: function (obj) { return "setLocalVoiceEqualization" in obj; }, get: function (obj) { return obj.setLocalVoiceEqualization; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVoiceReverbParam_decorators, { kind: "method", name: "setLocalVoiceReverbParam", static: false, private: false, access: { has: function (obj) { return "setLocalVoiceReverbParam" in obj; }, get: function (obj) { return obj.setLocalVoiceReverbParam; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableLocalVoiceReverb_decorators, { kind: "method", name: "enableLocalVoiceReverb", static: false, private: false, access: { has: function (obj) { return "enableLocalVoiceReverb" in obj; }, get: function (obj) { return obj.enableLocalVoiceReverb; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVideoCanvas_decorators, { kind: "method", name: "setLocalVideoCanvas", static: false, private: false, access: { has: function (obj) { return "setLocalVideoCanvas" in obj; }, get: function (obj) { return obj.setLocalVideoCanvas; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateLocalVideoCanvas_decorators, { kind: "method", name: "updateLocalVideoCanvas", static: false, private: false, access: { has: function (obj) { return "updateLocalVideoCanvas" in obj; }, get: function (obj) { return obj.updateLocalVideoCanvas; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVideoRender_decorators, { kind: "method", name: "setLocalVideoRender", static: false, private: false, access: { has: function (obj) { return "setLocalVideoRender" in obj; }, get: function (obj) { return obj.setLocalVideoRender; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteVideoRender_decorators, { kind: "method", name: "setRemoteVideoRender", static: false, private: false, access: { has: function (obj) { return "setRemoteVideoRender" in obj; }, get: function (obj) { return obj.setRemoteVideoRender; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateRemoteStreamVideoCanvas_decorators, { kind: "method", name: "updateRemoteStreamVideoCanvas", static: false, private: false, access: { has: function (obj) { return "updateRemoteStreamVideoCanvas" in obj; }, get: function (obj) { return obj.updateRemoteStreamVideoCanvas; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteVideoCanvas_decorators, { kind: "method", name: "setRemoteVideoCanvas", static: false, private: false, access: { has: function (obj) { return "setRemoteVideoCanvas" in obj; }, get: function (obj) { return obj.setRemoteVideoCanvas; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteVideoSuperResolution_decorators, { kind: "method", name: "setRemoteVideoSuperResolution", static: false, private: false, access: { has: function (obj) { return "setRemoteVideoSuperResolution" in obj; }, get: function (obj) { return obj.setRemoteVideoSuperResolution; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoDenoiser_decorators, { kind: "method", name: "setVideoDenoiser", static: false, private: false, access: { has: function (obj) { return "setVideoDenoiser" in obj; }, get: function (obj) { return obj.setVideoDenoiser; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVideoMirrorType_decorators, { kind: "method", name: "setLocalVideoMirrorType", static: false, private: false, access: { has: function (obj) { return "setLocalVideoMirrorType" in obj; }, get: function (obj) { return obj.setLocalVideoMirrorType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteVideoMirrorType_decorators, { kind: "method", name: "setRemoteVideoMirrorType", static: false, private: false, access: { has: function (obj) { return "setRemoteVideoMirrorType" in obj; }, get: function (obj) { return obj.setRemoteVideoMirrorType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoRotationMode_decorators, { kind: "method", name: "setVideoRotationMode", static: false, private: false, access: { has: function (obj) { return "setVideoRotationMode" in obj; }, get: function (obj) { return obj.setVideoRotationMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _switchCamera_decorators, { kind: "method", name: "switchCamera", static: false, private: false, access: { has: function (obj) { return "switchCamera" in obj; }, get: function (obj) { return obj.switchCamera; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioRoute_decorators, { kind: "method", name: "setAudioRoute", static: false, private: false, access: { has: function (obj) { return "setAudioRoute" in obj; }, get: function (obj) { return obj.setAudioRoute; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioRoute_decorators, { kind: "method", name: "getAudioRoute", static: false, private: false, access: { has: function (obj) { return "getAudioRoute" in obj; }, get: function (obj) { return obj.getAudioRoute; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setDefaultAudioRoute_decorators, { kind: "method", name: "setDefaultAudioRoute", static: false, private: false, access: { has: function (obj) { return "setDefaultAudioRoute" in obj; }, get: function (obj) { return obj.setDefaultAudioRoute; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableExternalSoundCard_decorators, { kind: "method", name: "enableExternalSoundCard", static: false, private: false, access: { has: function (obj) { return "enableExternalSoundCard" in obj; }, get: function (obj) { return obj.enableExternalSoundCard; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _muteAudioCapture_decorators, { kind: "method", name: "muteAudioCapture", static: false, private: false, access: { has: function (obj) { return "muteAudioCapture" in obj; }, get: function (obj) { return obj.muteAudioCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCaptureVolume_decorators, { kind: "method", name: "setCaptureVolume", static: false, private: false, access: { has: function (obj) { return "setCaptureVolume" in obj; }, get: function (obj) { return obj.setCaptureVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPlaybackVolume_decorators, { kind: "method", name: "setPlaybackVolume", static: false, private: false, access: { has: function (obj) { return "setPlaybackVolume" in obj; }, get: function (obj) { return obj.setPlaybackVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVoicePitch_decorators, { kind: "method", name: "setLocalVoicePitch", static: false, private: false, access: { has: function (obj) { return "setLocalVoicePitch" in obj; }, get: function (obj) { return obj.setLocalVoicePitch; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableVocalInstrumentBalance_decorators, { kind: "method", name: "enableVocalInstrumentBalance", static: false, private: false, access: { has: function (obj) { return "enableVocalInstrumentBalance" in obj; }, get: function (obj) { return obj.enableVocalInstrumentBalance; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enablePlaybackDucking_decorators, { kind: "method", name: "enablePlaybackDucking", static: false, private: false, access: { has: function (obj) { return "enablePlaybackDucking" in obj; }, get: function (obj) { return obj.enablePlaybackDucking; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _login_decorators, { kind: "method", name: "login", static: false, private: false, access: { has: function (obj) { return "login" in obj; }, get: function (obj) { return obj.login; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _logout_decorators, { kind: "method", name: "logout", static: false, private: false, access: { has: function (obj) { return "logout" in obj; }, get: function (obj) { return obj.logout; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateLoginToken_decorators, { kind: "method", name: "updateLoginToken", static: false, private: false, access: { has: function (obj) { return "updateLoginToken" in obj; }, get: function (obj) { return obj.updateLoginToken; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setServerParams_decorators, { kind: "method", name: "setServerParams", static: false, private: false, access: { has: function (obj) { return "setServerParams" in obj; }, get: function (obj) { return obj.setServerParams; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getPeerOnlineStatus_decorators, { kind: "method", name: "getPeerOnlineStatus", static: false, private: false, access: { has: function (obj) { return "getPeerOnlineStatus" in obj; }, get: function (obj) { return obj.getPeerOnlineStatus; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendUserMessageOutsideRoom_decorators, { kind: "method", name: "sendUserMessageOutsideRoom", static: false, private: false, access: { has: function (obj) { return "sendUserMessageOutsideRoom" in obj; }, get: function (obj) { return obj.sendUserMessageOutsideRoom; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendUserBinaryMessageOutsideRoom_decorators, { kind: "method", name: "sendUserBinaryMessageOutsideRoom", static: false, private: false, access: { has: function (obj) { return "sendUserBinaryMessageOutsideRoom" in obj; }, get: function (obj) { return obj.sendUserBinaryMessageOutsideRoom; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendServerMessage_decorators, { kind: "method", name: "sendServerMessage", static: false, private: false, access: { has: function (obj) { return "sendServerMessage" in obj; }, get: function (obj) { return obj.sendServerMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendServerBinaryMessage_decorators, { kind: "method", name: "sendServerBinaryMessage", static: false, private: false, access: { has: function (obj) { return "sendServerBinaryMessage" in obj; }, get: function (obj) { return obj.sendServerBinaryMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startNetworkDetection_decorators, { kind: "method", name: "startNetworkDetection", static: false, private: false, access: { has: function (obj) { return "startNetworkDetection" in obj; }, get: function (obj) { return obj.startNetworkDetection; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopNetworkDetection_decorators, { kind: "method", name: "stopNetworkDetection", static: false, private: false, access: { has: function (obj) { return "stopNetworkDetection" in obj; }, get: function (obj) { return obj.stopNetworkDetection; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableAudioFrameCallback_decorators, { kind: "method", name: "enableAudioFrameCallback", static: false, private: false, access: { has: function (obj) { return "enableAudioFrameCallback" in obj; }, get: function (obj) { return obj.enableAudioFrameCallback; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableAudioFrameCallback_decorators, { kind: "method", name: "disableAudioFrameCallback", static: false, private: false, access: { has: function (obj) { return "disableAudioFrameCallback" in obj; }, get: function (obj) { return obj.disableAudioFrameCallback; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerAudioFrameObserver_decorators, { kind: "method", name: "registerAudioFrameObserver", static: false, private: false, access: { has: function (obj) { return "registerAudioFrameObserver" in obj; }, get: function (obj) { return obj.registerAudioFrameObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerAudioProcessor_decorators, { kind: "method", name: "registerAudioProcessor", static: false, private: false, access: { has: function (obj) { return "registerAudioProcessor" in obj; }, get: function (obj) { return obj.registerAudioProcessor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableAudioProcessor_decorators, { kind: "method", name: "enableAudioProcessor", static: false, private: false, access: { has: function (obj) { return "enableAudioProcessor" in obj; }, get: function (obj) { return obj.enableAudioProcessor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableAudioProcessor_decorators, { kind: "method", name: "disableAudioProcessor", static: false, private: false, access: { has: function (obj) { return "disableAudioProcessor" in obj; }, get: function (obj) { return obj.disableAudioProcessor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerLocalVideoProcessor_decorators, { kind: "method", name: "registerLocalVideoProcessor", static: false, private: false, access: { has: function (obj) { return "registerLocalVideoProcessor" in obj; }, get: function (obj) { return obj.registerLocalVideoProcessor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoDigitalZoomConfig_decorators, { kind: "method", name: "setVideoDigitalZoomConfig", static: false, private: false, access: { has: function (obj) { return "setVideoDigitalZoomConfig" in obj; }, get: function (obj) { return obj.setVideoDigitalZoomConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoDigitalZoomControl_decorators, { kind: "method", name: "setVideoDigitalZoomControl", static: false, private: false, access: { has: function (obj) { return "setVideoDigitalZoomControl" in obj; }, get: function (obj) { return obj.setVideoDigitalZoomControl; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startVideoDigitalZoomControl_decorators, { kind: "method", name: "startVideoDigitalZoomControl", static: false, private: false, access: { has: function (obj) { return "startVideoDigitalZoomControl" in obj; }, get: function (obj) { return obj.startVideoDigitalZoomControl; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopVideoDigitalZoomControl_decorators, { kind: "method", name: "stopVideoDigitalZoomControl", static: false, private: false, access: { has: function (obj) { return "stopVideoDigitalZoomControl" in obj; }, get: function (obj) { return obj.stopVideoDigitalZoomControl; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerLocalEncodedVideoFrameObserver_decorators, { kind: "method", name: "registerLocalEncodedVideoFrameObserver", static: false, private: false, access: { has: function (obj) { return "registerLocalEncodedVideoFrameObserver" in obj; }, get: function (obj) { return obj.registerLocalEncodedVideoFrameObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerRemoteEncodedVideoFrameObserver_decorators, { kind: "method", name: "registerRemoteEncodedVideoFrameObserver", static: false, private: false, access: { has: function (obj) { return "registerRemoteEncodedVideoFrameObserver" in obj; }, get: function (obj) { return obj.registerRemoteEncodedVideoFrameObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoSourceType_decorators, { kind: "method", name: "setVideoSourceType", static: false, private: false, access: { has: function (obj) { return "setVideoSourceType" in obj; }, get: function (obj) { return obj.setVideoSourceType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushExternalVideoFrame_decorators, { kind: "method", name: "pushExternalVideoFrame", static: false, private: false, access: { has: function (obj) { return "pushExternalVideoFrame" in obj; }, get: function (obj) { return obj.pushExternalVideoFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startPushMixedStreamToCDN_decorators, { kind: "method", name: "startPushMixedStreamToCDN", static: false, private: false, access: { has: function (obj) { return "startPushMixedStreamToCDN" in obj; }, get: function (obj) { return obj.startPushMixedStreamToCDN; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updatePushMixedStreamToCDN_decorators, { kind: "method", name: "updatePushMixedStreamToCDN", static: false, private: false, access: { has: function (obj) { return "updatePushMixedStreamToCDN" in obj; }, get: function (obj) { return obj.updatePushMixedStreamToCDN; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startPushSingleStreamToCDN_decorators, { kind: "method", name: "startPushSingleStreamToCDN", static: false, private: false, access: { has: function (obj) { return "startPushSingleStreamToCDN" in obj; }, get: function (obj) { return obj.startPushSingleStreamToCDN; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopPushStreamToCDN_decorators, { kind: "method", name: "stopPushStreamToCDN", static: false, private: false, access: { has: function (obj) { return "stopPushStreamToCDN" in obj; }, get: function (obj) { return obj.stopPushStreamToCDN; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoCaptureConfig_decorators, { kind: "method", name: "setVideoCaptureConfig", static: false, private: false, access: { has: function (obj) { return "setVideoCaptureConfig" in obj; }, get: function (obj) { return obj.setVideoCaptureConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableSimulcastMode_decorators, { kind: "method", name: "enableSimulcastMode", static: false, private: false, access: { has: function (obj) { return "enableSimulcastMode" in obj; }, get: function (obj) { return obj.enableSimulcastMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoEncoderConfig_decorators, { kind: "method", name: "setVideoEncoderConfig", static: false, private: false, access: { has: function (obj) { return "setVideoEncoderConfig" in obj; }, get: function (obj) { return obj.setVideoEncoderConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setScreenVideoEncoderConfig_decorators, { kind: "method", name: "setScreenVideoEncoderConfig", static: false, private: false, access: { has: function (obj) { return "setScreenVideoEncoderConfig" in obj; }, get: function (obj) { return obj.setScreenVideoEncoderConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableAlphaChannelVideoEncode_decorators, { kind: "method", name: "enableAlphaChannelVideoEncode", static: false, private: false, access: { has: function (obj) { return "enableAlphaChannelVideoEncode" in obj; }, get: function (obj) { return obj.enableAlphaChannelVideoEncode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableAlphaChannelVideoEncode_decorators, { kind: "method", name: "disableAlphaChannelVideoEncode", static: false, private: false, access: { has: function (obj) { return "disableAlphaChannelVideoEncode" in obj; }, get: function (obj) { return obj.disableAlphaChannelVideoEncode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioSourceType_decorators, { kind: "method", name: "setAudioSourceType", static: false, private: false, access: { has: function (obj) { return "setAudioSourceType" in obj; }, get: function (obj) { return obj.setAudioSourceType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioRenderType_decorators, { kind: "method", name: "setAudioRenderType", static: false, private: false, access: { has: function (obj) { return "setAudioRenderType" in obj; }, get: function (obj) { return obj.setAudioRenderType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushExternalAudioFrame_decorators, { kind: "method", name: "pushExternalAudioFrame", static: false, private: false, access: { has: function (obj) { return "pushExternalAudioFrame" in obj; }, get: function (obj) { return obj.pushExternalAudioFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pullExternalAudioFrame_decorators, { kind: "method", name: "pullExternalAudioFrame", static: false, private: false, access: { has: function (obj) { return "pullExternalAudioFrame" in obj; }, get: function (obj) { return obj.pullExternalAudioFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushScreenVideoFrame_decorators, { kind: "method", name: "pushScreenVideoFrame", static: false, private: false, access: { has: function (obj) { return "pushScreenVideoFrame" in obj; }, get: function (obj) { return obj.pushScreenVideoFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteAudioPlaybackVolume_decorators, { kind: "method", name: "setRemoteAudioPlaybackVolume", static: false, private: false, access: { has: function (obj) { return "setRemoteAudioPlaybackVolume" in obj; }, get: function (obj) { return obj.setRemoteAudioPlaybackVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _createRTCRoom_decorators, { kind: "method", name: "createRTCRoom", static: false, private: false, access: { has: function (obj) { return "createRTCRoom" in obj; }, get: function (obj) { return obj.createRTCRoom; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPublishFallbackOption_decorators, { kind: "method", name: "setPublishFallbackOption", static: false, private: false, access: { has: function (obj) { return "setPublishFallbackOption" in obj; }, get: function (obj) { return obj.setPublishFallbackOption; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setSubscribeFallbackOption_decorators, { kind: "method", name: "setSubscribeFallbackOption", static: false, private: false, access: { has: function (obj) { return "setSubscribeFallbackOption" in obj; }, get: function (obj) { return obj.setSubscribeFallbackOption; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteUserPriority_decorators, { kind: "method", name: "setRemoteUserPriority", static: false, private: false, access: { has: function (obj) { return "setRemoteUserPriority" in obj; }, get: function (obj) { return obj.setRemoteUserPriority; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendSEIMessage_decorators, { kind: "method", name: "sendSEIMessage", static: false, private: false, access: { has: function (obj) { return "sendSEIMessage" in obj; }, get: function (obj) { return obj.sendSEIMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBusinessId_decorators, { kind: "method", name: "setBusinessId", static: false, private: false, access: { has: function (obj) { return "setBusinessId" in obj; }, get: function (obj) { return obj.setBusinessId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEncryptInfo_decorators, { kind: "method", name: "setEncryptInfo", static: false, private: false, access: { has: function (obj) { return "setEncryptInfo" in obj; }, get: function (obj) { return obj.setEncryptInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getVideoEffectInterface_decorators, { kind: "method", name: "getVideoEffectInterface", static: false, private: false, access: { has: function (obj) { return "getVideoEffectInterface" in obj; }, get: function (obj) { return obj.getVideoEffectInterface; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableEffectBeauty_decorators, { kind: "method", name: "enableEffectBeauty", static: false, private: false, access: { has: function (obj) { return "enableEffectBeauty" in obj; }, get: function (obj) { return obj.enableEffectBeauty; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBeautyIntensity_decorators, { kind: "method", name: "setBeautyIntensity", static: false, private: false, access: { has: function (obj) { return "setBeautyIntensity" in obj; }, get: function (obj) { return obj.setBeautyIntensity; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoOrientation_decorators, { kind: "method", name: "setVideoOrientation", static: false, private: false, access: { has: function (obj) { return "setVideoOrientation" in obj; }, get: function (obj) { return obj.setVideoOrientation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRuntimeParameters_decorators, { kind: "method", name: "setRuntimeParameters", static: false, private: false, access: { has: function (obj) { return "setRuntimeParameters" in obj; }, get: function (obj) { return obj.setRuntimeParameters; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _feedback_decorators, { kind: "method", name: "feedback", static: false, private: false, access: { has: function (obj) { return "feedback" in obj; }, get: function (obj) { return obj.feedback; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getNativeHandle_decorators, { kind: "method", name: "getNativeHandle", static: false, private: false, access: { has: function (obj) { return "getNativeHandle" in obj; }, get: function (obj) { return obj.getNativeHandle; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startASR_decorators, { kind: "method", name: "startASR", static: false, private: false, access: { has: function (obj) { return "startASR" in obj; }, get: function (obj) { return obj.startASR; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopASR_decorators, { kind: "method", name: "stopASR", static: false, private: false, access: { has: function (obj) { return "stopASR" in obj; }, get: function (obj) { return obj.stopASR; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startFileRecording_decorators, { kind: "method", name: "startFileRecording", static: false, private: false, access: { has: function (obj) { return "startFileRecording" in obj; }, get: function (obj) { return obj.startFileRecording; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopFileRecording_decorators, { kind: "method", name: "stopFileRecording", static: false, private: false, access: { has: function (obj) { return "stopFileRecording" in obj; }, get: function (obj) { return obj.stopFileRecording; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startAudioRecording_decorators, { kind: "method", name: "startAudioRecording", static: false, private: false, access: { has: function (obj) { return "startAudioRecording" in obj; }, get: function (obj) { return obj.startAudioRecording; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopAudioRecording_decorators, { kind: "method", name: "stopAudioRecording", static: false, private: false, access: { has: function (obj) { return "stopAudioRecording" in obj; }, get: function (obj) { return obj.stopAudioRecording; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioEffectPlayer_decorators, { kind: "method", name: "getAudioEffectPlayer", static: false, private: false, access: { has: function (obj) { return "getAudioEffectPlayer" in obj; }, get: function (obj) { return obj.getAudioEffectPlayer; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getMediaPlayer_decorators, { kind: "method", name: "getMediaPlayer", static: false, private: false, access: { has: function (obj) { return "getMediaPlayer" in obj; }, get: function (obj) { return obj.getMediaPlayer; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setScreenAudioSourceType_decorators, { kind: "method", name: "setScreenAudioSourceType", static: false, private: false, access: { has: function (obj) { return "setScreenAudioSourceType" in obj; }, get: function (obj) { return obj.setScreenAudioSourceType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setScreenAudioStreamIndex_decorators, { kind: "method", name: "setScreenAudioStreamIndex", static: false, private: false, access: { has: function (obj) { return "setScreenAudioStreamIndex" in obj; }, get: function (obj) { return obj.setScreenAudioStreamIndex; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushScreenAudioFrame_decorators, { kind: "method", name: "pushScreenAudioFrame", static: false, private: false, access: { has: function (obj) { return "pushScreenAudioFrame" in obj; }, get: function (obj) { return obj.pushScreenAudioFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startScreenCapture_decorators, { kind: "method", name: "startScreenCapture", static: false, private: false, access: { has: function (obj) { return "startScreenCapture" in obj; }, get: function (obj) { return obj.startScreenCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateScreenCapture_decorators, { kind: "method", name: "updateScreenCapture", static: false, private: false, access: { has: function (obj) { return "updateScreenCapture" in obj; }, get: function (obj) { return obj.updateScreenCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopScreenCapture_decorators, { kind: "method", name: "stopScreenCapture", static: false, private: false, access: { has: function (obj) { return "stopScreenCapture" in obj; }, get: function (obj) { return obj.stopScreenCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setExternalVideoEncoderEventHandler_decorators, { kind: "method", name: "setExternalVideoEncoderEventHandler", static: false, private: false, access: { has: function (obj) { return "setExternalVideoEncoderEventHandler" in obj; }, get: function (obj) { return obj.setExternalVideoEncoderEventHandler; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushExternalEncodedVideoFrame_decorators, { kind: "method", name: "pushExternalEncodedVideoFrame", static: false, private: false, access: { has: function (obj) { return "pushExternalEncodedVideoFrame" in obj; }, get: function (obj) { return obj.pushExternalEncodedVideoFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoDecoderConfig_decorators, { kind: "method", name: "setVideoDecoderConfig", static: false, private: false, access: { has: function (obj) { return "setVideoDecoderConfig" in obj; }, get: function (obj) { return obj.setVideoDecoderConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _requestRemoteVideoKeyFrame_decorators, { kind: "method", name: "requestRemoteVideoKeyFrame", static: false, private: false, access: { has: function (obj) { return "requestRemoteVideoKeyFrame" in obj; }, get: function (obj) { return obj.requestRemoteVideoKeyFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEarMonitorMode_decorators, { kind: "method", name: "setEarMonitorMode", static: false, private: false, access: { has: function (obj) { return "setEarMonitorMode" in obj; }, get: function (obj) { return obj.setEarMonitorMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEarMonitorVolume_decorators, { kind: "method", name: "setEarMonitorVolume", static: false, private: false, access: { has: function (obj) { return "setEarMonitorVolume" in obj; }, get: function (obj) { return obj.setEarMonitorVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableAudioPropertiesReport_decorators, { kind: "method", name: "enableAudioPropertiesReport", static: false, private: false, access: { has: function (obj) { return "enableAudioPropertiesReport" in obj; }, get: function (obj) { return obj.enableAudioPropertiesReport; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendStreamSyncInfo_decorators, { kind: "method", name: "sendStreamSyncInfo", static: false, private: false, access: { has: function (obj) { return "sendStreamSyncInfo" in obj; }, get: function (obj) { return obj.sendStreamSyncInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _isCameraTorchSupported_decorators, { kind: "method", name: "isCameraTorchSupported", static: false, private: false, access: { has: function (obj) { return "isCameraTorchSupported" in obj; }, get: function (obj) { return obj.isCameraTorchSupported; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _isCameraZoomSupported_decorators, { kind: "method", name: "isCameraZoomSupported", static: false, private: false, access: { has: function (obj) { return "isCameraZoomSupported" in obj; }, get: function (obj) { return obj.isCameraZoomSupported; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCameraZoomRatio_decorators, { kind: "method", name: "setCameraZoomRatio", static: false, private: false, access: { has: function (obj) { return "setCameraZoomRatio" in obj; }, get: function (obj) { return obj.setCameraZoomRatio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getCameraZoomMaxRatio_decorators, { kind: "method", name: "getCameraZoomMaxRatio", static: false, private: false, access: { has: function (obj) { return "getCameraZoomMaxRatio" in obj; }, get: function (obj) { return obj.getCameraZoomMaxRatio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCameraTorch_decorators, { kind: "method", name: "setCameraTorch", static: false, private: false, access: { has: function (obj) { return "setCameraTorch" in obj; }, get: function (obj) { return obj.setCameraTorch; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _isCameraFocusPositionSupported_decorators, { kind: "method", name: "isCameraFocusPositionSupported", static: false, private: false, access: { has: function (obj) { return "isCameraFocusPositionSupported" in obj; }, get: function (obj) { return obj.isCameraFocusPositionSupported; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCameraFocusPosition_decorators, { kind: "method", name: "setCameraFocusPosition", static: false, private: false, access: { has: function (obj) { return "setCameraFocusPosition" in obj; }, get: function (obj) { return obj.setCameraFocusPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _isCameraExposurePositionSupported_decorators, { kind: "method", name: "isCameraExposurePositionSupported", static: false, private: false, access: { has: function (obj) { return "isCameraExposurePositionSupported" in obj; }, get: function (obj) { return obj.isCameraExposurePositionSupported; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCameraExposurePosition_decorators, { kind: "method", name: "setCameraExposurePosition", static: false, private: false, access: { has: function (obj) { return "setCameraExposurePosition" in obj; }, get: function (obj) { return obj.setCameraExposurePosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCameraExposureCompensation_decorators, { kind: "method", name: "setCameraExposureCompensation", static: false, private: false, access: { has: function (obj) { return "setCameraExposureCompensation" in obj; }, get: function (obj) { return obj.setCameraExposureCompensation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableCameraAutoExposureFaceMode_decorators, { kind: "method", name: "enableCameraAutoExposureFaceMode", static: false, private: false, access: { has: function (obj) { return "enableCameraAutoExposureFaceMode" in obj; }, get: function (obj) { return obj.enableCameraAutoExposureFaceMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCameraAdaptiveMinimumFrameRate_decorators, { kind: "method", name: "setCameraAdaptiveMinimumFrameRate", static: false, private: false, access: { has: function (obj) { return "setCameraAdaptiveMinimumFrameRate" in obj; }, get: function (obj) { return obj.setCameraAdaptiveMinimumFrameRate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startPushPublicStream_decorators, { kind: "method", name: "startPushPublicStream", static: false, private: false, access: { has: function (obj) { return "startPushPublicStream" in obj; }, get: function (obj) { return obj.startPushPublicStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopPushPublicStream_decorators, { kind: "method", name: "stopPushPublicStream", static: false, private: false, access: { has: function (obj) { return "stopPushPublicStream" in obj; }, get: function (obj) { return obj.stopPushPublicStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updatePublicStreamParam_decorators, { kind: "method", name: "updatePublicStreamParam", static: false, private: false, access: { has: function (obj) { return "updatePublicStreamParam" in obj; }, get: function (obj) { return obj.updatePublicStreamParam; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startPlayPublicStream_decorators, { kind: "method", name: "startPlayPublicStream", static: false, private: false, access: { has: function (obj) { return "startPlayPublicStream" in obj; }, get: function (obj) { return obj.startPlayPublicStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopPlayPublicStream_decorators, { kind: "method", name: "stopPlayPublicStream", static: false, private: false, access: { has: function (obj) { return "stopPlayPublicStream" in obj; }, get: function (obj) { return obj.stopPlayPublicStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPublicStreamVideoCanvas_decorators, { kind: "method", name: "setPublicStreamVideoCanvas", static: false, private: false, access: { has: function (obj) { return "setPublicStreamVideoCanvas" in obj; }, get: function (obj) { return obj.setPublicStreamVideoCanvas; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPublicStreamVideoSink_decorators, { kind: "method", name: "setPublicStreamVideoSink", static: false, private: false, access: { has: function (obj) { return "setPublicStreamVideoSink" in obj; }, get: function (obj) { return obj.setPublicStreamVideoSink; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPublicStreamAudioPlaybackVolume_decorators, { kind: "method", name: "setPublicStreamAudioPlaybackVolume", static: false, private: false, access: { has: function (obj) { return "setPublicStreamAudioPlaybackVolume" in obj; }, get: function (obj) { return obj.setPublicStreamAudioPlaybackVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startEchoTest_decorators, { kind: "method", name: "startEchoTest", static: false, private: false, access: { has: function (obj) { return "startEchoTest" in obj; }, get: function (obj) { return obj.startEchoTest; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopEchoTest_decorators, { kind: "method", name: "stopEchoTest", static: false, private: false, access: { has: function (obj) { return "stopEchoTest" in obj; }, get: function (obj) { return obj.stopEchoTest; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoWatermark_decorators, { kind: "method", name: "setVideoWatermark", static: false, private: false, access: { has: function (obj) { return "setVideoWatermark" in obj; }, get: function (obj) { return obj.setVideoWatermark; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _clearVideoWatermark_decorators, { kind: "method", name: "clearVideoWatermark", static: false, private: false, access: { has: function (obj) { return "clearVideoWatermark" in obj; }, get: function (obj) { return obj.clearVideoWatermark; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setDummyCaptureImagePath_decorators, { kind: "method", name: "setDummyCaptureImagePath", static: false, private: false, access: { has: function (obj) { return "setDummyCaptureImagePath" in obj; }, get: function (obj) { return obj.setDummyCaptureImagePath; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _takeLocalSnapshot_decorators, { kind: "method", name: "takeLocalSnapshot", static: false, private: false, access: { has: function (obj) { return "takeLocalSnapshot" in obj; }, get: function (obj) { return obj.takeLocalSnapshot; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _takeRemoteSnapshot_decorators, { kind: "method", name: "takeRemoteSnapshot", static: false, private: false, access: { has: function (obj) { return "takeRemoteSnapshot" in obj; }, get: function (obj) { return obj.takeRemoteSnapshot; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startCloudProxy_decorators, { kind: "method", name: "startCloudProxy", static: false, private: false, access: { has: function (obj) { return "startCloudProxy" in obj; }, get: function (obj) { return obj.startCloudProxy; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopCloudProxy_decorators, { kind: "method", name: "stopCloudProxy", static: false, private: false, access: { has: function (obj) { return "stopCloudProxy" in obj; }, get: function (obj) { return obj.stopCloudProxy; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getSingScoringManager_decorators, { kind: "method", name: "getSingScoringManager", static: false, private: false, access: { has: function (obj) { return "getSingScoringManager" in obj; }, get: function (obj) { return obj.getSingScoringManager; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getNetworkTimeInfo_decorators, { kind: "method", name: "getNetworkTimeInfo", static: false, private: false, access: { has: function (obj) { return "getNetworkTimeInfo" in obj; }, get: function (obj) { return obj.getNetworkTimeInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getKTVManager_decorators, { kind: "method", name: "getKTVManager", static: false, private: false, access: { has: function (obj) { return "getKTVManager" in obj; }, get: function (obj) { return obj.getKTVManager; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startHardwareEchoDetection_decorators, { kind: "method", name: "startHardwareEchoDetection", static: false, private: false, access: { has: function (obj) { return "startHardwareEchoDetection" in obj; }, get: function (obj) { return obj.startHardwareEchoDetection; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopHardwareEchoDetection_decorators, { kind: "method", name: "stopHardwareEchoDetection", static: false, private: false, access: { has: function (obj) { return "stopHardwareEchoDetection" in obj; }, get: function (obj) { return obj.stopHardwareEchoDetection; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCellularEnhancement_decorators, { kind: "method", name: "setCellularEnhancement", static: false, private: false, access: { has: function (obj) { return "setCellularEnhancement" in obj; }, get: function (obj) { return obj.setCellularEnhancement; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalProxy_decorators, { kind: "method", name: "setLocalProxy", static: false, private: false, access: { has: function (obj) { return "setLocalProxy" in obj; }, get: function (obj) { return obj.setLocalProxy; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getVideoDeviceManager_decorators, { kind: "method", name: "getVideoDeviceManager", static: false, private: false, access: { has: function (obj) { return "getVideoDeviceManager" in obj; }, get: function (obj) { return obj.getVideoDeviceManager; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoCaptureRotation_decorators, { kind: "method", name: "setVideoCaptureRotation", static: false, private: false, access: { has: function (obj) { return "setVideoCaptureRotation" in obj; }, get: function (obj) { return obj.setVideoCaptureRotation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVideoSink_decorators, { kind: "method", name: "setLocalVideoSink", static: false, private: false, access: { has: function (obj) { return "setLocalVideoSink" in obj; }, get: function (obj) { return obj.setLocalVideoSink; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteVideoSink_decorators, { kind: "method", name: "setRemoteVideoSink", static: false, private: false, access: { has: function (obj) { return "setRemoteVideoSink" in obj; }, get: function (obj) { return obj.setRemoteVideoSink; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateRemoteStreamVideoCanvas_streamKey$renderMode$backgroundColor_decorators, { kind: "method", name: "updateRemoteStreamVideoCanvas_streamKey$renderMode$backgroundColor", static: false, private: false, access: { has: function (obj) { return "updateRemoteStreamVideoCanvas_streamKey$renderMode$backgroundColor" in obj; }, get: function (obj) { return obj.updateRemoteStreamVideoCanvas_streamKey$renderMode$backgroundColor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _replaceBackground_decorators, { kind: "method", name: "replaceBackground", static: false, private: false, access: { has: function (obj) { return "replaceBackground" in obj; }, get: function (obj) { return obj.replaceBackground; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioPlaybackDevice_decorators, { kind: "method", name: "setAudioPlaybackDevice", static: false, private: false, access: { has: function (obj) { return "setAudioPlaybackDevice" in obj; }, get: function (obj) { return obj.setAudioPlaybackDevice; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startLiveTranscoding_decorators, { kind: "method", name: "startLiveTranscoding", static: false, private: false, access: { has: function (obj) { return "startLiveTranscoding" in obj; }, get: function (obj) { return obj.startLiveTranscoding; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopLiveTranscoding_decorators, { kind: "method", name: "stopLiveTranscoding", static: false, private: false, access: { has: function (obj) { return "stopLiveTranscoding" in obj; }, get: function (obj) { return obj.stopLiveTranscoding; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateLiveTranscoding_decorators, { kind: "method", name: "updateLiveTranscoding", static: false, private: false, access: { has: function (obj) { return "updateLiveTranscoding" in obj; }, get: function (obj) { return obj.updateLiveTranscoding; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoEncoderConfig_videoStreamDescriptions$orientationMode_decorators, { kind: "method", name: "setVideoEncoderConfig_videoStreamDescriptions$orientationMode", static: false, private: false, access: { has: function (obj) { return "setVideoEncoderConfig_videoStreamDescriptions$orientationMode" in obj; }, get: function (obj) { return obj.setVideoEncoderConfig_videoStreamDescriptions$orientationMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoEncoderConfig_streamIndex$videoStreamDescriptions_decorators, { kind: "method", name: "setVideoEncoderConfig_streamIndex$videoStreamDescriptions", static: false, private: false, access: { has: function (obj) { return "setVideoEncoderConfig_streamIndex$videoStreamDescriptions" in obj; }, get: function (obj) { return obj.setVideoEncoderConfig_streamIndex$videoStreamDescriptions; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setOnDestroyCompletedCallback_decorators, { kind: "method", name: "setOnDestroyCompletedCallback", static: false, private: false, access: { has: function (obj) { return "setOnDestroyCompletedCallback" in obj; }, get: function (obj) { return obj.setOnDestroyCompletedCallback; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendSEIMessage_streamIndex$message$repeatCount_decorators, { kind: "method", name: "sendSEIMessage_streamIndex$message$repeatCount", static: false, private: false, access: { has: function (obj) { return "sendSEIMessage_streamIndex$message$repeatCount" in obj; }, get: function (obj) { return obj.sendSEIMessage_streamIndex$message$repeatCount; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _checkVideoEffectLicense_decorators, { kind: "method", name: "checkVideoEffectLicense", static: false, private: false, access: { has: function (obj) { return "checkVideoEffectLicense" in obj; }, get: function (obj) { return obj.checkVideoEffectLicense; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoEffectAlgoModelPath_decorators, { kind: "method", name: "setVideoEffectAlgoModelPath", static: false, private: false, access: { has: function (obj) { return "setVideoEffectAlgoModelPath" in obj; }, get: function (obj) { return obj.setVideoEffectAlgoModelPath; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableVideoEffect_decorators, { kind: "method", name: "enableVideoEffect", static: false, private: false, access: { has: function (obj) { return "enableVideoEffect" in obj; }, get: function (obj) { return obj.enableVideoEffect; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoEffectNodes_decorators, { kind: "method", name: "setVideoEffectNodes", static: false, private: false, access: { has: function (obj) { return "setVideoEffectNodes" in obj; }, get: function (obj) { return obj.setVideoEffectNodes; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateVideoEffectNode_decorators, { kind: "method", name: "updateVideoEffectNode", static: false, private: false, access: { has: function (obj) { return "updateVideoEffectNode" in obj; }, get: function (obj) { return obj.updateVideoEffectNode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBackgroundSticker_decorators, { kind: "method", name: "setBackgroundSticker", static: false, private: false, access: { has: function (obj) { return "setBackgroundSticker" in obj; }, get: function (obj) { return obj.setBackgroundSticker; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoEffectColorFilter_decorators, { kind: "method", name: "setVideoEffectColorFilter", static: false, private: false, access: { has: function (obj) { return "setVideoEffectColorFilter" in obj; }, get: function (obj) { return obj.setVideoEffectColorFilter; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoEffectColorFilterIntensity_decorators, { kind: "method", name: "setVideoEffectColorFilterIntensity", static: false, private: false, access: { has: function (obj) { return "setVideoEffectColorFilterIntensity" in obj; }, get: function (obj) { return obj.setVideoEffectColorFilterIntensity; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerFaceDetectionObserver_decorators, { kind: "method", name: "registerFaceDetectionObserver", static: false, private: false, access: { has: function (obj) { return "registerFaceDetectionObserver" in obj; }, get: function (obj) { return obj.registerFaceDetectionObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioMixingManager_decorators, { kind: "method", name: "getAudioMixingManager", static: false, private: false, access: { has: function (obj) { return "getAudioMixingManager" in obj; }, get: function (obj) { return obj.getAudioMixingManager; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _muteAudioPlayback_decorators, { kind: "method", name: "muteAudioPlayback", static: false, private: false, access: { has: function (obj) { return "muteAudioPlayback" in obj; }, get: function (obj) { return obj.muteAudioPlayback; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _static_mInstance_decorators, { kind: "field", name: "mInstance", static: true, private: false, access: { has: function (obj) { return "mInstance" in obj; }, get: function (obj) { return obj.mInstance; }, set: function (obj, value) { obj.mInstance = value; } }, metadata: _metadata }, _static_mInstance_initializers, _static_mInstance_extraInitializers);
        __esDecorate(null, null, _static_mInstanceEx_decorators, { kind: "field", name: "mInstanceEx", static: true, private: false, access: { has: function (obj) { return "mInstanceEx" in obj; }, get: function (obj) { return obj.mInstanceEx; }, set: function (obj, value) { obj.mInstanceEx = value; } }, metadata: _metadata }, _static_mInstanceEx_initializers, _static_mInstanceEx_extraInitializers);
        __esDecorate(null, null, _static_mRtcNativeLibraryLoader_decorators, { kind: "field", name: "mRtcNativeLibraryLoader", static: true, private: false, access: { has: function (obj) { return "mRtcNativeLibraryLoader" in obj; }, get: function (obj) { return obj.mRtcNativeLibraryLoader; }, set: function (obj, value) { obj.mRtcNativeLibraryLoader = value; } }, metadata: _metadata }, _static_mRtcNativeLibraryLoader_initializers, _static_mRtcNativeLibraryLoader_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        RTCVideo = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
    })();
    _classThis.mInstance = (__runInitializers(_classThis, _staticExtraInitializers), __runInitializers(_classThis, _static_mInstance_initializers, void 0));
    _classThis.mInstanceEx = (__runInitializers(_classThis, _static_mInstance_extraInitializers), __runInitializers(_classThis, _static_mInstanceEx_initializers, void 0));
    _classThis.mRtcNativeLibraryLoader = (__runInitializers(_classThis, _static_mInstanceEx_extraInitializers), __runInitializers(_classThis, _static_mRtcNativeLibraryLoader_initializers, void 0));
    _classThis.TAG = (__runInitializers(_classThis, _static_mRtcNativeLibraryLoader_extraInitializers), 'RtcVideo');
    (function () {
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return RTCVideo = _classThis;
}();
var RTCRoom$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.RTCRoom')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _destroy_decorators;
    var _joinRoom_decorators;
    var _setRTCRoomEventHandler_decorators;
    var _leaveRoom_decorators;
    var _setUserVisibility_decorators;
    var _updateToken_decorators;
    var _sendUserMessage_decorators;
    var _sendUserBinaryMessage_decorators;
    var _sendRoomMessage_decorators;
    var _sendRoomBinaryMessage_decorators;
    var _setMultiDeviceAVSync_decorators;
    var _setRemoteVideoConfig_decorators;
    var _publishStream_decorators;
    var _unpublishStream_decorators;
    var _publishScreen_decorators;
    var _unpublishScreen_decorators;
    var _subscribeStream_decorators;
    var _subscribeAllStreams_decorators;
    var _unsubscribeStream_decorators;
    var _unsubscribeAllStreams_decorators;
    var _subscribeScreen_decorators;
    var _unsubscribeScreen_decorators;
    var _pauseAllSubscribedStream_decorators;
    var _resumeAllSubscribedStream_decorators;
    var _startForwardStreamToRooms_decorators;
    var _updateForwardStreamToRooms_decorators;
    var _stopForwardStreamToRooms_decorators;
    var _pauseForwardStreamToAllRooms_decorators;
    var _resumeForwardStreamToAllRooms_decorators;
    var _getRangeAudio_decorators;
    var _getSpatialAudio_decorators;
    var _setRemoteRoomAudioPlaybackVolume_decorators;
    var _setAudioSelectionConfig_decorators;
    var _setRoomExtraInfo_decorators;
    var _startSubtitle_decorators;
    var _stopSubtitle_decorators;
    var _getRoomId_decorators;
    var _subscribeUserStream_decorators;
    _classThis = /** @class */ (function () {
        function RTCRoom_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        RTCRoom_1.prototype.destroy = function () {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.joinRoom = function (token, userInfo, roomConfig) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.setRTCRoomEventHandler = function (rtcRoomEventHandler) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.leaveRoom = function () {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.setUserVisibility = function (enable) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.updateToken = function (token) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.sendUserMessage = function (userId, messageStr, config) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.sendUserBinaryMessage = function (userId, buffer, config) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.sendRoomMessage = function (messageStr) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.sendRoomBinaryMessage = function (buffer) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.setMultiDeviceAVSync = function (audioUserId) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.setRemoteVideoConfig = function (userId, remoteVideoConfig) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.publishStream = function (type) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.unpublishStream = function (type) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.publishScreen = function (type) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.unpublishScreen = function (type) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.subscribeStream = function (uid, type) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.subscribeAllStreams = function (type) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.unsubscribeStream = function (uid, type) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.unsubscribeAllStreams = function (type) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.subscribeScreen = function (uid, type) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.unsubscribeScreen = function (uid, type) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.pauseAllSubscribedStream = function (mediaType) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.resumeAllSubscribedStream = function (mediaType) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.startForwardStreamToRooms = function (forwardStreamInfos) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.updateForwardStreamToRooms = function (forwardStreamInfos) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.stopForwardStreamToRooms = function () {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.pauseForwardStreamToAllRooms = function () {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.resumeForwardStreamToAllRooms = function () {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.getRangeAudio = function () {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.getSpatialAudio = function () {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.setRemoteRoomAudioPlaybackVolume = function (volume) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.setAudioSelectionConfig = function (audioSelectionPriority) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.setRoomExtraInfo = function (key, value) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.startSubtitle = function (subtitleConfig) {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.stopSubtitle = function () {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.getRoomId = function () {
            throw new Error('not implement');
        };
        RTCRoom_1.prototype.subscribeUserStream = function (uid, streamType, mediaType, subscribeVideoConfig) {
            throw new Error('not implement');
        };
        return RTCRoom_1;
    }());
    __setFunctionName(_classThis, "RTCRoom");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _destroy_decorators = [NativeMethodSync()];
        _joinRoom_decorators = [NativeMethodSync()];
        _setRTCRoomEventHandler_decorators = [NativeMethodSync()];
        _leaveRoom_decorators = [NativeMethodSync()];
        _setUserVisibility_decorators = [NativeMethodSync()];
        _updateToken_decorators = [NativeMethodSync()];
        _sendUserMessage_decorators = [NativeMethodSync()];
        _sendUserBinaryMessage_decorators = [NativeMethodSync()];
        _sendRoomMessage_decorators = [NativeMethodSync()];
        _sendRoomBinaryMessage_decorators = [NativeMethodSync()];
        _setMultiDeviceAVSync_decorators = [NativeMethodSync()];
        _setRemoteVideoConfig_decorators = [NativeMethodSync()];
        _publishStream_decorators = [NativeMethodSync()];
        _unpublishStream_decorators = [NativeMethodSync()];
        _publishScreen_decorators = [NativeMethodSync()];
        _unpublishScreen_decorators = [NativeMethodSync()];
        _subscribeStream_decorators = [NativeMethodSync()];
        _subscribeAllStreams_decorators = [NativeMethodSync()];
        _unsubscribeStream_decorators = [NativeMethodSync()];
        _unsubscribeAllStreams_decorators = [NativeMethodSync()];
        _subscribeScreen_decorators = [NativeMethodSync()];
        _unsubscribeScreen_decorators = [NativeMethodSync()];
        _pauseAllSubscribedStream_decorators = [NativeMethodSync()];
        _resumeAllSubscribedStream_decorators = [NativeMethodSync()];
        _startForwardStreamToRooms_decorators = [NativeMethodSync()];
        _updateForwardStreamToRooms_decorators = [NativeMethodSync()];
        _stopForwardStreamToRooms_decorators = [NativeMethodSync()];
        _pauseForwardStreamToAllRooms_decorators = [NativeMethodSync()];
        _resumeForwardStreamToAllRooms_decorators = [NativeMethodSync()];
        _getRangeAudio_decorators = [ReturnClass(function () { return IRangeAudio$1; }), NativeMethodSync()];
        _getSpatialAudio_decorators = [ReturnClass(function () { return ISpatialAudio$1; }), NativeMethodSync()];
        _setRemoteRoomAudioPlaybackVolume_decorators = [NativeMethodSync()];
        _setAudioSelectionConfig_decorators = [NativeMethodSync()];
        _setRoomExtraInfo_decorators = [NativeMethodSync()];
        _startSubtitle_decorators = [NativeMethodSync()];
        _stopSubtitle_decorators = [NativeMethodSync()];
        _getRoomId_decorators = [NativeMethodSync()];
        _subscribeUserStream_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _destroy_decorators, { kind: "method", name: "destroy", static: false, private: false, access: { has: function (obj) { return "destroy" in obj; }, get: function (obj) { return obj.destroy; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _joinRoom_decorators, { kind: "method", name: "joinRoom", static: false, private: false, access: { has: function (obj) { return "joinRoom" in obj; }, get: function (obj) { return obj.joinRoom; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRTCRoomEventHandler_decorators, { kind: "method", name: "setRTCRoomEventHandler", static: false, private: false, access: { has: function (obj) { return "setRTCRoomEventHandler" in obj; }, get: function (obj) { return obj.setRTCRoomEventHandler; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _leaveRoom_decorators, { kind: "method", name: "leaveRoom", static: false, private: false, access: { has: function (obj) { return "leaveRoom" in obj; }, get: function (obj) { return obj.leaveRoom; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setUserVisibility_decorators, { kind: "method", name: "setUserVisibility", static: false, private: false, access: { has: function (obj) { return "setUserVisibility" in obj; }, get: function (obj) { return obj.setUserVisibility; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateToken_decorators, { kind: "method", name: "updateToken", static: false, private: false, access: { has: function (obj) { return "updateToken" in obj; }, get: function (obj) { return obj.updateToken; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendUserMessage_decorators, { kind: "method", name: "sendUserMessage", static: false, private: false, access: { has: function (obj) { return "sendUserMessage" in obj; }, get: function (obj) { return obj.sendUserMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendUserBinaryMessage_decorators, { kind: "method", name: "sendUserBinaryMessage", static: false, private: false, access: { has: function (obj) { return "sendUserBinaryMessage" in obj; }, get: function (obj) { return obj.sendUserBinaryMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendRoomMessage_decorators, { kind: "method", name: "sendRoomMessage", static: false, private: false, access: { has: function (obj) { return "sendRoomMessage" in obj; }, get: function (obj) { return obj.sendRoomMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendRoomBinaryMessage_decorators, { kind: "method", name: "sendRoomBinaryMessage", static: false, private: false, access: { has: function (obj) { return "sendRoomBinaryMessage" in obj; }, get: function (obj) { return obj.sendRoomBinaryMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setMultiDeviceAVSync_decorators, { kind: "method", name: "setMultiDeviceAVSync", static: false, private: false, access: { has: function (obj) { return "setMultiDeviceAVSync" in obj; }, get: function (obj) { return obj.setMultiDeviceAVSync; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteVideoConfig_decorators, { kind: "method", name: "setRemoteVideoConfig", static: false, private: false, access: { has: function (obj) { return "setRemoteVideoConfig" in obj; }, get: function (obj) { return obj.setRemoteVideoConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _publishStream_decorators, { kind: "method", name: "publishStream", static: false, private: false, access: { has: function (obj) { return "publishStream" in obj; }, get: function (obj) { return obj.publishStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unpublishStream_decorators, { kind: "method", name: "unpublishStream", static: false, private: false, access: { has: function (obj) { return "unpublishStream" in obj; }, get: function (obj) { return obj.unpublishStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _publishScreen_decorators, { kind: "method", name: "publishScreen", static: false, private: false, access: { has: function (obj) { return "publishScreen" in obj; }, get: function (obj) { return obj.publishScreen; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unpublishScreen_decorators, { kind: "method", name: "unpublishScreen", static: false, private: false, access: { has: function (obj) { return "unpublishScreen" in obj; }, get: function (obj) { return obj.unpublishScreen; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _subscribeStream_decorators, { kind: "method", name: "subscribeStream", static: false, private: false, access: { has: function (obj) { return "subscribeStream" in obj; }, get: function (obj) { return obj.subscribeStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _subscribeAllStreams_decorators, { kind: "method", name: "subscribeAllStreams", static: false, private: false, access: { has: function (obj) { return "subscribeAllStreams" in obj; }, get: function (obj) { return obj.subscribeAllStreams; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unsubscribeStream_decorators, { kind: "method", name: "unsubscribeStream", static: false, private: false, access: { has: function (obj) { return "unsubscribeStream" in obj; }, get: function (obj) { return obj.unsubscribeStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unsubscribeAllStreams_decorators, { kind: "method", name: "unsubscribeAllStreams", static: false, private: false, access: { has: function (obj) { return "unsubscribeAllStreams" in obj; }, get: function (obj) { return obj.unsubscribeAllStreams; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _subscribeScreen_decorators, { kind: "method", name: "subscribeScreen", static: false, private: false, access: { has: function (obj) { return "subscribeScreen" in obj; }, get: function (obj) { return obj.subscribeScreen; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unsubscribeScreen_decorators, { kind: "method", name: "unsubscribeScreen", static: false, private: false, access: { has: function (obj) { return "unsubscribeScreen" in obj; }, get: function (obj) { return obj.unsubscribeScreen; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pauseAllSubscribedStream_decorators, { kind: "method", name: "pauseAllSubscribedStream", static: false, private: false, access: { has: function (obj) { return "pauseAllSubscribedStream" in obj; }, get: function (obj) { return obj.pauseAllSubscribedStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resumeAllSubscribedStream_decorators, { kind: "method", name: "resumeAllSubscribedStream", static: false, private: false, access: { has: function (obj) { return "resumeAllSubscribedStream" in obj; }, get: function (obj) { return obj.resumeAllSubscribedStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startForwardStreamToRooms_decorators, { kind: "method", name: "startForwardStreamToRooms", static: false, private: false, access: { has: function (obj) { return "startForwardStreamToRooms" in obj; }, get: function (obj) { return obj.startForwardStreamToRooms; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateForwardStreamToRooms_decorators, { kind: "method", name: "updateForwardStreamToRooms", static: false, private: false, access: { has: function (obj) { return "updateForwardStreamToRooms" in obj; }, get: function (obj) { return obj.updateForwardStreamToRooms; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopForwardStreamToRooms_decorators, { kind: "method", name: "stopForwardStreamToRooms", static: false, private: false, access: { has: function (obj) { return "stopForwardStreamToRooms" in obj; }, get: function (obj) { return obj.stopForwardStreamToRooms; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pauseForwardStreamToAllRooms_decorators, { kind: "method", name: "pauseForwardStreamToAllRooms", static: false, private: false, access: { has: function (obj) { return "pauseForwardStreamToAllRooms" in obj; }, get: function (obj) { return obj.pauseForwardStreamToAllRooms; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resumeForwardStreamToAllRooms_decorators, { kind: "method", name: "resumeForwardStreamToAllRooms", static: false, private: false, access: { has: function (obj) { return "resumeForwardStreamToAllRooms" in obj; }, get: function (obj) { return obj.resumeForwardStreamToAllRooms; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getRangeAudio_decorators, { kind: "method", name: "getRangeAudio", static: false, private: false, access: { has: function (obj) { return "getRangeAudio" in obj; }, get: function (obj) { return obj.getRangeAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getSpatialAudio_decorators, { kind: "method", name: "getSpatialAudio", static: false, private: false, access: { has: function (obj) { return "getSpatialAudio" in obj; }, get: function (obj) { return obj.getSpatialAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteRoomAudioPlaybackVolume_decorators, { kind: "method", name: "setRemoteRoomAudioPlaybackVolume", static: false, private: false, access: { has: function (obj) { return "setRemoteRoomAudioPlaybackVolume" in obj; }, get: function (obj) { return obj.setRemoteRoomAudioPlaybackVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioSelectionConfig_decorators, { kind: "method", name: "setAudioSelectionConfig", static: false, private: false, access: { has: function (obj) { return "setAudioSelectionConfig" in obj; }, get: function (obj) { return obj.setAudioSelectionConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRoomExtraInfo_decorators, { kind: "method", name: "setRoomExtraInfo", static: false, private: false, access: { has: function (obj) { return "setRoomExtraInfo" in obj; }, get: function (obj) { return obj.setRoomExtraInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startSubtitle_decorators, { kind: "method", name: "startSubtitle", static: false, private: false, access: { has: function (obj) { return "startSubtitle" in obj; }, get: function (obj) { return obj.startSubtitle; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopSubtitle_decorators, { kind: "method", name: "stopSubtitle", static: false, private: false, access: { has: function (obj) { return "stopSubtitle" in obj; }, get: function (obj) { return obj.stopSubtitle; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getRoomId_decorators, { kind: "method", name: "getRoomId", static: false, private: false, access: { has: function (obj) { return "getRoomId" in obj; }, get: function (obj) { return obj.getRoomId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _subscribeUserStream_decorators, { kind: "method", name: "subscribeUserStream", static: false, private: false, access: { has: function (obj) { return "subscribeUserStream" in obj; }, get: function (obj) { return obj.subscribeUserStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.video.IVideoProcessor')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _processVideoFrame_decorators;
    var _onGLEnvInitiated_decorators;
    var _onGLEnvRelease_decorators;
    _classThis = /** @class */ (function () {
        function IVideoProcessor_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        IVideoProcessor_1.prototype.processVideoFrame = function (frame) {
            throw new Error('not implement');
        };
        IVideoProcessor_1.prototype.onGLEnvInitiated = function () {
            throw new Error('not implement');
        };
        IVideoProcessor_1.prototype.onGLEnvRelease = function () {
            throw new Error('not implement');
        };
        return IVideoProcessor_1;
    }());
    __setFunctionName(_classThis, "IVideoProcessor");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _processVideoFrame_decorators = [ReturnClass(function () { return VideoFrame$1; }), NativeMethodSync()];
        _onGLEnvInitiated_decorators = [NativeMethodSync()];
        _onGLEnvRelease_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _processVideoFrame_decorators, { kind: "method", name: "processVideoFrame", static: false, private: false, access: { has: function (obj) { return "processVideoFrame" in obj; }, get: function (obj) { return obj.processVideoFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _onGLEnvInitiated_decorators, { kind: "method", name: "onGLEnvInitiated", static: false, private: false, access: { has: function (obj) { return "onGLEnvInitiated" in obj; }, get: function (obj) { return obj.onGLEnvInitiated; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _onGLEnvRelease_decorators, { kind: "method", name: "onGLEnvRelease", static: false, private: false, access: { has: function (obj) { return "onGLEnvRelease" in obj; }, get: function (obj) { return obj.onGLEnvRelease; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ISingScoringManager$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.audio.ISingScoringManager')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _initSingScoring_decorators;
    var _setSingScoringConfig_decorators;
    var _getStandardPitchInfo_decorators;
    var _startSingScoring_decorators;
    var _stopSingScoring_decorators;
    var _getLastSentenceScore_decorators;
    var _getTotalScore_decorators;
    var _getAverageScore_decorators;
    _classThis = /** @class */ (function () {
        function ISingScoringManager_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        ISingScoringManager_1.prototype.initSingScoring = function (singScoringAppkey, singAcoringToken, handler) {
            throw new Error('not implement');
        };
        ISingScoringManager_1.prototype.setSingScoringConfig = function (config) {
            throw new Error('not implement');
        };
        ISingScoringManager_1.prototype.getStandardPitchInfo = function (midiFilepath) {
            throw new Error('not implement');
        };
        ISingScoringManager_1.prototype.startSingScoring = function (position, scoringInfoInterval) {
            throw new Error('not implement');
        };
        ISingScoringManager_1.prototype.stopSingScoring = function () {
            throw new Error('not implement');
        };
        ISingScoringManager_1.prototype.getLastSentenceScore = function () {
            throw new Error('not implement');
        };
        ISingScoringManager_1.prototype.getTotalScore = function () {
            throw new Error('not implement');
        };
        ISingScoringManager_1.prototype.getAverageScore = function () {
            throw new Error('not implement');
        };
        return ISingScoringManager_1;
    }());
    __setFunctionName(_classThis, "ISingScoringManager");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _initSingScoring_decorators = [NativeMethodSync()];
        _setSingScoringConfig_decorators = [NativeMethodSync()];
        _getStandardPitchInfo_decorators = [NativeMethodSync()];
        _startSingScoring_decorators = [NativeMethodSync()];
        _stopSingScoring_decorators = [NativeMethodSync()];
        _getLastSentenceScore_decorators = [NativeMethodSync()];
        _getTotalScore_decorators = [NativeMethodSync()];
        _getAverageScore_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _initSingScoring_decorators, { kind: "method", name: "initSingScoring", static: false, private: false, access: { has: function (obj) { return "initSingScoring" in obj; }, get: function (obj) { return obj.initSingScoring; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setSingScoringConfig_decorators, { kind: "method", name: "setSingScoringConfig", static: false, private: false, access: { has: function (obj) { return "setSingScoringConfig" in obj; }, get: function (obj) { return obj.setSingScoringConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getStandardPitchInfo_decorators, { kind: "method", name: "getStandardPitchInfo", static: false, private: false, access: { has: function (obj) { return "getStandardPitchInfo" in obj; }, get: function (obj) { return obj.getStandardPitchInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startSingScoring_decorators, { kind: "method", name: "startSingScoring", static: false, private: false, access: { has: function (obj) { return "startSingScoring" in obj; }, get: function (obj) { return obj.startSingScoring; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopSingScoring_decorators, { kind: "method", name: "stopSingScoring", static: false, private: false, access: { has: function (obj) { return "stopSingScoring" in obj; }, get: function (obj) { return obj.stopSingScoring; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getLastSentenceScore_decorators, { kind: "method", name: "getLastSentenceScore", static: false, private: false, access: { has: function (obj) { return "getLastSentenceScore" in obj; }, get: function (obj) { return obj.getLastSentenceScore; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getTotalScore_decorators, { kind: "method", name: "getTotalScore", static: false, private: false, access: { has: function (obj) { return "getTotalScore" in obj; }, get: function (obj) { return obj.getTotalScore; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAverageScore_decorators, { kind: "method", name: "getAverageScore", static: false, private: false, access: { has: function (obj) { return "getAverageScore" in obj; }, get: function (obj) { return obj.getAverageScore; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IKTVManager$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.ktv.IKTVManager')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _setKTVManagerEventHandler_decorators;
    var _setMaxCacheSize_decorators;
    var _getMusicList_decorators;
    var _searchMusic_decorators;
    var _getHotMusic_decorators;
    var _getMusicDetail_decorators;
    var _downloadMusic_decorators;
    var _downloadLyric_decorators;
    var _downloadMidi_decorators;
    var _cancelDownload_decorators;
    var _clearCache_decorators;
    var _getKTVPlayer_decorators;
    _classThis = /** @class */ (function () {
        function IKTVManager_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        IKTVManager_1.prototype.setKTVManagerEventHandler = function (ktvManagerEventHandler) {
            throw new Error('not implement');
        };
        IKTVManager_1.prototype.setMaxCacheSize = function (maxCacheSizeMB) {
            throw new Error('not implement');
        };
        IKTVManager_1.prototype.getMusicList = function (pageNum, pageSize, filters) {
            throw new Error('not implement');
        };
        IKTVManager_1.prototype.searchMusic = function (keyWord, pageNum, pageSize, filters) {
            throw new Error('not implement');
        };
        IKTVManager_1.prototype.getHotMusic = function (hotTypes, filters) {
            throw new Error('not implement');
        };
        IKTVManager_1.prototype.getMusicDetail = function (musicId) {
            throw new Error('not implement');
        };
        IKTVManager_1.prototype.downloadMusic = function (musicId) {
            throw new Error('not implement');
        };
        IKTVManager_1.prototype.downloadLyric = function (musicId, lyricType) {
            throw new Error('not implement');
        };
        IKTVManager_1.prototype.downloadMidi = function (musicId) {
            throw new Error('not implement');
        };
        IKTVManager_1.prototype.cancelDownload = function (downloadId) {
            throw new Error('not implement');
        };
        IKTVManager_1.prototype.clearCache = function () {
            throw new Error('not implement');
        };
        IKTVManager_1.prototype.getKTVPlayer = function () {
            throw new Error('not implement');
        };
        return IKTVManager_1;
    }());
    __setFunctionName(_classThis, "IKTVManager");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _setKTVManagerEventHandler_decorators = [NativeMethodSync()];
        _setMaxCacheSize_decorators = [NativeMethodSync()];
        _getMusicList_decorators = [NativeMethodSync()];
        _searchMusic_decorators = [NativeMethodSync()];
        _getHotMusic_decorators = [NativeMethodSync()];
        _getMusicDetail_decorators = [NativeMethodSync()];
        _downloadMusic_decorators = [NativeMethodSync()];
        _downloadLyric_decorators = [NativeMethodSync()];
        _downloadMidi_decorators = [NativeMethodSync()];
        _cancelDownload_decorators = [NativeMethodSync()];
        _clearCache_decorators = [NativeMethodSync()];
        _getKTVPlayer_decorators = [ReturnClass(function () { return IKTVPlayer$1; }), NativeMethodSync()];
        __esDecorate(_classThis, null, _setKTVManagerEventHandler_decorators, { kind: "method", name: "setKTVManagerEventHandler", static: false, private: false, access: { has: function (obj) { return "setKTVManagerEventHandler" in obj; }, get: function (obj) { return obj.setKTVManagerEventHandler; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setMaxCacheSize_decorators, { kind: "method", name: "setMaxCacheSize", static: false, private: false, access: { has: function (obj) { return "setMaxCacheSize" in obj; }, get: function (obj) { return obj.setMaxCacheSize; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getMusicList_decorators, { kind: "method", name: "getMusicList", static: false, private: false, access: { has: function (obj) { return "getMusicList" in obj; }, get: function (obj) { return obj.getMusicList; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _searchMusic_decorators, { kind: "method", name: "searchMusic", static: false, private: false, access: { has: function (obj) { return "searchMusic" in obj; }, get: function (obj) { return obj.searchMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getHotMusic_decorators, { kind: "method", name: "getHotMusic", static: false, private: false, access: { has: function (obj) { return "getHotMusic" in obj; }, get: function (obj) { return obj.getHotMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getMusicDetail_decorators, { kind: "method", name: "getMusicDetail", static: false, private: false, access: { has: function (obj) { return "getMusicDetail" in obj; }, get: function (obj) { return obj.getMusicDetail; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _downloadMusic_decorators, { kind: "method", name: "downloadMusic", static: false, private: false, access: { has: function (obj) { return "downloadMusic" in obj; }, get: function (obj) { return obj.downloadMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _downloadLyric_decorators, { kind: "method", name: "downloadLyric", static: false, private: false, access: { has: function (obj) { return "downloadLyric" in obj; }, get: function (obj) { return obj.downloadLyric; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _downloadMidi_decorators, { kind: "method", name: "downloadMidi", static: false, private: false, access: { has: function (obj) { return "downloadMidi" in obj; }, get: function (obj) { return obj.downloadMidi; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _cancelDownload_decorators, { kind: "method", name: "cancelDownload", static: false, private: false, access: { has: function (obj) { return "cancelDownload" in obj; }, get: function (obj) { return obj.cancelDownload; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _clearCache_decorators, { kind: "method", name: "clearCache", static: false, private: false, access: { has: function (obj) { return "clearCache" in obj; }, get: function (obj) { return obj.clearCache; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getKTVPlayer_decorators, { kind: "method", name: "getKTVPlayer", static: false, private: false, access: { has: function (obj) { return "getKTVPlayer" in obj; }, get: function (obj) { return obj.getKTVPlayer; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IRangeAudio$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.audio.IRangeAudio')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _enableRangeAudio_decorators;
    var _updatePosition_decorators;
    var _updateReceiveRange_decorators;
    var _setAttenuationModel_decorators;
    var _setNoAttenuationFlags_decorators;
    _classThis = /** @class */ (function () {
        function IRangeAudio_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        IRangeAudio_1.prototype.enableRangeAudio = function (enable) {
            throw new Error('not implement');
        };
        IRangeAudio_1.prototype.updatePosition = function (pos) {
            throw new Error('not implement');
        };
        IRangeAudio_1.prototype.updateReceiveRange = function (range) {
            throw new Error('not implement');
        };
        IRangeAudio_1.prototype.setAttenuationModel = function (type, coefficient) {
            throw new Error('not implement');
        };
        IRangeAudio_1.prototype.setNoAttenuationFlags = function (flags) {
            throw new Error('not implement');
        };
        return IRangeAudio_1;
    }());
    __setFunctionName(_classThis, "IRangeAudio");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enableRangeAudio_decorators = [NativeMethodSync()];
        _updatePosition_decorators = [NativeMethodSync()];
        _updateReceiveRange_decorators = [NativeMethodSync()];
        _setAttenuationModel_decorators = [NativeMethodSync()];
        _setNoAttenuationFlags_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _enableRangeAudio_decorators, { kind: "method", name: "enableRangeAudio", static: false, private: false, access: { has: function (obj) { return "enableRangeAudio" in obj; }, get: function (obj) { return obj.enableRangeAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updatePosition_decorators, { kind: "method", name: "updatePosition", static: false, private: false, access: { has: function (obj) { return "updatePosition" in obj; }, get: function (obj) { return obj.updatePosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateReceiveRange_decorators, { kind: "method", name: "updateReceiveRange", static: false, private: false, access: { has: function (obj) { return "updateReceiveRange" in obj; }, get: function (obj) { return obj.updateReceiveRange; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAttenuationModel_decorators, { kind: "method", name: "setAttenuationModel", static: false, private: false, access: { has: function (obj) { return "setAttenuationModel" in obj; }, get: function (obj) { return obj.setAttenuationModel; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setNoAttenuationFlags_decorators, { kind: "method", name: "setNoAttenuationFlags", static: false, private: false, access: { has: function (obj) { return "setNoAttenuationFlags" in obj; }, get: function (obj) { return obj.setNoAttenuationFlags; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IAudioMixingManager$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.audio.IAudioMixingManager')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _startAudioMixing_decorators;
    var _stopAudioMixing_decorators;
    var _stopAllAudioMixing_decorators;
    var _pauseAudioMixing_decorators;
    var _pauseAllAudioMixing_decorators;
    var _resumeAudioMixing_decorators;
    var _resumeAllAudioMixing_decorators;
    var _preloadAudioMixing_decorators;
    var _unloadAudioMixing_decorators;
    var _setAllAudioMixingVolume_decorators;
    var _setAudioMixingVolume_decorators;
    var _getAudioMixingDuration_decorators;
    var _getAudioMixingCurrentPosition_decorators;
    var _setAudioMixingPosition_decorators;
    var _getAudioMixingPlaybackDuration_decorators;
    var _setAudioMixingDualMonoMode_decorators;
    var _setAudioMixingPitch_decorators;
    var _setAudioMixingPlaybackSpeed_decorators;
    var _setAudioMixingLoudness_decorators;
    var _setAudioMixingProgressInterval_decorators;
    var _enableAudioMixingFrame_decorators;
    var _disableAudioMixingFrame_decorators;
    var _pushAudioMixingFrame_decorators;
    var _getAudioTrackCount_decorators;
    var _selectAudioTrack_decorators;
    var _registerAudioFileFrameObserver_decorators;
    _classThis = /** @class */ (function () {
        function IAudioMixingManager_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        IAudioMixingManager_1.prototype.startAudioMixing = function (mixId, filePath, config) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.stopAudioMixing = function (mixId) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.stopAllAudioMixing = function () {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.pauseAudioMixing = function (mixId) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.pauseAllAudioMixing = function () {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.resumeAudioMixing = function (mixId) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.resumeAllAudioMixing = function () {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.preloadAudioMixing = function (mixId, filePath) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.unloadAudioMixing = function (mixId) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.setAllAudioMixingVolume = function (volume, type) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.setAudioMixingVolume = function (mixId, volume, type) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.getAudioMixingDuration = function (mixId) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.getAudioMixingCurrentPosition = function (mixId) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.setAudioMixingPosition = function (mixId, position) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.getAudioMixingPlaybackDuration = function (mixId) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.setAudioMixingDualMonoMode = function (mixId, mode) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.setAudioMixingPitch = function (mixId, pitch) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.setAudioMixingPlaybackSpeed = function (mixId, speed) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.setAudioMixingLoudness = function (mixId, loudness) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.setAudioMixingProgressInterval = function (mixId, interval) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.enableAudioMixingFrame = function (mixId, type) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.disableAudioMixingFrame = function (mixId) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.pushAudioMixingFrame = function (mixId, audioFrame) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.getAudioTrackCount = function (mixId) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.selectAudioTrack = function (mixId, audioTrackIndex) {
            throw new Error('not implement');
        };
        IAudioMixingManager_1.prototype.registerAudioFileFrameObserver = function (observer) {
            throw new Error('not implement');
        };
        return IAudioMixingManager_1;
    }());
    __setFunctionName(_classThis, "IAudioMixingManager");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _startAudioMixing_decorators = [NativeMethodSync()];
        _stopAudioMixing_decorators = [NativeMethodSync()];
        _stopAllAudioMixing_decorators = [NativeMethodSync()];
        _pauseAudioMixing_decorators = [NativeMethodSync()];
        _pauseAllAudioMixing_decorators = [NativeMethodSync()];
        _resumeAudioMixing_decorators = [NativeMethodSync()];
        _resumeAllAudioMixing_decorators = [NativeMethodSync()];
        _preloadAudioMixing_decorators = [NativeMethodSync()];
        _unloadAudioMixing_decorators = [NativeMethodSync()];
        _setAllAudioMixingVolume_decorators = [NativeMethodSync()];
        _setAudioMixingVolume_decorators = [NativeMethodSync()];
        _getAudioMixingDuration_decorators = [NativeMethodSync()];
        _getAudioMixingCurrentPosition_decorators = [NativeMethodSync()];
        _setAudioMixingPosition_decorators = [NativeMethodSync()];
        _getAudioMixingPlaybackDuration_decorators = [NativeMethodSync()];
        _setAudioMixingDualMonoMode_decorators = [NativeMethodSync()];
        _setAudioMixingPitch_decorators = [NativeMethodSync()];
        _setAudioMixingPlaybackSpeed_decorators = [NativeMethodSync()];
        _setAudioMixingLoudness_decorators = [NativeMethodSync()];
        _setAudioMixingProgressInterval_decorators = [NativeMethodSync()];
        _enableAudioMixingFrame_decorators = [NativeMethodSync()];
        _disableAudioMixingFrame_decorators = [NativeMethodSync()];
        _pushAudioMixingFrame_decorators = [NativeMethodSync()];
        _getAudioTrackCount_decorators = [NativeMethodSync()];
        _selectAudioTrack_decorators = [NativeMethodSync()];
        _registerAudioFileFrameObserver_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _startAudioMixing_decorators, { kind: "method", name: "startAudioMixing", static: false, private: false, access: { has: function (obj) { return "startAudioMixing" in obj; }, get: function (obj) { return obj.startAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopAudioMixing_decorators, { kind: "method", name: "stopAudioMixing", static: false, private: false, access: { has: function (obj) { return "stopAudioMixing" in obj; }, get: function (obj) { return obj.stopAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopAllAudioMixing_decorators, { kind: "method", name: "stopAllAudioMixing", static: false, private: false, access: { has: function (obj) { return "stopAllAudioMixing" in obj; }, get: function (obj) { return obj.stopAllAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pauseAudioMixing_decorators, { kind: "method", name: "pauseAudioMixing", static: false, private: false, access: { has: function (obj) { return "pauseAudioMixing" in obj; }, get: function (obj) { return obj.pauseAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pauseAllAudioMixing_decorators, { kind: "method", name: "pauseAllAudioMixing", static: false, private: false, access: { has: function (obj) { return "pauseAllAudioMixing" in obj; }, get: function (obj) { return obj.pauseAllAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resumeAudioMixing_decorators, { kind: "method", name: "resumeAudioMixing", static: false, private: false, access: { has: function (obj) { return "resumeAudioMixing" in obj; }, get: function (obj) { return obj.resumeAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resumeAllAudioMixing_decorators, { kind: "method", name: "resumeAllAudioMixing", static: false, private: false, access: { has: function (obj) { return "resumeAllAudioMixing" in obj; }, get: function (obj) { return obj.resumeAllAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _preloadAudioMixing_decorators, { kind: "method", name: "preloadAudioMixing", static: false, private: false, access: { has: function (obj) { return "preloadAudioMixing" in obj; }, get: function (obj) { return obj.preloadAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unloadAudioMixing_decorators, { kind: "method", name: "unloadAudioMixing", static: false, private: false, access: { has: function (obj) { return "unloadAudioMixing" in obj; }, get: function (obj) { return obj.unloadAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAllAudioMixingVolume_decorators, { kind: "method", name: "setAllAudioMixingVolume", static: false, private: false, access: { has: function (obj) { return "setAllAudioMixingVolume" in obj; }, get: function (obj) { return obj.setAllAudioMixingVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingVolume_decorators, { kind: "method", name: "setAudioMixingVolume", static: false, private: false, access: { has: function (obj) { return "setAudioMixingVolume" in obj; }, get: function (obj) { return obj.setAudioMixingVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioMixingDuration_decorators, { kind: "method", name: "getAudioMixingDuration", static: false, private: false, access: { has: function (obj) { return "getAudioMixingDuration" in obj; }, get: function (obj) { return obj.getAudioMixingDuration; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioMixingCurrentPosition_decorators, { kind: "method", name: "getAudioMixingCurrentPosition", static: false, private: false, access: { has: function (obj) { return "getAudioMixingCurrentPosition" in obj; }, get: function (obj) { return obj.getAudioMixingCurrentPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingPosition_decorators, { kind: "method", name: "setAudioMixingPosition", static: false, private: false, access: { has: function (obj) { return "setAudioMixingPosition" in obj; }, get: function (obj) { return obj.setAudioMixingPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioMixingPlaybackDuration_decorators, { kind: "method", name: "getAudioMixingPlaybackDuration", static: false, private: false, access: { has: function (obj) { return "getAudioMixingPlaybackDuration" in obj; }, get: function (obj) { return obj.getAudioMixingPlaybackDuration; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingDualMonoMode_decorators, { kind: "method", name: "setAudioMixingDualMonoMode", static: false, private: false, access: { has: function (obj) { return "setAudioMixingDualMonoMode" in obj; }, get: function (obj) { return obj.setAudioMixingDualMonoMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingPitch_decorators, { kind: "method", name: "setAudioMixingPitch", static: false, private: false, access: { has: function (obj) { return "setAudioMixingPitch" in obj; }, get: function (obj) { return obj.setAudioMixingPitch; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingPlaybackSpeed_decorators, { kind: "method", name: "setAudioMixingPlaybackSpeed", static: false, private: false, access: { has: function (obj) { return "setAudioMixingPlaybackSpeed" in obj; }, get: function (obj) { return obj.setAudioMixingPlaybackSpeed; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingLoudness_decorators, { kind: "method", name: "setAudioMixingLoudness", static: false, private: false, access: { has: function (obj) { return "setAudioMixingLoudness" in obj; }, get: function (obj) { return obj.setAudioMixingLoudness; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingProgressInterval_decorators, { kind: "method", name: "setAudioMixingProgressInterval", static: false, private: false, access: { has: function (obj) { return "setAudioMixingProgressInterval" in obj; }, get: function (obj) { return obj.setAudioMixingProgressInterval; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableAudioMixingFrame_decorators, { kind: "method", name: "enableAudioMixingFrame", static: false, private: false, access: { has: function (obj) { return "enableAudioMixingFrame" in obj; }, get: function (obj) { return obj.enableAudioMixingFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableAudioMixingFrame_decorators, { kind: "method", name: "disableAudioMixingFrame", static: false, private: false, access: { has: function (obj) { return "disableAudioMixingFrame" in obj; }, get: function (obj) { return obj.disableAudioMixingFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushAudioMixingFrame_decorators, { kind: "method", name: "pushAudioMixingFrame", static: false, private: false, access: { has: function (obj) { return "pushAudioMixingFrame" in obj; }, get: function (obj) { return obj.pushAudioMixingFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioTrackCount_decorators, { kind: "method", name: "getAudioTrackCount", static: false, private: false, access: { has: function (obj) { return "getAudioTrackCount" in obj; }, get: function (obj) { return obj.getAudioTrackCount; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _selectAudioTrack_decorators, { kind: "method", name: "selectAudioTrack", static: false, private: false, access: { has: function (obj) { return "selectAudioTrack" in obj; }, get: function (obj) { return obj.selectAudioTrack; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerAudioFileFrameObserver_decorators, { kind: "method", name: "registerAudioFileFrameObserver", static: false, private: false, access: { has: function (obj) { return "registerAudioFileFrameObserver" in obj; }, get: function (obj) { return obj.registerAudioFileFrameObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IMediaPlayer$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.audio.IMediaPlayer')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _open_decorators;
    var _start_decorators;
    var _openWithCustomSource_decorators;
    var _stop_decorators;
    var _pause_decorators;
    var _resume_decorators;
    var _setVolume_decorators;
    var _getVolume_decorators;
    var _getTotalDuration_decorators;
    var _getPlaybackDuration_decorators;
    var _getPosition_decorators;
    var _setAudioPitch_decorators;
    var _setPosition_decorators;
    var _setAudioDualMonoMode_decorators;
    var _getAudioTrackCount_decorators;
    var _selectAudioTrack_decorators;
    var _setPlaybackSpeed_decorators;
    var _setProgressInterval_decorators;
    var _setLoudness_decorators;
    var _registerAudioFrameObserver_decorators;
    var _pushExternalAudioFrame_decorators;
    var _setEventHandler_decorators;
    _classThis = /** @class */ (function () {
        function IMediaPlayer_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        IMediaPlayer_1.prototype.open = function (filePath, config) {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.start = function () {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.openWithCustomSource = function (source, config) {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.stop = function () {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.pause = function () {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.resume = function () {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.setVolume = function (volume, type) {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.getVolume = function (type) {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.getTotalDuration = function () {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.getPlaybackDuration = function () {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.getPosition = function () {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.setAudioPitch = function (pitch) {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.setPosition = function (position) {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.setAudioDualMonoMode = function (mode) {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.getAudioTrackCount = function () {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.selectAudioTrack = function (index) {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.setPlaybackSpeed = function (speed) {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.setProgressInterval = function (interval) {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.setLoudness = function (loudness) {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.registerAudioFrameObserver = function (observer) {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.pushExternalAudioFrame = function (audioFrame) {
            throw new Error('not implement');
        };
        IMediaPlayer_1.prototype.setEventHandler = function (handler) {
            throw new Error('not implement');
        };
        return IMediaPlayer_1;
    }());
    __setFunctionName(_classThis, "IMediaPlayer");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _open_decorators = [NativeMethodSync()];
        _start_decorators = [NativeMethodSync()];
        _openWithCustomSource_decorators = [NativeMethodSync()];
        _stop_decorators = [NativeMethodSync()];
        _pause_decorators = [NativeMethodSync()];
        _resume_decorators = [NativeMethodSync()];
        _setVolume_decorators = [NativeMethodSync()];
        _getVolume_decorators = [NativeMethodSync()];
        _getTotalDuration_decorators = [NativeMethodSync()];
        _getPlaybackDuration_decorators = [NativeMethodSync()];
        _getPosition_decorators = [NativeMethodSync()];
        _setAudioPitch_decorators = [NativeMethodSync()];
        _setPosition_decorators = [NativeMethodSync()];
        _setAudioDualMonoMode_decorators = [NativeMethodSync()];
        _getAudioTrackCount_decorators = [NativeMethodSync()];
        _selectAudioTrack_decorators = [NativeMethodSync()];
        _setPlaybackSpeed_decorators = [NativeMethodSync()];
        _setProgressInterval_decorators = [NativeMethodSync()];
        _setLoudness_decorators = [NativeMethodSync()];
        _registerAudioFrameObserver_decorators = [NativeMethodSync()];
        _pushExternalAudioFrame_decorators = [NativeMethodSync()];
        _setEventHandler_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _open_decorators, { kind: "method", name: "open", static: false, private: false, access: { has: function (obj) { return "open" in obj; }, get: function (obj) { return obj.open; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _start_decorators, { kind: "method", name: "start", static: false, private: false, access: { has: function (obj) { return "start" in obj; }, get: function (obj) { return obj.start; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _openWithCustomSource_decorators, { kind: "method", name: "openWithCustomSource", static: false, private: false, access: { has: function (obj) { return "openWithCustomSource" in obj; }, get: function (obj) { return obj.openWithCustomSource; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stop_decorators, { kind: "method", name: "stop", static: false, private: false, access: { has: function (obj) { return "stop" in obj; }, get: function (obj) { return obj.stop; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pause_decorators, { kind: "method", name: "pause", static: false, private: false, access: { has: function (obj) { return "pause" in obj; }, get: function (obj) { return obj.pause; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resume_decorators, { kind: "method", name: "resume", static: false, private: false, access: { has: function (obj) { return "resume" in obj; }, get: function (obj) { return obj.resume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVolume_decorators, { kind: "method", name: "setVolume", static: false, private: false, access: { has: function (obj) { return "setVolume" in obj; }, get: function (obj) { return obj.setVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getVolume_decorators, { kind: "method", name: "getVolume", static: false, private: false, access: { has: function (obj) { return "getVolume" in obj; }, get: function (obj) { return obj.getVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getTotalDuration_decorators, { kind: "method", name: "getTotalDuration", static: false, private: false, access: { has: function (obj) { return "getTotalDuration" in obj; }, get: function (obj) { return obj.getTotalDuration; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getPlaybackDuration_decorators, { kind: "method", name: "getPlaybackDuration", static: false, private: false, access: { has: function (obj) { return "getPlaybackDuration" in obj; }, get: function (obj) { return obj.getPlaybackDuration; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getPosition_decorators, { kind: "method", name: "getPosition", static: false, private: false, access: { has: function (obj) { return "getPosition" in obj; }, get: function (obj) { return obj.getPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioPitch_decorators, { kind: "method", name: "setAudioPitch", static: false, private: false, access: { has: function (obj) { return "setAudioPitch" in obj; }, get: function (obj) { return obj.setAudioPitch; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPosition_decorators, { kind: "method", name: "setPosition", static: false, private: false, access: { has: function (obj) { return "setPosition" in obj; }, get: function (obj) { return obj.setPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioDualMonoMode_decorators, { kind: "method", name: "setAudioDualMonoMode", static: false, private: false, access: { has: function (obj) { return "setAudioDualMonoMode" in obj; }, get: function (obj) { return obj.setAudioDualMonoMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioTrackCount_decorators, { kind: "method", name: "getAudioTrackCount", static: false, private: false, access: { has: function (obj) { return "getAudioTrackCount" in obj; }, get: function (obj) { return obj.getAudioTrackCount; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _selectAudioTrack_decorators, { kind: "method", name: "selectAudioTrack", static: false, private: false, access: { has: function (obj) { return "selectAudioTrack" in obj; }, get: function (obj) { return obj.selectAudioTrack; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPlaybackSpeed_decorators, { kind: "method", name: "setPlaybackSpeed", static: false, private: false, access: { has: function (obj) { return "setPlaybackSpeed" in obj; }, get: function (obj) { return obj.setPlaybackSpeed; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setProgressInterval_decorators, { kind: "method", name: "setProgressInterval", static: false, private: false, access: { has: function (obj) { return "setProgressInterval" in obj; }, get: function (obj) { return obj.setProgressInterval; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLoudness_decorators, { kind: "method", name: "setLoudness", static: false, private: false, access: { has: function (obj) { return "setLoudness" in obj; }, get: function (obj) { return obj.setLoudness; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerAudioFrameObserver_decorators, { kind: "method", name: "registerAudioFrameObserver", static: false, private: false, access: { has: function (obj) { return "registerAudioFrameObserver" in obj; }, get: function (obj) { return obj.registerAudioFrameObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushExternalAudioFrame_decorators, { kind: "method", name: "pushExternalAudioFrame", static: false, private: false, access: { has: function (obj) { return "pushExternalAudioFrame" in obj; }, get: function (obj) { return obj.pushExternalAudioFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEventHandler_decorators, { kind: "method", name: "setEventHandler", static: false, private: false, access: { has: function (obj) { return "setEventHandler" in obj; }, get: function (obj) { return obj.setEventHandler; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IAudioEffectPlayer$1 = function () {
    var _classDecorators = [NativeClass('com.ss.bytertc.engine.audio.IAudioEffectPlayer')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _start_decorators;
    var _stop_decorators;
    var _stopAll_decorators;
    var _preload_decorators;
    var _unload_decorators;
    var _unloadAll_decorators;
    var _pause_decorators;
    var _pauseAll_decorators;
    var _resume_decorators;
    var _resumeAll_decorators;
    var _setPosition_decorators;
    var _getPosition_decorators;
    var _setVolume_decorators;
    var _setVolumeAll_decorators;
    var _getVolume_decorators;
    var _getDuration_decorators;
    var _setEventHandler_decorators;
    _classThis = /** @class */ (function () {
        function IAudioEffectPlayer_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        IAudioEffectPlayer_1.prototype.start = function (effectId, filePath, config) {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.stop = function (effectId) {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.stopAll = function () {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.preload = function (effectId, filePath) {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.unload = function (effectId) {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.unloadAll = function () {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.pause = function (effectId) {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.pauseAll = function () {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.resume = function (effectId) {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.resumeAll = function () {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.setPosition = function (effectId, position) {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.getPosition = function (effectId) {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.setVolume = function (effectId, volume) {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.setVolumeAll = function (volume) {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.getVolume = function (effectId) {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.getDuration = function (effectId) {
            throw new Error('not implement');
        };
        IAudioEffectPlayer_1.prototype.setEventHandler = function (handler) {
            throw new Error('not implement');
        };
        return IAudioEffectPlayer_1;
    }());
    __setFunctionName(_classThis, "IAudioEffectPlayer");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _start_decorators = [NativeMethodSync()];
        _stop_decorators = [NativeMethodSync()];
        _stopAll_decorators = [NativeMethodSync()];
        _preload_decorators = [NativeMethodSync()];
        _unload_decorators = [NativeMethodSync()];
        _unloadAll_decorators = [NativeMethodSync()];
        _pause_decorators = [NativeMethodSync()];
        _pauseAll_decorators = [NativeMethodSync()];
        _resume_decorators = [NativeMethodSync()];
        _resumeAll_decorators = [NativeMethodSync()];
        _setPosition_decorators = [NativeMethodSync()];
        _getPosition_decorators = [NativeMethodSync()];
        _setVolume_decorators = [NativeMethodSync()];
        _setVolumeAll_decorators = [NativeMethodSync()];
        _getVolume_decorators = [NativeMethodSync()];
        _getDuration_decorators = [NativeMethodSync()];
        _setEventHandler_decorators = [NativeMethodSync()];
        __esDecorate(_classThis, null, _start_decorators, { kind: "method", name: "start", static: false, private: false, access: { has: function (obj) { return "start" in obj; }, get: function (obj) { return obj.start; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stop_decorators, { kind: "method", name: "stop", static: false, private: false, access: { has: function (obj) { return "stop" in obj; }, get: function (obj) { return obj.stop; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopAll_decorators, { kind: "method", name: "stopAll", static: false, private: false, access: { has: function (obj) { return "stopAll" in obj; }, get: function (obj) { return obj.stopAll; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _preload_decorators, { kind: "method", name: "preload", static: false, private: false, access: { has: function (obj) { return "preload" in obj; }, get: function (obj) { return obj.preload; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unload_decorators, { kind: "method", name: "unload", static: false, private: false, access: { has: function (obj) { return "unload" in obj; }, get: function (obj) { return obj.unload; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unloadAll_decorators, { kind: "method", name: "unloadAll", static: false, private: false, access: { has: function (obj) { return "unloadAll" in obj; }, get: function (obj) { return obj.unloadAll; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pause_decorators, { kind: "method", name: "pause", static: false, private: false, access: { has: function (obj) { return "pause" in obj; }, get: function (obj) { return obj.pause; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pauseAll_decorators, { kind: "method", name: "pauseAll", static: false, private: false, access: { has: function (obj) { return "pauseAll" in obj; }, get: function (obj) { return obj.pauseAll; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resume_decorators, { kind: "method", name: "resume", static: false, private: false, access: { has: function (obj) { return "resume" in obj; }, get: function (obj) { return obj.resume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resumeAll_decorators, { kind: "method", name: "resumeAll", static: false, private: false, access: { has: function (obj) { return "resumeAll" in obj; }, get: function (obj) { return obj.resumeAll; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPosition_decorators, { kind: "method", name: "setPosition", static: false, private: false, access: { has: function (obj) { return "setPosition" in obj; }, get: function (obj) { return obj.setPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getPosition_decorators, { kind: "method", name: "getPosition", static: false, private: false, access: { has: function (obj) { return "getPosition" in obj; }, get: function (obj) { return obj.getPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVolume_decorators, { kind: "method", name: "setVolume", static: false, private: false, access: { has: function (obj) { return "setVolume" in obj; }, get: function (obj) { return obj.setVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVolumeAll_decorators, { kind: "method", name: "setVolumeAll", static: false, private: false, access: { has: function (obj) { return "setVolumeAll" in obj; }, get: function (obj) { return obj.setVolumeAll; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getVolume_decorators, { kind: "method", name: "getVolume", static: false, private: false, access: { has: function (obj) { return "getVolume" in obj; }, get: function (obj) { return obj.getVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getDuration_decorators, { kind: "method", name: "getDuration", static: false, private: false, access: { has: function (obj) { return "getDuration" in obj; }, get: function (obj) { return obj.getDuration; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEventHandler_decorators, { kind: "method", name: "setEventHandler", static: false, private: false, access: { has: function (obj) { return "setEventHandler" in obj; }, get: function (obj) { return obj.setEventHandler; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();

var IRTCRoomEventHandler = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.handler.IRTCRoomEventHandler', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IRTCRoomEventHandler_1() {
        }
        return IRTCRoomEventHandler_1;
    }());
    __setFunctionName(_classThis, "IRTCRoomEventHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.ktv.IKTVPlayerEventHandler', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IKTVPlayerEventHandler_1() {
        }
        return IKTVPlayerEventHandler_1;
    }());
    __setFunctionName(_classThis, "IKTVPlayerEventHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var IAudioEffectPlayerEventHandler = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.IAudioEffectPlayerEventHandler', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IAudioEffectPlayerEventHandler_1() {
        }
        return IAudioEffectPlayerEventHandler_1;
    }());
    __setFunctionName(_classThis, "IAudioEffectPlayerEventHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IPushSingleStreamToCDNObserver = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.live.IPushSingleStreamToCDNObserver', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IPushSingleStreamToCDNObserver_1() {
        }
        return IPushSingleStreamToCDNObserver_1;
    }());
    __setFunctionName(_classThis, "IPushSingleStreamToCDNObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IRemoteEncodedVideoFrameObserver = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.mediaio.IRemoteEncodedVideoFrameObserver', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IRemoteEncodedVideoFrameObserver_1() {
        }
        return IRemoteEncodedVideoFrameObserver_1;
    }());
    __setFunctionName(_classThis, "IRemoteEncodedVideoFrameObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.ktv.IKTVManagerEventHandler', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IKTVManagerEventHandler_1() {
        }
        return IKTVManagerEventHandler_1;
    }());
    __setFunctionName(_classThis, "IKTVManagerEventHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
(function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.ISingScoringEventHandler', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ISingScoringEventHandler_1() {
        }
        return ISingScoringEventHandler_1;
    }());
    __setFunctionName(_classThis, "ISingScoringEventHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var IFaceDetectionObserver = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.video.IFaceDetectionObserver', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IFaceDetectionObserver_1() {
        }
        return IFaceDetectionObserver_1;
    }());
    __setFunctionName(_classThis, "IFaceDetectionObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IMixedStreamObserver = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.live.IMixedStreamObserver', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IMixedStreamObserver_1() {
        }
        return IMixedStreamObserver_1;
    }());
    __setFunctionName(_classThis, "IMixedStreamObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IMediaPlayerAudioFrameObserver = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.IMediaPlayerAudioFrameObserver', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IMediaPlayerAudioFrameObserver_1() {
        }
        return IMediaPlayerAudioFrameObserver_1;
    }());
    __setFunctionName(_classThis, "IMediaPlayerAudioFrameObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IAudioFileFrameObserver = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.IAudioFileFrameObserver', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IAudioFileFrameObserver_1() {
        }
        return IAudioFileFrameObserver_1;
    }());
    __setFunctionName(_classThis, "IAudioFileFrameObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.live.ILiveTranscodingObserver', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ILiveTranscodingObserver_1() {
        }
        return ILiveTranscodingObserver_1;
    }());
    __setFunctionName(_classThis, "ILiveTranscodingObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
(function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.handler.IRTCASREngineEventHandler', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IRTCASREngineEventHandler_1() {
        }
        return IRTCASREngineEventHandler_1;
    }());
    __setFunctionName(_classThis, "IRTCASREngineEventHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ILocalEncodedVideoFrameObserver = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.mediaio.ILocalEncodedVideoFrameObserver', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ILocalEncodedVideoFrameObserver_1() {
        }
        return ILocalEncodedVideoFrameObserver_1;
    }());
    __setFunctionName(_classThis, "ILocalEncodedVideoFrameObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IExternalVideoEncoderEventHandler = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.handler.IExternalVideoEncoderEventHandler', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IExternalVideoEncoderEventHandler_1() {
        }
        return IExternalVideoEncoderEventHandler_1;
    }());
    __setFunctionName(_classThis, "IExternalVideoEncoderEventHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IMediaPlayerEventHandler = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.IMediaPlayerEventHandler', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IMediaPlayerEventHandler_1() {
        }
        return IMediaPlayerEventHandler_1;
    }());
    __setFunctionName(_classThis, "IMediaPlayerEventHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IAudioFrameObserver = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.IAudioFrameObserver', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IAudioFrameObserver_1() {
        }
        return IAudioFrameObserver_1;
    }());
    __setFunctionName(_classThis, "IAudioFrameObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.handler.IRTCEncryptionHandler', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IRTCEncryptionHandler_1() {
        }
        return IRTCEncryptionHandler_1;
    }());
    __setFunctionName(_classThis, "IRTCEncryptionHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var IMediaPlayerCustomSourceProvider = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.IMediaPlayerCustomSourceProvider', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IMediaPlayerCustomSourceProvider_1() {
        }
        return IMediaPlayerCustomSourceProvider_1;
    }());
    __setFunctionName(_classThis, "IMediaPlayerCustomSourceProvider");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IRTCVideoEventHandler = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.handler.IRTCVideoEventHandler', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IRTCVideoEventHandler_1() {
        }
        return IRTCVideoEventHandler_1;
    }());
    __setFunctionName(_classThis, "IRTCVideoEventHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.video.ISnapshotResultCallback', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ISnapshotResultCallback_1() {
        }
        return ISnapshotResultCallback_1;
    }());
    __setFunctionName(_classThis, "ISnapshotResultCallback");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var IAudioFrameProcessor = function () {
    var _classDecorators = [NativeObserverClass('com.ss.bytertc.engine.IAudioFrameProcessor', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IAudioFrameProcessor_1() {
        }
        return IAudioFrameProcessor_1;
    }());
    __setFunctionName(_classThis, "IAudioFrameProcessor");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();

var UserMessageSendResult;
(function (UserMessageSendResult) {
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_SUCCESS"] = 0] = "USER_MESSAGE_SEND_RESULT_SUCCESS";
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_TIMEOUT"] = 1] = "USER_MESSAGE_SEND_RESULT_TIMEOUT";
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_BROKEN"] = 2] = "USER_MESSAGE_SEND_RESULT_BROKEN";
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_NO_RECEIVER"] = 3] = "USER_MESSAGE_SEND_RESULT_NO_RECEIVER";
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_NO_RELAY_PATH"] = 4] = "USER_MESSAGE_SEND_RESULT_NO_RELAY_PATH";
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_EXCEED_QPS"] = 5] = "USER_MESSAGE_SEND_RESULT_EXCEED_QPS";
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_NOT_JOIN"] = 100] = "USER_MESSAGE_SEND_RESULT_NOT_JOIN";
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_INIT"] = 101] = "USER_MESSAGE_SEND_RESULT_INIT";
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_NO_CONNECTION"] = 102] = "USER_MESSAGE_SEND_RESULT_NO_CONNECTION";
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH"] = 103] = "USER_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH";
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_EMPTY_USER"] = 104] = "USER_MESSAGE_SEND_RESULT_EMPTY_USER";
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_NOT_LOGIN"] = 105] = "USER_MESSAGE_SEND_RESULT_NOT_LOGIN";
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_SERVER_PARAMS_NOT_SET"] = 106] = "USER_MESSAGE_SEND_RESULT_SERVER_PARAMS_NOT_SET";
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_UNKNOWN"] = 1000] = "USER_MESSAGE_SEND_RESULT_UNKNOWN";
})(UserMessageSendResult || (UserMessageSendResult = {}));
var ByteRTCStreamSinglePushEvent;
(function (ByteRTCStreamSinglePushEvent) {
    ByteRTCStreamSinglePushEvent[ByteRTCStreamSinglePushEvent["SINGLE_STREAM_PUSH_START"] = 1] = "SINGLE_STREAM_PUSH_START";
    ByteRTCStreamSinglePushEvent[ByteRTCStreamSinglePushEvent["SINGLE_STREAM_PUSH_SUCCESS"] = 2] = "SINGLE_STREAM_PUSH_SUCCESS";
    ByteRTCStreamSinglePushEvent[ByteRTCStreamSinglePushEvent["SINGLE_STREAM_PUSH_FAILED"] = 3] = "SINGLE_STREAM_PUSH_FAILED";
    ByteRTCStreamSinglePushEvent[ByteRTCStreamSinglePushEvent["SINGLE_STREAM_PUSH_STOP"] = 4] = "SINGLE_STREAM_PUSH_STOP";
    ByteRTCStreamSinglePushEvent[ByteRTCStreamSinglePushEvent["SINGLE_STREAM_PUSH_TIMEOUT"] = 5] = "SINGLE_STREAM_PUSH_TIMEOUT";
    ByteRTCStreamSinglePushEvent[ByteRTCStreamSinglePushEvent["SINGLE_STREAM_PUSH_PARAM_ERROR"] = 6] = "SINGLE_STREAM_PUSH_PARAM_ERROR";
})(ByteRTCStreamSinglePushEvent || (ByteRTCStreamSinglePushEvent = {}));
var ByteRTCTranscoderErrorCode;
(function (ByteRTCTranscoderErrorCode) {
    ByteRTCTranscoderErrorCode[ByteRTCTranscoderErrorCode["TRANSCODER_ERROR_OK"] = 0] = "TRANSCODER_ERROR_OK";
    ByteRTCTranscoderErrorCode[ByteRTCTranscoderErrorCode["TRANSCODER_ERROR_BASE"] = 1090] = "TRANSCODER_ERROR_BASE";
    ByteRTCTranscoderErrorCode[ByteRTCTranscoderErrorCode["TRANSCODER_ERROR_INVALID_PARAM"] = 1091] = "TRANSCODER_ERROR_INVALID_PARAM";
    ByteRTCTranscoderErrorCode[ByteRTCTranscoderErrorCode["TRANSCODER_ERROR_INVALID_STATE"] = 1092] = "TRANSCODER_ERROR_INVALID_STATE";
    ByteRTCTranscoderErrorCode[ByteRTCTranscoderErrorCode["TRANSCODER_ERROR_INVALID_OPERATOR"] = 1093] = "TRANSCODER_ERROR_INVALID_OPERATOR";
    ByteRTCTranscoderErrorCode[ByteRTCTranscoderErrorCode["TRANSCODER_ERROR_TIMEOUT"] = 1094] = "TRANSCODER_ERROR_TIMEOUT";
    ByteRTCTranscoderErrorCode[ByteRTCTranscoderErrorCode["TRANSCODER_ERROR_INVALID_PARAM_BY_SERVER"] = 1095] = "TRANSCODER_ERROR_INVALID_PARAM_BY_SERVER";
    ByteRTCTranscoderErrorCode[ByteRTCTranscoderErrorCode["TRANSCODER_ERROR_SUB_TIMEOUT_BY_SERVER"] = 1096] = "TRANSCODER_ERROR_SUB_TIMEOUT_BY_SERVER";
    ByteRTCTranscoderErrorCode[ByteRTCTranscoderErrorCode["TRANSCODER_ERROR_INVALID_STATE_BY_SERVER"] = 1097] = "TRANSCODER_ERROR_INVALID_STATE_BY_SERVER";
    ByteRTCTranscoderErrorCode[ByteRTCTranscoderErrorCode["TRANSCODER_ERROR_AUTHENTICATION_BY_CDN"] = 1098] = "TRANSCODER_ERROR_AUTHENTICATION_BY_CDN";
    ByteRTCTranscoderErrorCode[ByteRTCTranscoderErrorCode["TRANSCODER_ERROR_TIMEOUT_BY_SIGNALING"] = 1099] = "TRANSCODER_ERROR_TIMEOUT_BY_SIGNALING";
    ByteRTCTranscoderErrorCode[ByteRTCTranscoderErrorCode["TRANSCODER_ERROR_MIX_IMAGE_FAIL"] = 1100] = "TRANSCODER_ERROR_MIX_IMAGE_FAIL";
    ByteRTCTranscoderErrorCode[ByteRTCTranscoderErrorCode["TRANSCODER_ERROR_UNKNOW_ERROR_BY_SERVER"] = 1101] = "TRANSCODER_ERROR_UNKNOW_ERROR_BY_SERVER";
})(ByteRTCTranscoderErrorCode || (ByteRTCTranscoderErrorCode = {}));
var AudioRecordingErrorCode;
(function (AudioRecordingErrorCode) {
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_OK"] = 0] = "AUDIO_RECORDING_ERROR_CODE_OK";
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_NO_PERMISSION"] = -1] = "AUDIO_RECORDING_ERROR_CODE_NO_PERMISSION";
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_NOT_IN_ROOM"] = -2] = "AUDIO_RECORDING_ERROR_CODE_NOT_IN_ROOM";
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_ALREADY_STARTED"] = -3] = "AUDIO_RECORDING_ERROR_CODE_ALREADY_STARTED";
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_NOT_STARTED"] = -4] = "AUDIO_RECORDING_ERROR_CODE_NOT_STARTED";
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_NOT_SUPPORT"] = -5] = "AUDIO_RECORDING_ERROR_CODE_NOT_SUPPORT";
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_OTHER"] = -6] = "AUDIO_RECORDING_ERROR_CODE_OTHER";
})(AudioRecordingErrorCode || (AudioRecordingErrorCode = {}));
var KTVErrorCode;
(function (KTVErrorCode) {
    KTVErrorCode[KTVErrorCode["OK"] = 0] = "OK";
    KTVErrorCode[KTVErrorCode["APPID_INVALID"] = -3000] = "APPID_INVALID";
    KTVErrorCode[KTVErrorCode["PARAS_INVALID"] = -3001] = "PARAS_INVALID";
    KTVErrorCode[KTVErrorCode["GET_MUSIC_FAILED"] = -3002] = "GET_MUSIC_FAILED";
    KTVErrorCode[KTVErrorCode["GET_LYRIC_FAILED"] = -3003] = "GET_LYRIC_FAILED";
    KTVErrorCode[KTVErrorCode["MUSIC_TAKEDOWN"] = -3004] = "MUSIC_TAKEDOWN";
    KTVErrorCode[KTVErrorCode["MUSIC_DOWNLOAD"] = -3005] = "MUSIC_DOWNLOAD";
    KTVErrorCode[KTVErrorCode["MIDI_DOWNLOAD_FAILED"] = -3006] = "MIDI_DOWNLOAD_FAILED";
    KTVErrorCode[KTVErrorCode["SYSTEM_BUSY"] = -3007] = "SYSTEM_BUSY";
    KTVErrorCode[KTVErrorCode["NETWORK"] = -3008] = "NETWORK";
    KTVErrorCode[KTVErrorCode["NOT_JOIN_ROOM"] = -3009] = "NOT_JOIN_ROOM";
    KTVErrorCode[KTVErrorCode["PARSE_DATA"] = -3010] = "PARSE_DATA";
    KTVErrorCode[KTVErrorCode["DOWNLOADING"] = -3012] = "DOWNLOADING";
    KTVErrorCode[KTVErrorCode["INTERNAL_DOMAIN"] = -3013] = "INTERNAL_DOMAIN";
    KTVErrorCode[KTVErrorCode["INSUFFICIENT_DISK_SPACE"] = -3014] = "INSUFFICIENT_DISK_SPACE";
    KTVErrorCode[KTVErrorCode["MUSIC_DECRYPTION_FAILED"] = -3015] = "MUSIC_DECRYPTION_FAILED";
    KTVErrorCode[KTVErrorCode["FILE_RENAME_FAILED"] = -3016] = "FILE_RENAME_FAILED";
    KTVErrorCode[KTVErrorCode["DOWNLOAD_TIMEOUT"] = -3017] = "DOWNLOAD_TIMEOUT";
    KTVErrorCode[KTVErrorCode["CLEAR_CACHE_FAILED"] = -3018] = "CLEAR_CACHE_FAILED";
    KTVErrorCode[KTVErrorCode["DOWNLOAD_CANCELED"] = -3019] = "DOWNLOAD_CANCELED";
})(KTVErrorCode || (KTVErrorCode = {}));
var PublicStreamErrorCode;
(function (PublicStreamErrorCode) {
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_SUCCESS"] = 0] = "ERROR_CODE_SUCCESS";
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_PUSH_PARAM_ERROR"] = 1191] = "ERROR_CODE_PUSH_PARAM_ERROR";
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_PUSH_STATE_ERROR"] = 1192] = "ERROR_CODE_PUSH_STATE_ERROR";
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_PUSH_INTERNAL_ERROR"] = 1193] = "ERROR_CODE_PUSH_INTERNAL_ERROR";
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_PUSH_ERROR"] = 1195] = "ERROR_CODE_PUSH_ERROR";
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_PUSH_TIMEOUT"] = 1196] = "ERROR_CODE_PUSH_TIMEOUT";
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_PULL_NO_PUSH_STREAM"] = 1300] = "ERROR_CODE_PULL_NO_PUSH_STREAM";
})(PublicStreamErrorCode || (PublicStreamErrorCode = {}));
var SubtitleErrorCode;
(function (SubtitleErrorCode) {
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_UNKNOW"] = -1] = "SUBTITLE_ERROR_CODE_UNKNOW";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_SUCCESS"] = 0] = "SUBTITLE_ERROR_CODE_SUCCESS";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_POST_PROCESS_ERROR"] = 1] = "SUBTITLE_ERROR_CODE_POST_PROCESS_ERROR";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_ASR_CONNECTION_ERROR"] = 2] = "SUBTITLE_ERROR_CODE_ASR_CONNECTION_ERROR";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_ASR_SERVICE_ERROR"] = 3] = "SUBTITLE_ERROR_CODE_ASR_SERVICE_ERROR";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_BEFORE_JOIN_ROOM"] = 4] = "SUBTITLE_ERROR_CODE_BEFORE_JOIN_ROOM";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_ALREADY_ON"] = 5] = "SUBTITLE_ERROR_CODE_ALREADY_ON";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_UNSUPPORTED_LANGUAGE"] = 6] = "SUBTITLE_ERROR_CODE_UNSUPPORTED_LANGUAGE";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_POST_PROCESS_TIMEOUT"] = 7] = "SUBTITLE_ERROR_CODE_POST_PROCESS_TIMEOUT";
})(SubtitleErrorCode || (SubtitleErrorCode = {}));
var ErrorCode;
(function (ErrorCode) {
    ErrorCode[ErrorCode["ERROR_CODE_INVALID_TOKEN"] = -1000] = "ERROR_CODE_INVALID_TOKEN";
    ErrorCode[ErrorCode["ERROR_CODE_JOIN_ROOM"] = -1001] = "ERROR_CODE_JOIN_ROOM";
    ErrorCode[ErrorCode["ERROR_CODE_NO_PUBLISH_PERMISSION"] = -1002] = "ERROR_CODE_NO_PUBLISH_PERMISSION";
    ErrorCode[ErrorCode["ERROR_CODE_NO_SUBSCRIBE_PERMISSION"] = -1003] = "ERROR_CODE_NO_SUBSCRIBE_PERMISSION";
    ErrorCode[ErrorCode["ERROR_CODE_DUPLICATE_LOGIN"] = -1004] = "ERROR_CODE_DUPLICATE_LOGIN";
    ErrorCode[ErrorCode["ERROR_CODE_APP_ID_NULL"] = -1005] = "ERROR_CODE_APP_ID_NULL";
    ErrorCode[ErrorCode["ERROR_CODE_KICKED_OUT"] = -1006] = "ERROR_CODE_KICKED_OUT";
    ErrorCode[ErrorCode["ERROR_CODE_ROOM_ID_ILLEGAL"] = -1007] = "ERROR_CODE_ROOM_ID_ILLEGAL";
    ErrorCode[ErrorCode["ERROR_CODE_TOKEN_EXPIRED"] = -1009] = "ERROR_CODE_TOKEN_EXPIRED";
    ErrorCode[ErrorCode["ERROR_CODE_UPDATE_TOKEN_WITH_INVALID_TOKEN"] = -1010] = "ERROR_CODE_UPDATE_TOKEN_WITH_INVALID_TOKEN";
    ErrorCode[ErrorCode["ERROR_CODE_ROOM_DISMISS"] = -1011] = "ERROR_CODE_ROOM_DISMISS";
    ErrorCode[ErrorCode["ERROR_CODE_JOIN_ROOM_WITHOUT_LICENSE_AUTHENTICATE_SDK"] = -1012] = "ERROR_CODE_JOIN_ROOM_WITHOUT_LICENSE_AUTHENTICATE_SDK";
    ErrorCode[ErrorCode["ERROR_CODE_ROOM_ALREADY_EXIST"] = -1013] = "ERROR_CODE_ROOM_ALREADY_EXIST";
    ErrorCode[ErrorCode["ERROR_CODE_USER_ID_DIFFERENT"] = -1014] = "ERROR_CODE_USER_ID_DIFFERENT";
    ErrorCode[ErrorCode["ERROR_CODE_SERVER_LICENSE_EXPIRE"] = -1017] = "ERROR_CODE_SERVER_LICENSE_EXPIRE";
    ErrorCode[ErrorCode["ERROR_CODE_EXCEEDS_THE_UPPER_LIMIT"] = -1018] = "ERROR_CODE_EXCEEDS_THE_UPPER_LIMIT";
    ErrorCode[ErrorCode["ERROR_CODE_LICENSE_PARAMETER_ERROR"] = -1019] = "ERROR_CODE_LICENSE_PARAMETER_ERROR";
    ErrorCode[ErrorCode["ERROR_CODE_LICENSE_FILE_PATH_ERROR"] = -1020] = "ERROR_CODE_LICENSE_FILE_PATH_ERROR";
    ErrorCode[ErrorCode["ERROR_CODE_LICENSE_ILLEGAL"] = -1021] = "ERROR_CODE_LICENSE_ILLEGAL";
    ErrorCode[ErrorCode["ERROR_CODE_LICENSE_EXPIRED"] = -1022] = "ERROR_CODE_LICENSE_EXPIRED";
    ErrorCode[ErrorCode["ERROR_CODE_LICENSE_INFORMATION_NOT_MATCH"] = -1023] = "ERROR_CODE_LICENSE_INFORMATION_NOT_MATCH";
    ErrorCode[ErrorCode["ERROR_CODE_LICENSE_NOT_MATCH_WITH_CACHE"] = -1024] = "ERROR_CODE_LICENSE_NOT_MATCH_WITH_CACHE";
    ErrorCode[ErrorCode["ERROR_CODE_JOIN_ROOM_ROOM_FORBIDDEN"] = -1025] = "ERROR_CODE_JOIN_ROOM_ROOM_FORBIDDEN";
    ErrorCode[ErrorCode["ERROR_CODE_JOIN_ROOM_USER_FORBIDDEN"] = -1026] = "ERROR_CODE_JOIN_ROOM_USER_FORBIDDEN";
    ErrorCode[ErrorCode["ERROR_CODE_JOIN_ROOM_LICENSE_FUNCTION_NOT_FOUND"] = -1027] = "ERROR_CODE_JOIN_ROOM_LICENSE_FUNCTION_NOT_FOUND";
    ErrorCode[ErrorCode["ERROR_CODE_OVER_SUBSCRIBE_LIMIT"] = -1070] = "ERROR_CODE_OVER_SUBSCRIBE_LIMIT";
    ErrorCode[ErrorCode["ERROR_CODE_LOAD_SO_LIB"] = -1072] = "ERROR_CODE_LOAD_SO_LIB";
    ErrorCode[ErrorCode["ERROR_CODE_OVER_STREAM_PUBLISH_LIMIT"] = -1080] = "ERROR_CODE_OVER_STREAM_PUBLISH_LIMIT";
    ErrorCode[ErrorCode["ERROR_CODE_INVALID_AUDIO_SYNC_USERID_REPEATED"] = -1083] = "ERROR_CODE_INVALID_AUDIO_SYNC_USERID_REPEATED";
    ErrorCode[ErrorCode["ERROR_CODE_ABNORMAL_SERVER_STATUS"] = -1084] = "ERROR_CODE_ABNORMAL_SERVER_STATUS";
    ErrorCode[ErrorCode["ERROR_CODE_MULTI_ROOM_UNPUBLISH_FAILED"] = -1085] = "ERROR_CODE_MULTI_ROOM_UNPUBLISH_FAILED";
    ErrorCode[ErrorCode["ERROR_CODE_WRONG_AREA_CODE"] = -1086] = "ERROR_CODE_WRONG_AREA_CODE";
    ErrorCode[ErrorCode["ERROR_CODE_OVER_SCREEN_PUBLISH_LIMIT"] = -1081] = "ERROR_CODE_OVER_SCREEN_PUBLISH_LIMIT";
    ErrorCode[ErrorCode["ERROR_CODE_OVER_VIDEO_PUBLISH_LIMIT"] = -1082] = "ERROR_CODE_OVER_VIDEO_PUBLISH_LIMIT";
})(ErrorCode || (ErrorCode = {}));
var WarningCode;
(function (WarningCode) {
    WarningCode[WarningCode["WARNING_CODE_JOIN_ROOM_FAILED"] = -2001] = "WARNING_CODE_JOIN_ROOM_FAILED";
    WarningCode[WarningCode["WARNING_CODE_PUBLISH_STREAM_FAILED"] = -2002] = "WARNING_CODE_PUBLISH_STREAM_FAILED";
    WarningCode[WarningCode["WARNING_CODE_SUBSCRIBE_STREAM_FAILED404"] = -2003] = "WARNING_CODE_SUBSCRIBE_STREAM_FAILED404";
    WarningCode[WarningCode["WARNING_CODE_SUBSCRIBE_STREAM_FAILED5XX"] = -2004] = "WARNING_CODE_SUBSCRIBE_STREAM_FAILED5XX";
    WarningCode[WarningCode["WARNING_CODE_INVOKE_ERROR"] = -2005] = "WARNING_CODE_INVOKE_ERROR";
    WarningCode[WarningCode["WARNING_CODE_INVALID_EXPECT_MEDIA_SERVER_ADDRESS"] = -2007] = "WARNING_CODE_INVALID_EXPECT_MEDIA_SERVER_ADDRESS";
    WarningCode[WarningCode["WARNING_CODE_PUBLISH_STREAM_FORBIDEN"] = -2009] = "WARNING_CODE_PUBLISH_STREAM_FORBIDEN";
    WarningCode[WarningCode["WARNING_CODE_SEND_CUSTOM_MESSAGE"] = -2011] = "WARNING_CODE_SEND_CUSTOM_MESSAGE";
    WarningCode[WarningCode["WARNING_CODE_RECEIVE_USER_NOTIFY_STOP"] = -2013] = "WARNING_CODE_RECEIVE_USER_NOTIFY_STOP";
    WarningCode[WarningCode["WARNING_CODE_USER_IN_PUBLISH"] = -2014] = "WARNING_CODE_USER_IN_PUBLISH";
    WarningCode[WarningCode["WARNING_CODE_OLD_ROOM_BEEN_REPLACED"] = -2016] = "WARNING_CODE_OLD_ROOM_BEEN_REPLACED";
    WarningCode[WarningCode["WARNING_CODE_IN_ECHO_TEST_MODE"] = -2017] = "WARNING_CODE_IN_ECHO_TEST_MODE";
    WarningCode[WarningCode["WARNING_CODE_NO_CAMERA_PERMISSION"] = -5001] = "WARNING_CODE_NO_CAMERA_PERMISSION";
    WarningCode[WarningCode["WARNING_CODE_SET_SCREEN_AUDIO_SOURCE_TYPE_FAILED"] = -5009] = "WARNING_CODE_SET_SCREEN_AUDIO_SOURCE_TYPE_FAILED";
    WarningCode[WarningCode["WARNING_CODE_SET_SCREEN_STREAM_INDEX_FAILED"] = -5010] = "WARNING_CODE_SET_SCREEN_STREAM_INDEX_FAILED";
    WarningCode[WarningCode["WARNING_CODE_SET_SCREEN_STREAM_INVALID_VOICE_PITCH"] = -5011] = "WARNING_CODE_SET_SCREEN_STREAM_INVALID_VOICE_PITCH";
    WarningCode[WarningCode["WARNING_CODE_INVALID_CALL_FOR_EXT_AUDIO"] = -5013] = "WARNING_CODE_INVALID_CALL_FOR_EXT_AUDIO";
    WarningCode[WarningCode["WARNING_CODE_INVALID_SAMI_APPKEY_OR_TOKEN"] = -7002] = "WARNING_CODE_INVALID_SAMI_APPKEY_OR_TOKEN";
    WarningCode[WarningCode["WARNING_CODE_INVALID_RESOURCE_PATH"] = -7003] = "WARNING_CODE_INVALID_RESOURCE_PATH";
    WarningCode[WarningCode["WARNING_CODE_LOAD_SAMI_LIBRARY_FAILED"] = -7004] = "WARNING_CODE_LOAD_SAMI_LIBRARY_FAILED";
    WarningCode[WarningCode["WARNING_CODE_INVALID_SAMI_EFFECT_TYPE"] = -7005] = "WARNING_CODE_INVALID_SAMI_EFFECT_TYPE";
    WarningCode[WarningCode["WARNING_CODE_GET_ROOM_FAILED"] = -2000] = "WARNING_CODE_GET_ROOM_FAILED";
    WarningCode[WarningCode["WARNING_CODE_SUBSCRIBE_STREAM_FORBIDEN"] = -2010] = "WARNING_CODE_SUBSCRIBE_STREAM_FORBIDEN";
    WarningCode[WarningCode["WARNING_CODE_ROOM_ID_ALREADY_EXIST"] = -2015] = "WARNING_CODE_ROOM_ID_ALREADY_EXIST";
    WarningCode[WarningCode["WARNING_CODE_NO_MICROPHONE_PERMISSION"] = -5002] = "WARNING_CODE_NO_MICROPHONE_PERMISSION";
    WarningCode[WarningCode["WARNING_CODE_RECODING_DEVICE_START_FAILED"] = -5003] = "WARNING_CODE_RECODING_DEVICE_START_FAILED";
    WarningCode[WarningCode["WARNING_CODE_PLAYOUT_DEVICE_START_FAILED"] = -5004] = "WARNING_CODE_PLAYOUT_DEVICE_START_FAILED";
    WarningCode[WarningCode["WARNING_CODE_NO_RECORDING_DEVICE"] = -5005] = "WARNING_CODE_NO_RECORDING_DEVICE";
    WarningCode[WarningCode["WARNING_CODE_NO_PLAYOUT_DEVICE"] = -5006] = "WARNING_CODE_NO_PLAYOUT_DEVICE";
    WarningCode[WarningCode["WARNING_CODE_RECORDING_SILENCE"] = -5007] = "WARNING_CODE_RECORDING_SILENCE";
    WarningCode[WarningCode["WARNING_CODE_MEDIA_DEVICE_OPERATION_DENIED"] = -5008] = "WARNING_CODE_MEDIA_DEVICE_OPERATION_DENIED";
})(WarningCode || (WarningCode = {}));
var RoomMessageSendResult;
(function (RoomMessageSendResult) {
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_SUCCESS"] = 200] = "ROOM_MESSAGE_SEND_RESULT_SUCCESS";
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_EXCEED_QPS"] = 5] = "ROOM_MESSAGE_SEND_RESULT_EXCEED_QPS";
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_NOT_JOIN"] = 100] = "ROOM_MESSAGE_SEND_RESULT_NOT_JOIN";
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_INIT"] = 101] = "ROOM_MESSAGE_SEND_RESULT_INIT";
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_NO_CONNECTION"] = 102] = "ROOM_MESSAGE_SEND_RESULT_NO_CONNECTION";
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH"] = 103] = "ROOM_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH";
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_UNKNOWN"] = 1000] = "ROOM_MESSAGE_SEND_RESULT_UNKNOWN";
})(RoomMessageSendResult || (RoomMessageSendResult = {}));
var LoginErrorCode;
(function (LoginErrorCode) {
    LoginErrorCode[LoginErrorCode["LOGIN_ERROR_CODE_SUCCESS"] = 0] = "LOGIN_ERROR_CODE_SUCCESS";
    LoginErrorCode[LoginErrorCode["LOGIN_ERROR_CODE_INVALID_TOKEN"] = -1000] = "LOGIN_ERROR_CODE_INVALID_TOKEN";
    LoginErrorCode[LoginErrorCode["LOGIN_ERROR_CODE_LOGIN_FAILED"] = -1001] = "LOGIN_ERROR_CODE_LOGIN_FAILED";
    LoginErrorCode[LoginErrorCode["LOGIN_ERROR_CODE_INVALID_USER_ID"] = -1002] = "LOGIN_ERROR_CODE_INVALID_USER_ID";
    LoginErrorCode[LoginErrorCode["LOGIN_ERROR_CODE_SERVER_ERROR"] = -1003] = "LOGIN_ERROR_CODE_SERVER_ERROR";
})(LoginErrorCode || (LoginErrorCode = {}));
var TranscodingError;
(function (TranscodingError) {
    TranscodingError[TranscodingError["TRANSCODING_ERROR_OK"] = 0] = "TRANSCODING_ERROR_OK";
    TranscodingError[TranscodingError["TRANSCODING_ERROR_INVALID_ARGUMENT"] = 1] = "TRANSCODING_ERROR_INVALID_ARGUMENT";
    TranscodingError[TranscodingError["TRANSCODING_ERROR_SUBSCRIBE"] = 2] = "TRANSCODING_ERROR_SUBSCRIBE";
    TranscodingError[TranscodingError["TRANSCODING_ERROR_PROCESSING"] = 3] = "TRANSCODING_ERROR_PROCESSING";
    TranscodingError[TranscodingError["TRANSCODING_ERROR_PUBLISH"] = 4] = "TRANSCODING_ERROR_PUBLISH";
})(TranscodingError || (TranscodingError = {}));

var ByteRTCASRAuthorizationType;
(function (ByteRTCASRAuthorizationType) {
    ByteRTCASRAuthorizationType[ByteRTCASRAuthorizationType["ByteRTCASRAuthorizationTypeToken"] = 0] = "ByteRTCASRAuthorizationTypeToken";
    ByteRTCASRAuthorizationType[ByteRTCASRAuthorizationType["ByteRTCASRAuthorizationTypeSignature"] = 1] = "ByteRTCASRAuthorizationTypeSignature";
})(ByteRTCASRAuthorizationType || (ByteRTCASRAuthorizationType = {}));
var ByteRTCLiveTranscoding = function () {
    var _classDecorators = [NativeClass('ByteRTCLiveTranscoding')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _instanceExtraInitializers = [];
    var _static_defaultTranscoding_decorators;
    var _expectedMixingType_decorators;
    var _expectedMixingType_initializers = [];
    var _expectedMixingType_extraInitializers = [];
    var _layout_decorators;
    var _layout_initializers = [];
    var _layout_extraInitializers = [];
    var _video_decorators;
    var _video_initializers = [];
    var _video_extraInitializers = [];
    var _audio_decorators;
    var _audio_initializers = [];
    var _audio_extraInitializers = [];
    var _clientMixParam_decorators;
    var _clientMixParam_initializers = [];
    var _clientMixParam_extraInitializers = [];
    var _spatialConfig_decorators;
    var _spatialConfig_initializers = [];
    var _spatialConfig_extraInitializers = [];
    var _url_decorators;
    var _url_initializers = [];
    var _url_extraInitializers = [];
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCLiveTranscoding_1() {
            this.expectedMixingType = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _expectedMixingType_initializers, void 0));
            this.layout = (__runInitializers(this, _expectedMixingType_extraInitializers), __runInitializers(this, _layout_initializers, void 0));
            this.video = (__runInitializers(this, _layout_extraInitializers), __runInitializers(this, _video_initializers, void 0));
            this.audio = (__runInitializers(this, _video_extraInitializers), __runInitializers(this, _audio_initializers, void 0));
            this.clientMixParam = (__runInitializers(this, _audio_extraInitializers), __runInitializers(this, _clientMixParam_initializers, void 0));
            this.spatialConfig = (__runInitializers(this, _clientMixParam_extraInitializers), __runInitializers(this, _spatialConfig_initializers, void 0));
            this.url = (__runInitializers(this, _spatialConfig_extraInitializers), __runInitializers(this, _url_initializers, void 0));
            this.roomId = (__runInitializers(this, _url_extraInitializers), __runInitializers(this, _roomId_initializers, void 0));
            this.userId = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _userId_initializers, void 0));
            __runInitializers(this, _userId_extraInitializers);
        }
        ByteRTCLiveTranscoding_1.defaultTranscoding = function () {
            throw new Error('not implement');
        };
        ByteRTCLiveTranscoding_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCLiveTranscoding_1;
    }());
    __setFunctionName(_classThis, "ByteRTCLiveTranscoding");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_defaultTranscoding_decorators = [NativeStaticMethodSync('defaultTranscoding')];
        _expectedMixingType_decorators = [NativeMember()];
        _layout_decorators = [NativeMember()];
        _video_decorators = [NativeMember()];
        _audio_decorators = [NativeMember()];
        _clientMixParam_decorators = [NativeMember()];
        _spatialConfig_decorators = [NativeMember()];
        _url_decorators = [NativeMember()];
        _roomId_decorators = [NativeMember()];
        _userId_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _static_defaultTranscoding_decorators, { kind: "method", name: "defaultTranscoding", static: true, private: false, access: { has: function (obj) { return "defaultTranscoding" in obj; }, get: function (obj) { return obj.defaultTranscoding; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _expectedMixingType_decorators, { kind: "field", name: "expectedMixingType", static: false, private: false, access: { has: function (obj) { return "expectedMixingType" in obj; }, get: function (obj) { return obj.expectedMixingType; }, set: function (obj, value) { obj.expectedMixingType = value; } }, metadata: _metadata }, _expectedMixingType_initializers, _expectedMixingType_extraInitializers);
        __esDecorate(null, null, _layout_decorators, { kind: "field", name: "layout", static: false, private: false, access: { has: function (obj) { return "layout" in obj; }, get: function (obj) { return obj.layout; }, set: function (obj, value) { obj.layout = value; } }, metadata: _metadata }, _layout_initializers, _layout_extraInitializers);
        __esDecorate(null, null, _video_decorators, { kind: "field", name: "video", static: false, private: false, access: { has: function (obj) { return "video" in obj; }, get: function (obj) { return obj.video; }, set: function (obj, value) { obj.video = value; } }, metadata: _metadata }, _video_initializers, _video_extraInitializers);
        __esDecorate(null, null, _audio_decorators, { kind: "field", name: "audio", static: false, private: false, access: { has: function (obj) { return "audio" in obj; }, get: function (obj) { return obj.audio; }, set: function (obj, value) { obj.audio = value; } }, metadata: _metadata }, _audio_initializers, _audio_extraInitializers);
        __esDecorate(null, null, _clientMixParam_decorators, { kind: "field", name: "clientMixParam", static: false, private: false, access: { has: function (obj) { return "clientMixParam" in obj; }, get: function (obj) { return obj.clientMixParam; }, set: function (obj, value) { obj.clientMixParam = value; } }, metadata: _metadata }, _clientMixParam_initializers, _clientMixParam_extraInitializers);
        __esDecorate(null, null, _spatialConfig_decorators, { kind: "field", name: "spatialConfig", static: false, private: false, access: { has: function (obj) { return "spatialConfig" in obj; }, get: function (obj) { return obj.spatialConfig; }, set: function (obj, value) { obj.spatialConfig = value; } }, metadata: _metadata }, _spatialConfig_initializers, _spatialConfig_extraInitializers);
        __esDecorate(null, null, _url_decorators, { kind: "field", name: "url", static: false, private: false, access: { has: function (obj) { return "url" in obj; }, get: function (obj) { return obj.url; }, set: function (obj, value) { obj.url = value; } }, metadata: _metadata }, _url_initializers, _url_extraInitializers);
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _staticExtraInitializers);
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioEffectPlayerConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCAudioEffectPlayerConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _type_decorators;
    var _type_initializers = [];
    var _type_extraInitializers = [];
    var _pitch_decorators;
    var _pitch_initializers = [];
    var _pitch_extraInitializers = [];
    var _playCount_decorators;
    var _playCount_initializers = [];
    var _playCount_extraInitializers = [];
    var _startPos_decorators;
    var _startPos_initializers = [];
    var _startPos_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioEffectPlayerConfig_1() {
            this.type = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _type_initializers, void 0));
            this.pitch = (__runInitializers(this, _type_extraInitializers), __runInitializers(this, _pitch_initializers, void 0));
            this.playCount = (__runInitializers(this, _pitch_extraInitializers), __runInitializers(this, _playCount_initializers, void 0));
            this.startPos = (__runInitializers(this, _playCount_extraInitializers), __runInitializers(this, _startPos_initializers, void 0));
            __runInitializers(this, _startPos_extraInitializers);
        }
        ByteRTCAudioEffectPlayerConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCAudioEffectPlayerConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioEffectPlayerConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _type_decorators = [NativeMember()];
        _pitch_decorators = [NativeMember()];
        _playCount_decorators = [NativeMember()];
        _startPos_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _type_decorators, { kind: "field", name: "type", static: false, private: false, access: { has: function (obj) { return "type" in obj; }, get: function (obj) { return obj.type; }, set: function (obj, value) { obj.type = value; } }, metadata: _metadata }, _type_initializers, _type_extraInitializers);
        __esDecorate(null, null, _pitch_decorators, { kind: "field", name: "pitch", static: false, private: false, access: { has: function (obj) { return "pitch" in obj; }, get: function (obj) { return obj.pitch; }, set: function (obj, value) { obj.pitch = value; } }, metadata: _metadata }, _pitch_initializers, _pitch_extraInitializers);
        __esDecorate(null, null, _playCount_decorators, { kind: "field", name: "playCount", static: false, private: false, access: { has: function (obj) { return "playCount" in obj; }, get: function (obj) { return obj.playCount; }, set: function (obj, value) { obj.playCount = value; } }, metadata: _metadata }, _playCount_initializers, _playCount_extraInitializers);
        __esDecorate(null, null, _startPos_decorators, { kind: "field", name: "startPos", static: false, private: false, access: { has: function (obj) { return "startPos" in obj; }, get: function (obj) { return obj.startPos; }, set: function (obj, value) { obj.startPos = value; } }, metadata: _metadata }, _startPos_initializers, _startPos_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRecordingInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCRecordingInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _filePath_decorators;
    var _filePath_initializers = [];
    var _filePath_extraInitializers = [];
    var _codecType_decorators;
    var _codecType_initializers = [];
    var _codecType_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRecordingInfo_1() {
            this.filePath = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _filePath_initializers, void 0));
            this.codecType = (__runInitializers(this, _filePath_extraInitializers), __runInitializers(this, _codecType_initializers, void 0));
            this.width = (__runInitializers(this, _codecType_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            __runInitializers(this, _height_extraInitializers);
        }
        ByteRTCRecordingInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRecordingInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRecordingInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _filePath_decorators = [NativeMember()];
        _codecType_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _filePath_decorators, { kind: "field", name: "filePath", static: false, private: false, access: { has: function (obj) { return "filePath" in obj; }, get: function (obj) { return obj.filePath; }, set: function (obj, value) { obj.filePath = value; } }, metadata: _metadata }, _filePath_initializers, _filePath_extraInitializers);
        __esDecorate(null, null, _codecType_decorators, { kind: "field", name: "codecType", static: false, private: false, access: { has: function (obj) { return "codecType" in obj; }, get: function (obj) { return obj.codecType; }, set: function (obj, value) { obj.codecType = value; } }, metadata: _metadata }, _codecType_initializers, _codecType_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCSubscribeConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCSubscribeConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _subscribeVideo_decorators;
    var _subscribeVideo_initializers = [];
    var _subscribeVideo_extraInitializers = [];
    var _subscribeAudio_decorators;
    var _subscribeAudio_initializers = [];
    var _subscribeAudio_extraInitializers = [];
    var _videoIndex_decorators;
    var _videoIndex_initializers = [];
    var _videoIndex_extraInitializers = [];
    var _svcLayer_decorators;
    var _svcLayer_initializers = [];
    var _svcLayer_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _framerate_decorators;
    var _framerate_initializers = [];
    var _framerate_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCSubscribeConfig_1() {
            this.isScreen = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.subscribeVideo = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _subscribeVideo_initializers, void 0));
            this.subscribeAudio = (__runInitializers(this, _subscribeVideo_extraInitializers), __runInitializers(this, _subscribeAudio_initializers, void 0));
            this.videoIndex = (__runInitializers(this, _subscribeAudio_extraInitializers), __runInitializers(this, _videoIndex_initializers, void 0));
            this.svcLayer = (__runInitializers(this, _videoIndex_extraInitializers), __runInitializers(this, _svcLayer_initializers, void 0));
            this.width = (__runInitializers(this, _svcLayer_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.framerate = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _framerate_initializers, void 0));
            __runInitializers(this, _framerate_extraInitializers);
        }
        ByteRTCSubscribeConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCSubscribeConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCSubscribeConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _isScreen_decorators = [NativeMember()];
        _subscribeVideo_decorators = [NativeMember()];
        _subscribeAudio_decorators = [NativeMember()];
        _videoIndex_decorators = [NativeMember()];
        _svcLayer_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _framerate_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _subscribeVideo_decorators, { kind: "field", name: "subscribeVideo", static: false, private: false, access: { has: function (obj) { return "subscribeVideo" in obj; }, get: function (obj) { return obj.subscribeVideo; }, set: function (obj, value) { obj.subscribeVideo = value; } }, metadata: _metadata }, _subscribeVideo_initializers, _subscribeVideo_extraInitializers);
        __esDecorate(null, null, _subscribeAudio_decorators, { kind: "field", name: "subscribeAudio", static: false, private: false, access: { has: function (obj) { return "subscribeAudio" in obj; }, get: function (obj) { return obj.subscribeAudio; }, set: function (obj, value) { obj.subscribeAudio = value; } }, metadata: _metadata }, _subscribeAudio_initializers, _subscribeAudio_extraInitializers);
        __esDecorate(null, null, _videoIndex_decorators, { kind: "field", name: "videoIndex", static: false, private: false, access: { has: function (obj) { return "videoIndex" in obj; }, get: function (obj) { return obj.videoIndex; }, set: function (obj, value) { obj.videoIndex = value; } }, metadata: _metadata }, _videoIndex_initializers, _videoIndex_extraInitializers);
        __esDecorate(null, null, _svcLayer_decorators, { kind: "field", name: "svcLayer", static: false, private: false, access: { has: function (obj) { return "svcLayer" in obj; }, get: function (obj) { return obj.svcLayer; }, set: function (obj, value) { obj.svcLayer = value; } }, metadata: _metadata }, _svcLayer_initializers, _svcLayer_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _framerate_decorators, { kind: "field", name: "framerate", static: false, private: false, access: { has: function (obj) { return "framerate" in obj; }, get: function (obj) { return obj.framerate; }, set: function (obj, value) { obj.framerate = value; } }, metadata: _metadata }, _framerate_initializers, _framerate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCUserInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCUserInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _extraInfo_decorators;
    var _extraInfo_initializers = [];
    var _extraInfo_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCUserInfo_1() {
            this.userId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _userId_initializers, void 0));
            this.extraInfo = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _extraInfo_initializers, void 0));
            __runInitializers(this, _extraInfo_extraInitializers);
        }
        ByteRTCUserInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCUserInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCUserInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _userId_decorators = [NativeMember()];
        _extraInfo_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _extraInfo_decorators, { kind: "field", name: "extraInfo", static: false, private: false, access: { has: function (obj) { return "extraInfo" in obj; }, get: function (obj) { return obj.extraInfo; }, set: function (obj, value) { obj.extraInfo = value; } }, metadata: _metadata }, _extraInfo_initializers, _extraInfo_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioPlaybackDevice;
(function (ByteRTCAudioPlaybackDevice) {
    ByteRTCAudioPlaybackDevice[ByteRTCAudioPlaybackDevice["ByteRTCAudioPlaybackDeviceHeadset"] = 1] = "ByteRTCAudioPlaybackDeviceHeadset";
    ByteRTCAudioPlaybackDevice[ByteRTCAudioPlaybackDevice["ByteRTCAudioPlaybackDeviceEarpiece"] = 2] = "ByteRTCAudioPlaybackDeviceEarpiece";
    ByteRTCAudioPlaybackDevice[ByteRTCAudioPlaybackDevice["ByteRTCAudioPlaybackDeviceSpeakerphone"] = 3] = "ByteRTCAudioPlaybackDeviceSpeakerphone";
    ByteRTCAudioPlaybackDevice[ByteRTCAudioPlaybackDevice["ByteRTCAudioPlaybackDeviceHeadsetBluetooth"] = 4] = "ByteRTCAudioPlaybackDeviceHeadsetBluetooth";
    ByteRTCAudioPlaybackDevice[ByteRTCAudioPlaybackDevice["ByteRTCAudioPlaybackDeviceHeadsetUSB"] = 5] = "ByteRTCAudioPlaybackDeviceHeadsetUSB";
})(ByteRTCAudioPlaybackDevice || (ByteRTCAudioPlaybackDevice = {}));
var ByteRTCMessageConfig;
(function (ByteRTCMessageConfig) {
    ByteRTCMessageConfig[ByteRTCMessageConfig["ByteRTCMessageConfigReliableOrdered"] = 0] = "ByteRTCMessageConfigReliableOrdered";
    ByteRTCMessageConfig[ByteRTCMessageConfig["ByteRTCMessageConfigUnreliableOrdered"] = 1] = "ByteRTCMessageConfigUnreliableOrdered";
    ByteRTCMessageConfig[ByteRTCMessageConfig["ByteRTCMessageConfigUnreliableUnordered"] = 2] = "ByteRTCMessageConfigUnreliableUnordered";
})(ByteRTCMessageConfig || (ByteRTCMessageConfig = {}));
(function () {
    var _classDecorators = [NativeObserverClass('ByteRTCVideoSinkDelegate', {
            onFrame: 'onFrame:',
            renderPixelBuffer$rotation$contentType$extendedData: 'renderPixelBuffer:rotation:contentType:extendedData:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoSinkDelegate_1() {
        }
        return ByteRTCVideoSinkDelegate_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoSinkDelegate");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCMixedStreamConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCMixedStreamConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _instanceExtraInitializers = [];
    var _static_defaultMixedStreamConfig_decorators;
    var _expectedMixingType_decorators;
    var _expectedMixingType_initializers = [];
    var _expectedMixingType_extraInitializers = [];
    var _layoutConfig_decorators;
    var _layoutConfig_initializers = [];
    var _layoutConfig_extraInitializers = [];
    var _videoConfig_decorators;
    var _videoConfig_initializers = [];
    var _videoConfig_extraInitializers = [];
    var _audioConfig_decorators;
    var _audioConfig_initializers = [];
    var _audioConfig_extraInitializers = [];
    var _clientMixConfig_decorators;
    var _clientMixConfig_initializers = [];
    var _clientMixConfig_extraInitializers = [];
    var _spatialAudioConfig_decorators;
    var _spatialAudioConfig_initializers = [];
    var _spatialAudioConfig_extraInitializers = [];
    var _serverControlConfig_decorators;
    var _serverControlConfig_initializers = [];
    var _serverControlConfig_extraInitializers = [];
    var _pushURL_decorators;
    var _pushURL_initializers = [];
    var _pushURL_extraInitializers = [];
    var _roomID_decorators;
    var _roomID_initializers = [];
    var _roomID_extraInitializers = [];
    var _userID_decorators;
    var _userID_initializers = [];
    var _userID_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMixedStreamConfig_1() {
            this.expectedMixingType = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _expectedMixingType_initializers, void 0));
            this.layoutConfig = (__runInitializers(this, _expectedMixingType_extraInitializers), __runInitializers(this, _layoutConfig_initializers, void 0));
            this.videoConfig = (__runInitializers(this, _layoutConfig_extraInitializers), __runInitializers(this, _videoConfig_initializers, void 0));
            this.audioConfig = (__runInitializers(this, _videoConfig_extraInitializers), __runInitializers(this, _audioConfig_initializers, void 0));
            this.clientMixConfig = (__runInitializers(this, _audioConfig_extraInitializers), __runInitializers(this, _clientMixConfig_initializers, void 0));
            this.spatialAudioConfig = (__runInitializers(this, _clientMixConfig_extraInitializers), __runInitializers(this, _spatialAudioConfig_initializers, void 0));
            this.serverControlConfig = (__runInitializers(this, _spatialAudioConfig_extraInitializers), __runInitializers(this, _serverControlConfig_initializers, void 0));
            this.pushURL = (__runInitializers(this, _serverControlConfig_extraInitializers), __runInitializers(this, _pushURL_initializers, void 0));
            this.roomID = (__runInitializers(this, _pushURL_extraInitializers), __runInitializers(this, _roomID_initializers, void 0));
            this.userID = (__runInitializers(this, _roomID_extraInitializers), __runInitializers(this, _userID_initializers, void 0));
            __runInitializers(this, _userID_extraInitializers);
        }
        ByteRTCMixedStreamConfig_1.defaultMixedStreamConfig = function () {
            throw new Error('not implement');
        };
        ByteRTCMixedStreamConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMixedStreamConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMixedStreamConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_defaultMixedStreamConfig_decorators = [NativeStaticMethodSync('defaultMixedStreamConfig')];
        _expectedMixingType_decorators = [NativeMember()];
        _layoutConfig_decorators = [NativeMember()];
        _videoConfig_decorators = [NativeMember()];
        _audioConfig_decorators = [NativeMember()];
        _clientMixConfig_decorators = [NativeMember()];
        _spatialAudioConfig_decorators = [NativeMember()];
        _serverControlConfig_decorators = [NativeMember()];
        _pushURL_decorators = [NativeMember()];
        _roomID_decorators = [NativeMember()];
        _userID_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _static_defaultMixedStreamConfig_decorators, { kind: "method", name: "defaultMixedStreamConfig", static: true, private: false, access: { has: function (obj) { return "defaultMixedStreamConfig" in obj; }, get: function (obj) { return obj.defaultMixedStreamConfig; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _expectedMixingType_decorators, { kind: "field", name: "expectedMixingType", static: false, private: false, access: { has: function (obj) { return "expectedMixingType" in obj; }, get: function (obj) { return obj.expectedMixingType; }, set: function (obj, value) { obj.expectedMixingType = value; } }, metadata: _metadata }, _expectedMixingType_initializers, _expectedMixingType_extraInitializers);
        __esDecorate(null, null, _layoutConfig_decorators, { kind: "field", name: "layoutConfig", static: false, private: false, access: { has: function (obj) { return "layoutConfig" in obj; }, get: function (obj) { return obj.layoutConfig; }, set: function (obj, value) { obj.layoutConfig = value; } }, metadata: _metadata }, _layoutConfig_initializers, _layoutConfig_extraInitializers);
        __esDecorate(null, null, _videoConfig_decorators, { kind: "field", name: "videoConfig", static: false, private: false, access: { has: function (obj) { return "videoConfig" in obj; }, get: function (obj) { return obj.videoConfig; }, set: function (obj, value) { obj.videoConfig = value; } }, metadata: _metadata }, _videoConfig_initializers, _videoConfig_extraInitializers);
        __esDecorate(null, null, _audioConfig_decorators, { kind: "field", name: "audioConfig", static: false, private: false, access: { has: function (obj) { return "audioConfig" in obj; }, get: function (obj) { return obj.audioConfig; }, set: function (obj, value) { obj.audioConfig = value; } }, metadata: _metadata }, _audioConfig_initializers, _audioConfig_extraInitializers);
        __esDecorate(null, null, _clientMixConfig_decorators, { kind: "field", name: "clientMixConfig", static: false, private: false, access: { has: function (obj) { return "clientMixConfig" in obj; }, get: function (obj) { return obj.clientMixConfig; }, set: function (obj, value) { obj.clientMixConfig = value; } }, metadata: _metadata }, _clientMixConfig_initializers, _clientMixConfig_extraInitializers);
        __esDecorate(null, null, _spatialAudioConfig_decorators, { kind: "field", name: "spatialAudioConfig", static: false, private: false, access: { has: function (obj) { return "spatialAudioConfig" in obj; }, get: function (obj) { return obj.spatialAudioConfig; }, set: function (obj, value) { obj.spatialAudioConfig = value; } }, metadata: _metadata }, _spatialAudioConfig_initializers, _spatialAudioConfig_extraInitializers);
        __esDecorate(null, null, _serverControlConfig_decorators, { kind: "field", name: "serverControlConfig", static: false, private: false, access: { has: function (obj) { return "serverControlConfig" in obj; }, get: function (obj) { return obj.serverControlConfig; }, set: function (obj, value) { obj.serverControlConfig = value; } }, metadata: _metadata }, _serverControlConfig_initializers, _serverControlConfig_extraInitializers);
        __esDecorate(null, null, _pushURL_decorators, { kind: "field", name: "pushURL", static: false, private: false, access: { has: function (obj) { return "pushURL" in obj; }, get: function (obj) { return obj.pushURL; }, set: function (obj, value) { obj.pushURL = value; } }, metadata: _metadata }, _pushURL_initializers, _pushURL_extraInitializers);
        __esDecorate(null, null, _roomID_decorators, { kind: "field", name: "roomID", static: false, private: false, access: { has: function (obj) { return "roomID" in obj; }, get: function (obj) { return obj.roomID; }, set: function (obj, value) { obj.roomID = value; } }, metadata: _metadata }, _roomID_initializers, _roomID_extraInitializers);
        __esDecorate(null, null, _userID_decorators, { kind: "field", name: "userID", static: false, private: false, access: { has: function (obj) { return "userID" in obj; }, get: function (obj) { return obj.userID; }, set: function (obj, value) { obj.userID = value; } }, metadata: _metadata }, _userID_initializers, _userID_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _staticExtraInitializers);
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCNetworkDetectionLinkType;
(function (ByteRTCNetworkDetectionLinkType) {
    ByteRTCNetworkDetectionLinkType[ByteRTCNetworkDetectionLinkType["ByteRTCNetworkDetectionLinkTypeUp"] = 0] = "ByteRTCNetworkDetectionLinkTypeUp";
    ByteRTCNetworkDetectionLinkType[ByteRTCNetworkDetectionLinkType["ByteRTCNetworkDetectionLinkTypeDown"] = 1] = "ByteRTCNetworkDetectionLinkTypeDown";
})(ByteRTCNetworkDetectionLinkType || (ByteRTCNetworkDetectionLinkType = {}));
var ByteRTCVirtualBackgroundSource = function () {
    var _classDecorators = [NativeClass('ByteRTCVirtualBackgroundSource')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _sourceType_decorators;
    var _sourceType_initializers = [];
    var _sourceType_extraInitializers = [];
    var _sourceColor_decorators;
    var _sourceColor_initializers = [];
    var _sourceColor_extraInitializers = [];
    var _sourcePath_decorators;
    var _sourcePath_initializers = [];
    var _sourcePath_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVirtualBackgroundSource_1() {
            this.sourceType = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _sourceType_initializers, void 0));
            this.sourceColor = (__runInitializers(this, _sourceType_extraInitializers), __runInitializers(this, _sourceColor_initializers, void 0));
            this.sourcePath = (__runInitializers(this, _sourceColor_extraInitializers), __runInitializers(this, _sourcePath_initializers, void 0));
            __runInitializers(this, _sourcePath_extraInitializers);
        }
        ByteRTCVirtualBackgroundSource_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVirtualBackgroundSource_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVirtualBackgroundSource");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _sourceType_decorators = [NativeMember()];
        _sourceColor_decorators = [NativeMember()];
        _sourcePath_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _sourceType_decorators, { kind: "field", name: "sourceType", static: false, private: false, access: { has: function (obj) { return "sourceType" in obj; }, get: function (obj) { return obj.sourceType; }, set: function (obj, value) { obj.sourceType = value; } }, metadata: _metadata }, _sourceType_initializers, _sourceType_extraInitializers);
        __esDecorate(null, null, _sourceColor_decorators, { kind: "field", name: "sourceColor", static: false, private: false, access: { has: function (obj) { return "sourceColor" in obj; }, get: function (obj) { return obj.sourceColor; }, set: function (obj, value) { obj.sourceColor = value; } }, metadata: _metadata }, _sourceColor_initializers, _sourceColor_extraInitializers);
        __esDecorate(null, null, _sourcePath_decorators, { kind: "field", name: "sourcePath", static: false, private: false, access: { has: function (obj) { return "sourcePath" in obj; }, get: function (obj) { return obj.sourcePath; }, set: function (obj, value) { obj.sourcePath = value; } }, metadata: _metadata }, _sourcePath_initializers, _sourcePath_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCLocalVideoSinkConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCLocalVideoSinkConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _position_decorators;
    var _position_initializers = [];
    var _position_extraInitializers = [];
    var _requiredPixelFormat_decorators;
    var _requiredPixelFormat_initializers = [];
    var _requiredPixelFormat_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCLocalVideoSinkConfig_1() {
            this.position = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _position_initializers, void 0));
            this.requiredPixelFormat = (__runInitializers(this, _position_extraInitializers), __runInitializers(this, _requiredPixelFormat_initializers, void 0));
            __runInitializers(this, _requiredPixelFormat_extraInitializers);
        }
        ByteRTCLocalVideoSinkConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCLocalVideoSinkConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCLocalVideoSinkConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _position_decorators = [NativeMember()];
        _requiredPixelFormat_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _position_decorators, { kind: "field", name: "position", static: false, private: false, access: { has: function (obj) { return "position" in obj; }, get: function (obj) { return obj.position; }, set: function (obj, value) { obj.position = value; } }, metadata: _metadata }, _position_initializers, _position_extraInitializers);
        __esDecorate(null, null, _requiredPixelFormat_decorators, { kind: "field", name: "requiredPixelFormat", static: false, private: false, access: { has: function (obj) { return "requiredPixelFormat" in obj; }, get: function (obj) { return obj.requiredPixelFormat; }, set: function (obj, value) { obj.requiredPixelFormat = value; } }, metadata: _metadata }, _requiredPixelFormat_initializers, _requiredPixelFormat_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCDataMessageSourceType;
(function (ByteRTCDataMessageSourceType) {
    ByteRTCDataMessageSourceType[ByteRTCDataMessageSourceType["ByteRTCDataMessageSourceTypeDefault"] = 0] = "ByteRTCDataMessageSourceTypeDefault";
    ByteRTCDataMessageSourceType[ByteRTCDataMessageSourceType["ByteRTCDataMessageSourceTypeSystem"] = 1] = "ByteRTCDataMessageSourceTypeSystem";
})(ByteRTCDataMessageSourceType || (ByteRTCDataMessageSourceType = {}));
var ByteRTCVideoCapturePreference;
(function (ByteRTCVideoCapturePreference) {
    ByteRTCVideoCapturePreference[ByteRTCVideoCapturePreference["ByteRTCVideoCapturePreferenceAuto"] = 0] = "ByteRTCVideoCapturePreferenceAuto";
    ByteRTCVideoCapturePreference[ByteRTCVideoCapturePreference["ByteRTCVideoCapturePreferenceMannal"] = 1] = "ByteRTCVideoCapturePreferenceMannal";
    ByteRTCVideoCapturePreference[ByteRTCVideoCapturePreference["ByteRTCVideoCapturePreferenceAutoPerformance"] = 2] = "ByteRTCVideoCapturePreferenceAutoPerformance";
})(ByteRTCVideoCapturePreference || (ByteRTCVideoCapturePreference = {}));
var ByteRTCProblemFeedbackOption;
(function (ByteRTCProblemFeedbackOption) {
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionNone"] = 0] = "ByteRTCProblemFeedbackOptionNone";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionOtherMessage"] = 1] = "ByteRTCProblemFeedbackOptionOtherMessage";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionDisconnected"] = 2] = "ByteRTCProblemFeedbackOptionDisconnected";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionEarBackDelay"] = 4] = "ByteRTCProblemFeedbackOptionEarBackDelay";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionLocalNoise"] = 1024] = "ByteRTCProblemFeedbackOptionLocalNoise";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionLocalAudioLagging"] = 2048] = "ByteRTCProblemFeedbackOptionLocalAudioLagging";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionLocalNoAudio"] = 4096] = "ByteRTCProblemFeedbackOptionLocalNoAudio";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionLocalAudioStrength"] = 8192] = "ByteRTCProblemFeedbackOptionLocalAudioStrength";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionLocalEcho"] = 16384] = "ByteRTCProblemFeedbackOptionLocalEcho";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionLocalVideoFuzzy"] = 16777216] = "ByteRTCProblemFeedbackOptionLocalVideoFuzzy";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionLocalNotSync"] = 33554432] = "ByteRTCProblemFeedbackOptionLocalNotSync";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionLocalVideoLagging"] = 67108864] = "ByteRTCProblemFeedbackOptionLocalVideoLagging";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionLocalNoVideo"] = 134217728] = "ByteRTCProblemFeedbackOptionLocalNoVideo";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionRemoteNoise"] = 32] = "ByteRTCProblemFeedbackOptionRemoteNoise";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionRemoteAudioLagging"] = 64] = "ByteRTCProblemFeedbackOptionRemoteAudioLagging";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionRemoteNoAudio"] = 128] = "ByteRTCProblemFeedbackOptionRemoteNoAudio";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionRemoteAudioStrength"] = 256] = "ByteRTCProblemFeedbackOptionRemoteAudioStrength";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionRemoteEcho"] = 512] = "ByteRTCProblemFeedbackOptionRemoteEcho";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionRemoteVideoFuzzy"] = 524288] = "ByteRTCProblemFeedbackOptionRemoteVideoFuzzy";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionRemoteNotSync"] = 1048576] = "ByteRTCProblemFeedbackOptionRemoteNotSync";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionRemoteVideoLagging"] = 2097152] = "ByteRTCProblemFeedbackOptionRemoteVideoLagging";
    ByteRTCProblemFeedbackOption[ByteRTCProblemFeedbackOption["ByteRTCProblemFeedbackOptionRemoteNoVideo"] = 4194304] = "ByteRTCProblemFeedbackOptionRemoteNoVideo";
})(ByteRTCProblemFeedbackOption || (ByteRTCProblemFeedbackOption = {}));
var ByteRTCAudioFormat = function () {
    var _classDecorators = [NativeClass('ByteRTCAudioFormat')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _sampleRate_decorators;
    var _sampleRate_initializers = [];
    var _sampleRate_extraInitializers = [];
    var _channel_decorators;
    var _channel_initializers = [];
    var _channel_extraInitializers = [];
    var _samplesPerCall_decorators;
    var _samplesPerCall_initializers = [];
    var _samplesPerCall_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioFormat_1() {
            this.sampleRate = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _sampleRate_initializers, void 0));
            this.channel = (__runInitializers(this, _sampleRate_extraInitializers), __runInitializers(this, _channel_initializers, void 0));
            this.samplesPerCall = (__runInitializers(this, _channel_extraInitializers), __runInitializers(this, _samplesPerCall_initializers, void 0));
            __runInitializers(this, _samplesPerCall_extraInitializers);
        }
        ByteRTCAudioFormat_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCAudioFormat_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioFormat");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _sampleRate_decorators = [NativeMember()];
        _channel_decorators = [NativeMember()];
        _samplesPerCall_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _sampleRate_decorators, { kind: "field", name: "sampleRate", static: false, private: false, access: { has: function (obj) { return "sampleRate" in obj; }, get: function (obj) { return obj.sampleRate; }, set: function (obj, value) { obj.sampleRate = value; } }, metadata: _metadata }, _sampleRate_initializers, _sampleRate_extraInitializers);
        __esDecorate(null, null, _channel_decorators, { kind: "field", name: "channel", static: false, private: false, access: { has: function (obj) { return "channel" in obj; }, get: function (obj) { return obj.channel; }, set: function (obj, value) { obj.channel = value; } }, metadata: _metadata }, _channel_initializers, _channel_extraInitializers);
        __esDecorate(null, null, _samplesPerCall_decorators, { kind: "field", name: "samplesPerCall", static: false, private: false, access: { has: function (obj) { return "samplesPerCall" in obj; }, get: function (obj) { return obj.samplesPerCall; }, set: function (obj, value) { obj.samplesPerCall = value; } }, metadata: _metadata }, _samplesPerCall_initializers, _samplesPerCall_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCNetworkType;
(function (ByteRTCNetworkType) {
    ByteRTCNetworkType[ByteRTCNetworkType["ByteRTCNetworkTypeUnknown"] = -1] = "ByteRTCNetworkTypeUnknown";
    ByteRTCNetworkType[ByteRTCNetworkType["ByteRTCNetworkTypeDisconnected"] = 0] = "ByteRTCNetworkTypeDisconnected";
    ByteRTCNetworkType[ByteRTCNetworkType["ByteRTCNetworkTypeLAN"] = 1] = "ByteRTCNetworkTypeLAN";
    ByteRTCNetworkType[ByteRTCNetworkType["ByteRTCNetworkTypeWIFI"] = 2] = "ByteRTCNetworkTypeWIFI";
    ByteRTCNetworkType[ByteRTCNetworkType["ByteRTCNetworkTypeMobile2G"] = 3] = "ByteRTCNetworkTypeMobile2G";
    ByteRTCNetworkType[ByteRTCNetworkType["ByteRTCNetworkTypeMobile3G"] = 4] = "ByteRTCNetworkTypeMobile3G";
    ByteRTCNetworkType[ByteRTCNetworkType["ByteRTCNetworkTypeMobile4G"] = 5] = "ByteRTCNetworkTypeMobile4G";
    ByteRTCNetworkType[ByteRTCNetworkType["ByteRTCNetworkTypeMobile5G"] = 6] = "ByteRTCNetworkTypeMobile5G";
})(ByteRTCNetworkType || (ByteRTCNetworkType = {}));
var ByteRTCVideoFrame = function () {
    var _classDecorators = [NativeClass('ByteRTCVideoFrame')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _format_decorators;
    var _format_initializers = [];
    var _format_extraInitializers = [];
    var _contentType_decorators;
    var _contentType_initializers = [];
    var _contentType_extraInitializers = [];
    var _time_decorators;
    var _time_initializers = [];
    var _time_extraInitializers = [];
    var _strideInPixels_decorators;
    var _strideInPixels_initializers = [];
    var _strideInPixels_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _textureBuf_decorators;
    var _textureBuf_initializers = [];
    var _textureBuf_extraInitializers = [];
    var _dataBuf_decorators;
    var _dataBuf_initializers = [];
    var _dataBuf_extraInitializers = [];
    var _rotation_decorators;
    var _rotation_initializers = [];
    var _rotation_extraInitializers = [];
    var _colorSpace_decorators;
    var _colorSpace_initializers = [];
    var _colorSpace_extraInitializers = [];
    var _cameraId_decorators;
    var _cameraId_initializers = [];
    var _cameraId_extraInitializers = [];
    var _extendedData_decorators;
    var _extendedData_initializers = [];
    var _extendedData_extraInitializers = [];
    var _supplementaryInfo_decorators;
    var _supplementaryInfo_initializers = [];
    var _supplementaryInfo_extraInitializers = [];
    var _numberOfPlanes_decorators;
    var _numberOfPlanes_initializers = [];
    var _numberOfPlanes_extraInitializers = [];
    var _planeDatas_decorators;
    var _planeDatas_initializers = [];
    var _planeDatas_extraInitializers = [];
    var _planeStrides_decorators;
    var _planeStrides_initializers = [];
    var _planeStrides_extraInitializers = [];
    var _stride_decorators;
    var _stride_initializers = [];
    var _stride_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoFrame_1() {
            this.format = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _format_initializers, void 0));
            this.contentType = (__runInitializers(this, _format_extraInitializers), __runInitializers(this, _contentType_initializers, void 0));
            this.time = (__runInitializers(this, _contentType_extraInitializers), __runInitializers(this, _time_initializers, void 0));
            this.strideInPixels = (__runInitializers(this, _time_extraInitializers), __runInitializers(this, _strideInPixels_initializers, void 0));
            this.width = (__runInitializers(this, _strideInPixels_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.textureBuf = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _textureBuf_initializers, void 0));
            this.dataBuf = (__runInitializers(this, _textureBuf_extraInitializers), __runInitializers(this, _dataBuf_initializers, void 0));
            this.rotation = (__runInitializers(this, _dataBuf_extraInitializers), __runInitializers(this, _rotation_initializers, void 0));
            this.colorSpace = (__runInitializers(this, _rotation_extraInitializers), __runInitializers(this, _colorSpace_initializers, void 0));
            this.cameraId = (__runInitializers(this, _colorSpace_extraInitializers), __runInitializers(this, _cameraId_initializers, void 0));
            this.extendedData = (__runInitializers(this, _cameraId_extraInitializers), __runInitializers(this, _extendedData_initializers, void 0));
            this.supplementaryInfo = (__runInitializers(this, _extendedData_extraInitializers), __runInitializers(this, _supplementaryInfo_initializers, void 0));
            this.numberOfPlanes = (__runInitializers(this, _supplementaryInfo_extraInitializers), __runInitializers(this, _numberOfPlanes_initializers, void 0));
            this.planeDatas = (__runInitializers(this, _numberOfPlanes_extraInitializers), __runInitializers(this, _planeDatas_initializers, void 0));
            this.planeStrides = (__runInitializers(this, _planeDatas_extraInitializers), __runInitializers(this, _planeStrides_initializers, void 0));
            this.stride = (__runInitializers(this, _planeStrides_extraInitializers), __runInitializers(this, _stride_initializers, void 0));
            __runInitializers(this, _stride_extraInitializers);
        }
        ByteRTCVideoFrame_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVideoFrame_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoFrame");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _format_decorators = [NativeMember()];
        _contentType_decorators = [NativeMember()];
        _time_decorators = [NativeMember()];
        _strideInPixels_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _textureBuf_decorators = [NativeMember()];
        _dataBuf_decorators = [NativeMember()];
        _rotation_decorators = [NativeMember()];
        _colorSpace_decorators = [NativeMember()];
        _cameraId_decorators = [NativeMember()];
        _extendedData_decorators = [NativeMember()];
        _supplementaryInfo_decorators = [NativeMember()];
        _numberOfPlanes_decorators = [NativeMember()];
        _planeDatas_decorators = [NativeMember()];
        _planeStrides_decorators = [NativeMember()];
        _stride_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _format_decorators, { kind: "field", name: "format", static: false, private: false, access: { has: function (obj) { return "format" in obj; }, get: function (obj) { return obj.format; }, set: function (obj, value) { obj.format = value; } }, metadata: _metadata }, _format_initializers, _format_extraInitializers);
        __esDecorate(null, null, _contentType_decorators, { kind: "field", name: "contentType", static: false, private: false, access: { has: function (obj) { return "contentType" in obj; }, get: function (obj) { return obj.contentType; }, set: function (obj, value) { obj.contentType = value; } }, metadata: _metadata }, _contentType_initializers, _contentType_extraInitializers);
        __esDecorate(null, null, _time_decorators, { kind: "field", name: "time", static: false, private: false, access: { has: function (obj) { return "time" in obj; }, get: function (obj) { return obj.time; }, set: function (obj, value) { obj.time = value; } }, metadata: _metadata }, _time_initializers, _time_extraInitializers);
        __esDecorate(null, null, _strideInPixels_decorators, { kind: "field", name: "strideInPixels", static: false, private: false, access: { has: function (obj) { return "strideInPixels" in obj; }, get: function (obj) { return obj.strideInPixels; }, set: function (obj, value) { obj.strideInPixels = value; } }, metadata: _metadata }, _strideInPixels_initializers, _strideInPixels_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _textureBuf_decorators, { kind: "field", name: "textureBuf", static: false, private: false, access: { has: function (obj) { return "textureBuf" in obj; }, get: function (obj) { return obj.textureBuf; }, set: function (obj, value) { obj.textureBuf = value; } }, metadata: _metadata }, _textureBuf_initializers, _textureBuf_extraInitializers);
        __esDecorate(null, null, _dataBuf_decorators, { kind: "field", name: "dataBuf", static: false, private: false, access: { has: function (obj) { return "dataBuf" in obj; }, get: function (obj) { return obj.dataBuf; }, set: function (obj, value) { obj.dataBuf = value; } }, metadata: _metadata }, _dataBuf_initializers, _dataBuf_extraInitializers);
        __esDecorate(null, null, _rotation_decorators, { kind: "field", name: "rotation", static: false, private: false, access: { has: function (obj) { return "rotation" in obj; }, get: function (obj) { return obj.rotation; }, set: function (obj, value) { obj.rotation = value; } }, metadata: _metadata }, _rotation_initializers, _rotation_extraInitializers);
        __esDecorate(null, null, _colorSpace_decorators, { kind: "field", name: "colorSpace", static: false, private: false, access: { has: function (obj) { return "colorSpace" in obj; }, get: function (obj) { return obj.colorSpace; }, set: function (obj, value) { obj.colorSpace = value; } }, metadata: _metadata }, _colorSpace_initializers, _colorSpace_extraInitializers);
        __esDecorate(null, null, _cameraId_decorators, { kind: "field", name: "cameraId", static: false, private: false, access: { has: function (obj) { return "cameraId" in obj; }, get: function (obj) { return obj.cameraId; }, set: function (obj, value) { obj.cameraId = value; } }, metadata: _metadata }, _cameraId_initializers, _cameraId_extraInitializers);
        __esDecorate(null, null, _extendedData_decorators, { kind: "field", name: "extendedData", static: false, private: false, access: { has: function (obj) { return "extendedData" in obj; }, get: function (obj) { return obj.extendedData; }, set: function (obj, value) { obj.extendedData = value; } }, metadata: _metadata }, _extendedData_initializers, _extendedData_extraInitializers);
        __esDecorate(null, null, _supplementaryInfo_decorators, { kind: "field", name: "supplementaryInfo", static: false, private: false, access: { has: function (obj) { return "supplementaryInfo" in obj; }, get: function (obj) { return obj.supplementaryInfo; }, set: function (obj, value) { obj.supplementaryInfo = value; } }, metadata: _metadata }, _supplementaryInfo_initializers, _supplementaryInfo_extraInitializers);
        __esDecorate(null, null, _numberOfPlanes_decorators, { kind: "field", name: "numberOfPlanes", static: false, private: false, access: { has: function (obj) { return "numberOfPlanes" in obj; }, get: function (obj) { return obj.numberOfPlanes; }, set: function (obj, value) { obj.numberOfPlanes = value; } }, metadata: _metadata }, _numberOfPlanes_initializers, _numberOfPlanes_extraInitializers);
        __esDecorate(null, null, _planeDatas_decorators, { kind: "field", name: "planeDatas", static: false, private: false, access: { has: function (obj) { return "planeDatas" in obj; }, get: function (obj) { return obj.planeDatas; }, set: function (obj, value) { obj.planeDatas = value; } }, metadata: _metadata }, _planeDatas_initializers, _planeDatas_extraInitializers);
        __esDecorate(null, null, _planeStrides_decorators, { kind: "field", name: "planeStrides", static: false, private: false, access: { has: function (obj) { return "planeStrides" in obj; }, get: function (obj) { return obj.planeStrides; }, set: function (obj, value) { obj.planeStrides = value; } }, metadata: _metadata }, _planeStrides_initializers, _planeStrides_extraInitializers);
        __esDecorate(null, null, _stride_decorators, { kind: "field", name: "stride", static: false, private: false, access: { has: function (obj) { return "stride" in obj; }, get: function (obj) { return obj.stride; }, set: function (obj, value) { obj.stride = value; } }, metadata: _metadata }, _stride_initializers, _stride_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCPlayerError;
(function (ByteRTCPlayerError) {
    ByteRTCPlayerError[ByteRTCPlayerError["ByteRTCPlayerErrorOK"] = 0] = "ByteRTCPlayerErrorOK";
    ByteRTCPlayerError[ByteRTCPlayerError["ByteRTCPlayerErrorFormatNotSupport"] = 1] = "ByteRTCPlayerErrorFormatNotSupport";
    ByteRTCPlayerError[ByteRTCPlayerError["ByteRTCPlayerErrorInvalidPath"] = 2] = "ByteRTCPlayerErrorInvalidPath";
    ByteRTCPlayerError[ByteRTCPlayerError["ByteRTCPlayerErrorInvalidState"] = 3] = "ByteRTCPlayerErrorInvalidState";
    ByteRTCPlayerError[ByteRTCPlayerError["ByteRTCPlayerErrorInvalidPosition"] = 4] = "ByteRTCPlayerErrorInvalidPosition";
    ByteRTCPlayerError[ByteRTCPlayerError["ByteRTCPlayerErrorInvalidVolume"] = 5] = "ByteRTCPlayerErrorInvalidVolume";
    ByteRTCPlayerError[ByteRTCPlayerError["ByteRTCPlayerErrorInvalidPitch"] = 6] = "ByteRTCPlayerErrorInvalidPitch";
    ByteRTCPlayerError[ByteRTCPlayerError["ByteRTCPlayerErrorInvalidAudioTrackIndex"] = 7] = "ByteRTCPlayerErrorInvalidAudioTrackIndex";
    ByteRTCPlayerError[ByteRTCPlayerError["ByteRTCPlayerErrorInvalidPlaybackSpeed"] = 8] = "ByteRTCPlayerErrorInvalidPlaybackSpeed";
    ByteRTCPlayerError[ByteRTCPlayerError["ByteRTCPlayerErrorInvalidEffectId"] = 9] = "ByteRTCPlayerErrorInvalidEffectId";
})(ByteRTCPlayerError || (ByteRTCPlayerError = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCAudioEnhancementConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _enhanceSignaling_decorators;
    var _enhanceSignaling_initializers = [];
    var _enhanceSignaling_extraInitializers = [];
    var _enhanceAudio_decorators;
    var _enhanceAudio_initializers = [];
    var _enhanceAudio_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioEnhancementConfig_1() {
            this.enhanceSignaling = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _enhanceSignaling_initializers, void 0));
            this.enhanceAudio = (__runInitializers(this, _enhanceSignaling_extraInitializers), __runInitializers(this, _enhanceAudio_initializers, void 0));
            __runInitializers(this, _enhanceAudio_extraInitializers);
        }
        ByteRTCAudioEnhancementConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCAudioEnhancementConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioEnhancementConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enhanceSignaling_decorators = [NativeMember()];
        _enhanceAudio_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _enhanceSignaling_decorators, { kind: "field", name: "enhanceSignaling", static: false, private: false, access: { has: function (obj) { return "enhanceSignaling" in obj; }, get: function (obj) { return obj.enhanceSignaling; }, set: function (obj, value) { obj.enhanceSignaling = value; } }, metadata: _metadata }, _enhanceSignaling_initializers, _enhanceSignaling_extraInitializers);
        __esDecorate(null, null, _enhanceAudio_decorators, { kind: "field", name: "enhanceAudio", static: false, private: false, access: { has: function (obj) { return "enhanceAudio" in obj; }, get: function (obj) { return obj.enhanceAudio; }, set: function (obj, value) { obj.enhanceAudio = value; } }, metadata: _metadata }, _enhanceAudio_initializers, _enhanceAudio_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCLocalAudioStreamState;
(function (ByteRTCLocalAudioStreamState) {
    ByteRTCLocalAudioStreamState[ByteRTCLocalAudioStreamState["ByteRTCLocalAudioStreamStateStopped"] = 0] = "ByteRTCLocalAudioStreamStateStopped";
    ByteRTCLocalAudioStreamState[ByteRTCLocalAudioStreamState["ByteRTCLocalAudioStreamStateRecording"] = 1] = "ByteRTCLocalAudioStreamStateRecording";
    ByteRTCLocalAudioStreamState[ByteRTCLocalAudioStreamState["ByteRTCLocalAudioStreamStateEncoding"] = 2] = "ByteRTCLocalAudioStreamStateEncoding";
    ByteRTCLocalAudioStreamState[ByteRTCLocalAudioStreamState["ByteRTCLocalAudioStreamStateFailed"] = 3] = "ByteRTCLocalAudioStreamStateFailed";
})(ByteRTCLocalAudioStreamState || (ByteRTCLocalAudioStreamState = {}));
var ByteRTCMixedStreamVideoType;
(function (ByteRTCMixedStreamVideoType) {
    ByteRTCMixedStreamVideoType[ByteRTCMixedStreamVideoType["ByteRTCMixedStreamVideoTypeMain"] = 0] = "ByteRTCMixedStreamVideoTypeMain";
    ByteRTCMixedStreamVideoType[ByteRTCMixedStreamVideoType["ByteRTCMixedStreamVideoTypeScreen"] = 1] = "ByteRTCMixedStreamVideoTypeScreen";
})(ByteRTCMixedStreamVideoType || (ByteRTCMixedStreamVideoType = {}));
var ByteRTCVoiceReverbType;
(function (ByteRTCVoiceReverbType) {
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbOriginal"] = 0] = "ByteRTCVoiceReverbOriginal";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbEcho"] = 1] = "ByteRTCVoiceReverbEcho";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbConcert"] = 2] = "ByteRTCVoiceReverbConcert";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbEthereal"] = 3] = "ByteRTCVoiceReverbEthereal";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbKTV"] = 4] = "ByteRTCVoiceReverbKTV";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbStudio"] = 5] = "ByteRTCVoiceReverbStudio";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbVirtualStereo"] = 6] = "ByteRTCVoiceReverbVirtualStereo";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbSpacious"] = 7] = "ByteRTCVoiceReverbSpacious";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverb3D"] = 8] = "ByteRTCVoiceReverb3D";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbPop"] = 9] = "ByteRTCVoiceReverbPop";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbDisco"] = 10] = "ByteRTCVoiceReverbDisco";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbOldRecord"] = 11] = "ByteRTCVoiceReverbOldRecord";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbHarmony"] = 12] = "ByteRTCVoiceReverbHarmony";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbRock"] = 13] = "ByteRTCVoiceReverbRock";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbBlues"] = 14] = "ByteRTCVoiceReverbBlues";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbJazz"] = 15] = "ByteRTCVoiceReverbJazz";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbElectronic"] = 16] = "ByteRTCVoiceReverbElectronic";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbVinyl"] = 17] = "ByteRTCVoiceReverbVinyl";
    ByteRTCVoiceReverbType[ByteRTCVoiceReverbType["ByteRTCVoiceReverbChamber"] = 18] = "ByteRTCVoiceReverbChamber";
})(ByteRTCVoiceReverbType || (ByteRTCVoiceReverbType = {}));
var ByteRTCAudioFrameSource;
(function (ByteRTCAudioFrameSource) {
    ByteRTCAudioFrameSource[ByteRTCAudioFrameSource["ByteRTCAudioFrameSourceTypeMic"] = 0] = "ByteRTCAudioFrameSourceTypeMic";
    ByteRTCAudioFrameSource[ByteRTCAudioFrameSource["ByteRTCAudioFrameSourceTypePlayback"] = 1] = "ByteRTCAudioFrameSourceTypePlayback";
    ByteRTCAudioFrameSource[ByteRTCAudioFrameSource["ByteRTCAudioFrameSourceTypeMixed"] = 2] = "ByteRTCAudioFrameSourceTypeMixed";
})(ByteRTCAudioFrameSource || (ByteRTCAudioFrameSource = {}));
var ByteRTCLocalAudioStreamError;
(function (ByteRTCLocalAudioStreamError) {
    ByteRTCLocalAudioStreamError[ByteRTCLocalAudioStreamError["ByteRTCLocalAudioStreamErrorOk"] = 0] = "ByteRTCLocalAudioStreamErrorOk";
    ByteRTCLocalAudioStreamError[ByteRTCLocalAudioStreamError["ByteRTCLocalAudioStreamErrorFailure"] = 1] = "ByteRTCLocalAudioStreamErrorFailure";
    ByteRTCLocalAudioStreamError[ByteRTCLocalAudioStreamError["ByteRTCLocalAudioStreamErrorDeviceNoPermission"] = 2] = "ByteRTCLocalAudioStreamErrorDeviceNoPermission";
    ByteRTCLocalAudioStreamError[ByteRTCLocalAudioStreamError["ByteRTCLocalAudioStreamErrorDeviceBusy"] = 3] = "ByteRTCLocalAudioStreamErrorDeviceBusy";
    ByteRTCLocalAudioStreamError[ByteRTCLocalAudioStreamError["ByteRTCLocalAudioStreamErrorRecordFailure"] = 4] = "ByteRTCLocalAudioStreamErrorRecordFailure";
    ByteRTCLocalAudioStreamError[ByteRTCLocalAudioStreamError["ByteRTCLocalAudioStreamErrorEncodeFailure"] = 5] = "ByteRTCLocalAudioStreamErrorEncodeFailure";
    ByteRTCLocalAudioStreamError[ByteRTCLocalAudioStreamError["ByteRTCLocalAudioStreamErrorNoRecordingDevice"] = 6] = "ByteRTCLocalAudioStreamErrorNoRecordingDevice";
})(ByteRTCLocalAudioStreamError || (ByteRTCLocalAudioStreamError = {}));
var ByteRTCUserOfflineReason;
(function (ByteRTCUserOfflineReason) {
    ByteRTCUserOfflineReason[ByteRTCUserOfflineReason["ByteRTCUserOfflineReasonQuit"] = 0] = "ByteRTCUserOfflineReasonQuit";
    ByteRTCUserOfflineReason[ByteRTCUserOfflineReason["ByteRTCUserOfflineReasonDropped"] = 1] = "ByteRTCUserOfflineReasonDropped";
    ByteRTCUserOfflineReason[ByteRTCUserOfflineReason["ByteRTCUserOfflineReasonSwitchToInvisible"] = 2] = "ByteRTCUserOfflineReasonSwitchToInvisible";
    ByteRTCUserOfflineReason[ByteRTCUserOfflineReason["ByteRTCUserOfflineReasonKickedByAdmin"] = 3] = "ByteRTCUserOfflineReasonKickedByAdmin";
})(ByteRTCUserOfflineReason || (ByteRTCUserOfflineReason = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCExpressionDetectInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _age_decorators;
    var _age_initializers = [];
    var _age_extraInitializers = [];
    var _boyProb_decorators;
    var _boyProb_initializers = [];
    var _boyProb_extraInitializers = [];
    var _attractive_decorators;
    var _attractive_initializers = [];
    var _attractive_extraInitializers = [];
    var _happyScore_decorators;
    var _happyScore_initializers = [];
    var _happyScore_extraInitializers = [];
    var _sadScore_decorators;
    var _sadScore_initializers = [];
    var _sadScore_extraInitializers = [];
    var _angryScore_decorators;
    var _angryScore_initializers = [];
    var _angryScore_extraInitializers = [];
    var _surpriseScore_decorators;
    var _surpriseScore_initializers = [];
    var _surpriseScore_extraInitializers = [];
    var _arousal_decorators;
    var _arousal_initializers = [];
    var _arousal_extraInitializers = [];
    var _valence_decorators;
    var _valence_initializers = [];
    var _valence_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCExpressionDetectInfo_1() {
            this.age = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _age_initializers, void 0));
            this.boyProb = (__runInitializers(this, _age_extraInitializers), __runInitializers(this, _boyProb_initializers, void 0));
            this.attractive = (__runInitializers(this, _boyProb_extraInitializers), __runInitializers(this, _attractive_initializers, void 0));
            this.happyScore = (__runInitializers(this, _attractive_extraInitializers), __runInitializers(this, _happyScore_initializers, void 0));
            this.sadScore = (__runInitializers(this, _happyScore_extraInitializers), __runInitializers(this, _sadScore_initializers, void 0));
            this.angryScore = (__runInitializers(this, _sadScore_extraInitializers), __runInitializers(this, _angryScore_initializers, void 0));
            this.surpriseScore = (__runInitializers(this, _angryScore_extraInitializers), __runInitializers(this, _surpriseScore_initializers, void 0));
            this.arousal = (__runInitializers(this, _surpriseScore_extraInitializers), __runInitializers(this, _arousal_initializers, void 0));
            this.valence = (__runInitializers(this, _arousal_extraInitializers), __runInitializers(this, _valence_initializers, void 0));
            __runInitializers(this, _valence_extraInitializers);
        }
        ByteRTCExpressionDetectInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCExpressionDetectInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCExpressionDetectInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _age_decorators = [NativeMember()];
        _boyProb_decorators = [NativeMember()];
        _attractive_decorators = [NativeMember()];
        _happyScore_decorators = [NativeMember()];
        _sadScore_decorators = [NativeMember()];
        _angryScore_decorators = [NativeMember()];
        _surpriseScore_decorators = [NativeMember()];
        _arousal_decorators = [NativeMember()];
        _valence_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _age_decorators, { kind: "field", name: "age", static: false, private: false, access: { has: function (obj) { return "age" in obj; }, get: function (obj) { return obj.age; }, set: function (obj, value) { obj.age = value; } }, metadata: _metadata }, _age_initializers, _age_extraInitializers);
        __esDecorate(null, null, _boyProb_decorators, { kind: "field", name: "boyProb", static: false, private: false, access: { has: function (obj) { return "boyProb" in obj; }, get: function (obj) { return obj.boyProb; }, set: function (obj, value) { obj.boyProb = value; } }, metadata: _metadata }, _boyProb_initializers, _boyProb_extraInitializers);
        __esDecorate(null, null, _attractive_decorators, { kind: "field", name: "attractive", static: false, private: false, access: { has: function (obj) { return "attractive" in obj; }, get: function (obj) { return obj.attractive; }, set: function (obj, value) { obj.attractive = value; } }, metadata: _metadata }, _attractive_initializers, _attractive_extraInitializers);
        __esDecorate(null, null, _happyScore_decorators, { kind: "field", name: "happyScore", static: false, private: false, access: { has: function (obj) { return "happyScore" in obj; }, get: function (obj) { return obj.happyScore; }, set: function (obj, value) { obj.happyScore = value; } }, metadata: _metadata }, _happyScore_initializers, _happyScore_extraInitializers);
        __esDecorate(null, null, _sadScore_decorators, { kind: "field", name: "sadScore", static: false, private: false, access: { has: function (obj) { return "sadScore" in obj; }, get: function (obj) { return obj.sadScore; }, set: function (obj, value) { obj.sadScore = value; } }, metadata: _metadata }, _sadScore_initializers, _sadScore_extraInitializers);
        __esDecorate(null, null, _angryScore_decorators, { kind: "field", name: "angryScore", static: false, private: false, access: { has: function (obj) { return "angryScore" in obj; }, get: function (obj) { return obj.angryScore; }, set: function (obj, value) { obj.angryScore = value; } }, metadata: _metadata }, _angryScore_initializers, _angryScore_extraInitializers);
        __esDecorate(null, null, _surpriseScore_decorators, { kind: "field", name: "surpriseScore", static: false, private: false, access: { has: function (obj) { return "surpriseScore" in obj; }, get: function (obj) { return obj.surpriseScore; }, set: function (obj, value) { obj.surpriseScore = value; } }, metadata: _metadata }, _surpriseScore_initializers, _surpriseScore_extraInitializers);
        __esDecorate(null, null, _arousal_decorators, { kind: "field", name: "arousal", static: false, private: false, access: { has: function (obj) { return "arousal" in obj; }, get: function (obj) { return obj.arousal; }, set: function (obj, value) { obj.arousal = value; } }, metadata: _metadata }, _arousal_initializers, _arousal_extraInitializers);
        __esDecorate(null, null, _valence_decorators, { kind: "field", name: "valence", static: false, private: false, access: { has: function (obj) { return "valence" in obj; }, get: function (obj) { return obj.valence; }, set: function (obj, value) { obj.valence = value; } }, metadata: _metadata }, _valence_initializers, _valence_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
(function () {
    var _classDecorators = [NativeClass('ByteRTCForwardStreamConfiguration')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _token_decorators;
    var _token_initializers = [];
    var _token_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCForwardStreamConfiguration_1() {
            this.roomId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _roomId_initializers, void 0));
            this.token = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _token_initializers, void 0));
            __runInitializers(this, _token_extraInitializers);
        }
        ByteRTCForwardStreamConfiguration_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCForwardStreamConfiguration_1;
    }());
    __setFunctionName(_classThis, "ByteRTCForwardStreamConfiguration");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _roomId_decorators = [NativeMember()];
        _token_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _token_decorators, { kind: "field", name: "token", static: false, private: false, access: { has: function (obj) { return "token" in obj; }, get: function (obj) { return obj.token; }, set: function (obj, value) { obj.token = value; } }, metadata: _metadata }, _token_initializers, _token_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCVideoEncoderConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCVideoEncoderConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _frameRate_decorators;
    var _frameRate_initializers = [];
    var _frameRate_extraInitializers = [];
    var _maxBitrate_decorators;
    var _maxBitrate_initializers = [];
    var _maxBitrate_extraInitializers = [];
    var _minBitrate_decorators;
    var _minBitrate_initializers = [];
    var _minBitrate_extraInitializers = [];
    var _encoderPreference_decorators;
    var _encoderPreference_initializers = [];
    var _encoderPreference_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoEncoderConfig_1() {
            this.width = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.frameRate = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _frameRate_initializers, void 0));
            this.maxBitrate = (__runInitializers(this, _frameRate_extraInitializers), __runInitializers(this, _maxBitrate_initializers, void 0));
            this.minBitrate = (__runInitializers(this, _maxBitrate_extraInitializers), __runInitializers(this, _minBitrate_initializers, void 0));
            this.encoderPreference = (__runInitializers(this, _minBitrate_extraInitializers), __runInitializers(this, _encoderPreference_initializers, void 0));
            __runInitializers(this, _encoderPreference_extraInitializers);
        }
        ByteRTCVideoEncoderConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVideoEncoderConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoEncoderConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _frameRate_decorators = [NativeMember()];
        _maxBitrate_decorators = [NativeMember()];
        _minBitrate_decorators = [NativeMember()];
        _encoderPreference_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _frameRate_decorators, { kind: "field", name: "frameRate", static: false, private: false, access: { has: function (obj) { return "frameRate" in obj; }, get: function (obj) { return obj.frameRate; }, set: function (obj, value) { obj.frameRate = value; } }, metadata: _metadata }, _frameRate_initializers, _frameRate_extraInitializers);
        __esDecorate(null, null, _maxBitrate_decorators, { kind: "field", name: "maxBitrate", static: false, private: false, access: { has: function (obj) { return "maxBitrate" in obj; }, get: function (obj) { return obj.maxBitrate; }, set: function (obj, value) { obj.maxBitrate = value; } }, metadata: _metadata }, _maxBitrate_initializers, _maxBitrate_extraInitializers);
        __esDecorate(null, null, _minBitrate_decorators, { kind: "field", name: "minBitrate", static: false, private: false, access: { has: function (obj) { return "minBitrate" in obj; }, get: function (obj) { return obj.minBitrate; }, set: function (obj, value) { obj.minBitrate = value; } }, metadata: _metadata }, _minBitrate_initializers, _minBitrate_extraInitializers);
        __esDecorate(null, null, _encoderPreference_decorators, { kind: "field", name: "encoderPreference", static: false, private: false, access: { has: function (obj) { return "encoderPreference" in obj; }, get: function (obj) { return obj.encoderPreference; }, set: function (obj, value) { obj.encoderPreference = value; } }, metadata: _metadata }, _encoderPreference_initializers, _encoderPreference_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCUserVisibilityChangeError;
(function (ByteRTCUserVisibilityChangeError) {
    ByteRTCUserVisibilityChangeError[ByteRTCUserVisibilityChangeError["ByteRTCUserVisibilityChangeErrorOk"] = 0] = "ByteRTCUserVisibilityChangeErrorOk";
    ByteRTCUserVisibilityChangeError[ByteRTCUserVisibilityChangeError["ByteRTCUserVisibilityChangeErrorUnknown"] = 1] = "ByteRTCUserVisibilityChangeErrorUnknown";
    ByteRTCUserVisibilityChangeError[ByteRTCUserVisibilityChangeError["ByteRTCUserVisibilityChangeErrorTooManyVisibleUser"] = 2] = "ByteRTCUserVisibilityChangeErrorTooManyVisibleUser";
})(ByteRTCUserVisibilityChangeError || (ByteRTCUserVisibilityChangeError = {}));
var ByteRTCKTVPlayerErrorCode;
(function (ByteRTCKTVPlayerErrorCode) {
    ByteRTCKTVPlayerErrorCode[ByteRTCKTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeOK"] = 0] = "ByteRTCKTVPlayerErrorCodeOK";
    ByteRTCKTVPlayerErrorCode[ByteRTCKTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeFileNotExist"] = -3020] = "ByteRTCKTVPlayerErrorCodeFileNotExist";
    ByteRTCKTVPlayerErrorCode[ByteRTCKTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeFileError"] = -3021] = "ByteRTCKTVPlayerErrorCodeFileError";
    ByteRTCKTVPlayerErrorCode[ByteRTCKTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeNotJoinRoom"] = -3022] = "ByteRTCKTVPlayerErrorCodeNotJoinRoom";
    ByteRTCKTVPlayerErrorCode[ByteRTCKTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeParam"] = -3023] = "ByteRTCKTVPlayerErrorCodeParam";
    ByteRTCKTVPlayerErrorCode[ByteRTCKTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeStartError"] = -3024] = "ByteRTCKTVPlayerErrorCodeStartError";
    ByteRTCKTVPlayerErrorCode[ByteRTCKTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeMixIdError"] = -3025] = "ByteRTCKTVPlayerErrorCodeMixIdError";
    ByteRTCKTVPlayerErrorCode[ByteRTCKTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodePositionError"] = -3026] = "ByteRTCKTVPlayerErrorCodePositionError";
    ByteRTCKTVPlayerErrorCode[ByteRTCKTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeAudioVolumeError"] = -3027] = "ByteRTCKTVPlayerErrorCodeAudioVolumeError";
    ByteRTCKTVPlayerErrorCode[ByteRTCKTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeTypeError"] = -3028] = "ByteRTCKTVPlayerErrorCodeTypeError";
    ByteRTCKTVPlayerErrorCode[ByteRTCKTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodePitchError"] = -3029] = "ByteRTCKTVPlayerErrorCodePitchError";
    ByteRTCKTVPlayerErrorCode[ByteRTCKTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeAudioTrackError"] = -3030] = "ByteRTCKTVPlayerErrorCodeAudioTrackError";
    ByteRTCKTVPlayerErrorCode[ByteRTCKTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeStartingError"] = -3031] = "ByteRTCKTVPlayerErrorCodeStartingError";
})(ByteRTCKTVPlayerErrorCode || (ByteRTCKTVPlayerErrorCode = {}));
var ByteRTCMusicFilterType;
(function (ByteRTCMusicFilterType) {
    ByteRTCMusicFilterType[ByteRTCMusicFilterType["ByteRTCMusicFilterTypeNone"] = 0] = "ByteRTCMusicFilterTypeNone";
    ByteRTCMusicFilterType[ByteRTCMusicFilterType["ByteRTCMusicFilterTypeWithoutLyric"] = 1] = "ByteRTCMusicFilterTypeWithoutLyric";
    ByteRTCMusicFilterType[ByteRTCMusicFilterType["ByteRTCMusicFilterTypeUnsupportedScore"] = 2] = "ByteRTCMusicFilterTypeUnsupportedScore";
    ByteRTCMusicFilterType[ByteRTCMusicFilterType["ByteRTCMusicFilterTypeUnsupportedAccopmay"] = 4] = "ByteRTCMusicFilterTypeUnsupportedAccopmay";
    ByteRTCMusicFilterType[ByteRTCMusicFilterType["ByteRTCMusicFilterTypeUnsupportedClimx"] = 8] = "ByteRTCMusicFilterTypeUnsupportedClimx";
})(ByteRTCMusicFilterType || (ByteRTCMusicFilterType = {}));
var ByteRTCLocalProxyType;
(function (ByteRTCLocalProxyType) {
    ByteRTCLocalProxyType[ByteRTCLocalProxyType["ByteRTCLocalProxyTypeSocks5"] = 1] = "ByteRTCLocalProxyTypeSocks5";
    ByteRTCLocalProxyType[ByteRTCLocalProxyType["ByteRTCLocalProxyTypeHttpTunnel"] = 2] = "ByteRTCLocalProxyTypeHttpTunnel";
})(ByteRTCLocalProxyType || (ByteRTCLocalProxyType = {}));
var ByteRTCForwardStreamEventInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCForwardStreamEventInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _event_decorators;
    var _event_initializers = [];
    var _event_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCForwardStreamEventInfo_1() {
            this.roomId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _roomId_initializers, void 0));
            this.event = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _event_initializers, void 0));
            __runInitializers(this, _event_extraInitializers);
        }
        ByteRTCForwardStreamEventInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCForwardStreamEventInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCForwardStreamEventInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _roomId_decorators = [NativeMember()];
        _event_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _event_decorators, { kind: "field", name: "event", static: false, private: false, access: { has: function (obj) { return "event" in obj; }, get: function (obj) { return obj.event; }, set: function (obj, value) { obj.event = value; } }, metadata: _metadata }, _event_initializers, _event_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCMixedStreamClientMixVideoFormat;
(function (ByteRTCMixedStreamClientMixVideoFormat) {
    ByteRTCMixedStreamClientMixVideoFormat[ByteRTCMixedStreamClientMixVideoFormat["ByteRTCMixedStreamClientMixVideoFormatI420"] = 0] = "ByteRTCMixedStreamClientMixVideoFormatI420";
    ByteRTCMixedStreamClientMixVideoFormat[ByteRTCMixedStreamClientMixVideoFormat["ByteRTCMixedStreamClientMixVideoFormatTexture2D"] = 1] = "ByteRTCMixedStreamClientMixVideoFormatTexture2D";
    ByteRTCMixedStreamClientMixVideoFormat[ByteRTCMixedStreamClientMixVideoFormat["ByteRTCMixedStreamClientMixVideoFormatCVPixelBufferBGRA"] = 2] = "ByteRTCMixedStreamClientMixVideoFormatCVPixelBufferBGRA";
    ByteRTCMixedStreamClientMixVideoFormat[ByteRTCMixedStreamClientMixVideoFormat["ByteRTCMixedStreamClientMixVideoFormatNV12"] = 3] = "ByteRTCMixedStreamClientMixVideoFormatNV12";
})(ByteRTCMixedStreamClientMixVideoFormat || (ByteRTCMixedStreamClientMixVideoFormat = {}));
var ByteRTCLocalLogLevel;
(function (ByteRTCLocalLogLevel) {
    ByteRTCLocalLogLevel[ByteRTCLocalLogLevel["ByteRTCLocalLogLevelInfo"] = 0] = "ByteRTCLocalLogLevelInfo";
    ByteRTCLocalLogLevel[ByteRTCLocalLogLevel["ByteRTCLocalLogLevelWarning"] = 1] = "ByteRTCLocalLogLevelWarning";
    ByteRTCLocalLogLevel[ByteRTCLocalLogLevel["ByteRTCLocalLogLevelError"] = 2] = "ByteRTCLocalLogLevelError";
    ByteRTCLocalLogLevel[ByteRTCLocalLogLevel["ByteRTCLocalLogLevelNone"] = 3] = "ByteRTCLocalLogLevelNone";
})(ByteRTCLocalLogLevel || (ByteRTCLocalLogLevel = {}));
var ByteRTCLocalProxyState;
(function (ByteRTCLocalProxyState) {
    ByteRTCLocalProxyState[ByteRTCLocalProxyState["ByteRTCLocalProxyStateInited"] = 0] = "ByteRTCLocalProxyStateInited";
    ByteRTCLocalProxyState[ByteRTCLocalProxyState["ByteRTCLocalProxyStateConnected"] = 1] = "ByteRTCLocalProxyStateConnected";
    ByteRTCLocalProxyState[ByteRTCLocalProxyState["ByteRTCLocalProxyStateError"] = 2] = "ByteRTCLocalProxyStateError";
})(ByteRTCLocalProxyState || (ByteRTCLocalProxyState = {}));
var ByteRTCStreamIndex;
(function (ByteRTCStreamIndex) {
    ByteRTCStreamIndex[ByteRTCStreamIndex["ByteRTCStreamIndexMain"] = 0] = "ByteRTCStreamIndexMain";
    ByteRTCStreamIndex[ByteRTCStreamIndex["ByteRTCStreamIndexScreen"] = 1] = "ByteRTCStreamIndexScreen";
    ByteRTCStreamIndex[ByteRTCStreamIndex["ByteRTCStreamIndex3rd"] = 2] = "ByteRTCStreamIndex3rd";
    ByteRTCStreamIndex[ByteRTCStreamIndex["ByteRTCStreamIndex4th"] = 3] = "ByteRTCStreamIndex4th";
    ByteRTCStreamIndex[ByteRTCStreamIndex["ByteRTCStreamIndex5th"] = 4] = "ByteRTCStreamIndex5th";
    ByteRTCStreamIndex[ByteRTCStreamIndex["ByteRTCStreamIndex6th"] = 5] = "ByteRTCStreamIndex6th";
    ByteRTCStreamIndex[ByteRTCStreamIndex["ByteRTCStreamIndex7th"] = 6] = "ByteRTCStreamIndex7th";
    ByteRTCStreamIndex[ByteRTCStreamIndex["ByteRTCStreamIndexMax"] = 7] = "ByteRTCStreamIndexMax";
})(ByteRTCStreamIndex || (ByteRTCStreamIndex = {}));
var ByteRTCScreenVideoEncoderConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCScreenVideoEncoderConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _frameRate_decorators;
    var _frameRate_initializers = [];
    var _frameRate_extraInitializers = [];
    var _maxBitrate_decorators;
    var _maxBitrate_initializers = [];
    var _maxBitrate_extraInitializers = [];
    var _minBitrate_decorators;
    var _minBitrate_initializers = [];
    var _minBitrate_extraInitializers = [];
    var _encoderPreference_decorators;
    var _encoderPreference_initializers = [];
    var _encoderPreference_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCScreenVideoEncoderConfig_1() {
            this.width = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.frameRate = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _frameRate_initializers, void 0));
            this.maxBitrate = (__runInitializers(this, _frameRate_extraInitializers), __runInitializers(this, _maxBitrate_initializers, void 0));
            this.minBitrate = (__runInitializers(this, _maxBitrate_extraInitializers), __runInitializers(this, _minBitrate_initializers, void 0));
            this.encoderPreference = (__runInitializers(this, _minBitrate_extraInitializers), __runInitializers(this, _encoderPreference_initializers, void 0));
            __runInitializers(this, _encoderPreference_extraInitializers);
        }
        ByteRTCScreenVideoEncoderConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCScreenVideoEncoderConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCScreenVideoEncoderConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _frameRate_decorators = [NativeMember()];
        _maxBitrate_decorators = [NativeMember()];
        _minBitrate_decorators = [NativeMember()];
        _encoderPreference_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _frameRate_decorators, { kind: "field", name: "frameRate", static: false, private: false, access: { has: function (obj) { return "frameRate" in obj; }, get: function (obj) { return obj.frameRate; }, set: function (obj, value) { obj.frameRate = value; } }, metadata: _metadata }, _frameRate_initializers, _frameRate_extraInitializers);
        __esDecorate(null, null, _maxBitrate_decorators, { kind: "field", name: "maxBitrate", static: false, private: false, access: { has: function (obj) { return "maxBitrate" in obj; }, get: function (obj) { return obj.maxBitrate; }, set: function (obj, value) { obj.maxBitrate = value; } }, metadata: _metadata }, _maxBitrate_initializers, _maxBitrate_extraInitializers);
        __esDecorate(null, null, _minBitrate_decorators, { kind: "field", name: "minBitrate", static: false, private: false, access: { has: function (obj) { return "minBitrate" in obj; }, get: function (obj) { return obj.minBitrate; }, set: function (obj, value) { obj.minBitrate = value; } }, metadata: _metadata }, _minBitrate_initializers, _minBitrate_extraInitializers);
        __esDecorate(null, null, _encoderPreference_decorators, { kind: "field", name: "encoderPreference", static: false, private: false, access: { has: function (obj) { return "encoderPreference" in obj; }, get: function (obj) { return obj.encoderPreference; }, set: function (obj, value) { obj.encoderPreference = value; } }, metadata: _metadata }, _encoderPreference_initializers, _encoderPreference_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCSysStats = function () {
    var _classDecorators = [NativeClass('ByteRTCSysStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _cpuCores_decorators;
    var _cpuCores_initializers = [];
    var _cpuCores_extraInitializers = [];
    var _cpuAppUsage_decorators;
    var _cpuAppUsage_initializers = [];
    var _cpuAppUsage_extraInitializers = [];
    var _memoryUsage_decorators;
    var _memoryUsage_initializers = [];
    var _memoryUsage_extraInitializers = [];
    var _fullMemory_decorators;
    var _fullMemory_initializers = [];
    var _fullMemory_extraInitializers = [];
    var _totalMemoryUsage_decorators;
    var _totalMemoryUsage_initializers = [];
    var _totalMemoryUsage_extraInitializers = [];
    var _freeMemory_decorators;
    var _freeMemory_initializers = [];
    var _freeMemory_extraInitializers = [];
    var _memoryRatio_decorators;
    var _memoryRatio_initializers = [];
    var _memoryRatio_extraInitializers = [];
    var _totalMemoryRatio_decorators;
    var _totalMemoryRatio_initializers = [];
    var _totalMemoryRatio_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCSysStats_1() {
            this.cpuCores = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _cpuCores_initializers, void 0));
            this.cpuAppUsage = (__runInitializers(this, _cpuCores_extraInitializers), __runInitializers(this, _cpuAppUsage_initializers, void 0));
            this.memoryUsage = (__runInitializers(this, _cpuAppUsage_extraInitializers), __runInitializers(this, _memoryUsage_initializers, void 0));
            this.fullMemory = (__runInitializers(this, _memoryUsage_extraInitializers), __runInitializers(this, _fullMemory_initializers, void 0));
            this.totalMemoryUsage = (__runInitializers(this, _fullMemory_extraInitializers), __runInitializers(this, _totalMemoryUsage_initializers, void 0));
            this.freeMemory = (__runInitializers(this, _totalMemoryUsage_extraInitializers), __runInitializers(this, _freeMemory_initializers, void 0));
            this.memoryRatio = (__runInitializers(this, _freeMemory_extraInitializers), __runInitializers(this, _memoryRatio_initializers, void 0));
            this.totalMemoryRatio = (__runInitializers(this, _memoryRatio_extraInitializers), __runInitializers(this, _totalMemoryRatio_initializers, void 0));
            __runInitializers(this, _totalMemoryRatio_extraInitializers);
        }
        ByteRTCSysStats_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCSysStats_1;
    }());
    __setFunctionName(_classThis, "ByteRTCSysStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _cpuCores_decorators = [NativeMember()];
        _cpuAppUsage_decorators = [NativeMember()];
        _memoryUsage_decorators = [NativeMember()];
        _fullMemory_decorators = [NativeMember()];
        _totalMemoryUsage_decorators = [NativeMember()];
        _freeMemory_decorators = [NativeMember()];
        _memoryRatio_decorators = [NativeMember()];
        _totalMemoryRatio_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _cpuCores_decorators, { kind: "field", name: "cpuCores", static: false, private: false, access: { has: function (obj) { return "cpuCores" in obj; }, get: function (obj) { return obj.cpuCores; }, set: function (obj, value) { obj.cpuCores = value; } }, metadata: _metadata }, _cpuCores_initializers, _cpuCores_extraInitializers);
        __esDecorate(null, null, _cpuAppUsage_decorators, { kind: "field", name: "cpuAppUsage", static: false, private: false, access: { has: function (obj) { return "cpuAppUsage" in obj; }, get: function (obj) { return obj.cpuAppUsage; }, set: function (obj, value) { obj.cpuAppUsage = value; } }, metadata: _metadata }, _cpuAppUsage_initializers, _cpuAppUsage_extraInitializers);
        __esDecorate(null, null, _memoryUsage_decorators, { kind: "field", name: "memoryUsage", static: false, private: false, access: { has: function (obj) { return "memoryUsage" in obj; }, get: function (obj) { return obj.memoryUsage; }, set: function (obj, value) { obj.memoryUsage = value; } }, metadata: _metadata }, _memoryUsage_initializers, _memoryUsage_extraInitializers);
        __esDecorate(null, null, _fullMemory_decorators, { kind: "field", name: "fullMemory", static: false, private: false, access: { has: function (obj) { return "fullMemory" in obj; }, get: function (obj) { return obj.fullMemory; }, set: function (obj, value) { obj.fullMemory = value; } }, metadata: _metadata }, _fullMemory_initializers, _fullMemory_extraInitializers);
        __esDecorate(null, null, _totalMemoryUsage_decorators, { kind: "field", name: "totalMemoryUsage", static: false, private: false, access: { has: function (obj) { return "totalMemoryUsage" in obj; }, get: function (obj) { return obj.totalMemoryUsage; }, set: function (obj, value) { obj.totalMemoryUsage = value; } }, metadata: _metadata }, _totalMemoryUsage_initializers, _totalMemoryUsage_extraInitializers);
        __esDecorate(null, null, _freeMemory_decorators, { kind: "field", name: "freeMemory", static: false, private: false, access: { has: function (obj) { return "freeMemory" in obj; }, get: function (obj) { return obj.freeMemory; }, set: function (obj, value) { obj.freeMemory = value; } }, metadata: _metadata }, _freeMemory_initializers, _freeMemory_extraInitializers);
        __esDecorate(null, null, _memoryRatio_decorators, { kind: "field", name: "memoryRatio", static: false, private: false, access: { has: function (obj) { return "memoryRatio" in obj; }, get: function (obj) { return obj.memoryRatio; }, set: function (obj, value) { obj.memoryRatio = value; } }, metadata: _metadata }, _memoryRatio_initializers, _memoryRatio_extraInitializers);
        __esDecorate(null, null, _totalMemoryRatio_decorators, { kind: "field", name: "totalMemoryRatio", static: false, private: false, access: { has: function (obj) { return "totalMemoryRatio" in obj; }, get: function (obj) { return obj.totalMemoryRatio; }, set: function (obj, value) { obj.totalMemoryRatio = value; } }, metadata: _metadata }, _totalMemoryRatio_initializers, _totalMemoryRatio_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCVideoStreamState;
(function (ByteRTCVideoStreamState) {
    ByteRTCVideoStreamState[ByteRTCVideoStreamState["ByteRTCVideoStreamStateSuccess"] = 0] = "ByteRTCVideoStreamStateSuccess";
    ByteRTCVideoStreamState[ByteRTCVideoStreamState["ByteRTCVideoStreamStateInvalid"] = -2] = "ByteRTCVideoStreamStateInvalid";
})(ByteRTCVideoStreamState || (ByteRTCVideoStreamState = {}));
var ByteRTCMixedStreamVideoConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCMixedStreamVideoConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _videoCodec_decorators;
    var _videoCodec_initializers = [];
    var _videoCodec_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _fps_decorators;
    var _fps_initializers = [];
    var _fps_extraInitializers = [];
    var _gop_decorators;
    var _gop_initializers = [];
    var _gop_extraInitializers = [];
    var _bitrate_decorators;
    var _bitrate_initializers = [];
    var _bitrate_extraInitializers = [];
    var _enableBFrame_decorators;
    var _enableBFrame_initializers = [];
    var _enableBFrame_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMixedStreamVideoConfig_1() {
            this.videoCodec = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _videoCodec_initializers, void 0));
            this.width = (__runInitializers(this, _videoCodec_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.fps = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _fps_initializers, void 0));
            this.gop = (__runInitializers(this, _fps_extraInitializers), __runInitializers(this, _gop_initializers, void 0));
            this.bitrate = (__runInitializers(this, _gop_extraInitializers), __runInitializers(this, _bitrate_initializers, void 0));
            this.enableBFrame = (__runInitializers(this, _bitrate_extraInitializers), __runInitializers(this, _enableBFrame_initializers, void 0));
            __runInitializers(this, _enableBFrame_extraInitializers);
        }
        ByteRTCMixedStreamVideoConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMixedStreamVideoConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMixedStreamVideoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _videoCodec_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _fps_decorators = [NativeMember()];
        _gop_decorators = [NativeMember()];
        _bitrate_decorators = [NativeMember()];
        _enableBFrame_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _videoCodec_decorators, { kind: "field", name: "videoCodec", static: false, private: false, access: { has: function (obj) { return "videoCodec" in obj; }, get: function (obj) { return obj.videoCodec; }, set: function (obj, value) { obj.videoCodec = value; } }, metadata: _metadata }, _videoCodec_initializers, _videoCodec_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _fps_decorators, { kind: "field", name: "fps", static: false, private: false, access: { has: function (obj) { return "fps" in obj; }, get: function (obj) { return obj.fps; }, set: function (obj, value) { obj.fps = value; } }, metadata: _metadata }, _fps_initializers, _fps_extraInitializers);
        __esDecorate(null, null, _gop_decorators, { kind: "field", name: "gop", static: false, private: false, access: { has: function (obj) { return "gop" in obj; }, get: function (obj) { return obj.gop; }, set: function (obj, value) { obj.gop = value; } }, metadata: _metadata }, _gop_initializers, _gop_extraInitializers);
        __esDecorate(null, null, _bitrate_decorators, { kind: "field", name: "bitrate", static: false, private: false, access: { has: function (obj) { return "bitrate" in obj; }, get: function (obj) { return obj.bitrate; }, set: function (obj, value) { obj.bitrate = value; } }, metadata: _metadata }, _bitrate_initializers, _bitrate_extraInitializers);
        __esDecorate(null, null, _enableBFrame_decorators, { kind: "field", name: "enableBFrame", static: false, private: false, access: { has: function (obj) { return "enableBFrame" in obj; }, get: function (obj) { return obj.enableBFrame; }, set: function (obj, value) { obj.enableBFrame = value; } }, metadata: _metadata }, _enableBFrame_initializers, _enableBFrame_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCVideoRenderMirrorType;
(function (ByteRTCVideoRenderMirrorType) {
    ByteRTCVideoRenderMirrorType[ByteRTCVideoRenderMirrorType["ByteRTCVideoRenderMirrorTypeOn"] = 1] = "ByteRTCVideoRenderMirrorTypeOn";
    ByteRTCVideoRenderMirrorType[ByteRTCVideoRenderMirrorType["ByteRTCVideoRenderMirrorTypeOff"] = 2] = "ByteRTCVideoRenderMirrorTypeOff";
})(ByteRTCVideoRenderMirrorType || (ByteRTCVideoRenderMirrorType = {}));
var ByteRTCVideoSourceType;
(function (ByteRTCVideoSourceType) {
    ByteRTCVideoSourceType[ByteRTCVideoSourceType["ByteRTCVideoSourceTypeExternal"] = 0] = "ByteRTCVideoSourceTypeExternal";
    ByteRTCVideoSourceType[ByteRTCVideoSourceType["ByteRTCVideoSourceTypeInternal"] = 1] = "ByteRTCVideoSourceTypeInternal";
    ByteRTCVideoSourceType[ByteRTCVideoSourceType["ByteRTCVideoSourceTypeEncodedAutoSimulcast"] = 2] = "ByteRTCVideoSourceTypeEncodedAutoSimulcast";
    ByteRTCVideoSourceType[ByteRTCVideoSourceType["ByteRTCVideoSourceTypeEncodedManualSimulcast"] = 3] = "ByteRTCVideoSourceTypeEncodedManualSimulcast";
})(ByteRTCVideoSourceType || (ByteRTCVideoSourceType = {}));
var ByteRTCUserOnlineStatus;
(function (ByteRTCUserOnlineStatus) {
    ByteRTCUserOnlineStatus[ByteRTCUserOnlineStatus["ByteRTCUserOnlineStatusOffline"] = 0] = "ByteRTCUserOnlineStatusOffline";
    ByteRTCUserOnlineStatus[ByteRTCUserOnlineStatus["ByteRTCUserOnlineStatusOnline"] = 1] = "ByteRTCUserOnlineStatusOnline";
    ByteRTCUserOnlineStatus[ByteRTCUserOnlineStatus["ByteRTCUserOnlineStatusUnreachable"] = 2] = "ByteRTCUserOnlineStatusUnreachable";
})(ByteRTCUserOnlineStatus || (ByteRTCUserOnlineStatus = {}));
var ByteRTCMusicInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCMusicInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _musicId_decorators;
    var _musicId_initializers = [];
    var _musicId_extraInitializers = [];
    var _musicName_decorators;
    var _musicName_initializers = [];
    var _musicName_extraInitializers = [];
    var _singer_decorators;
    var _singer_initializers = [];
    var _singer_extraInitializers = [];
    var _vendorId_decorators;
    var _vendorId_initializers = [];
    var _vendorId_extraInitializers = [];
    var _vendorName_decorators;
    var _vendorName_initializers = [];
    var _vendorName_extraInitializers = [];
    var _updateTimestamp_decorators;
    var _updateTimestamp_initializers = [];
    var _updateTimestamp_extraInitializers = [];
    var _posterUrl_decorators;
    var _posterUrl_initializers = [];
    var _posterUrl_extraInitializers = [];
    var _lyricStatus_decorators;
    var _lyricStatus_initializers = [];
    var _lyricStatus_extraInitializers = [];
    var _duration_decorators;
    var _duration_initializers = [];
    var _duration_extraInitializers = [];
    var _enableScore_decorators;
    var _enableScore_initializers = [];
    var _enableScore_extraInitializers = [];
    var _climaxStartTime_decorators;
    var _climaxStartTime_initializers = [];
    var _climaxStartTime_extraInitializers = [];
    var _climaxEndTime_decorators;
    var _climaxEndTime_initializers = [];
    var _climaxEndTime_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMusicInfo_1() {
            this.musicId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _musicId_initializers, void 0));
            this.musicName = (__runInitializers(this, _musicId_extraInitializers), __runInitializers(this, _musicName_initializers, void 0));
            this.singer = (__runInitializers(this, _musicName_extraInitializers), __runInitializers(this, _singer_initializers, void 0));
            this.vendorId = (__runInitializers(this, _singer_extraInitializers), __runInitializers(this, _vendorId_initializers, void 0));
            this.vendorName = (__runInitializers(this, _vendorId_extraInitializers), __runInitializers(this, _vendorName_initializers, void 0));
            this.updateTimestamp = (__runInitializers(this, _vendorName_extraInitializers), __runInitializers(this, _updateTimestamp_initializers, void 0));
            this.posterUrl = (__runInitializers(this, _updateTimestamp_extraInitializers), __runInitializers(this, _posterUrl_initializers, void 0));
            this.lyricStatus = (__runInitializers(this, _posterUrl_extraInitializers), __runInitializers(this, _lyricStatus_initializers, void 0));
            this.duration = (__runInitializers(this, _lyricStatus_extraInitializers), __runInitializers(this, _duration_initializers, void 0));
            this.enableScore = (__runInitializers(this, _duration_extraInitializers), __runInitializers(this, _enableScore_initializers, void 0));
            this.climaxStartTime = (__runInitializers(this, _enableScore_extraInitializers), __runInitializers(this, _climaxStartTime_initializers, void 0));
            this.climaxEndTime = (__runInitializers(this, _climaxStartTime_extraInitializers), __runInitializers(this, _climaxEndTime_initializers, void 0));
            __runInitializers(this, _climaxEndTime_extraInitializers);
        }
        ByteRTCMusicInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMusicInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMusicInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _musicId_decorators = [NativeMember()];
        _musicName_decorators = [NativeMember()];
        _singer_decorators = [NativeMember()];
        _vendorId_decorators = [NativeMember()];
        _vendorName_decorators = [NativeMember()];
        _updateTimestamp_decorators = [NativeMember()];
        _posterUrl_decorators = [NativeMember()];
        _lyricStatus_decorators = [NativeMember()];
        _duration_decorators = [NativeMember()];
        _enableScore_decorators = [NativeMember()];
        _climaxStartTime_decorators = [NativeMember()];
        _climaxEndTime_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _musicId_decorators, { kind: "field", name: "musicId", static: false, private: false, access: { has: function (obj) { return "musicId" in obj; }, get: function (obj) { return obj.musicId; }, set: function (obj, value) { obj.musicId = value; } }, metadata: _metadata }, _musicId_initializers, _musicId_extraInitializers);
        __esDecorate(null, null, _musicName_decorators, { kind: "field", name: "musicName", static: false, private: false, access: { has: function (obj) { return "musicName" in obj; }, get: function (obj) { return obj.musicName; }, set: function (obj, value) { obj.musicName = value; } }, metadata: _metadata }, _musicName_initializers, _musicName_extraInitializers);
        __esDecorate(null, null, _singer_decorators, { kind: "field", name: "singer", static: false, private: false, access: { has: function (obj) { return "singer" in obj; }, get: function (obj) { return obj.singer; }, set: function (obj, value) { obj.singer = value; } }, metadata: _metadata }, _singer_initializers, _singer_extraInitializers);
        __esDecorate(null, null, _vendorId_decorators, { kind: "field", name: "vendorId", static: false, private: false, access: { has: function (obj) { return "vendorId" in obj; }, get: function (obj) { return obj.vendorId; }, set: function (obj, value) { obj.vendorId = value; } }, metadata: _metadata }, _vendorId_initializers, _vendorId_extraInitializers);
        __esDecorate(null, null, _vendorName_decorators, { kind: "field", name: "vendorName", static: false, private: false, access: { has: function (obj) { return "vendorName" in obj; }, get: function (obj) { return obj.vendorName; }, set: function (obj, value) { obj.vendorName = value; } }, metadata: _metadata }, _vendorName_initializers, _vendorName_extraInitializers);
        __esDecorate(null, null, _updateTimestamp_decorators, { kind: "field", name: "updateTimestamp", static: false, private: false, access: { has: function (obj) { return "updateTimestamp" in obj; }, get: function (obj) { return obj.updateTimestamp; }, set: function (obj, value) { obj.updateTimestamp = value; } }, metadata: _metadata }, _updateTimestamp_initializers, _updateTimestamp_extraInitializers);
        __esDecorate(null, null, _posterUrl_decorators, { kind: "field", name: "posterUrl", static: false, private: false, access: { has: function (obj) { return "posterUrl" in obj; }, get: function (obj) { return obj.posterUrl; }, set: function (obj, value) { obj.posterUrl = value; } }, metadata: _metadata }, _posterUrl_initializers, _posterUrl_extraInitializers);
        __esDecorate(null, null, _lyricStatus_decorators, { kind: "field", name: "lyricStatus", static: false, private: false, access: { has: function (obj) { return "lyricStatus" in obj; }, get: function (obj) { return obj.lyricStatus; }, set: function (obj, value) { obj.lyricStatus = value; } }, metadata: _metadata }, _lyricStatus_initializers, _lyricStatus_extraInitializers);
        __esDecorate(null, null, _duration_decorators, { kind: "field", name: "duration", static: false, private: false, access: { has: function (obj) { return "duration" in obj; }, get: function (obj) { return obj.duration; }, set: function (obj, value) { obj.duration = value; } }, metadata: _metadata }, _duration_initializers, _duration_extraInitializers);
        __esDecorate(null, null, _enableScore_decorators, { kind: "field", name: "enableScore", static: false, private: false, access: { has: function (obj) { return "enableScore" in obj; }, get: function (obj) { return obj.enableScore; }, set: function (obj, value) { obj.enableScore = value; } }, metadata: _metadata }, _enableScore_initializers, _enableScore_extraInitializers);
        __esDecorate(null, null, _climaxStartTime_decorators, { kind: "field", name: "climaxStartTime", static: false, private: false, access: { has: function (obj) { return "climaxStartTime" in obj; }, get: function (obj) { return obj.climaxStartTime; }, set: function (obj, value) { obj.climaxStartTime = value; } }, metadata: _metadata }, _climaxStartTime_initializers, _climaxStartTime_extraInitializers);
        __esDecorate(null, null, _climaxEndTime_decorators, { kind: "field", name: "climaxEndTime", static: false, private: false, access: { has: function (obj) { return "climaxEndTime" in obj; }, get: function (obj) { return obj.climaxEndTime; }, set: function (obj, value) { obj.climaxEndTime = value; } }, metadata: _metadata }, _climaxEndTime_initializers, _climaxEndTime_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCMixedStreamLayoutRegionConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCMixedStreamLayoutRegionConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _userID_decorators;
    var _userID_initializers = [];
    var _userID_extraInitializers = [];
    var _roomID_decorators;
    var _roomID_initializers = [];
    var _roomID_extraInitializers = [];
    var _locationX_decorators;
    var _locationX_initializers = [];
    var _locationX_extraInitializers = [];
    var _locationY_decorators;
    var _locationY_initializers = [];
    var _locationY_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _zOrder_decorators;
    var _zOrder_initializers = [];
    var _zOrder_extraInitializers = [];
    var _isLocalUser_decorators;
    var _isLocalUser_initializers = [];
    var _isLocalUser_extraInitializers = [];
    var _streamType_decorators;
    var _streamType_initializers = [];
    var _streamType_extraInitializers = [];
    var _alpha_decorators;
    var _alpha_initializers = [];
    var _alpha_extraInitializers = [];
    var _cornerRadius_decorators;
    var _cornerRadius_initializers = [];
    var _cornerRadius_extraInitializers = [];
    var _mediaType_decorators;
    var _mediaType_initializers = [];
    var _mediaType_extraInitializers = [];
    var _renderMode_decorators;
    var _renderMode_initializers = [];
    var _renderMode_extraInitializers = [];
    var _regionContentType_decorators;
    var _regionContentType_initializers = [];
    var _regionContentType_extraInitializers = [];
    var _imageWaterMark_decorators;
    var _imageWaterMark_initializers = [];
    var _imageWaterMark_extraInitializers = [];
    var _imageWaterMarkConfig_decorators;
    var _imageWaterMarkConfig_initializers = [];
    var _imageWaterMarkConfig_extraInitializers = [];
    var _spatialPosition_decorators;
    var _spatialPosition_initializers = [];
    var _spatialPosition_extraInitializers = [];
    var _applySpatialAudio_decorators;
    var _applySpatialAudio_initializers = [];
    var _applySpatialAudio_extraInitializers = [];
    var _alternateImageFillMode_decorators;
    var _alternateImageFillMode_initializers = [];
    var _alternateImageFillMode_extraInitializers = [];
    var _alternateImageUrl_decorators;
    var _alternateImageUrl_initializers = [];
    var _alternateImageUrl_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMixedStreamLayoutRegionConfig_1() {
            this.userID = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _userID_initializers, void 0));
            this.roomID = (__runInitializers(this, _userID_extraInitializers), __runInitializers(this, _roomID_initializers, void 0));
            this.locationX = (__runInitializers(this, _roomID_extraInitializers), __runInitializers(this, _locationX_initializers, void 0));
            this.locationY = (__runInitializers(this, _locationX_extraInitializers), __runInitializers(this, _locationY_initializers, void 0));
            this.width = (__runInitializers(this, _locationY_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.zOrder = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _zOrder_initializers, void 0));
            this.isLocalUser = (__runInitializers(this, _zOrder_extraInitializers), __runInitializers(this, _isLocalUser_initializers, void 0));
            this.streamType = (__runInitializers(this, _isLocalUser_extraInitializers), __runInitializers(this, _streamType_initializers, void 0));
            this.alpha = (__runInitializers(this, _streamType_extraInitializers), __runInitializers(this, _alpha_initializers, void 0));
            this.cornerRadius = (__runInitializers(this, _alpha_extraInitializers), __runInitializers(this, _cornerRadius_initializers, void 0));
            this.mediaType = (__runInitializers(this, _cornerRadius_extraInitializers), __runInitializers(this, _mediaType_initializers, void 0));
            this.renderMode = (__runInitializers(this, _mediaType_extraInitializers), __runInitializers(this, _renderMode_initializers, void 0));
            this.regionContentType = (__runInitializers(this, _renderMode_extraInitializers), __runInitializers(this, _regionContentType_initializers, void 0));
            this.imageWaterMark = (__runInitializers(this, _regionContentType_extraInitializers), __runInitializers(this, _imageWaterMark_initializers, void 0));
            this.imageWaterMarkConfig = (__runInitializers(this, _imageWaterMark_extraInitializers), __runInitializers(this, _imageWaterMarkConfig_initializers, void 0));
            this.spatialPosition = (__runInitializers(this, _imageWaterMarkConfig_extraInitializers), __runInitializers(this, _spatialPosition_initializers, void 0));
            this.applySpatialAudio = (__runInitializers(this, _spatialPosition_extraInitializers), __runInitializers(this, _applySpatialAudio_initializers, void 0));
            this.alternateImageFillMode = (__runInitializers(this, _applySpatialAudio_extraInitializers), __runInitializers(this, _alternateImageFillMode_initializers, void 0));
            this.alternateImageUrl = (__runInitializers(this, _alternateImageFillMode_extraInitializers), __runInitializers(this, _alternateImageUrl_initializers, void 0));
            __runInitializers(this, _alternateImageUrl_extraInitializers);
        }
        ByteRTCMixedStreamLayoutRegionConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMixedStreamLayoutRegionConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMixedStreamLayoutRegionConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _userID_decorators = [NativeMember()];
        _roomID_decorators = [NativeMember()];
        _locationX_decorators = [NativeMember()];
        _locationY_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _zOrder_decorators = [NativeMember()];
        _isLocalUser_decorators = [NativeMember()];
        _streamType_decorators = [NativeMember()];
        _alpha_decorators = [NativeMember()];
        _cornerRadius_decorators = [NativeMember()];
        _mediaType_decorators = [NativeMember()];
        _renderMode_decorators = [NativeMember()];
        _regionContentType_decorators = [NativeMember()];
        _imageWaterMark_decorators = [NativeMember()];
        _imageWaterMarkConfig_decorators = [NativeMember()];
        _spatialPosition_decorators = [NativeMember()];
        _applySpatialAudio_decorators = [NativeMember()];
        _alternateImageFillMode_decorators = [NativeMember()];
        _alternateImageUrl_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _userID_decorators, { kind: "field", name: "userID", static: false, private: false, access: { has: function (obj) { return "userID" in obj; }, get: function (obj) { return obj.userID; }, set: function (obj, value) { obj.userID = value; } }, metadata: _metadata }, _userID_initializers, _userID_extraInitializers);
        __esDecorate(null, null, _roomID_decorators, { kind: "field", name: "roomID", static: false, private: false, access: { has: function (obj) { return "roomID" in obj; }, get: function (obj) { return obj.roomID; }, set: function (obj, value) { obj.roomID = value; } }, metadata: _metadata }, _roomID_initializers, _roomID_extraInitializers);
        __esDecorate(null, null, _locationX_decorators, { kind: "field", name: "locationX", static: false, private: false, access: { has: function (obj) { return "locationX" in obj; }, get: function (obj) { return obj.locationX; }, set: function (obj, value) { obj.locationX = value; } }, metadata: _metadata }, _locationX_initializers, _locationX_extraInitializers);
        __esDecorate(null, null, _locationY_decorators, { kind: "field", name: "locationY", static: false, private: false, access: { has: function (obj) { return "locationY" in obj; }, get: function (obj) { return obj.locationY; }, set: function (obj, value) { obj.locationY = value; } }, metadata: _metadata }, _locationY_initializers, _locationY_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _zOrder_decorators, { kind: "field", name: "zOrder", static: false, private: false, access: { has: function (obj) { return "zOrder" in obj; }, get: function (obj) { return obj.zOrder; }, set: function (obj, value) { obj.zOrder = value; } }, metadata: _metadata }, _zOrder_initializers, _zOrder_extraInitializers);
        __esDecorate(null, null, _isLocalUser_decorators, { kind: "field", name: "isLocalUser", static: false, private: false, access: { has: function (obj) { return "isLocalUser" in obj; }, get: function (obj) { return obj.isLocalUser; }, set: function (obj, value) { obj.isLocalUser = value; } }, metadata: _metadata }, _isLocalUser_initializers, _isLocalUser_extraInitializers);
        __esDecorate(null, null, _streamType_decorators, { kind: "field", name: "streamType", static: false, private: false, access: { has: function (obj) { return "streamType" in obj; }, get: function (obj) { return obj.streamType; }, set: function (obj, value) { obj.streamType = value; } }, metadata: _metadata }, _streamType_initializers, _streamType_extraInitializers);
        __esDecorate(null, null, _alpha_decorators, { kind: "field", name: "alpha", static: false, private: false, access: { has: function (obj) { return "alpha" in obj; }, get: function (obj) { return obj.alpha; }, set: function (obj, value) { obj.alpha = value; } }, metadata: _metadata }, _alpha_initializers, _alpha_extraInitializers);
        __esDecorate(null, null, _cornerRadius_decorators, { kind: "field", name: "cornerRadius", static: false, private: false, access: { has: function (obj) { return "cornerRadius" in obj; }, get: function (obj) { return obj.cornerRadius; }, set: function (obj, value) { obj.cornerRadius = value; } }, metadata: _metadata }, _cornerRadius_initializers, _cornerRadius_extraInitializers);
        __esDecorate(null, null, _mediaType_decorators, { kind: "field", name: "mediaType", static: false, private: false, access: { has: function (obj) { return "mediaType" in obj; }, get: function (obj) { return obj.mediaType; }, set: function (obj, value) { obj.mediaType = value; } }, metadata: _metadata }, _mediaType_initializers, _mediaType_extraInitializers);
        __esDecorate(null, null, _renderMode_decorators, { kind: "field", name: "renderMode", static: false, private: false, access: { has: function (obj) { return "renderMode" in obj; }, get: function (obj) { return obj.renderMode; }, set: function (obj, value) { obj.renderMode = value; } }, metadata: _metadata }, _renderMode_initializers, _renderMode_extraInitializers);
        __esDecorate(null, null, _regionContentType_decorators, { kind: "field", name: "regionContentType", static: false, private: false, access: { has: function (obj) { return "regionContentType" in obj; }, get: function (obj) { return obj.regionContentType; }, set: function (obj, value) { obj.regionContentType = value; } }, metadata: _metadata }, _regionContentType_initializers, _regionContentType_extraInitializers);
        __esDecorate(null, null, _imageWaterMark_decorators, { kind: "field", name: "imageWaterMark", static: false, private: false, access: { has: function (obj) { return "imageWaterMark" in obj; }, get: function (obj) { return obj.imageWaterMark; }, set: function (obj, value) { obj.imageWaterMark = value; } }, metadata: _metadata }, _imageWaterMark_initializers, _imageWaterMark_extraInitializers);
        __esDecorate(null, null, _imageWaterMarkConfig_decorators, { kind: "field", name: "imageWaterMarkConfig", static: false, private: false, access: { has: function (obj) { return "imageWaterMarkConfig" in obj; }, get: function (obj) { return obj.imageWaterMarkConfig; }, set: function (obj, value) { obj.imageWaterMarkConfig = value; } }, metadata: _metadata }, _imageWaterMarkConfig_initializers, _imageWaterMarkConfig_extraInitializers);
        __esDecorate(null, null, _spatialPosition_decorators, { kind: "field", name: "spatialPosition", static: false, private: false, access: { has: function (obj) { return "spatialPosition" in obj; }, get: function (obj) { return obj.spatialPosition; }, set: function (obj, value) { obj.spatialPosition = value; } }, metadata: _metadata }, _spatialPosition_initializers, _spatialPosition_extraInitializers);
        __esDecorate(null, null, _applySpatialAudio_decorators, { kind: "field", name: "applySpatialAudio", static: false, private: false, access: { has: function (obj) { return "applySpatialAudio" in obj; }, get: function (obj) { return obj.applySpatialAudio; }, set: function (obj, value) { obj.applySpatialAudio = value; } }, metadata: _metadata }, _applySpatialAudio_initializers, _applySpatialAudio_extraInitializers);
        __esDecorate(null, null, _alternateImageFillMode_decorators, { kind: "field", name: "alternateImageFillMode", static: false, private: false, access: { has: function (obj) { return "alternateImageFillMode" in obj; }, get: function (obj) { return obj.alternateImageFillMode; }, set: function (obj, value) { obj.alternateImageFillMode = value; } }, metadata: _metadata }, _alternateImageFillMode_initializers, _alternateImageFillMode_extraInitializers);
        __esDecorate(null, null, _alternateImageUrl_decorators, { kind: "field", name: "alternateImageUrl", static: false, private: false, access: { has: function (obj) { return "alternateImageUrl" in obj; }, get: function (obj) { return obj.alternateImageUrl; }, set: function (obj, value) { obj.alternateImageUrl = value; } }, metadata: _metadata }, _alternateImageUrl_initializers, _alternateImageUrl_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRoomStats = function () {
    var _classDecorators = [NativeClass('ByteRTCRoomStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _duration_decorators;
    var _duration_initializers = [];
    var _duration_extraInitializers = [];
    var _txBytes_decorators;
    var _txBytes_initializers = [];
    var _txBytes_extraInitializers = [];
    var _rxBytes_decorators;
    var _rxBytes_initializers = [];
    var _rxBytes_extraInitializers = [];
    var _txKbitrate_decorators;
    var _txKbitrate_initializers = [];
    var _txKbitrate_extraInitializers = [];
    var _rxKbitrate_decorators;
    var _rxKbitrate_initializers = [];
    var _rxKbitrate_extraInitializers = [];
    var _txAudioKBitrate_decorators;
    var _txAudioKBitrate_initializers = [];
    var _txAudioKBitrate_extraInitializers = [];
    var _rxAudioKBitrate_decorators;
    var _rxAudioKBitrate_initializers = [];
    var _rxAudioKBitrate_extraInitializers = [];
    var _txVideoKBitrate_decorators;
    var _txVideoKBitrate_initializers = [];
    var _txVideoKBitrate_extraInitializers = [];
    var _rxVideoKBitrate_decorators;
    var _rxVideoKBitrate_initializers = [];
    var _rxVideoKBitrate_extraInitializers = [];
    var _txScreenKBitrate_decorators;
    var _txScreenKBitrate_initializers = [];
    var _txScreenKBitrate_extraInitializers = [];
    var _rxScreenKBitrate_decorators;
    var _rxScreenKBitrate_initializers = [];
    var _rxScreenKBitrate_extraInitializers = [];
    var _userCount_decorators;
    var _userCount_initializers = [];
    var _userCount_extraInitializers = [];
    var _rxLostrate_decorators;
    var _rxLostrate_initializers = [];
    var _rxLostrate_extraInitializers = [];
    var _txLostrate_decorators;
    var _txLostrate_initializers = [];
    var _txLostrate_extraInitializers = [];
    var _rtt_decorators;
    var _rtt_initializers = [];
    var _rtt_extraInitializers = [];
    var _txJitter_decorators;
    var _txJitter_initializers = [];
    var _txJitter_extraInitializers = [];
    var _txCellularKBitrate_decorators;
    var _txCellularKBitrate_initializers = [];
    var _txCellularKBitrate_extraInitializers = [];
    var _rxCellularKBitrate_decorators;
    var _rxCellularKBitrate_initializers = [];
    var _rxCellularKBitrate_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRoomStats_1() {
            this.duration = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _duration_initializers, void 0));
            this.txBytes = (__runInitializers(this, _duration_extraInitializers), __runInitializers(this, _txBytes_initializers, void 0));
            this.rxBytes = (__runInitializers(this, _txBytes_extraInitializers), __runInitializers(this, _rxBytes_initializers, void 0));
            this.txKbitrate = (__runInitializers(this, _rxBytes_extraInitializers), __runInitializers(this, _txKbitrate_initializers, void 0));
            this.rxKbitrate = (__runInitializers(this, _txKbitrate_extraInitializers), __runInitializers(this, _rxKbitrate_initializers, void 0));
            this.txAudioKBitrate = (__runInitializers(this, _rxKbitrate_extraInitializers), __runInitializers(this, _txAudioKBitrate_initializers, void 0));
            this.rxAudioKBitrate = (__runInitializers(this, _txAudioKBitrate_extraInitializers), __runInitializers(this, _rxAudioKBitrate_initializers, void 0));
            this.txVideoKBitrate = (__runInitializers(this, _rxAudioKBitrate_extraInitializers), __runInitializers(this, _txVideoKBitrate_initializers, void 0));
            this.rxVideoKBitrate = (__runInitializers(this, _txVideoKBitrate_extraInitializers), __runInitializers(this, _rxVideoKBitrate_initializers, void 0));
            this.txScreenKBitrate = (__runInitializers(this, _rxVideoKBitrate_extraInitializers), __runInitializers(this, _txScreenKBitrate_initializers, void 0));
            this.rxScreenKBitrate = (__runInitializers(this, _txScreenKBitrate_extraInitializers), __runInitializers(this, _rxScreenKBitrate_initializers, void 0));
            this.userCount = (__runInitializers(this, _rxScreenKBitrate_extraInitializers), __runInitializers(this, _userCount_initializers, void 0));
            this.rxLostrate = (__runInitializers(this, _userCount_extraInitializers), __runInitializers(this, _rxLostrate_initializers, void 0));
            this.txLostrate = (__runInitializers(this, _rxLostrate_extraInitializers), __runInitializers(this, _txLostrate_initializers, void 0));
            this.rtt = (__runInitializers(this, _txLostrate_extraInitializers), __runInitializers(this, _rtt_initializers, void 0));
            this.txJitter = (__runInitializers(this, _rtt_extraInitializers), __runInitializers(this, _txJitter_initializers, void 0));
            this.txCellularKBitrate = (__runInitializers(this, _txJitter_extraInitializers), __runInitializers(this, _txCellularKBitrate_initializers, void 0));
            this.rxCellularKBitrate = (__runInitializers(this, _txCellularKBitrate_extraInitializers), __runInitializers(this, _rxCellularKBitrate_initializers, void 0));
            __runInitializers(this, _rxCellularKBitrate_extraInitializers);
        }
        ByteRTCRoomStats_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRoomStats_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRoomStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _duration_decorators = [NativeMember()];
        _txBytes_decorators = [NativeMember()];
        _rxBytes_decorators = [NativeMember()];
        _txKbitrate_decorators = [NativeMember()];
        _rxKbitrate_decorators = [NativeMember()];
        _txAudioKBitrate_decorators = [NativeMember()];
        _rxAudioKBitrate_decorators = [NativeMember()];
        _txVideoKBitrate_decorators = [NativeMember()];
        _rxVideoKBitrate_decorators = [NativeMember()];
        _txScreenKBitrate_decorators = [NativeMember()];
        _rxScreenKBitrate_decorators = [NativeMember()];
        _userCount_decorators = [NativeMember()];
        _rxLostrate_decorators = [NativeMember()];
        _txLostrate_decorators = [NativeMember()];
        _rtt_decorators = [NativeMember()];
        _txJitter_decorators = [NativeMember()];
        _txCellularKBitrate_decorators = [NativeMember()];
        _rxCellularKBitrate_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _duration_decorators, { kind: "field", name: "duration", static: false, private: false, access: { has: function (obj) { return "duration" in obj; }, get: function (obj) { return obj.duration; }, set: function (obj, value) { obj.duration = value; } }, metadata: _metadata }, _duration_initializers, _duration_extraInitializers);
        __esDecorate(null, null, _txBytes_decorators, { kind: "field", name: "txBytes", static: false, private: false, access: { has: function (obj) { return "txBytes" in obj; }, get: function (obj) { return obj.txBytes; }, set: function (obj, value) { obj.txBytes = value; } }, metadata: _metadata }, _txBytes_initializers, _txBytes_extraInitializers);
        __esDecorate(null, null, _rxBytes_decorators, { kind: "field", name: "rxBytes", static: false, private: false, access: { has: function (obj) { return "rxBytes" in obj; }, get: function (obj) { return obj.rxBytes; }, set: function (obj, value) { obj.rxBytes = value; } }, metadata: _metadata }, _rxBytes_initializers, _rxBytes_extraInitializers);
        __esDecorate(null, null, _txKbitrate_decorators, { kind: "field", name: "txKbitrate", static: false, private: false, access: { has: function (obj) { return "txKbitrate" in obj; }, get: function (obj) { return obj.txKbitrate; }, set: function (obj, value) { obj.txKbitrate = value; } }, metadata: _metadata }, _txKbitrate_initializers, _txKbitrate_extraInitializers);
        __esDecorate(null, null, _rxKbitrate_decorators, { kind: "field", name: "rxKbitrate", static: false, private: false, access: { has: function (obj) { return "rxKbitrate" in obj; }, get: function (obj) { return obj.rxKbitrate; }, set: function (obj, value) { obj.rxKbitrate = value; } }, metadata: _metadata }, _rxKbitrate_initializers, _rxKbitrate_extraInitializers);
        __esDecorate(null, null, _txAudioKBitrate_decorators, { kind: "field", name: "txAudioKBitrate", static: false, private: false, access: { has: function (obj) { return "txAudioKBitrate" in obj; }, get: function (obj) { return obj.txAudioKBitrate; }, set: function (obj, value) { obj.txAudioKBitrate = value; } }, metadata: _metadata }, _txAudioKBitrate_initializers, _txAudioKBitrate_extraInitializers);
        __esDecorate(null, null, _rxAudioKBitrate_decorators, { kind: "field", name: "rxAudioKBitrate", static: false, private: false, access: { has: function (obj) { return "rxAudioKBitrate" in obj; }, get: function (obj) { return obj.rxAudioKBitrate; }, set: function (obj, value) { obj.rxAudioKBitrate = value; } }, metadata: _metadata }, _rxAudioKBitrate_initializers, _rxAudioKBitrate_extraInitializers);
        __esDecorate(null, null, _txVideoKBitrate_decorators, { kind: "field", name: "txVideoKBitrate", static: false, private: false, access: { has: function (obj) { return "txVideoKBitrate" in obj; }, get: function (obj) { return obj.txVideoKBitrate; }, set: function (obj, value) { obj.txVideoKBitrate = value; } }, metadata: _metadata }, _txVideoKBitrate_initializers, _txVideoKBitrate_extraInitializers);
        __esDecorate(null, null, _rxVideoKBitrate_decorators, { kind: "field", name: "rxVideoKBitrate", static: false, private: false, access: { has: function (obj) { return "rxVideoKBitrate" in obj; }, get: function (obj) { return obj.rxVideoKBitrate; }, set: function (obj, value) { obj.rxVideoKBitrate = value; } }, metadata: _metadata }, _rxVideoKBitrate_initializers, _rxVideoKBitrate_extraInitializers);
        __esDecorate(null, null, _txScreenKBitrate_decorators, { kind: "field", name: "txScreenKBitrate", static: false, private: false, access: { has: function (obj) { return "txScreenKBitrate" in obj; }, get: function (obj) { return obj.txScreenKBitrate; }, set: function (obj, value) { obj.txScreenKBitrate = value; } }, metadata: _metadata }, _txScreenKBitrate_initializers, _txScreenKBitrate_extraInitializers);
        __esDecorate(null, null, _rxScreenKBitrate_decorators, { kind: "field", name: "rxScreenKBitrate", static: false, private: false, access: { has: function (obj) { return "rxScreenKBitrate" in obj; }, get: function (obj) { return obj.rxScreenKBitrate; }, set: function (obj, value) { obj.rxScreenKBitrate = value; } }, metadata: _metadata }, _rxScreenKBitrate_initializers, _rxScreenKBitrate_extraInitializers);
        __esDecorate(null, null, _userCount_decorators, { kind: "field", name: "userCount", static: false, private: false, access: { has: function (obj) { return "userCount" in obj; }, get: function (obj) { return obj.userCount; }, set: function (obj, value) { obj.userCount = value; } }, metadata: _metadata }, _userCount_initializers, _userCount_extraInitializers);
        __esDecorate(null, null, _rxLostrate_decorators, { kind: "field", name: "rxLostrate", static: false, private: false, access: { has: function (obj) { return "rxLostrate" in obj; }, get: function (obj) { return obj.rxLostrate; }, set: function (obj, value) { obj.rxLostrate = value; } }, metadata: _metadata }, _rxLostrate_initializers, _rxLostrate_extraInitializers);
        __esDecorate(null, null, _txLostrate_decorators, { kind: "field", name: "txLostrate", static: false, private: false, access: { has: function (obj) { return "txLostrate" in obj; }, get: function (obj) { return obj.txLostrate; }, set: function (obj, value) { obj.txLostrate = value; } }, metadata: _metadata }, _txLostrate_initializers, _txLostrate_extraInitializers);
        __esDecorate(null, null, _rtt_decorators, { kind: "field", name: "rtt", static: false, private: false, access: { has: function (obj) { return "rtt" in obj; }, get: function (obj) { return obj.rtt; }, set: function (obj, value) { obj.rtt = value; } }, metadata: _metadata }, _rtt_initializers, _rtt_extraInitializers);
        __esDecorate(null, null, _txJitter_decorators, { kind: "field", name: "txJitter", static: false, private: false, access: { has: function (obj) { return "txJitter" in obj; }, get: function (obj) { return obj.txJitter; }, set: function (obj, value) { obj.txJitter = value; } }, metadata: _metadata }, _txJitter_initializers, _txJitter_extraInitializers);
        __esDecorate(null, null, _txCellularKBitrate_decorators, { kind: "field", name: "txCellularKBitrate", static: false, private: false, access: { has: function (obj) { return "txCellularKBitrate" in obj; }, get: function (obj) { return obj.txCellularKBitrate; }, set: function (obj, value) { obj.txCellularKBitrate = value; } }, metadata: _metadata }, _txCellularKBitrate_initializers, _txCellularKBitrate_extraInitializers);
        __esDecorate(null, null, _rxCellularKBitrate_decorators, { kind: "field", name: "rxCellularKBitrate", static: false, private: false, access: { has: function (obj) { return "rxCellularKBitrate" in obj; }, get: function (obj) { return obj.rxCellularKBitrate; }, set: function (obj, value) { obj.rxCellularKBitrate = value; } }, metadata: _metadata }, _rxCellularKBitrate_initializers, _rxCellularKBitrate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioRecordingState;
(function (ByteRTCAudioRecordingState) {
    ByteRTCAudioRecordingState[ByteRTCAudioRecordingState["ByteRTCAudioRecordingStateError"] = 0] = "ByteRTCAudioRecordingStateError";
    ByteRTCAudioRecordingState[ByteRTCAudioRecordingState["ByteRTCAudioRecordingStateProcessing"] = 1] = "ByteRTCAudioRecordingStateProcessing";
    ByteRTCAudioRecordingState[ByteRTCAudioRecordingState["ByteRTCAudioRecordingStateSuccess"] = 2] = "ByteRTCAudioRecordingStateSuccess";
})(ByteRTCAudioRecordingState || (ByteRTCAudioRecordingState = {}));
var ByteRTCMediaDeviceState;
(function (ByteRTCMediaDeviceState) {
    ByteRTCMediaDeviceState[ByteRTCMediaDeviceState["ByteRTCMediaDeviceStateStarted"] = 1] = "ByteRTCMediaDeviceStateStarted";
    ByteRTCMediaDeviceState[ByteRTCMediaDeviceState["ByteRTCMediaDeviceStateStopped"] = 2] = "ByteRTCMediaDeviceStateStopped";
    ByteRTCMediaDeviceState[ByteRTCMediaDeviceState["ByteRTCMediaDeviceStateRuntimeError"] = 3] = "ByteRTCMediaDeviceStateRuntimeError";
    ByteRTCMediaDeviceState[ByteRTCMediaDeviceState["ByteRTCMediaDeviceStateAdded"] = 10] = "ByteRTCMediaDeviceStateAdded";
    ByteRTCMediaDeviceState[ByteRTCMediaDeviceState["ByteRTCMediaDeviceStateRemoved"] = 11] = "ByteRTCMediaDeviceStateRemoved";
    ByteRTCMediaDeviceState[ByteRTCMediaDeviceState["ByteRTCMediaDeviceStateInterruptionBegan"] = 12] = "ByteRTCMediaDeviceStateInterruptionBegan";
    ByteRTCMediaDeviceState[ByteRTCMediaDeviceState["ByteRTCMediaDeviceStateInterruptionEnded"] = 13] = "ByteRTCMediaDeviceStateInterruptionEnded";
    ByteRTCMediaDeviceState[ByteRTCMediaDeviceState["ByteRTCMediaDeviceListUpdated"] = 16] = "ByteRTCMediaDeviceListUpdated";
})(ByteRTCMediaDeviceState || (ByteRTCMediaDeviceState = {}));
var ByteRTCAudioRoute;
(function (ByteRTCAudioRoute) {
    ByteRTCAudioRoute[ByteRTCAudioRoute["ByteRTCAudioRouteDefault"] = -1] = "ByteRTCAudioRouteDefault";
    ByteRTCAudioRoute[ByteRTCAudioRoute["ByteRTCAudioRouteHeadset"] = 1] = "ByteRTCAudioRouteHeadset";
    ByteRTCAudioRoute[ByteRTCAudioRoute["ByteRTCAudioRouteEarpiece"] = 2] = "ByteRTCAudioRouteEarpiece";
    ByteRTCAudioRoute[ByteRTCAudioRoute["ByteRTCAudioRouteSpeakerphone"] = 3] = "ByteRTCAudioRouteSpeakerphone";
    ByteRTCAudioRoute[ByteRTCAudioRoute["ByteRTCAudioRouteHeadsetBluetooth"] = 4] = "ByteRTCAudioRouteHeadsetBluetooth";
    ByteRTCAudioRoute[ByteRTCAudioRoute["ByteRTCAudioRouteHeadsetUSB"] = 5] = "ByteRTCAudioRouteHeadsetUSB";
})(ByteRTCAudioRoute || (ByteRTCAudioRoute = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRtcScreenCapturerExt')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _shared_decorators;
    var _shared_initializers = [];
    var _shared_extraInitializers = [];
    var _delegate_decorators;
    var _delegate_initializers = [];
    var _delegate_extraInitializers = [];
    var _startWithDelegate_decorators;
    var _stop_decorators;
    var _processSampleBuffer_decorators;
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRtcScreenCapturerExt_1() {
            this.shared = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _shared_initializers, void 0));
            this.delegate = (__runInitializers(this, _shared_extraInitializers), __runInitializers(this, _delegate_initializers, void 0));
            __runInitializers(this, _delegate_extraInitializers);
        }
        ByteRtcScreenCapturerExt_1.prototype.startWithDelegate = function (delegate, groupId) {
            throw new Error('not implement');
        };
        ByteRtcScreenCapturerExt_1.prototype.stop = function () {
            throw new Error('not implement');
        };
        ByteRtcScreenCapturerExt_1.prototype.processSampleBuffer = function (sampleBuffer, sampleBufferType) {
            throw new Error('not implement');
        };
        ByteRtcScreenCapturerExt_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRtcScreenCapturerExt_1;
    }());
    __setFunctionName(_classThis, "ByteRtcScreenCapturerExt");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _shared_decorators = [NativeMember()];
        _delegate_decorators = [NativeMember()];
        _startWithDelegate_decorators = [NativeMethodSync('startWithDelegate:groupId:')];
        _stop_decorators = [NativeMethodSync('stop')];
        _processSampleBuffer_decorators = [NativeMethodSync('processSampleBuffer:withType:')];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _startWithDelegate_decorators, { kind: "method", name: "startWithDelegate", static: false, private: false, access: { has: function (obj) { return "startWithDelegate" in obj; }, get: function (obj) { return obj.startWithDelegate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stop_decorators, { kind: "method", name: "stop", static: false, private: false, access: { has: function (obj) { return "stop" in obj; }, get: function (obj) { return obj.stop; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _processSampleBuffer_decorators, { kind: "method", name: "processSampleBuffer", static: false, private: false, access: { has: function (obj) { return "processSampleBuffer" in obj; }, get: function (obj) { return obj.processSampleBuffer; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _shared_decorators, { kind: "field", name: "shared", static: false, private: false, access: { has: function (obj) { return "shared" in obj; }, get: function (obj) { return obj.shared; }, set: function (obj, value) { obj.shared = value; } }, metadata: _metadata }, _shared_initializers, _shared_extraInitializers);
        __esDecorate(null, null, _delegate_decorators, { kind: "field", name: "delegate", static: false, private: false, access: { has: function (obj) { return "delegate" in obj; }, get: function (obj) { return obj.delegate; }, set: function (obj, value) { obj.delegate = value; } }, metadata: _metadata }, _delegate_initializers, _delegate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCVideoDecoderConfig;
(function (ByteRTCVideoDecoderConfig) {
    ByteRTCVideoDecoderConfig[ByteRTCVideoDecoderConfig["ByteRTCVideoDecoderConfigRaw"] = 0] = "ByteRTCVideoDecoderConfigRaw";
    ByteRTCVideoDecoderConfig[ByteRTCVideoDecoderConfig["ByteRTCVideoDecoderConfigEncode"] = 1] = "ByteRTCVideoDecoderConfigEncode";
    ByteRTCVideoDecoderConfig[ByteRTCVideoDecoderConfig["ByteRTCVideoDecoderConfigBoth"] = 2] = "ByteRTCVideoDecoderConfigBoth";
})(ByteRTCVideoDecoderConfig || (ByteRTCVideoDecoderConfig = {}));
var ByteRTCMixedStreamLayoutRegionImageWaterMarkConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCMixedStreamLayoutRegionImageWaterMarkConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _imageWidth_decorators;
    var _imageWidth_initializers = [];
    var _imageWidth_extraInitializers = [];
    var _imageHeight_decorators;
    var _imageHeight_initializers = [];
    var _imageHeight_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMixedStreamLayoutRegionImageWaterMarkConfig_1() {
            this.imageWidth = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _imageWidth_initializers, void 0));
            this.imageHeight = (__runInitializers(this, _imageWidth_extraInitializers), __runInitializers(this, _imageHeight_initializers, void 0));
            __runInitializers(this, _imageHeight_extraInitializers);
        }
        ByteRTCMixedStreamLayoutRegionImageWaterMarkConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMixedStreamLayoutRegionImageWaterMarkConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMixedStreamLayoutRegionImageWaterMarkConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _imageWidth_decorators = [NativeMember()];
        _imageHeight_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _imageWidth_decorators, { kind: "field", name: "imageWidth", static: false, private: false, access: { has: function (obj) { return "imageWidth" in obj; }, get: function (obj) { return obj.imageWidth; }, set: function (obj, value) { obj.imageWidth = value; } }, metadata: _metadata }, _imageWidth_initializers, _imageWidth_extraInitializers);
        __esDecorate(null, null, _imageHeight_decorators, { kind: "field", name: "imageHeight", static: false, private: false, access: { has: function (obj) { return "imageHeight" in obj; }, get: function (obj) { return obj.imageHeight; }, set: function (obj, value) { obj.imageHeight = value; } }, metadata: _metadata }, _imageHeight_initializers, _imageHeight_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCVideoPixelFormat;
(function (ByteRTCVideoPixelFormat) {
    ByteRTCVideoPixelFormat[ByteRTCVideoPixelFormat["ByteRTCVideoPixelFormatUnknown"] = 0] = "ByteRTCVideoPixelFormatUnknown";
    ByteRTCVideoPixelFormat[ByteRTCVideoPixelFormat["ByteRTCVideoPixelFormatI420"] = 1] = "ByteRTCVideoPixelFormatI420";
    ByteRTCVideoPixelFormat[ByteRTCVideoPixelFormat["ByteRTCVideoPixelFormatBGRA"] = 2] = "ByteRTCVideoPixelFormatBGRA";
    ByteRTCVideoPixelFormat[ByteRTCVideoPixelFormat["ByteRTCVideoPixelFormatNV21"] = 3] = "ByteRTCVideoPixelFormatNV21";
    ByteRTCVideoPixelFormat[ByteRTCVideoPixelFormat["ByteRTCVideoPixelFormatRGBA"] = 4] = "ByteRTCVideoPixelFormatRGBA";
    ByteRTCVideoPixelFormat[ByteRTCVideoPixelFormat["ByteRTCVideoPixelFormatIMC2"] = 5] = "ByteRTCVideoPixelFormatIMC2";
    ByteRTCVideoPixelFormat[ByteRTCVideoPixelFormat["ByteRTCVideoPixelFormatARGB"] = 7] = "ByteRTCVideoPixelFormatARGB";
    ByteRTCVideoPixelFormat[ByteRTCVideoPixelFormat["ByteRTCVideoPixelFormatNV12"] = 8] = "ByteRTCVideoPixelFormatNV12";
    ByteRTCVideoPixelFormat[ByteRTCVideoPixelFormat["ByteRTCVideoPixelFormatGLTexture2D"] = 10] = "ByteRTCVideoPixelFormatGLTexture2D";
    ByteRTCVideoPixelFormat[ByteRTCVideoPixelFormat["ByteRTCVideoPixelFormatGLTextureOES"] = 11] = "ByteRTCVideoPixelFormatGLTextureOES";
    ByteRTCVideoPixelFormat[ByteRTCVideoPixelFormat["ByteRTCVideoPixelFormatCVPixelBuffer"] = 12] = "ByteRTCVideoPixelFormatCVPixelBuffer";
})(ByteRTCVideoPixelFormat || (ByteRTCVideoPixelFormat = {}));
var ByteRTCEncryptType;
(function (ByteRTCEncryptType) {
    ByteRTCEncryptType[ByteRTCEncryptType["ByteRTCEncryptTypeCustomize"] = 0] = "ByteRTCEncryptTypeCustomize";
    ByteRTCEncryptType[ByteRTCEncryptType["ByteRTCEncryptTypeAES128CBC"] = 1] = "ByteRTCEncryptTypeAES128CBC";
    ByteRTCEncryptType[ByteRTCEncryptType["ByteRTCEncryptTypeAES256CBC"] = 2] = "ByteRTCEncryptTypeAES256CBC";
    ByteRTCEncryptType[ByteRTCEncryptType["ByteRTCEncryptTypeAES128ECB"] = 3] = "ByteRTCEncryptTypeAES128ECB";
    ByteRTCEncryptType[ByteRTCEncryptType["ByteRTCEncryptTypeAES256ECB"] = 4] = "ByteRTCEncryptTypeAES256ECB";
})(ByteRTCEncryptType || (ByteRTCEncryptType = {}));
var ByteRTCMixedStreamSyncStrategy;
(function (ByteRTCMixedStreamSyncStrategy) {
    ByteRTCMixedStreamSyncStrategy[ByteRTCMixedStreamSyncStrategy["ByteRTCMixedStreamSyncStrategyNoSync"] = 0] = "ByteRTCMixedStreamSyncStrategyNoSync";
    ByteRTCMixedStreamSyncStrategy[ByteRTCMixedStreamSyncStrategy["ByteRTCMixedStreamSyncStrategyAudioPreciseSync"] = 1] = "ByteRTCMixedStreamSyncStrategyAudioPreciseSync";
    ByteRTCMixedStreamSyncStrategy[ByteRTCMixedStreamSyncStrategy["ByteRTCMixedStreamSyncStrategySimplexModeSync"] = 2] = "ByteRTCMixedStreamSyncStrategySimplexModeSync";
})(ByteRTCMixedStreamSyncStrategy || (ByteRTCMixedStreamSyncStrategy = {}));
var ByteRTCDownloadResult = function () {
    var _classDecorators = [NativeClass('ByteRTCDownloadResult')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _musicId_decorators;
    var _musicId_initializers = [];
    var _musicId_extraInitializers = [];
    var _fileType_decorators;
    var _fileType_initializers = [];
    var _fileType_extraInitializers = [];
    var _filePath_decorators;
    var _filePath_initializers = [];
    var _filePath_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCDownloadResult_1() {
            this.musicId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _musicId_initializers, void 0));
            this.fileType = (__runInitializers(this, _musicId_extraInitializers), __runInitializers(this, _fileType_initializers, void 0));
            this.filePath = (__runInitializers(this, _fileType_extraInitializers), __runInitializers(this, _filePath_initializers, void 0));
            __runInitializers(this, _filePath_extraInitializers);
        }
        ByteRTCDownloadResult_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCDownloadResult_1;
    }());
    __setFunctionName(_classThis, "ByteRTCDownloadResult");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _musicId_decorators = [NativeMember()];
        _fileType_decorators = [NativeMember()];
        _filePath_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _musicId_decorators, { kind: "field", name: "musicId", static: false, private: false, access: { has: function (obj) { return "musicId" in obj; }, get: function (obj) { return obj.musicId; }, set: function (obj, value) { obj.musicId = value; } }, metadata: _metadata }, _musicId_initializers, _musicId_extraInitializers);
        __esDecorate(null, null, _fileType_decorators, { kind: "field", name: "fileType", static: false, private: false, access: { has: function (obj) { return "fileType" in obj; }, get: function (obj) { return obj.fileType; }, set: function (obj, value) { obj.fileType = value; } }, metadata: _metadata }, _fileType_initializers, _fileType_extraInitializers);
        __esDecorate(null, null, _filePath_decorators, { kind: "field", name: "filePath", static: false, private: false, access: { has: function (obj) { return "filePath" in obj; }, get: function (obj) { return obj.filePath; }, set: function (obj, value) { obj.filePath = value; } }, metadata: _metadata }, _filePath_initializers, _filePath_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('ByteRTCVideoCompositingRegion')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _uid_decorators;
    var _uid_initializers = [];
    var _uid_extraInitializers = [];
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _x_decorators;
    var _x_initializers = [];
    var _x_extraInitializers = [];
    var _y_decorators;
    var _y_initializers = [];
    var _y_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _zOrder_decorators;
    var _zOrder_initializers = [];
    var _zOrder_extraInitializers = [];
    var _localUser_decorators;
    var _localUser_initializers = [];
    var _localUser_extraInitializers = [];
    var _screenStream_decorators;
    var _screenStream_initializers = [];
    var _screenStream_extraInitializers = [];
    var _alpha_decorators;
    var _alpha_initializers = [];
    var _alpha_extraInitializers = [];
    var _cornerRadius_decorators;
    var _cornerRadius_initializers = [];
    var _cornerRadius_extraInitializers = [];
    var _contentControl_decorators;
    var _contentControl_initializers = [];
    var _contentControl_extraInitializers = [];
    var _renderMode_decorators;
    var _renderMode_initializers = [];
    var _renderMode_extraInitializers = [];
    var _type_decorators;
    var _type_initializers = [];
    var _type_extraInitializers = [];
    var _data_decorators;
    var _data_initializers = [];
    var _data_extraInitializers = [];
    var _dataParam_decorators;
    var _dataParam_initializers = [];
    var _dataParam_extraInitializers = [];
    var _spatialPosition_decorators;
    var _spatialPosition_initializers = [];
    var _spatialPosition_extraInitializers = [];
    var _applySpatialAudio_decorators;
    var _applySpatialAudio_initializers = [];
    var _applySpatialAudio_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoCompositingRegion_1() {
            this.uid = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _uid_initializers, void 0));
            this.roomId = (__runInitializers(this, _uid_extraInitializers), __runInitializers(this, _roomId_initializers, void 0));
            this.x = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _x_initializers, void 0));
            this.y = (__runInitializers(this, _x_extraInitializers), __runInitializers(this, _y_initializers, void 0));
            this.width = (__runInitializers(this, _y_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.zOrder = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _zOrder_initializers, void 0));
            this.localUser = (__runInitializers(this, _zOrder_extraInitializers), __runInitializers(this, _localUser_initializers, void 0));
            this.screenStream = (__runInitializers(this, _localUser_extraInitializers), __runInitializers(this, _screenStream_initializers, void 0));
            this.alpha = (__runInitializers(this, _screenStream_extraInitializers), __runInitializers(this, _alpha_initializers, void 0));
            this.cornerRadius = (__runInitializers(this, _alpha_extraInitializers), __runInitializers(this, _cornerRadius_initializers, void 0));
            this.contentControl = (__runInitializers(this, _cornerRadius_extraInitializers), __runInitializers(this, _contentControl_initializers, void 0));
            this.renderMode = (__runInitializers(this, _contentControl_extraInitializers), __runInitializers(this, _renderMode_initializers, void 0));
            this.type = (__runInitializers(this, _renderMode_extraInitializers), __runInitializers(this, _type_initializers, void 0));
            this.data = (__runInitializers(this, _type_extraInitializers), __runInitializers(this, _data_initializers, void 0));
            this.dataParam = (__runInitializers(this, _data_extraInitializers), __runInitializers(this, _dataParam_initializers, void 0));
            this.spatialPosition = (__runInitializers(this, _dataParam_extraInitializers), __runInitializers(this, _spatialPosition_initializers, void 0));
            this.applySpatialAudio = (__runInitializers(this, _spatialPosition_extraInitializers), __runInitializers(this, _applySpatialAudio_initializers, void 0));
            __runInitializers(this, _applySpatialAudio_extraInitializers);
        }
        ByteRTCVideoCompositingRegion_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVideoCompositingRegion_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoCompositingRegion");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _uid_decorators = [NativeMember()];
        _roomId_decorators = [NativeMember()];
        _x_decorators = [NativeMember()];
        _y_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _zOrder_decorators = [NativeMember()];
        _localUser_decorators = [NativeMember()];
        _screenStream_decorators = [NativeMember()];
        _alpha_decorators = [NativeMember()];
        _cornerRadius_decorators = [NativeMember()];
        _contentControl_decorators = [NativeMember()];
        _renderMode_decorators = [NativeMember()];
        _type_decorators = [NativeMember()];
        _data_decorators = [NativeMember()];
        _dataParam_decorators = [NativeMember()];
        _spatialPosition_decorators = [NativeMember()];
        _applySpatialAudio_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _uid_decorators, { kind: "field", name: "uid", static: false, private: false, access: { has: function (obj) { return "uid" in obj; }, get: function (obj) { return obj.uid; }, set: function (obj, value) { obj.uid = value; } }, metadata: _metadata }, _uid_initializers, _uid_extraInitializers);
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _x_decorators, { kind: "field", name: "x", static: false, private: false, access: { has: function (obj) { return "x" in obj; }, get: function (obj) { return obj.x; }, set: function (obj, value) { obj.x = value; } }, metadata: _metadata }, _x_initializers, _x_extraInitializers);
        __esDecorate(null, null, _y_decorators, { kind: "field", name: "y", static: false, private: false, access: { has: function (obj) { return "y" in obj; }, get: function (obj) { return obj.y; }, set: function (obj, value) { obj.y = value; } }, metadata: _metadata }, _y_initializers, _y_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _zOrder_decorators, { kind: "field", name: "zOrder", static: false, private: false, access: { has: function (obj) { return "zOrder" in obj; }, get: function (obj) { return obj.zOrder; }, set: function (obj, value) { obj.zOrder = value; } }, metadata: _metadata }, _zOrder_initializers, _zOrder_extraInitializers);
        __esDecorate(null, null, _localUser_decorators, { kind: "field", name: "localUser", static: false, private: false, access: { has: function (obj) { return "localUser" in obj; }, get: function (obj) { return obj.localUser; }, set: function (obj, value) { obj.localUser = value; } }, metadata: _metadata }, _localUser_initializers, _localUser_extraInitializers);
        __esDecorate(null, null, _screenStream_decorators, { kind: "field", name: "screenStream", static: false, private: false, access: { has: function (obj) { return "screenStream" in obj; }, get: function (obj) { return obj.screenStream; }, set: function (obj, value) { obj.screenStream = value; } }, metadata: _metadata }, _screenStream_initializers, _screenStream_extraInitializers);
        __esDecorate(null, null, _alpha_decorators, { kind: "field", name: "alpha", static: false, private: false, access: { has: function (obj) { return "alpha" in obj; }, get: function (obj) { return obj.alpha; }, set: function (obj, value) { obj.alpha = value; } }, metadata: _metadata }, _alpha_initializers, _alpha_extraInitializers);
        __esDecorate(null, null, _cornerRadius_decorators, { kind: "field", name: "cornerRadius", static: false, private: false, access: { has: function (obj) { return "cornerRadius" in obj; }, get: function (obj) { return obj.cornerRadius; }, set: function (obj, value) { obj.cornerRadius = value; } }, metadata: _metadata }, _cornerRadius_initializers, _cornerRadius_extraInitializers);
        __esDecorate(null, null, _contentControl_decorators, { kind: "field", name: "contentControl", static: false, private: false, access: { has: function (obj) { return "contentControl" in obj; }, get: function (obj) { return obj.contentControl; }, set: function (obj, value) { obj.contentControl = value; } }, metadata: _metadata }, _contentControl_initializers, _contentControl_extraInitializers);
        __esDecorate(null, null, _renderMode_decorators, { kind: "field", name: "renderMode", static: false, private: false, access: { has: function (obj) { return "renderMode" in obj; }, get: function (obj) { return obj.renderMode; }, set: function (obj, value) { obj.renderMode = value; } }, metadata: _metadata }, _renderMode_initializers, _renderMode_extraInitializers);
        __esDecorate(null, null, _type_decorators, { kind: "field", name: "type", static: false, private: false, access: { has: function (obj) { return "type" in obj; }, get: function (obj) { return obj.type; }, set: function (obj, value) { obj.type = value; } }, metadata: _metadata }, _type_initializers, _type_extraInitializers);
        __esDecorate(null, null, _data_decorators, { kind: "field", name: "data", static: false, private: false, access: { has: function (obj) { return "data" in obj; }, get: function (obj) { return obj.data; }, set: function (obj, value) { obj.data = value; } }, metadata: _metadata }, _data_initializers, _data_extraInitializers);
        __esDecorate(null, null, _dataParam_decorators, { kind: "field", name: "dataParam", static: false, private: false, access: { has: function (obj) { return "dataParam" in obj; }, get: function (obj) { return obj.dataParam; }, set: function (obj, value) { obj.dataParam = value; } }, metadata: _metadata }, _dataParam_initializers, _dataParam_extraInitializers);
        __esDecorate(null, null, _spatialPosition_decorators, { kind: "field", name: "spatialPosition", static: false, private: false, access: { has: function (obj) { return "spatialPosition" in obj; }, get: function (obj) { return obj.spatialPosition; }, set: function (obj, value) { obj.spatialPosition = value; } }, metadata: _metadata }, _spatialPosition_initializers, _spatialPosition_extraInitializers);
        __esDecorate(null, null, _applySpatialAudio_decorators, { kind: "field", name: "applySpatialAudio", static: false, private: false, access: { has: function (obj) { return "applySpatialAudio" in obj; }, get: function (obj) { return obj.applySpatialAudio; }, set: function (obj, value) { obj.applySpatialAudio = value; } }, metadata: _metadata }, _applySpatialAudio_initializers, _applySpatialAudio_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCLocalProxyError;
(function (ByteRTCLocalProxyError) {
    ByteRTCLocalProxyError[ByteRTCLocalProxyError["ByteRTCLocalProxyErrorOK"] = 0] = "ByteRTCLocalProxyErrorOK";
    ByteRTCLocalProxyError[ByteRTCLocalProxyError["ByteRTCLocalProxyErrorSocks5VersionError"] = 1] = "ByteRTCLocalProxyErrorSocks5VersionError";
    ByteRTCLocalProxyError[ByteRTCLocalProxyError["ByteRTCLocalProxyErrorSocks5FormatError"] = 2] = "ByteRTCLocalProxyErrorSocks5FormatError";
    ByteRTCLocalProxyError[ByteRTCLocalProxyError["ByteRTCLocalProxyErrorSocks5InvalidValue"] = 3] = "ByteRTCLocalProxyErrorSocks5InvalidValue";
    ByteRTCLocalProxyError[ByteRTCLocalProxyError["ByteRTCLocalProxyErrorSocks5UserPassNotGiven"] = 4] = "ByteRTCLocalProxyErrorSocks5UserPassNotGiven";
    ByteRTCLocalProxyError[ByteRTCLocalProxyError["ByteRTCLocalProxyErrorSocks5TcpClosed"] = 5] = "ByteRTCLocalProxyErrorSocks5TcpClosed";
    ByteRTCLocalProxyError[ByteRTCLocalProxyError["ByteRTCLocalProxyErrorHttpTunnelFailed"] = 6] = "ByteRTCLocalProxyErrorHttpTunnelFailed";
})(ByteRTCLocalProxyError || (ByteRTCLocalProxyError = {}));
exports.BluetoothMode = void 0;
(function (ByteRTCBluetoothMode) {
    ByteRTCBluetoothMode[ByteRTCBluetoothMode["ByteRTCBluetoothModeAuto"] = 0] = "ByteRTCBluetoothModeAuto";
    ByteRTCBluetoothMode[ByteRTCBluetoothMode["ByteRTCBluetoothModeA2DP"] = 1] = "ByteRTCBluetoothModeA2DP";
    ByteRTCBluetoothMode[ByteRTCBluetoothMode["ByteRTCBluetoothModeHFP"] = 2] = "ByteRTCBluetoothModeHFP";
})(exports.BluetoothMode || (exports.BluetoothMode = {}));
var ByteRTCVideoContentType;
(function (ByteRTCVideoContentType) {
    ByteRTCVideoContentType[ByteRTCVideoContentType["ByteRTCVideoContentTypeNormalFrame"] = 0] = "ByteRTCVideoContentTypeNormalFrame";
    ByteRTCVideoContentType[ByteRTCVideoContentType["ByteRTCVideoContentTypeBlackFrame"] = 1] = "ByteRTCVideoContentTypeBlackFrame";
})(ByteRTCVideoContentType || (ByteRTCVideoContentType = {}));
var ByteRTCRemoteVideoStats = function () {
    var _classDecorators = [NativeClass('ByteRTCRemoteVideoStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _videoLossRate_decorators;
    var _videoLossRate_initializers = [];
    var _videoLossRate_extraInitializers = [];
    var _receivedKBitrate_decorators;
    var _receivedKBitrate_initializers = [];
    var _receivedKBitrate_extraInitializers = [];
    var _receivedFrameRate_decorators;
    var _receivedFrameRate_initializers = [];
    var _receivedFrameRate_extraInitializers = [];
    var _decoderOutputFrameRate_decorators;
    var _decoderOutputFrameRate_initializers = [];
    var _decoderOutputFrameRate_extraInitializers = [];
    var _renderOutputFrameRate_decorators;
    var _renderOutputFrameRate_initializers = [];
    var _renderOutputFrameRate_extraInitializers = [];
    var _stallCount_decorators;
    var _stallCount_initializers = [];
    var _stallCount_extraInitializers = [];
    var _stallDuration_decorators;
    var _stallDuration_initializers = [];
    var _stallDuration_extraInitializers = [];
    var _e2eDelay_decorators;
    var _e2eDelay_initializers = [];
    var _e2eDelay_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _statsInterval_decorators;
    var _statsInterval_initializers = [];
    var _statsInterval_extraInitializers = [];
    var _rtt_decorators;
    var _rtt_initializers = [];
    var _rtt_extraInitializers = [];
    var _frozenRate_decorators;
    var _frozenRate_initializers = [];
    var _frozenRate_extraInitializers = [];
    var _codecType_decorators;
    var _codecType_initializers = [];
    var _codecType_extraInitializers = [];
    var _videoIndex_decorators;
    var _videoIndex_initializers = [];
    var _videoIndex_extraInitializers = [];
    var _jitter_decorators;
    var _jitter_initializers = [];
    var _jitter_extraInitializers = [];
    var _superResolutionMode_decorators;
    var _superResolutionMode_initializers = [];
    var _superResolutionMode_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRemoteVideoStats_1() {
            this.width = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.videoLossRate = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _videoLossRate_initializers, void 0));
            this.receivedKBitrate = (__runInitializers(this, _videoLossRate_extraInitializers), __runInitializers(this, _receivedKBitrate_initializers, void 0));
            this.receivedFrameRate = (__runInitializers(this, _receivedKBitrate_extraInitializers), __runInitializers(this, _receivedFrameRate_initializers, void 0));
            this.decoderOutputFrameRate = (__runInitializers(this, _receivedFrameRate_extraInitializers), __runInitializers(this, _decoderOutputFrameRate_initializers, void 0));
            this.renderOutputFrameRate = (__runInitializers(this, _decoderOutputFrameRate_extraInitializers), __runInitializers(this, _renderOutputFrameRate_initializers, void 0));
            this.stallCount = (__runInitializers(this, _renderOutputFrameRate_extraInitializers), __runInitializers(this, _stallCount_initializers, void 0));
            this.stallDuration = (__runInitializers(this, _stallCount_extraInitializers), __runInitializers(this, _stallDuration_initializers, void 0));
            this.e2eDelay = (__runInitializers(this, _stallDuration_extraInitializers), __runInitializers(this, _e2eDelay_initializers, void 0));
            this.isScreen = (__runInitializers(this, _e2eDelay_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.statsInterval = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _statsInterval_initializers, void 0));
            this.rtt = (__runInitializers(this, _statsInterval_extraInitializers), __runInitializers(this, _rtt_initializers, void 0));
            this.frozenRate = (__runInitializers(this, _rtt_extraInitializers), __runInitializers(this, _frozenRate_initializers, void 0));
            this.codecType = (__runInitializers(this, _frozenRate_extraInitializers), __runInitializers(this, _codecType_initializers, void 0));
            this.videoIndex = (__runInitializers(this, _codecType_extraInitializers), __runInitializers(this, _videoIndex_initializers, void 0));
            this.jitter = (__runInitializers(this, _videoIndex_extraInitializers), __runInitializers(this, _jitter_initializers, void 0));
            this.superResolutionMode = (__runInitializers(this, _jitter_extraInitializers), __runInitializers(this, _superResolutionMode_initializers, void 0));
            __runInitializers(this, _superResolutionMode_extraInitializers);
        }
        ByteRTCRemoteVideoStats_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRemoteVideoStats_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRemoteVideoStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _videoLossRate_decorators = [NativeMember()];
        _receivedKBitrate_decorators = [NativeMember()];
        _receivedFrameRate_decorators = [NativeMember()];
        _decoderOutputFrameRate_decorators = [NativeMember()];
        _renderOutputFrameRate_decorators = [NativeMember()];
        _stallCount_decorators = [NativeMember()];
        _stallDuration_decorators = [NativeMember()];
        _e2eDelay_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _statsInterval_decorators = [NativeMember()];
        _rtt_decorators = [NativeMember()];
        _frozenRate_decorators = [NativeMember()];
        _codecType_decorators = [NativeMember()];
        _videoIndex_decorators = [NativeMember()];
        _jitter_decorators = [NativeMember()];
        _superResolutionMode_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _videoLossRate_decorators, { kind: "field", name: "videoLossRate", static: false, private: false, access: { has: function (obj) { return "videoLossRate" in obj; }, get: function (obj) { return obj.videoLossRate; }, set: function (obj, value) { obj.videoLossRate = value; } }, metadata: _metadata }, _videoLossRate_initializers, _videoLossRate_extraInitializers);
        __esDecorate(null, null, _receivedKBitrate_decorators, { kind: "field", name: "receivedKBitrate", static: false, private: false, access: { has: function (obj) { return "receivedKBitrate" in obj; }, get: function (obj) { return obj.receivedKBitrate; }, set: function (obj, value) { obj.receivedKBitrate = value; } }, metadata: _metadata }, _receivedKBitrate_initializers, _receivedKBitrate_extraInitializers);
        __esDecorate(null, null, _receivedFrameRate_decorators, { kind: "field", name: "receivedFrameRate", static: false, private: false, access: { has: function (obj) { return "receivedFrameRate" in obj; }, get: function (obj) { return obj.receivedFrameRate; }, set: function (obj, value) { obj.receivedFrameRate = value; } }, metadata: _metadata }, _receivedFrameRate_initializers, _receivedFrameRate_extraInitializers);
        __esDecorate(null, null, _decoderOutputFrameRate_decorators, { kind: "field", name: "decoderOutputFrameRate", static: false, private: false, access: { has: function (obj) { return "decoderOutputFrameRate" in obj; }, get: function (obj) { return obj.decoderOutputFrameRate; }, set: function (obj, value) { obj.decoderOutputFrameRate = value; } }, metadata: _metadata }, _decoderOutputFrameRate_initializers, _decoderOutputFrameRate_extraInitializers);
        __esDecorate(null, null, _renderOutputFrameRate_decorators, { kind: "field", name: "renderOutputFrameRate", static: false, private: false, access: { has: function (obj) { return "renderOutputFrameRate" in obj; }, get: function (obj) { return obj.renderOutputFrameRate; }, set: function (obj, value) { obj.renderOutputFrameRate = value; } }, metadata: _metadata }, _renderOutputFrameRate_initializers, _renderOutputFrameRate_extraInitializers);
        __esDecorate(null, null, _stallCount_decorators, { kind: "field", name: "stallCount", static: false, private: false, access: { has: function (obj) { return "stallCount" in obj; }, get: function (obj) { return obj.stallCount; }, set: function (obj, value) { obj.stallCount = value; } }, metadata: _metadata }, _stallCount_initializers, _stallCount_extraInitializers);
        __esDecorate(null, null, _stallDuration_decorators, { kind: "field", name: "stallDuration", static: false, private: false, access: { has: function (obj) { return "stallDuration" in obj; }, get: function (obj) { return obj.stallDuration; }, set: function (obj, value) { obj.stallDuration = value; } }, metadata: _metadata }, _stallDuration_initializers, _stallDuration_extraInitializers);
        __esDecorate(null, null, _e2eDelay_decorators, { kind: "field", name: "e2eDelay", static: false, private: false, access: { has: function (obj) { return "e2eDelay" in obj; }, get: function (obj) { return obj.e2eDelay; }, set: function (obj, value) { obj.e2eDelay = value; } }, metadata: _metadata }, _e2eDelay_initializers, _e2eDelay_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _statsInterval_decorators, { kind: "field", name: "statsInterval", static: false, private: false, access: { has: function (obj) { return "statsInterval" in obj; }, get: function (obj) { return obj.statsInterval; }, set: function (obj, value) { obj.statsInterval = value; } }, metadata: _metadata }, _statsInterval_initializers, _statsInterval_extraInitializers);
        __esDecorate(null, null, _rtt_decorators, { kind: "field", name: "rtt", static: false, private: false, access: { has: function (obj) { return "rtt" in obj; }, get: function (obj) { return obj.rtt; }, set: function (obj, value) { obj.rtt = value; } }, metadata: _metadata }, _rtt_initializers, _rtt_extraInitializers);
        __esDecorate(null, null, _frozenRate_decorators, { kind: "field", name: "frozenRate", static: false, private: false, access: { has: function (obj) { return "frozenRate" in obj; }, get: function (obj) { return obj.frozenRate; }, set: function (obj, value) { obj.frozenRate = value; } }, metadata: _metadata }, _frozenRate_initializers, _frozenRate_extraInitializers);
        __esDecorate(null, null, _codecType_decorators, { kind: "field", name: "codecType", static: false, private: false, access: { has: function (obj) { return "codecType" in obj; }, get: function (obj) { return obj.codecType; }, set: function (obj, value) { obj.codecType = value; } }, metadata: _metadata }, _codecType_initializers, _codecType_extraInitializers);
        __esDecorate(null, null, _videoIndex_decorators, { kind: "field", name: "videoIndex", static: false, private: false, access: { has: function (obj) { return "videoIndex" in obj; }, get: function (obj) { return obj.videoIndex; }, set: function (obj, value) { obj.videoIndex = value; } }, metadata: _metadata }, _videoIndex_initializers, _videoIndex_extraInitializers);
        __esDecorate(null, null, _jitter_decorators, { kind: "field", name: "jitter", static: false, private: false, access: { has: function (obj) { return "jitter" in obj; }, get: function (obj) { return obj.jitter; }, set: function (obj, value) { obj.jitter = value; } }, metadata: _metadata }, _jitter_initializers, _jitter_extraInitializers);
        __esDecorate(null, null, _superResolutionMode_decorators, { kind: "field", name: "superResolutionMode", static: false, private: false, access: { has: function (obj) { return "superResolutionMode" in obj; }, get: function (obj) { return obj.superResolutionMode; }, set: function (obj, value) { obj.superResolutionMode = value; } }, metadata: _metadata }, _superResolutionMode_initializers, _superResolutionMode_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCDownloadLyricType;
(function (ByteRTCDownloadLyricType) {
    ByteRTCDownloadLyricType[ByteRTCDownloadLyricType["ByteRTCDownloadLyricTypeKRC"] = 0] = "ByteRTCDownloadLyricTypeKRC";
    ByteRTCDownloadLyricType[ByteRTCDownloadLyricType["ByteRTCDownloadLyricTypeLRC"] = 1] = "ByteRTCDownloadLyricTypeLRC";
})(ByteRTCDownloadLyricType || (ByteRTCDownloadLyricType = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCFrameExtendedData')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _frameType_decorators;
    var _frameType_initializers = [];
    var _frameType_extraInitializers = [];
    var _extendedData_decorators;
    var _extendedData_initializers = [];
    var _extendedData_extraInitializers = [];
    var _extendedDataLen_decorators;
    var _extendedDataLen_initializers = [];
    var _extendedDataLen_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCFrameExtendedData_1() {
            this.frameType = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _frameType_initializers, void 0));
            this.extendedData = (__runInitializers(this, _frameType_extraInitializers), __runInitializers(this, _extendedData_initializers, void 0));
            this.extendedDataLen = (__runInitializers(this, _extendedData_extraInitializers), __runInitializers(this, _extendedDataLen_initializers, void 0));
            __runInitializers(this, _extendedDataLen_extraInitializers);
        }
        ByteRTCFrameExtendedData_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCFrameExtendedData_1;
    }());
    __setFunctionName(_classThis, "ByteRTCFrameExtendedData");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _frameType_decorators = [NativeMember()];
        _extendedData_decorators = [NativeMember()];
        _extendedDataLen_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _frameType_decorators, { kind: "field", name: "frameType", static: false, private: false, access: { has: function (obj) { return "frameType" in obj; }, get: function (obj) { return obj.frameType; }, set: function (obj, value) { obj.frameType = value; } }, metadata: _metadata }, _frameType_initializers, _frameType_extraInitializers);
        __esDecorate(null, null, _extendedData_decorators, { kind: "field", name: "extendedData", static: false, private: false, access: { has: function (obj) { return "extendedData" in obj; }, get: function (obj) { return obj.extendedData; }, set: function (obj, value) { obj.extendedData = value; } }, metadata: _metadata }, _extendedData_initializers, _extendedData_extraInitializers);
        __esDecorate(null, null, _extendedDataLen_decorators, { kind: "field", name: "extendedDataLen", static: false, private: false, access: { has: function (obj) { return "extendedDataLen" in obj; }, get: function (obj) { return obj.extendedDataLen; }, set: function (obj, value) { obj.extendedDataLen = value; } }, metadata: _metadata }, _extendedDataLen_initializers, _extendedDataLen_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCRoomConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCRoomConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _profile_decorators;
    var _profile_initializers = [];
    var _profile_extraInitializers = [];
    var _isAutoPublish_decorators;
    var _isAutoPublish_initializers = [];
    var _isAutoPublish_extraInitializers = [];
    var _isAutoSubscribeAudio_decorators;
    var _isAutoSubscribeAudio_initializers = [];
    var _isAutoSubscribeAudio_extraInitializers = [];
    var _isAutoSubscribeVideo_decorators;
    var _isAutoSubscribeVideo_initializers = [];
    var _isAutoSubscribeVideo_extraInitializers = [];
    var _remoteVideoConfig_decorators;
    var _remoteVideoConfig_initializers = [];
    var _remoteVideoConfig_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRoomConfig_1() {
            this.profile = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _profile_initializers, void 0));
            this.isAutoPublish = (__runInitializers(this, _profile_extraInitializers), __runInitializers(this, _isAutoPublish_initializers, void 0));
            this.isAutoSubscribeAudio = (__runInitializers(this, _isAutoPublish_extraInitializers), __runInitializers(this, _isAutoSubscribeAudio_initializers, void 0));
            this.isAutoSubscribeVideo = (__runInitializers(this, _isAutoSubscribeAudio_extraInitializers), __runInitializers(this, _isAutoSubscribeVideo_initializers, void 0));
            this.remoteVideoConfig = (__runInitializers(this, _isAutoSubscribeVideo_extraInitializers), __runInitializers(this, _remoteVideoConfig_initializers, void 0));
            __runInitializers(this, _remoteVideoConfig_extraInitializers);
        }
        ByteRTCRoomConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRoomConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRoomConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _profile_decorators = [NativeMember()];
        _isAutoPublish_decorators = [NativeMember()];
        _isAutoSubscribeAudio_decorators = [NativeMember()];
        _isAutoSubscribeVideo_decorators = [NativeMember()];
        _remoteVideoConfig_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _profile_decorators, { kind: "field", name: "profile", static: false, private: false, access: { has: function (obj) { return "profile" in obj; }, get: function (obj) { return obj.profile; }, set: function (obj, value) { obj.profile = value; } }, metadata: _metadata }, _profile_initializers, _profile_extraInitializers);
        __esDecorate(null, null, _isAutoPublish_decorators, { kind: "field", name: "isAutoPublish", static: false, private: false, access: { has: function (obj) { return "isAutoPublish" in obj; }, get: function (obj) { return obj.isAutoPublish; }, set: function (obj, value) { obj.isAutoPublish = value; } }, metadata: _metadata }, _isAutoPublish_initializers, _isAutoPublish_extraInitializers);
        __esDecorate(null, null, _isAutoSubscribeAudio_decorators, { kind: "field", name: "isAutoSubscribeAudio", static: false, private: false, access: { has: function (obj) { return "isAutoSubscribeAudio" in obj; }, get: function (obj) { return obj.isAutoSubscribeAudio; }, set: function (obj, value) { obj.isAutoSubscribeAudio = value; } }, metadata: _metadata }, _isAutoSubscribeAudio_initializers, _isAutoSubscribeAudio_extraInitializers);
        __esDecorate(null, null, _isAutoSubscribeVideo_decorators, { kind: "field", name: "isAutoSubscribeVideo", static: false, private: false, access: { has: function (obj) { return "isAutoSubscribeVideo" in obj; }, get: function (obj) { return obj.isAutoSubscribeVideo; }, set: function (obj, value) { obj.isAutoSubscribeVideo = value; } }, metadata: _metadata }, _isAutoSubscribeVideo_initializers, _isAutoSubscribeVideo_extraInitializers);
        __esDecorate(null, null, _remoteVideoConfig_decorators, { kind: "field", name: "remoteVideoConfig", static: false, private: false, access: { has: function (obj) { return "remoteVideoConfig" in obj; }, get: function (obj) { return obj.remoteVideoConfig; }, set: function (obj, value) { obj.remoteVideoConfig = value; } }, metadata: _metadata }, _remoteVideoConfig_initializers, _remoteVideoConfig_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('ByteRTCScreenCaptureSourceInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _sourceType_decorators;
    var _sourceType_initializers = [];
    var _sourceType_extraInitializers = [];
    var _sourceId_decorators;
    var _sourceId_initializers = [];
    var _sourceId_extraInitializers = [];
    var _sourceName_decorators;
    var _sourceName_initializers = [];
    var _sourceName_extraInitializers = [];
    var _application_decorators;
    var _application_initializers = [];
    var _application_extraInitializers = [];
    var _pid_decorators;
    var _pid_initializers = [];
    var _pid_extraInitializers = [];
    var _primaryMonitor_decorators;
    var _primaryMonitor_initializers = [];
    var _primaryMonitor_extraInitializers = [];
    var _regionRect_decorators;
    var _regionRect_initializers = [];
    var _regionRect_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCScreenCaptureSourceInfo_1() {
            this.sourceType = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _sourceType_initializers, void 0));
            this.sourceId = (__runInitializers(this, _sourceType_extraInitializers), __runInitializers(this, _sourceId_initializers, void 0));
            this.sourceName = (__runInitializers(this, _sourceId_extraInitializers), __runInitializers(this, _sourceName_initializers, void 0));
            this.application = (__runInitializers(this, _sourceName_extraInitializers), __runInitializers(this, _application_initializers, void 0));
            this.pid = (__runInitializers(this, _application_extraInitializers), __runInitializers(this, _pid_initializers, void 0));
            this.primaryMonitor = (__runInitializers(this, _pid_extraInitializers), __runInitializers(this, _primaryMonitor_initializers, void 0));
            this.regionRect = (__runInitializers(this, _primaryMonitor_extraInitializers), __runInitializers(this, _regionRect_initializers, void 0));
            __runInitializers(this, _regionRect_extraInitializers);
        }
        ByteRTCScreenCaptureSourceInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCScreenCaptureSourceInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCScreenCaptureSourceInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _sourceType_decorators = [NativeMember()];
        _sourceId_decorators = [NativeMember()];
        _sourceName_decorators = [NativeMember()];
        _application_decorators = [NativeMember()];
        _pid_decorators = [NativeMember()];
        _primaryMonitor_decorators = [NativeMember()];
        _regionRect_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _sourceType_decorators, { kind: "field", name: "sourceType", static: false, private: false, access: { has: function (obj) { return "sourceType" in obj; }, get: function (obj) { return obj.sourceType; }, set: function (obj, value) { obj.sourceType = value; } }, metadata: _metadata }, _sourceType_initializers, _sourceType_extraInitializers);
        __esDecorate(null, null, _sourceId_decorators, { kind: "field", name: "sourceId", static: false, private: false, access: { has: function (obj) { return "sourceId" in obj; }, get: function (obj) { return obj.sourceId; }, set: function (obj, value) { obj.sourceId = value; } }, metadata: _metadata }, _sourceId_initializers, _sourceId_extraInitializers);
        __esDecorate(null, null, _sourceName_decorators, { kind: "field", name: "sourceName", static: false, private: false, access: { has: function (obj) { return "sourceName" in obj; }, get: function (obj) { return obj.sourceName; }, set: function (obj, value) { obj.sourceName = value; } }, metadata: _metadata }, _sourceName_initializers, _sourceName_extraInitializers);
        __esDecorate(null, null, _application_decorators, { kind: "field", name: "application", static: false, private: false, access: { has: function (obj) { return "application" in obj; }, get: function (obj) { return obj.application; }, set: function (obj, value) { obj.application = value; } }, metadata: _metadata }, _application_initializers, _application_extraInitializers);
        __esDecorate(null, null, _pid_decorators, { kind: "field", name: "pid", static: false, private: false, access: { has: function (obj) { return "pid" in obj; }, get: function (obj) { return obj.pid; }, set: function (obj, value) { obj.pid = value; } }, metadata: _metadata }, _pid_initializers, _pid_extraInitializers);
        __esDecorate(null, null, _primaryMonitor_decorators, { kind: "field", name: "primaryMonitor", static: false, private: false, access: { has: function (obj) { return "primaryMonitor" in obj; }, get: function (obj) { return obj.primaryMonitor; }, set: function (obj, value) { obj.primaryMonitor = value; } }, metadata: _metadata }, _primaryMonitor_initializers, _primaryMonitor_extraInitializers);
        __esDecorate(null, null, _regionRect_decorators, { kind: "field", name: "regionRect", static: false, private: false, access: { has: function (obj) { return "regionRect" in obj; }, get: function (obj) { return obj.regionRect; }, set: function (obj, value) { obj.regionRect = value; } }, metadata: _metadata }, _regionRect_initializers, _regionRect_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
(function () {
    var _classDecorators = [NativeClass('ByteRTCVideoCompositingLayout')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _backgroundColor_decorators;
    var _backgroundColor_initializers = [];
    var _backgroundColor_extraInitializers = [];
    var _regions_decorators;
    var _regions_initializers = [];
    var _regions_extraInitializers = [];
    var _appData_decorators;
    var _appData_initializers = [];
    var _appData_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoCompositingLayout_1() {
            this.backgroundColor = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _backgroundColor_initializers, void 0));
            this.regions = (__runInitializers(this, _backgroundColor_extraInitializers), __runInitializers(this, _regions_initializers, void 0));
            this.appData = (__runInitializers(this, _regions_extraInitializers), __runInitializers(this, _appData_initializers, void 0));
            __runInitializers(this, _appData_extraInitializers);
        }
        ByteRTCVideoCompositingLayout_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVideoCompositingLayout_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoCompositingLayout");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _backgroundColor_decorators = [NativeMember()];
        _regions_decorators = [NativeMember()];
        _appData_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _backgroundColor_decorators, { kind: "field", name: "backgroundColor", static: false, private: false, access: { has: function (obj) { return "backgroundColor" in obj; }, get: function (obj) { return obj.backgroundColor; }, set: function (obj, value) { obj.backgroundColor = value; } }, metadata: _metadata }, _backgroundColor_initializers, _backgroundColor_extraInitializers);
        __esDecorate(null, null, _regions_decorators, { kind: "field", name: "regions", static: false, private: false, access: { has: function (obj) { return "regions" in obj; }, get: function (obj) { return obj.regions; }, set: function (obj, value) { obj.regions = value; } }, metadata: _metadata }, _regions_initializers, _regions_extraInitializers);
        __esDecorate(null, null, _appData_decorators, { kind: "field", name: "appData", static: false, private: false, access: { has: function (obj) { return "appData" in obj; }, get: function (obj) { return obj.appData; }, set: function (obj, value) { obj.appData = value; } }, metadata: _metadata }, _appData_initializers, _appData_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCBandFrequency;
(function (ByteRTCBandFrequency) {
    ByteRTCBandFrequency[ByteRTCBandFrequency["ByteRTCBandFrequency31"] = 0] = "ByteRTCBandFrequency31";
    ByteRTCBandFrequency[ByteRTCBandFrequency["ByteRTCBandFrequency62"] = 1] = "ByteRTCBandFrequency62";
    ByteRTCBandFrequency[ByteRTCBandFrequency["ByteRTCBandFrequency125"] = 2] = "ByteRTCBandFrequency125";
    ByteRTCBandFrequency[ByteRTCBandFrequency["ByteRTCBandFrequency250"] = 3] = "ByteRTCBandFrequency250";
    ByteRTCBandFrequency[ByteRTCBandFrequency["ByteRTCBandFrequency500"] = 4] = "ByteRTCBandFrequency500";
    ByteRTCBandFrequency[ByteRTCBandFrequency["ByteRTCBandFrequency1k"] = 5] = "ByteRTCBandFrequency1k";
    ByteRTCBandFrequency[ByteRTCBandFrequency["ByteRTCBandFrequency2k"] = 6] = "ByteRTCBandFrequency2k";
    ByteRTCBandFrequency[ByteRTCBandFrequency["ByteRTCBandFrequency4k"] = 7] = "ByteRTCBandFrequency4k";
    ByteRTCBandFrequency[ByteRTCBandFrequency["ByteRTCBandFrequency8k"] = 8] = "ByteRTCBandFrequency8k";
    ByteRTCBandFrequency[ByteRTCBandFrequency["ByteRTCBandFrequency16k"] = 9] = "ByteRTCBandFrequency16k";
})(ByteRTCBandFrequency || (ByteRTCBandFrequency = {}));
var ByteRTCAudioDumpStatus;
(function (ByteRTCAudioDumpStatus) {
    ByteRTCAudioDumpStatus[ByteRTCAudioDumpStatus["ByteRTCAudioDumpStartFailure"] = 0] = "ByteRTCAudioDumpStartFailure";
    ByteRTCAudioDumpStatus[ByteRTCAudioDumpStatus["ByteRTCAudioDumpStartSuccess"] = 1] = "ByteRTCAudioDumpStartSuccess";
    ByteRTCAudioDumpStatus[ByteRTCAudioDumpStatus["ByteRTCAudioDumpStopFailure"] = 2] = "ByteRTCAudioDumpStopFailure";
    ByteRTCAudioDumpStatus[ByteRTCAudioDumpStatus["ByteRTCAudioDumpStopSuccess"] = 3] = "ByteRTCAudioDumpStopSuccess";
    ByteRTCAudioDumpStatus[ByteRTCAudioDumpStatus["ByteRTCAudioDumpRunningFailure"] = 4] = "ByteRTCAudioDumpRunningFailure";
    ByteRTCAudioDumpStatus[ByteRTCAudioDumpStatus["ByteRTCAudioDumpRunningSuccess"] = 5] = "ByteRTCAudioDumpRunningSuccess";
})(ByteRTCAudioDumpStatus || (ByteRTCAudioDumpStatus = {}));
var ByteRTCAudioProfileType;
(function (ByteRTCAudioProfileType) {
    ByteRTCAudioProfileType[ByteRTCAudioProfileType["ByteRTCAudioProfileDefault"] = 0] = "ByteRTCAudioProfileDefault";
    ByteRTCAudioProfileType[ByteRTCAudioProfileType["ByteRTCAudioProfileFluent"] = 1] = "ByteRTCAudioProfileFluent";
    ByteRTCAudioProfileType[ByteRTCAudioProfileType["ByteRTCAudioProfileStandard"] = 2] = "ByteRTCAudioProfileStandard";
    ByteRTCAudioProfileType[ByteRTCAudioProfileType["ByteRTCAudioProfileHD"] = 3] = "ByteRTCAudioProfileHD";
    ByteRTCAudioProfileType[ByteRTCAudioProfileType["ByteRTCAudioProfileStandardStereo"] = 4] = "ByteRTCAudioProfileStandardStereo";
    ByteRTCAudioProfileType[ByteRTCAudioProfileType["ByteRTCAudioProfileHDMono"] = 5] = "ByteRTCAudioProfileHDMono";
})(ByteRTCAudioProfileType || (ByteRTCAudioProfileType = {}));
var ByteRTCAggregationOption;
(function (ByteRTCAggregationOption) {
    ByteRTCAggregationOption[ByteRTCAggregationOption["ByteRTCAggregationOptionMin"] = 0] = "ByteRTCAggregationOptionMin";
    ByteRTCAggregationOption[ByteRTCAggregationOption["ByteRTCAggregationOptionMax"] = 1] = "ByteRTCAggregationOptionMax";
    ByteRTCAggregationOption[ByteRTCAggregationOption["ByteRTCAggregationOptionMajority"] = 2] = "ByteRTCAggregationOptionMajority";
})(ByteRTCAggregationOption || (ByteRTCAggregationOption = {}));
var ByteRTCMediaStreamType;
(function (ByteRTCMediaStreamType) {
    ByteRTCMediaStreamType[ByteRTCMediaStreamType["ByteRTCMediaStreamTypeAudio"] = 1] = "ByteRTCMediaStreamTypeAudio";
    ByteRTCMediaStreamType[ByteRTCMediaStreamType["ByteRTCMediaStreamTypeVideo"] = 2] = "ByteRTCMediaStreamTypeVideo";
    ByteRTCMediaStreamType[ByteRTCMediaStreamType["ByteRTCMediaStreamTypeBoth"] = 3] = "ByteRTCMediaStreamTypeBoth";
})(ByteRTCMediaStreamType || (ByteRTCMediaStreamType = {}));
var ByteRTCEchoTestResult;
(function (ByteRTCEchoTestResult) {
    ByteRTCEchoTestResult[ByteRTCEchoTestResult["ByteRTCEchoTestResultSuccess"] = 0] = "ByteRTCEchoTestResultSuccess";
    ByteRTCEchoTestResult[ByteRTCEchoTestResult["ByteRTCEchoTestResultTimeout"] = 1] = "ByteRTCEchoTestResultTimeout";
    ByteRTCEchoTestResult[ByteRTCEchoTestResult["ByteRTCEchoTestResultIntervalShort"] = 2] = "ByteRTCEchoTestResultIntervalShort";
    ByteRTCEchoTestResult[ByteRTCEchoTestResult["ByteRTCEchoTestResultAudioDeviceError"] = 3] = "ByteRTCEchoTestResultAudioDeviceError";
    ByteRTCEchoTestResult[ByteRTCEchoTestResult["ByteRTCEchoTestResultVideoDeviceError"] = 4] = "ByteRTCEchoTestResultVideoDeviceError";
    ByteRTCEchoTestResult[ByteRTCEchoTestResult["ByteRTCEchoTestResultAudioReceiveError"] = 5] = "ByteRTCEchoTestResultAudioReceiveError";
    ByteRTCEchoTestResult[ByteRTCEchoTestResult["ByteRTCEchoTestResultVideoReceiveError"] = 6] = "ByteRTCEchoTestResultVideoReceiveError";
    ByteRTCEchoTestResult[ByteRTCEchoTestResult["ByteRTCEchoTestResultInternalError"] = 7] = "ByteRTCEchoTestResultInternalError";
})(ByteRTCEchoTestResult || (ByteRTCEchoTestResult = {}));
var ByteRTCRoomProfile;
(function (ByteRTCRoomProfile) {
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileCommunication"] = 0] = "ByteRTCRoomProfileCommunication";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileGame"] = 2] = "ByteRTCRoomProfileGame";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileCloudGame"] = 3] = "ByteRTCRoomProfileCloudGame";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileLowLatency"] = 4] = "ByteRTCRoomProfileLowLatency";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileChat"] = 5] = "ByteRTCRoomProfileChat";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileChatRoom"] = 6] = "ByteRTCRoomProfileChatRoom";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileLwTogether"] = 7] = "ByteRTCRoomProfileLwTogether";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileGameHD"] = 8] = "ByteRTCRoomProfileGameHD";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileCoHost"] = 9] = "ByteRTCRoomProfileCoHost";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileInteractivePodcast"] = 10] = "ByteRTCRoomProfileInteractivePodcast";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileKTV"] = 11] = "ByteRTCRoomProfileKTV";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileChorus"] = 12] = "ByteRTCRoomProfileChorus";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileVRChat"] = 13] = "ByteRTCRoomProfileVRChat";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileGameStreaming"] = 14] = "ByteRTCRoomProfileGameStreaming";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileLanLiveStreaming"] = 15] = "ByteRTCRoomProfileLanLiveStreaming";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileMeeting"] = 16] = "ByteRTCRoomProfileMeeting";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileMeetingRoom"] = 17] = "ByteRTCRoomProfileMeetingRoom";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileClassroom"] = 18] = "ByteRTCRoomProfileClassroom";
    ByteRTCRoomProfile[ByteRTCRoomProfile["ByteRTCRoomProfileLiveBroadcasting"] = 1] = "ByteRTCRoomProfileLiveBroadcasting";
})(ByteRTCRoomProfile || (ByteRTCRoomProfile = {}));
var ByteRTCPositionInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCPositionInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _position_decorators;
    var _position_initializers = [];
    var _position_extraInitializers = [];
    var _orientation_decorators;
    var _orientation_initializers = [];
    var _orientation_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCPositionInfo_1() {
            this.position = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _position_initializers, void 0));
            this.orientation = (__runInitializers(this, _position_extraInitializers), __runInitializers(this, _orientation_initializers, void 0));
            __runInitializers(this, _orientation_extraInitializers);
        }
        ByteRTCPositionInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCPositionInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCPositionInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _position_decorators = [NativeMember()];
        _orientation_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _position_decorators, { kind: "field", name: "position", static: false, private: false, access: { has: function (obj) { return "position" in obj; }, get: function (obj) { return obj.position; }, set: function (obj, value) { obj.position = value; } }, metadata: _metadata }, _position_initializers, _position_extraInitializers);
        __esDecorate(null, null, _orientation_decorators, { kind: "field", name: "orientation", static: false, private: false, access: { has: function (obj) { return "orientation" in obj; }, get: function (obj) { return obj.orientation; }, set: function (obj, value) { obj.orientation = value; } }, metadata: _metadata }, _orientation_initializers, _orientation_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('ByteRTCScreenParam')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _frameRate_decorators;
    var _frameRate_initializers = [];
    var _frameRate_extraInitializers = [];
    var _bitrate_decorators;
    var _bitrate_initializers = [];
    var _bitrate_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCScreenParam_1() {
            this.frameRate = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _frameRate_initializers, void 0));
            this.bitrate = (__runInitializers(this, _frameRate_extraInitializers), __runInitializers(this, _bitrate_initializers, void 0));
            __runInitializers(this, _bitrate_extraInitializers);
        }
        ByteRTCScreenParam_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCScreenParam_1;
    }());
    __setFunctionName(_classThis, "ByteRTCScreenParam");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _frameRate_decorators = [NativeMember()];
        _bitrate_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _frameRate_decorators, { kind: "field", name: "frameRate", static: false, private: false, access: { has: function (obj) { return "frameRate" in obj; }, get: function (obj) { return obj.frameRate; }, set: function (obj, value) { obj.frameRate = value; } }, metadata: _metadata }, _frameRate_initializers, _frameRate_extraInitializers);
        __esDecorate(null, null, _bitrate_decorators, { kind: "field", name: "bitrate", static: false, private: false, access: { has: function (obj) { return "bitrate" in obj; }, get: function (obj) { return obj.bitrate; }, set: function (obj, value) { obj.bitrate = value; } }, metadata: _metadata }, _bitrate_initializers, _bitrate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCScreenCaptureSourceType;
(function (ByteRTCScreenCaptureSourceType) {
    ByteRTCScreenCaptureSourceType[ByteRTCScreenCaptureSourceType["ByteRTCScreenCaptureSourceTypeUnknown"] = 0] = "ByteRTCScreenCaptureSourceTypeUnknown";
    ByteRTCScreenCaptureSourceType[ByteRTCScreenCaptureSourceType["ByteRTCScreenCaptureSourceTypeWindow"] = 1] = "ByteRTCScreenCaptureSourceTypeWindow";
    ByteRTCScreenCaptureSourceType[ByteRTCScreenCaptureSourceType["ByteRTCScreenCaptureSourceTypeScreen"] = 2] = "ByteRTCScreenCaptureSourceTypeScreen";
})(ByteRTCScreenCaptureSourceType || (ByteRTCScreenCaptureSourceType = {}));
var ByteRTCTranscoderContentControlType;
(function (ByteRTCTranscoderContentControlType) {
    ByteRTCTranscoderContentControlType[ByteRTCTranscoderContentControlType["ByteRTCTranscoderContentControlTypeHasAudioAndVideo"] = 0] = "ByteRTCTranscoderContentControlTypeHasAudioAndVideo";
    ByteRTCTranscoderContentControlType[ByteRTCTranscoderContentControlType["ByteRTCTranscoderContentControlTypeHasAudioOnly"] = 1] = "ByteRTCTranscoderContentControlTypeHasAudioOnly";
    ByteRTCTranscoderContentControlType[ByteRTCTranscoderContentControlType["ByteRTCTranscoderContentControlTypeHasVideoOnly"] = 2] = "ByteRTCTranscoderContentControlTypeHasVideoOnly";
})(ByteRTCTranscoderContentControlType || (ByteRTCTranscoderContentControlType = {}));
var ByteRTCClientMixVideoFormat;
(function (ByteRTCClientMixVideoFormat) {
    ByteRTCClientMixVideoFormat[ByteRTCClientMixVideoFormat["ByteRTCClientMixVideoFormatI420"] = 0] = "ByteRTCClientMixVideoFormatI420";
    ByteRTCClientMixVideoFormat[ByteRTCClientMixVideoFormat["ByteRTCClientMixVideoFormatTexture2D"] = 1] = "ByteRTCClientMixVideoFormatTexture2D";
    ByteRTCClientMixVideoFormat[ByteRTCClientMixVideoFormat["ByteRTCClientMixVideoFormatCVPixelBufferBGRA"] = 2] = "ByteRTCClientMixVideoFormatCVPixelBufferBGRA";
    ByteRTCClientMixVideoFormat[ByteRTCClientMixVideoFormat["ByteRTCClientMixVideoFormatNV12"] = 3] = "ByteRTCClientMixVideoFormatNV12";
})(ByteRTCClientMixVideoFormat || (ByteRTCClientMixVideoFormat = {}));
var ByteRTCForwardStreamState;
(function (ByteRTCForwardStreamState) {
    ByteRTCForwardStreamState[ByteRTCForwardStreamState["ByteRTCForwardStreamStateIdle"] = 0] = "ByteRTCForwardStreamStateIdle";
    ByteRTCForwardStreamState[ByteRTCForwardStreamState["ByteRTCForwardStreamStateSuccess"] = 1] = "ByteRTCForwardStreamStateSuccess";
    ByteRTCForwardStreamState[ByteRTCForwardStreamState["ByteRTCForwardStreamStateFailure"] = 2] = "ByteRTCForwardStreamStateFailure";
})(ByteRTCForwardStreamState || (ByteRTCForwardStreamState = {}));
var ByteRTCMediaPlayerCustomSourceSeekWhence;
(function (ByteRTCMediaPlayerCustomSourceSeekWhence) {
    ByteRTCMediaPlayerCustomSourceSeekWhence[ByteRTCMediaPlayerCustomSourceSeekWhence["ByteRTCMediaPlayerCustomSourceSeekWhenceSet"] = 0] = "ByteRTCMediaPlayerCustomSourceSeekWhenceSet";
    ByteRTCMediaPlayerCustomSourceSeekWhence[ByteRTCMediaPlayerCustomSourceSeekWhence["ByteRTCMediaPlayerCustomSourceSeekWhenceCur"] = 1] = "ByteRTCMediaPlayerCustomSourceSeekWhenceCur";
    ByteRTCMediaPlayerCustomSourceSeekWhence[ByteRTCMediaPlayerCustomSourceSeekWhence["ByteRTCMediaPlayerCustomSourceSeekWhenceEnd"] = 2] = "ByteRTCMediaPlayerCustomSourceSeekWhenceEnd";
    ByteRTCMediaPlayerCustomSourceSeekWhence[ByteRTCMediaPlayerCustomSourceSeekWhence["ByteRTCMediaPlayerCustomSourceSeekWhenceSize"] = 3] = "ByteRTCMediaPlayerCustomSourceSeekWhenceSize";
})(ByteRTCMediaPlayerCustomSourceSeekWhence || (ByteRTCMediaPlayerCustomSourceSeekWhence = {}));
var ByteRTCAudioMixingDualMonoMode;
(function (ByteRTCAudioMixingDualMonoMode) {
    ByteRTCAudioMixingDualMonoMode[ByteRTCAudioMixingDualMonoMode["ByteRTCAudioMixingDualMonoModeAuto"] = 0] = "ByteRTCAudioMixingDualMonoModeAuto";
    ByteRTCAudioMixingDualMonoMode[ByteRTCAudioMixingDualMonoMode["ByteRTCAudioMixingDualMonoModeL"] = 1] = "ByteRTCAudioMixingDualMonoModeL";
    ByteRTCAudioMixingDualMonoMode[ByteRTCAudioMixingDualMonoMode["ByteRTCAudioMixingDualMonoModeR"] = 2] = "ByteRTCAudioMixingDualMonoModeR";
    ByteRTCAudioMixingDualMonoMode[ByteRTCAudioMixingDualMonoMode["ByteRTCAudioMixingDualMonoModeMix"] = 3] = "ByteRTCAudioMixingDualMonoModeMix";
})(ByteRTCAudioMixingDualMonoMode || (ByteRTCAudioMixingDualMonoMode = {}));
var ByteRTCRecordingType;
(function (ByteRTCRecordingType) {
    ByteRTCRecordingType[ByteRTCRecordingType["ByteRTCRecordingTypeAudioOnly"] = 0] = "ByteRTCRecordingTypeAudioOnly";
    ByteRTCRecordingType[ByteRTCRecordingType["ByteRTCRecordingTypeVideoOnly"] = 1] = "ByteRTCRecordingTypeVideoOnly";
    ByteRTCRecordingType[ByteRTCRecordingType["ByteRTCRecordingTypeVideoAndAudio"] = 2] = "ByteRTCRecordingTypeVideoAndAudio";
})(ByteRTCRecordingType || (ByteRTCRecordingType = {}));
var ByteRTCZoomDirectionType;
(function (ByteRTCZoomDirectionType) {
    ByteRTCZoomDirectionType[ByteRTCZoomDirectionType["ByteRTCZoomDirectionTypeMoveLeft"] = 0] = "ByteRTCZoomDirectionTypeMoveLeft";
    ByteRTCZoomDirectionType[ByteRTCZoomDirectionType["ByteRTCZoomDirectionTypeMoveRight"] = 1] = "ByteRTCZoomDirectionTypeMoveRight";
    ByteRTCZoomDirectionType[ByteRTCZoomDirectionType["ByteRTCZoomDirectionTypeMoveUp"] = 2] = "ByteRTCZoomDirectionTypeMoveUp";
    ByteRTCZoomDirectionType[ByteRTCZoomDirectionType["ByteRTCZoomDirectionTypeMoveDown"] = 3] = "ByteRTCZoomDirectionTypeMoveDown";
    ByteRTCZoomDirectionType[ByteRTCZoomDirectionType["ByteRTCZoomDirectionTypeZoomOut"] = 4] = "ByteRTCZoomDirectionTypeZoomOut";
    ByteRTCZoomDirectionType[ByteRTCZoomDirectionType["ByteRTCZoomDirectionTypeZoomIn"] = 5] = "ByteRTCZoomDirectionTypeZoomIn";
    ByteRTCZoomDirectionType[ByteRTCZoomDirectionType["ByteRTCZoomDirectionTypeReset"] = 6] = "ByteRTCZoomDirectionTypeReset";
})(ByteRTCZoomDirectionType || (ByteRTCZoomDirectionType = {}));
var ByteRTCNetworkDetectionStopReason;
(function (ByteRTCNetworkDetectionStopReason) {
    ByteRTCNetworkDetectionStopReason[ByteRTCNetworkDetectionStopReason["ByteRTCNetworkDetectionStopReasonUser"] = 0] = "ByteRTCNetworkDetectionStopReasonUser";
    ByteRTCNetworkDetectionStopReason[ByteRTCNetworkDetectionStopReason["ByteRTCNetworkDetectionStopReasonTimeout"] = 1] = "ByteRTCNetworkDetectionStopReasonTimeout";
    ByteRTCNetworkDetectionStopReason[ByteRTCNetworkDetectionStopReason["ByteRTCNetworkDetectionStopReasonConnectionLost"] = 2] = "ByteRTCNetworkDetectionStopReasonConnectionLost";
    ByteRTCNetworkDetectionStopReason[ByteRTCNetworkDetectionStopReason["ByteRTCNetworkDetectionStopReasonStreaming"] = 3] = "ByteRTCNetworkDetectionStopReasonStreaming";
    ByteRTCNetworkDetectionStopReason[ByteRTCNetworkDetectionStopReason["ByteRTCNetworkDetectionStopReasonInnerErr"] = 4] = "ByteRTCNetworkDetectionStopReasonInnerErr";
})(ByteRTCNetworkDetectionStopReason || (ByteRTCNetworkDetectionStopReason = {}));
var ByteRTCAudioQuality;
(function (ByteRTCAudioQuality) {
    ByteRTCAudioQuality[ByteRTCAudioQuality["ByteRTCAudioQualityLow"] = 0] = "ByteRTCAudioQualityLow";
    ByteRTCAudioQuality[ByteRTCAudioQuality["ByteRTCAudioQualityMedium"] = 1] = "ByteRTCAudioQualityMedium";
    ByteRTCAudioQuality[ByteRTCAudioQuality["ByteRTCAudioQualityHigh"] = 2] = "ByteRTCAudioQualityHigh";
    ByteRTCAudioQuality[ByteRTCAudioQuality["ByteRTCAudioQualityUltraHigh"] = 3] = "ByteRTCAudioQualityUltraHigh";
})(ByteRTCAudioQuality || (ByteRTCAudioQuality = {}));
var ByteRTCMediaPlayerCustomSourceMode;
(function (ByteRTCMediaPlayerCustomSourceMode) {
    ByteRTCMediaPlayerCustomSourceMode[ByteRTCMediaPlayerCustomSourceMode["ByteRTCMediaPlayerCustomSourceModePush"] = 0] = "ByteRTCMediaPlayerCustomSourceModePush";
    ByteRTCMediaPlayerCustomSourceMode[ByteRTCMediaPlayerCustomSourceMode["ByteRTCMediaPlayerCustomSourceModePull"] = 1] = "ByteRTCMediaPlayerCustomSourceModePull";
})(ByteRTCMediaPlayerCustomSourceMode || (ByteRTCMediaPlayerCustomSourceMode = {}));
var ByteRTCRenderMode;
(function (ByteRTCRenderMode) {
    ByteRTCRenderMode[ByteRTCRenderMode["ByteRTCRenderModeHidden"] = 1] = "ByteRTCRenderModeHidden";
    ByteRTCRenderMode[ByteRTCRenderMode["ByteRTCRenderModeFit"] = 2] = "ByteRTCRenderModeFit";
    ByteRTCRenderMode[ByteRTCRenderMode["ByteRTCRenderModeFill"] = 3] = "ByteRTCRenderModeFill";
})(ByteRTCRenderMode || (ByteRTCRenderMode = {}));
var ByteRTCSEIStreamEventType;
(function (ByteRTCSEIStreamEventType) {
    ByteRTCSEIStreamEventType[ByteRTCSEIStreamEventType["ByteRTCSEIStreamEventTypeStreamAdd"] = 0] = "ByteRTCSEIStreamEventTypeStreamAdd";
    ByteRTCSEIStreamEventType[ByteRTCSEIStreamEventType["ByteRTCSEIStreamEventTypeStreamRemove"] = 1] = "ByteRTCSEIStreamEventTypeStreamRemove";
})(ByteRTCSEIStreamEventType || (ByteRTCSEIStreamEventType = {}));
var ByteRTCVideoDenoiseModeChangedReason;
(function (ByteRTCVideoDenoiseModeChangedReason) {
    ByteRTCVideoDenoiseModeChangedReason[ByteRTCVideoDenoiseModeChangedReason["ByteRTCVideoDenoiseModeChangedReasonNull"] = -1] = "ByteRTCVideoDenoiseModeChangedReasonNull";
    ByteRTCVideoDenoiseModeChangedReason[ByteRTCVideoDenoiseModeChangedReason["ByteRTCVideoDenoiseModeChangedReasonApiOff"] = 0] = "ByteRTCVideoDenoiseModeChangedReasonApiOff";
    ByteRTCVideoDenoiseModeChangedReason[ByteRTCVideoDenoiseModeChangedReason["ByteRTCVideoDenoiseModeChangedReasonApiOn"] = 1] = "ByteRTCVideoDenoiseModeChangedReasonApiOn";
    ByteRTCVideoDenoiseModeChangedReason[ByteRTCVideoDenoiseModeChangedReason["ByteRTCVideoDenoiseModeChangedReasonConfigDisabled"] = 2] = "ByteRTCVideoDenoiseModeChangedReasonConfigDisabled";
    ByteRTCVideoDenoiseModeChangedReason[ByteRTCVideoDenoiseModeChangedReason["ByteRTCVideoDenoiseModeChangedReasonConfigEnabled"] = 3] = "ByteRTCVideoDenoiseModeChangedReasonConfigEnabled";
    ByteRTCVideoDenoiseModeChangedReason[ByteRTCVideoDenoiseModeChangedReason["ByteRTCVideoDenoiseModeChangedReasonInternalException"] = 4] = "ByteRTCVideoDenoiseModeChangedReasonInternalException";
    ByteRTCVideoDenoiseModeChangedReason[ByteRTCVideoDenoiseModeChangedReason["ByteRTCVideoDenoiseModeChangedReasonDynamicClose"] = 5] = "ByteRTCVideoDenoiseModeChangedReasonDynamicClose";
    ByteRTCVideoDenoiseModeChangedReason[ByteRTCVideoDenoiseModeChangedReason["ByteRTCVideoDenoiseModeChangedReasonDynamicOpen"] = 6] = "ByteRTCVideoDenoiseModeChangedReasonDynamicOpen";
    ByteRTCVideoDenoiseModeChangedReason[ByteRTCVideoDenoiseModeChangedReason["ByteRTCVideoDenoiseModeChangedReasonResolution"] = 7] = "ByteRTCVideoDenoiseModeChangedReasonResolution";
})(ByteRTCVideoDenoiseModeChangedReason || (ByteRTCVideoDenoiseModeChangedReason = {}));
var ByteRTCRecordingConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCRecordingConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _dirPath_decorators;
    var _dirPath_initializers = [];
    var _dirPath_extraInitializers = [];
    var _recordingFileType_decorators;
    var _recordingFileType_initializers = [];
    var _recordingFileType_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRecordingConfig_1() {
            this.dirPath = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _dirPath_initializers, void 0));
            this.recordingFileType = (__runInitializers(this, _dirPath_extraInitializers), __runInitializers(this, _recordingFileType_initializers, void 0));
            __runInitializers(this, _recordingFileType_extraInitializers);
        }
        ByteRTCRecordingConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRecordingConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRecordingConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _dirPath_decorators = [NativeMember()];
        _recordingFileType_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _dirPath_decorators, { kind: "field", name: "dirPath", static: false, private: false, access: { has: function (obj) { return "dirPath" in obj; }, get: function (obj) { return obj.dirPath; }, set: function (obj, value) { obj.dirPath = value; } }, metadata: _metadata }, _dirPath_initializers, _dirPath_extraInitializers);
        __esDecorate(null, null, _recordingFileType_decorators, { kind: "field", name: "recordingFileType", static: false, private: false, access: { has: function (obj) { return "recordingFileType" in obj; }, get: function (obj) { return obj.recordingFileType; }, set: function (obj, value) { obj.recordingFileType = value; } }, metadata: _metadata }, _recordingFileType_initializers, _recordingFileType_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRemoteVideoSinkConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCRemoteVideoSinkConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _position_decorators;
    var _position_initializers = [];
    var _position_extraInitializers = [];
    var _requiredPixelFormat_decorators;
    var _requiredPixelFormat_initializers = [];
    var _requiredPixelFormat_extraInitializers = [];
    var _applyRotation_decorators;
    var _applyRotation_initializers = [];
    var _applyRotation_extraInitializers = [];
    var _mirrorType_decorators;
    var _mirrorType_initializers = [];
    var _mirrorType_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRemoteVideoSinkConfig_1() {
            this.position = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _position_initializers, void 0));
            this.requiredPixelFormat = (__runInitializers(this, _position_extraInitializers), __runInitializers(this, _requiredPixelFormat_initializers, void 0));
            this.applyRotation = (__runInitializers(this, _requiredPixelFormat_extraInitializers), __runInitializers(this, _applyRotation_initializers, void 0));
            this.mirrorType = (__runInitializers(this, _applyRotation_extraInitializers), __runInitializers(this, _mirrorType_initializers, void 0));
            __runInitializers(this, _mirrorType_extraInitializers);
        }
        ByteRTCRemoteVideoSinkConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRemoteVideoSinkConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRemoteVideoSinkConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _position_decorators = [NativeMember()];
        _requiredPixelFormat_decorators = [NativeMember()];
        _applyRotation_decorators = [NativeMember()];
        _mirrorType_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _position_decorators, { kind: "field", name: "position", static: false, private: false, access: { has: function (obj) { return "position" in obj; }, get: function (obj) { return obj.position; }, set: function (obj, value) { obj.position = value; } }, metadata: _metadata }, _position_initializers, _position_extraInitializers);
        __esDecorate(null, null, _requiredPixelFormat_decorators, { kind: "field", name: "requiredPixelFormat", static: false, private: false, access: { has: function (obj) { return "requiredPixelFormat" in obj; }, get: function (obj) { return obj.requiredPixelFormat; }, set: function (obj, value) { obj.requiredPixelFormat = value; } }, metadata: _metadata }, _requiredPixelFormat_initializers, _requiredPixelFormat_extraInitializers);
        __esDecorate(null, null, _applyRotation_decorators, { kind: "field", name: "applyRotation", static: false, private: false, access: { has: function (obj) { return "applyRotation" in obj; }, get: function (obj) { return obj.applyRotation; }, set: function (obj, value) { obj.applyRotation = value; } }, metadata: _metadata }, _applyRotation_initializers, _applyRotation_extraInitializers);
        __esDecorate(null, null, _mirrorType_decorators, { kind: "field", name: "mirrorType", static: false, private: false, access: { has: function (obj) { return "mirrorType" in obj; }, get: function (obj) { return obj.mirrorType; }, set: function (obj, value) { obj.mirrorType = value; } }, metadata: _metadata }, _mirrorType_initializers, _mirrorType_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCVideoOutputOrientationMode;
(function (ByteRTCVideoOutputOrientationMode) {
    ByteRTCVideoOutputOrientationMode[ByteRTCVideoOutputOrientationMode["ByteRTCVideoOutputOrientationModeAdaptative"] = 0] = "ByteRTCVideoOutputOrientationModeAdaptative";
    ByteRTCVideoOutputOrientationMode[ByteRTCVideoOutputOrientationMode["ByteRTCVideoOutputOrientationModeFixedLandscape"] = 1] = "ByteRTCVideoOutputOrientationModeFixedLandscape";
    ByteRTCVideoOutputOrientationMode[ByteRTCVideoOutputOrientationMode["ByteRTCVideoOutputOrientationModeFixedPortrait"] = 2] = "ByteRTCVideoOutputOrientationModeFixedPortrait";
})(ByteRTCVideoOutputOrientationMode || (ByteRTCVideoOutputOrientationMode = {}));
var ByteRTCVideoSuperResolutionMode;
(function (ByteRTCVideoSuperResolutionMode) {
    ByteRTCVideoSuperResolutionMode[ByteRTCVideoSuperResolutionMode["ByteRTCVideoSuperResolutionModeOff"] = 0] = "ByteRTCVideoSuperResolutionModeOff";
    ByteRTCVideoSuperResolutionMode[ByteRTCVideoSuperResolutionMode["ByteRTCVideoSuperResolutionModeOn"] = 1] = "ByteRTCVideoSuperResolutionModeOn";
})(ByteRTCVideoSuperResolutionMode || (ByteRTCVideoSuperResolutionMode = {}));
var ByteRTCLocalVideoRenderPosition;
(function (ByteRTCLocalVideoRenderPosition) {
    ByteRTCLocalVideoRenderPosition[ByteRTCLocalVideoRenderPosition["ByteRTCLocalVideoRenderPositionAfterCapture"] = 0] = "ByteRTCLocalVideoRenderPositionAfterCapture";
    ByteRTCLocalVideoRenderPosition[ByteRTCLocalVideoRenderPosition["ByteRTCLocalVideoRenderPositionAfterPreprocess"] = 1] = "ByteRTCLocalVideoRenderPositionAfterPreprocess";
})(ByteRTCLocalVideoRenderPosition || (ByteRTCLocalVideoRenderPosition = {}));
var ByteRTCRemoteVideoStateChangeReason;
(function (ByteRTCRemoteVideoStateChangeReason) {
    ByteRTCRemoteVideoStateChangeReason[ByteRTCRemoteVideoStateChangeReason["ByteRTCRemoteVideoStateChangeReasonInternal"] = 0] = "ByteRTCRemoteVideoStateChangeReasonInternal";
    ByteRTCRemoteVideoStateChangeReason[ByteRTCRemoteVideoStateChangeReason["ByteRTCRemoteVideoStateChangeReasonNetworkCongestion"] = 1] = "ByteRTCRemoteVideoStateChangeReasonNetworkCongestion";
    ByteRTCRemoteVideoStateChangeReason[ByteRTCRemoteVideoStateChangeReason["ByteRTCRemoteVideoStateChangeReasonNetworkRecovery"] = 2] = "ByteRTCRemoteVideoStateChangeReasonNetworkRecovery";
    ByteRTCRemoteVideoStateChangeReason[ByteRTCRemoteVideoStateChangeReason["ByteRTCRemoteVideoStateChangeReasonLocalMuted"] = 3] = "ByteRTCRemoteVideoStateChangeReasonLocalMuted";
    ByteRTCRemoteVideoStateChangeReason[ByteRTCRemoteVideoStateChangeReason["ByteRTCRemoteVideoStateChangeReasonLocalUnmuted"] = 4] = "ByteRTCRemoteVideoStateChangeReasonLocalUnmuted";
    ByteRTCRemoteVideoStateChangeReason[ByteRTCRemoteVideoStateChangeReason["ByteRTCRemoteVideoStateChangeReasonRemoteMuted"] = 5] = "ByteRTCRemoteVideoStateChangeReasonRemoteMuted";
    ByteRTCRemoteVideoStateChangeReason[ByteRTCRemoteVideoStateChangeReason["ByteRTCRemoteVideoStateChangeReasonRemoteUnmuted"] = 6] = "ByteRTCRemoteVideoStateChangeReasonRemoteUnmuted";
    ByteRTCRemoteVideoStateChangeReason[ByteRTCRemoteVideoStateChangeReason["ByteRTCRemoteVideoStateChangeReasonRemoteOffline"] = 7] = "ByteRTCRemoteVideoStateChangeReasonRemoteOffline";
})(ByteRTCRemoteVideoStateChangeReason || (ByteRTCRemoteVideoStateChangeReason = {}));
var ByteRTCVideoStreamType;
(function (ByteRTCVideoStreamType) {
    ByteRTCVideoStreamType[ByteRTCVideoStreamType["ByteRTCVideoStreamTypeHigh"] = 0] = "ByteRTCVideoStreamTypeHigh";
    ByteRTCVideoStreamType[ByteRTCVideoStreamType["ByteRTCVideoStreamTypeLow"] = 1] = "ByteRTCVideoStreamTypeLow";
})(ByteRTCVideoStreamType || (ByteRTCVideoStreamType = {}));
var ByteRTCMixedStreamVideoCodecType;
(function (ByteRTCMixedStreamVideoCodecType) {
    ByteRTCMixedStreamVideoCodecType[ByteRTCMixedStreamVideoCodecType["ByteRTCMixedStreamVideoCodecTypeH264"] = 0] = "ByteRTCMixedStreamVideoCodecTypeH264";
    ByteRTCMixedStreamVideoCodecType[ByteRTCMixedStreamVideoCodecType["ByteRTCMixedStreamVideoCodecTypeByteVC1"] = 1] = "ByteRTCMixedStreamVideoCodecTypeByteVC1";
})(ByteRTCMixedStreamVideoCodecType || (ByteRTCMixedStreamVideoCodecType = {}));
var ByteRTCFirstFramePlayState;
(function (ByteRTCFirstFramePlayState) {
    ByteRTCFirstFramePlayState[ByteRTCFirstFramePlayState["ByteRTCFirstFramePlayStatePlaying"] = 0] = "ByteRTCFirstFramePlayStatePlaying";
    ByteRTCFirstFramePlayState[ByteRTCFirstFramePlayState["ByteRTCFirstFramePlayStatePlay"] = 1] = "ByteRTCFirstFramePlayStatePlay";
    ByteRTCFirstFramePlayState[ByteRTCFirstFramePlayState["ByteRTCFirstFramePlayStateEnd"] = 2] = "ByteRTCFirstFramePlayStateEnd";
})(ByteRTCFirstFramePlayState || (ByteRTCFirstFramePlayState = {}));
var ByteRTCAVSyncState;
(function (ByteRTCAVSyncState) {
    ByteRTCAVSyncState[ByteRTCAVSyncState["ByteRTCAVSyncStateAVStreamSyncBegin"] = 0] = "ByteRTCAVSyncStateAVStreamSyncBegin";
    ByteRTCAVSyncState[ByteRTCAVSyncState["ByteRTCAVSyncStateAudioStreamRemove"] = 1] = "ByteRTCAVSyncStateAudioStreamRemove";
    ByteRTCAVSyncState[ByteRTCAVSyncState["ByteRTCAVSyncStateVideoStreamRemove"] = 2] = "ByteRTCAVSyncStateVideoStreamRemove";
    ByteRTCAVSyncState[ByteRTCAVSyncState["ByteRTCAVSyncStateSetAVSyncStreamId"] = 3] = "ByteRTCAVSyncStateSetAVSyncStreamId";
})(ByteRTCAVSyncState || (ByteRTCAVSyncState = {}));
var ByteRTCPauseResumControlMediaType;
(function (ByteRTCPauseResumControlMediaType) {
    ByteRTCPauseResumControlMediaType[ByteRTCPauseResumControlMediaType["ByteRTCControlMediaTypeAudio"] = 0] = "ByteRTCControlMediaTypeAudio";
    ByteRTCPauseResumControlMediaType[ByteRTCPauseResumControlMediaType["ByteRtcControlMediaTypeVideo"] = 1] = "ByteRtcControlMediaTypeVideo";
    ByteRTCPauseResumControlMediaType[ByteRTCPauseResumControlMediaType["ByteRtcControlMediaTypeAudioAndVideo"] = 2] = "ByteRtcControlMediaTypeAudioAndVideo";
})(ByteRTCPauseResumControlMediaType || (ByteRTCPauseResumControlMediaType = {}));
var ByteRTCVideoCaptureConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCVideoCaptureConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _preference_decorators;
    var _preference_initializers = [];
    var _preference_extraInitializers = [];
    var _videoSize_decorators;
    var _videoSize_initializers = [];
    var _videoSize_extraInitializers = [];
    var _frameRate_decorators;
    var _frameRate_initializers = [];
    var _frameRate_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoCaptureConfig_1() {
            this.preference = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _preference_initializers, void 0));
            this.videoSize = (__runInitializers(this, _preference_extraInitializers), __runInitializers(this, _videoSize_initializers, void 0));
            this.frameRate = (__runInitializers(this, _videoSize_extraInitializers), __runInitializers(this, _frameRate_initializers, void 0));
            __runInitializers(this, _frameRate_extraInitializers);
        }
        ByteRTCVideoCaptureConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVideoCaptureConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoCaptureConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _preference_decorators = [NativeMember()];
        _videoSize_decorators = [NativeMember()];
        _frameRate_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _preference_decorators, { kind: "field", name: "preference", static: false, private: false, access: { has: function (obj) { return "preference" in obj; }, get: function (obj) { return obj.preference; }, set: function (obj, value) { obj.preference = value; } }, metadata: _metadata }, _preference_initializers, _preference_extraInitializers);
        __esDecorate(null, null, _videoSize_decorators, { kind: "field", name: "videoSize", static: false, private: false, access: { has: function (obj) { return "videoSize" in obj; }, get: function (obj) { return obj.videoSize; }, set: function (obj, value) { obj.videoSize = value; } }, metadata: _metadata }, _videoSize_initializers, _videoSize_extraInitializers);
        __esDecorate(null, null, _frameRate_decorators, { kind: "field", name: "frameRate", static: false, private: false, access: { has: function (obj) { return "frameRate" in obj; }, get: function (obj) { return obj.frameRate; }, set: function (obj, value) { obj.frameRate = value; } }, metadata: _metadata }, _frameRate_initializers, _frameRate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCVideoSuperResolutionModeChangedReason;
(function (ByteRTCVideoSuperResolutionModeChangedReason) {
    ByteRTCVideoSuperResolutionModeChangedReason[ByteRTCVideoSuperResolutionModeChangedReason["ByteRTCVideoSuperResolutionModeChangedReasonAPIOff"] = 0] = "ByteRTCVideoSuperResolutionModeChangedReasonAPIOff";
    ByteRTCVideoSuperResolutionModeChangedReason[ByteRTCVideoSuperResolutionModeChangedReason["ByteRTCVideoSuperResolutionModeChangedReasonAPIOn"] = 1] = "ByteRTCVideoSuperResolutionModeChangedReasonAPIOn";
    ByteRTCVideoSuperResolutionModeChangedReason[ByteRTCVideoSuperResolutionModeChangedReason["ByteRTCVideoSuperResolutionModeChangedReasonResolutionExceed"] = 2] = "ByteRTCVideoSuperResolutionModeChangedReasonResolutionExceed";
    ByteRTCVideoSuperResolutionModeChangedReason[ByteRTCVideoSuperResolutionModeChangedReason["ByteRTCVideoSuperResolutionModeChangedReasonOverUse"] = 3] = "ByteRTCVideoSuperResolutionModeChangedReasonOverUse";
    ByteRTCVideoSuperResolutionModeChangedReason[ByteRTCVideoSuperResolutionModeChangedReason["ByteRTCVideoSuperResolutionModeChangedReasonDeviceNotSupport"] = 4] = "ByteRTCVideoSuperResolutionModeChangedReasonDeviceNotSupport";
    ByteRTCVideoSuperResolutionModeChangedReason[ByteRTCVideoSuperResolutionModeChangedReason["ByteRTCVideoSuperResolutionModeChangedReasonDynamicClose"] = 5] = "ByteRTCVideoSuperResolutionModeChangedReasonDynamicClose";
    ByteRTCVideoSuperResolutionModeChangedReason[ByteRTCVideoSuperResolutionModeChangedReason["ByteRTCVideoSuperResolutionModeChangedReasonOtherSettingDisabled"] = 6] = "ByteRTCVideoSuperResolutionModeChangedReasonOtherSettingDisabled";
    ByteRTCVideoSuperResolutionModeChangedReason[ByteRTCVideoSuperResolutionModeChangedReason["ByteRTCVideoSuperResolutionModeChangedReasonOtherSettingEnabled"] = 7] = "ByteRTCVideoSuperResolutionModeChangedReasonOtherSettingEnabled";
    ByteRTCVideoSuperResolutionModeChangedReason[ByteRTCVideoSuperResolutionModeChangedReason["ByteRTCVideoSuperResolutionModeChangedReasonNoComponent"] = 8] = "ByteRTCVideoSuperResolutionModeChangedReasonNoComponent";
    ByteRTCVideoSuperResolutionModeChangedReason[ByteRTCVideoSuperResolutionModeChangedReason["ByteRTCVideoSuperResolutionModeChangedReasonStreamNotExist"] = 9] = "ByteRTCVideoSuperResolutionModeChangedReasonStreamNotExist";
})(ByteRTCVideoSuperResolutionModeChangedReason || (ByteRTCVideoSuperResolutionModeChangedReason = {}));
var ByteRTCUser = function () {
    var _classDecorators = [NativeClass('ByteRTCUser')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _metaData_decorators;
    var _metaData_initializers = [];
    var _metaData_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCUser_1() {
            this.userId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _userId_initializers, void 0));
            this.metaData = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _metaData_initializers, void 0));
            __runInitializers(this, _metaData_extraInitializers);
        }
        ByteRTCUser_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCUser_1;
    }());
    __setFunctionName(_classThis, "ByteRTCUser");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _userId_decorators = [NativeMember()];
        _metaData_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _metaData_decorators, { kind: "field", name: "metaData", static: false, private: false, access: { has: function (obj) { return "metaData" in obj; }, get: function (obj) { return obj.metaData; }, set: function (obj, value) { obj.metaData = value; } }, metadata: _metadata }, _metaData_initializers, _metaData_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCPerformanceAlarmMode;
(function (ByteRTCPerformanceAlarmMode) {
    ByteRTCPerformanceAlarmMode[ByteRTCPerformanceAlarmMode["ByteRTCPerformanceAlarmModeNormal"] = 0] = "ByteRTCPerformanceAlarmModeNormal";
    ByteRTCPerformanceAlarmMode[ByteRTCPerformanceAlarmMode["ByteRTCPerformanceAlarmModeSimulcast"] = 1] = "ByteRTCPerformanceAlarmModeSimulcast";
})(ByteRTCPerformanceAlarmMode || (ByteRTCPerformanceAlarmMode = {}));
var ByteRTCRemoteStreamSwitchEvent = function () {
    var _classDecorators = [NativeClass('ByteRTCRemoteStreamSwitchEvent')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _uid_decorators;
    var _uid_initializers = [];
    var _uid_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _beforeVideoIndex_decorators;
    var _beforeVideoIndex_initializers = [];
    var _beforeVideoIndex_extraInitializers = [];
    var _afterVideoIndex_decorators;
    var _afterVideoIndex_initializers = [];
    var _afterVideoIndex_extraInitializers = [];
    var _beforeVideoEnabled_decorators;
    var _beforeVideoEnabled_initializers = [];
    var _beforeVideoEnabled_extraInitializers = [];
    var _afterVideoEnabled_decorators;
    var _afterVideoEnabled_initializers = [];
    var _afterVideoEnabled_extraInitializers = [];
    var _reason_decorators;
    var _reason_initializers = [];
    var _reason_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRemoteStreamSwitchEvent_1() {
            this.uid = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _uid_initializers, void 0));
            this.isScreen = (__runInitializers(this, _uid_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.beforeVideoIndex = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _beforeVideoIndex_initializers, void 0));
            this.afterVideoIndex = (__runInitializers(this, _beforeVideoIndex_extraInitializers), __runInitializers(this, _afterVideoIndex_initializers, void 0));
            this.beforeVideoEnabled = (__runInitializers(this, _afterVideoIndex_extraInitializers), __runInitializers(this, _beforeVideoEnabled_initializers, void 0));
            this.afterVideoEnabled = (__runInitializers(this, _beforeVideoEnabled_extraInitializers), __runInitializers(this, _afterVideoEnabled_initializers, void 0));
            this.reason = (__runInitializers(this, _afterVideoEnabled_extraInitializers), __runInitializers(this, _reason_initializers, void 0));
            __runInitializers(this, _reason_extraInitializers);
        }
        ByteRTCRemoteStreamSwitchEvent_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRemoteStreamSwitchEvent_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRemoteStreamSwitchEvent");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _uid_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _beforeVideoIndex_decorators = [NativeMember()];
        _afterVideoIndex_decorators = [NativeMember()];
        _beforeVideoEnabled_decorators = [NativeMember()];
        _afterVideoEnabled_decorators = [NativeMember()];
        _reason_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _uid_decorators, { kind: "field", name: "uid", static: false, private: false, access: { has: function (obj) { return "uid" in obj; }, get: function (obj) { return obj.uid; }, set: function (obj, value) { obj.uid = value; } }, metadata: _metadata }, _uid_initializers, _uid_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _beforeVideoIndex_decorators, { kind: "field", name: "beforeVideoIndex", static: false, private: false, access: { has: function (obj) { return "beforeVideoIndex" in obj; }, get: function (obj) { return obj.beforeVideoIndex; }, set: function (obj, value) { obj.beforeVideoIndex = value; } }, metadata: _metadata }, _beforeVideoIndex_initializers, _beforeVideoIndex_extraInitializers);
        __esDecorate(null, null, _afterVideoIndex_decorators, { kind: "field", name: "afterVideoIndex", static: false, private: false, access: { has: function (obj) { return "afterVideoIndex" in obj; }, get: function (obj) { return obj.afterVideoIndex; }, set: function (obj, value) { obj.afterVideoIndex = value; } }, metadata: _metadata }, _afterVideoIndex_initializers, _afterVideoIndex_extraInitializers);
        __esDecorate(null, null, _beforeVideoEnabled_decorators, { kind: "field", name: "beforeVideoEnabled", static: false, private: false, access: { has: function (obj) { return "beforeVideoEnabled" in obj; }, get: function (obj) { return obj.beforeVideoEnabled; }, set: function (obj, value) { obj.beforeVideoEnabled = value; } }, metadata: _metadata }, _beforeVideoEnabled_initializers, _beforeVideoEnabled_extraInitializers);
        __esDecorate(null, null, _afterVideoEnabled_decorators, { kind: "field", name: "afterVideoEnabled", static: false, private: false, access: { has: function (obj) { return "afterVideoEnabled" in obj; }, get: function (obj) { return obj.afterVideoEnabled; }, set: function (obj, value) { obj.afterVideoEnabled = value; } }, metadata: _metadata }, _afterVideoEnabled_initializers, _afterVideoEnabled_extraInitializers);
        __esDecorate(null, null, _reason_decorators, { kind: "field", name: "reason", static: false, private: false, access: { has: function (obj) { return "reason" in obj; }, get: function (obj) { return obj.reason; }, set: function (obj, value) { obj.reason = value; } }, metadata: _metadata }, _reason_initializers, _reason_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCLocalAudioStats = function () {
    var _classDecorators = [NativeClass('ByteRTCLocalAudioStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _audioLossRate_decorators;
    var _audioLossRate_initializers = [];
    var _audioLossRate_extraInitializers = [];
    var _sentKBitrate_decorators;
    var _sentKBitrate_initializers = [];
    var _sentKBitrate_extraInitializers = [];
    var _recordSampleRate_decorators;
    var _recordSampleRate_initializers = [];
    var _recordSampleRate_extraInitializers = [];
    var _statsInterval_decorators;
    var _statsInterval_initializers = [];
    var _statsInterval_extraInitializers = [];
    var _rtt_decorators;
    var _rtt_initializers = [];
    var _rtt_extraInitializers = [];
    var _numChannels_decorators;
    var _numChannels_initializers = [];
    var _numChannels_extraInitializers = [];
    var _sentSampleRate_decorators;
    var _sentSampleRate_initializers = [];
    var _sentSampleRate_extraInitializers = [];
    var _jitter_decorators;
    var _jitter_initializers = [];
    var _jitter_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCLocalAudioStats_1() {
            this.audioLossRate = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _audioLossRate_initializers, void 0));
            this.sentKBitrate = (__runInitializers(this, _audioLossRate_extraInitializers), __runInitializers(this, _sentKBitrate_initializers, void 0));
            this.recordSampleRate = (__runInitializers(this, _sentKBitrate_extraInitializers), __runInitializers(this, _recordSampleRate_initializers, void 0));
            this.statsInterval = (__runInitializers(this, _recordSampleRate_extraInitializers), __runInitializers(this, _statsInterval_initializers, void 0));
            this.rtt = (__runInitializers(this, _statsInterval_extraInitializers), __runInitializers(this, _rtt_initializers, void 0));
            this.numChannels = (__runInitializers(this, _rtt_extraInitializers), __runInitializers(this, _numChannels_initializers, void 0));
            this.sentSampleRate = (__runInitializers(this, _numChannels_extraInitializers), __runInitializers(this, _sentSampleRate_initializers, void 0));
            this.jitter = (__runInitializers(this, _sentSampleRate_extraInitializers), __runInitializers(this, _jitter_initializers, void 0));
            __runInitializers(this, _jitter_extraInitializers);
        }
        ByteRTCLocalAudioStats_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCLocalAudioStats_1;
    }());
    __setFunctionName(_classThis, "ByteRTCLocalAudioStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _audioLossRate_decorators = [NativeMember()];
        _sentKBitrate_decorators = [NativeMember()];
        _recordSampleRate_decorators = [NativeMember()];
        _statsInterval_decorators = [NativeMember()];
        _rtt_decorators = [NativeMember()];
        _numChannels_decorators = [NativeMember()];
        _sentSampleRate_decorators = [NativeMember()];
        _jitter_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _audioLossRate_decorators, { kind: "field", name: "audioLossRate", static: false, private: false, access: { has: function (obj) { return "audioLossRate" in obj; }, get: function (obj) { return obj.audioLossRate; }, set: function (obj, value) { obj.audioLossRate = value; } }, metadata: _metadata }, _audioLossRate_initializers, _audioLossRate_extraInitializers);
        __esDecorate(null, null, _sentKBitrate_decorators, { kind: "field", name: "sentKBitrate", static: false, private: false, access: { has: function (obj) { return "sentKBitrate" in obj; }, get: function (obj) { return obj.sentKBitrate; }, set: function (obj, value) { obj.sentKBitrate = value; } }, metadata: _metadata }, _sentKBitrate_initializers, _sentKBitrate_extraInitializers);
        __esDecorate(null, null, _recordSampleRate_decorators, { kind: "field", name: "recordSampleRate", static: false, private: false, access: { has: function (obj) { return "recordSampleRate" in obj; }, get: function (obj) { return obj.recordSampleRate; }, set: function (obj, value) { obj.recordSampleRate = value; } }, metadata: _metadata }, _recordSampleRate_initializers, _recordSampleRate_extraInitializers);
        __esDecorate(null, null, _statsInterval_decorators, { kind: "field", name: "statsInterval", static: false, private: false, access: { has: function (obj) { return "statsInterval" in obj; }, get: function (obj) { return obj.statsInterval; }, set: function (obj, value) { obj.statsInterval = value; } }, metadata: _metadata }, _statsInterval_initializers, _statsInterval_extraInitializers);
        __esDecorate(null, null, _rtt_decorators, { kind: "field", name: "rtt", static: false, private: false, access: { has: function (obj) { return "rtt" in obj; }, get: function (obj) { return obj.rtt; }, set: function (obj, value) { obj.rtt = value; } }, metadata: _metadata }, _rtt_initializers, _rtt_extraInitializers);
        __esDecorate(null, null, _numChannels_decorators, { kind: "field", name: "numChannels", static: false, private: false, access: { has: function (obj) { return "numChannels" in obj; }, get: function (obj) { return obj.numChannels; }, set: function (obj, value) { obj.numChannels = value; } }, metadata: _metadata }, _numChannels_initializers, _numChannels_extraInitializers);
        __esDecorate(null, null, _sentSampleRate_decorators, { kind: "field", name: "sentSampleRate", static: false, private: false, access: { has: function (obj) { return "sentSampleRate" in obj; }, get: function (obj) { return obj.sentSampleRate; }, set: function (obj, value) { obj.sentSampleRate = value; } }, metadata: _metadata }, _sentSampleRate_initializers, _sentSampleRate_extraInitializers);
        __esDecorate(null, null, _jitter_decorators, { kind: "field", name: "jitter", static: false, private: false, access: { has: function (obj) { return "jitter" in obj; }, get: function (obj) { return obj.jitter; }, set: function (obj, value) { obj.jitter = value; } }, metadata: _metadata }, _jitter_initializers, _jitter_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioAlignmentMode;
(function (ByteRTCAudioAlignmentMode) {
    ByteRTCAudioAlignmentMode[ByteRTCAudioAlignmentMode["ByteRTCAudioAlignmentModeOff"] = 0] = "ByteRTCAudioAlignmentModeOff";
    ByteRTCAudioAlignmentMode[ByteRTCAudioAlignmentMode["ByteRTCAudioAlignmentModeAudioMixing"] = 1] = "ByteRTCAudioAlignmentModeAudioMixing";
})(ByteRTCAudioAlignmentMode || (ByteRTCAudioAlignmentMode = {}));
var ByteRTCReceiveRange = function () {
    var _classDecorators = [NativeClass('ByteRTCReceiveRange')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _min_decorators;
    var _min_initializers = [];
    var _min_extraInitializers = [];
    var _max_decorators;
    var _max_initializers = [];
    var _max_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCReceiveRange_1() {
            this.min = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _min_initializers, void 0));
            this.max = (__runInitializers(this, _min_extraInitializers), __runInitializers(this, _max_initializers, void 0));
            __runInitializers(this, _max_extraInitializers);
        }
        ByteRTCReceiveRange_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCReceiveRange_1;
    }());
    __setFunctionName(_classThis, "ByteRTCReceiveRange");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _min_decorators = [NativeMember()];
        _max_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _min_decorators, { kind: "field", name: "min", static: false, private: false, access: { has: function (obj) { return "min" in obj; }, get: function (obj) { return obj.min; }, set: function (obj, value) { obj.min = value; } }, metadata: _metadata }, _min_initializers, _min_extraInitializers);
        __esDecorate(null, null, _max_decorators, { kind: "field", name: "max", static: false, private: false, access: { has: function (obj) { return "max" in obj; }, get: function (obj) { return obj.max; }, set: function (obj, value) { obj.max = value; } }, metadata: _metadata }, _max_initializers, _max_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRecordingState;
(function (ByteRTCRecordingState) {
    ByteRTCRecordingState[ByteRTCRecordingState["ByteRTCRecordingStateError"] = 0] = "ByteRTCRecordingStateError";
    ByteRTCRecordingState[ByteRTCRecordingState["ByteRTCRecordingStateProcessing"] = 1] = "ByteRTCRecordingStateProcessing";
    ByteRTCRecordingState[ByteRTCRecordingState["ByteRTCRecordingStateSuccess"] = 2] = "ByteRTCRecordingStateSuccess";
})(ByteRTCRecordingState || (ByteRTCRecordingState = {}));
var ByteRTCFaceDetectionResult = function () {
    var _classDecorators = [NativeClass('ByteRTCFaceDetectionResult')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _detectResult_decorators;
    var _detectResult_initializers = [];
    var _detectResult_extraInitializers = [];
    var _imageWidth_decorators;
    var _imageWidth_initializers = [];
    var _imageWidth_extraInitializers = [];
    var _imageHeight_decorators;
    var _imageHeight_initializers = [];
    var _imageHeight_extraInitializers = [];
    var _faces_decorators;
    var _faces_initializers = [];
    var _faces_extraInitializers = [];
    var _frameTimestamp_decorators;
    var _frameTimestamp_initializers = [];
    var _frameTimestamp_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCFaceDetectionResult_1() {
            this.detectResult = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _detectResult_initializers, void 0));
            this.imageWidth = (__runInitializers(this, _detectResult_extraInitializers), __runInitializers(this, _imageWidth_initializers, void 0));
            this.imageHeight = (__runInitializers(this, _imageWidth_extraInitializers), __runInitializers(this, _imageHeight_initializers, void 0));
            this.faces = (__runInitializers(this, _imageHeight_extraInitializers), __runInitializers(this, _faces_initializers, void 0));
            this.frameTimestamp = (__runInitializers(this, _faces_extraInitializers), __runInitializers(this, _frameTimestamp_initializers, void 0));
            __runInitializers(this, _frameTimestamp_extraInitializers);
        }
        ByteRTCFaceDetectionResult_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCFaceDetectionResult_1;
    }());
    __setFunctionName(_classThis, "ByteRTCFaceDetectionResult");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _detectResult_decorators = [NativeMember()];
        _imageWidth_decorators = [NativeMember()];
        _imageHeight_decorators = [NativeMember()];
        _faces_decorators = [NativeMember()];
        _frameTimestamp_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _detectResult_decorators, { kind: "field", name: "detectResult", static: false, private: false, access: { has: function (obj) { return "detectResult" in obj; }, get: function (obj) { return obj.detectResult; }, set: function (obj, value) { obj.detectResult = value; } }, metadata: _metadata }, _detectResult_initializers, _detectResult_extraInitializers);
        __esDecorate(null, null, _imageWidth_decorators, { kind: "field", name: "imageWidth", static: false, private: false, access: { has: function (obj) { return "imageWidth" in obj; }, get: function (obj) { return obj.imageWidth; }, set: function (obj, value) { obj.imageWidth = value; } }, metadata: _metadata }, _imageWidth_initializers, _imageWidth_extraInitializers);
        __esDecorate(null, null, _imageHeight_decorators, { kind: "field", name: "imageHeight", static: false, private: false, access: { has: function (obj) { return "imageHeight" in obj; }, get: function (obj) { return obj.imageHeight; }, set: function (obj, value) { obj.imageHeight = value; } }, metadata: _metadata }, _imageHeight_initializers, _imageHeight_extraInitializers);
        __esDecorate(null, null, _faces_decorators, { kind: "field", name: "faces", static: false, private: false, access: { has: function (obj) { return "faces" in obj; }, get: function (obj) { return obj.faces; }, set: function (obj, value) { obj.faces = value; } }, metadata: _metadata }, _faces_initializers, _faces_extraInitializers);
        __esDecorate(null, null, _frameTimestamp_decorators, { kind: "field", name: "frameTimestamp", static: false, private: false, access: { has: function (obj) { return "frameTimestamp" in obj; }, get: function (obj) { return obj.frameTimestamp; }, set: function (obj, value) { obj.frameTimestamp = value; } }, metadata: _metadata }, _frameTimestamp_initializers, _frameTimestamp_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('ByteRTCVideoByteWatermark')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _x_decorators;
    var _x_initializers = [];
    var _x_extraInitializers = [];
    var _y_decorators;
    var _y_initializers = [];
    var _y_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoByteWatermark_1() {
            this.x = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _x_initializers, void 0));
            this.y = (__runInitializers(this, _x_extraInitializers), __runInitializers(this, _y_initializers, void 0));
            this.width = (__runInitializers(this, _y_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            __runInitializers(this, _height_extraInitializers);
        }
        ByteRTCVideoByteWatermark_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVideoByteWatermark_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoByteWatermark");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _x_decorators = [NativeMember()];
        _y_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _x_decorators, { kind: "field", name: "x", static: false, private: false, access: { has: function (obj) { return "x" in obj; }, get: function (obj) { return obj.x; }, set: function (obj, value) { obj.x = value; } }, metadata: _metadata }, _x_initializers, _x_extraInitializers);
        __esDecorate(null, null, _y_decorators, { kind: "field", name: "y", static: false, private: false, access: { has: function (obj) { return "y" in obj; }, get: function (obj) { return obj.y; }, set: function (obj, value) { obj.y = value; } }, metadata: _metadata }, _y_initializers, _y_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCStreamSycnInfoConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCStreamSycnInfoConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _streamIndex_decorators;
    var _streamIndex_initializers = [];
    var _streamIndex_extraInitializers = [];
    var _repeatCount_decorators;
    var _repeatCount_initializers = [];
    var _repeatCount_extraInitializers = [];
    var _streamType_decorators;
    var _streamType_initializers = [];
    var _streamType_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCStreamSycnInfoConfig_1() {
            this.streamIndex = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _streamIndex_initializers, void 0));
            this.repeatCount = (__runInitializers(this, _streamIndex_extraInitializers), __runInitializers(this, _repeatCount_initializers, void 0));
            this.streamType = (__runInitializers(this, _repeatCount_extraInitializers), __runInitializers(this, _streamType_initializers, void 0));
            __runInitializers(this, _streamType_extraInitializers);
        }
        ByteRTCStreamSycnInfoConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCStreamSycnInfoConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCStreamSycnInfoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _streamIndex_decorators = [NativeMember()];
        _repeatCount_decorators = [NativeMember()];
        _streamType_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _streamIndex_decorators, { kind: "field", name: "streamIndex", static: false, private: false, access: { has: function (obj) { return "streamIndex" in obj; }, get: function (obj) { return obj.streamIndex; }, set: function (obj, value) { obj.streamIndex = value; } }, metadata: _metadata }, _streamIndex_initializers, _streamIndex_extraInitializers);
        __esDecorate(null, null, _repeatCount_decorators, { kind: "field", name: "repeatCount", static: false, private: false, access: { has: function (obj) { return "repeatCount" in obj; }, get: function (obj) { return obj.repeatCount; }, set: function (obj, value) { obj.repeatCount = value; } }, metadata: _metadata }, _repeatCount_initializers, _repeatCount_extraInitializers);
        __esDecorate(null, null, _streamType_decorators, { kind: "field", name: "streamType", static: false, private: false, access: { has: function (obj) { return "streamType" in obj; }, get: function (obj) { return obj.streamType; }, set: function (obj, value) { obj.streamType = value; } }, metadata: _metadata }, _streamType_initializers, _streamType_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCEchoTestConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCEchoTestConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _view_decorators;
    var _view_initializers = [];
    var _view_extraInitializers = [];
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _token_decorators;
    var _token_initializers = [];
    var _token_extraInitializers = [];
    var _enableAudio_decorators;
    var _enableAudio_initializers = [];
    var _enableAudio_extraInitializers = [];
    var _enableVideo_decorators;
    var _enableVideo_initializers = [];
    var _enableVideo_extraInitializers = [];
    var _audioReportInterval_decorators;
    var _audioReportInterval_initializers = [];
    var _audioReportInterval_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCEchoTestConfig_1() {
            this.view = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _view_initializers, void 0));
            this.roomId = (__runInitializers(this, _view_extraInitializers), __runInitializers(this, _roomId_initializers, void 0));
            this.userId = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _userId_initializers, void 0));
            this.token = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _token_initializers, void 0));
            this.enableAudio = (__runInitializers(this, _token_extraInitializers), __runInitializers(this, _enableAudio_initializers, void 0));
            this.enableVideo = (__runInitializers(this, _enableAudio_extraInitializers), __runInitializers(this, _enableVideo_initializers, void 0));
            this.audioReportInterval = (__runInitializers(this, _enableVideo_extraInitializers), __runInitializers(this, _audioReportInterval_initializers, void 0));
            __runInitializers(this, _audioReportInterval_extraInitializers);
        }
        ByteRTCEchoTestConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCEchoTestConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCEchoTestConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _view_decorators = [NativeMember()];
        _roomId_decorators = [NativeMember()];
        _userId_decorators = [NativeMember()];
        _token_decorators = [NativeMember()];
        _enableAudio_decorators = [NativeMember()];
        _enableVideo_decorators = [NativeMember()];
        _audioReportInterval_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _view_decorators, { kind: "field", name: "view", static: false, private: false, access: { has: function (obj) { return "view" in obj; }, get: function (obj) { return obj.view; }, set: function (obj, value) { obj.view = value; } }, metadata: _metadata }, _view_initializers, _view_extraInitializers);
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _token_decorators, { kind: "field", name: "token", static: false, private: false, access: { has: function (obj) { return "token" in obj; }, get: function (obj) { return obj.token; }, set: function (obj, value) { obj.token = value; } }, metadata: _metadata }, _token_initializers, _token_extraInitializers);
        __esDecorate(null, null, _enableAudio_decorators, { kind: "field", name: "enableAudio", static: false, private: false, access: { has: function (obj) { return "enableAudio" in obj; }, get: function (obj) { return obj.enableAudio; }, set: function (obj, value) { obj.enableAudio = value; } }, metadata: _metadata }, _enableAudio_initializers, _enableAudio_extraInitializers);
        __esDecorate(null, null, _enableVideo_decorators, { kind: "field", name: "enableVideo", static: false, private: false, access: { has: function (obj) { return "enableVideo" in obj; }, get: function (obj) { return obj.enableVideo; }, set: function (obj, value) { obj.enableVideo = value; } }, metadata: _metadata }, _enableVideo_initializers, _enableVideo_extraInitializers);
        __esDecorate(null, null, _audioReportInterval_decorators, { kind: "field", name: "audioReportInterval", static: false, private: false, access: { has: function (obj) { return "audioReportInterval" in obj; }, get: function (obj) { return obj.audioReportInterval; }, set: function (obj, value) { obj.audioReportInterval = value; } }, metadata: _metadata }, _audioReportInterval_initializers, _audioReportInterval_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCFrameRateRatio;
(function (ByteRTCFrameRateRatio) {
    ByteRTCFrameRateRatio[ByteRTCFrameRateRatio["ByteRTCFrameRateRatioOrigin"] = 0] = "ByteRTCFrameRateRatioOrigin";
    ByteRTCFrameRateRatio[ByteRTCFrameRateRatio["ByteRTCFrameRateRatioHalf"] = 1] = "ByteRTCFrameRateRatioHalf";
    ByteRTCFrameRateRatio[ByteRTCFrameRateRatio["ByteRTCFrameRateRatioQuater"] = 2] = "ByteRTCFrameRateRatioQuater";
})(ByteRTCFrameRateRatio || (ByteRTCFrameRateRatio = {}));
var ByteRTCMixedStreamRenderMode;
(function (ByteRTCMixedStreamRenderMode) {
    ByteRTCMixedStreamRenderMode[ByteRTCMixedStreamRenderMode["ByteRTCMixedStreamRenderModeHidden"] = 1] = "ByteRTCMixedStreamRenderModeHidden";
    ByteRTCMixedStreamRenderMode[ByteRTCMixedStreamRenderMode["ByteRTCMixedStreamRenderModeFit"] = 2] = "ByteRTCMixedStreamRenderModeFit";
    ByteRTCMixedStreamRenderMode[ByteRTCMixedStreamRenderMode["ByteRTCMixedStreamRenderModeAdaptive"] = 3] = "ByteRTCMixedStreamRenderModeAdaptive";
})(ByteRTCMixedStreamRenderMode || (ByteRTCMixedStreamRenderMode = {}));
var ByteRTCMirrorType;
(function (ByteRTCMirrorType) {
    ByteRTCMirrorType[ByteRTCMirrorType["ByteRTCMirrorTypeNone"] = 0] = "ByteRTCMirrorTypeNone";
    ByteRTCMirrorType[ByteRTCMirrorType["ByteRTCMirrorTypeRender"] = 1] = "ByteRTCMirrorTypeRender";
    ByteRTCMirrorType[ByteRTCMirrorType["ByteRTCMirrorTypeRenderAndEncoder"] = 3] = "ByteRTCMirrorTypeRenderAndEncoder";
})(ByteRTCMirrorType || (ByteRTCMirrorType = {}));
var ByteRTCForwardStreamError;
(function (ByteRTCForwardStreamError) {
    ByteRTCForwardStreamError[ByteRTCForwardStreamError["ByteRTCForwardStreamErrorOK"] = 0] = "ByteRTCForwardStreamErrorOK";
    ByteRTCForwardStreamError[ByteRTCForwardStreamError["ByteRTCForwardStreamErrorInvalidArgument"] = 1201] = "ByteRTCForwardStreamErrorInvalidArgument";
    ByteRTCForwardStreamError[ByteRTCForwardStreamError["ByteRTCForwardStreamErrorInvalidToken"] = 1202] = "ByteRTCForwardStreamErrorInvalidToken";
    ByteRTCForwardStreamError[ByteRTCForwardStreamError["ByteRTCForwardStreamErrorResponse"] = 1203] = "ByteRTCForwardStreamErrorResponse";
    ByteRTCForwardStreamError[ByteRTCForwardStreamError["ByteRTCForwardStreamErrorRemoteKicked"] = 1204] = "ByteRTCForwardStreamErrorRemoteKicked";
    ByteRTCForwardStreamError[ByteRTCForwardStreamError["ByteRTCForwardStreamErrorNotSupport"] = 1205] = "ByteRTCForwardStreamErrorNotSupport";
})(ByteRTCForwardStreamError || (ByteRTCForwardStreamError = {}));
var ByteRTCReturnStatus;
(function (ByteRTCReturnStatus) {
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusSuccess"] = 0] = "ByteRTCReturnStatusSuccess";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusFailure"] = -1] = "ByteRTCReturnStatusFailure";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusParameterErr"] = -2] = "ByteRTCReturnStatusParameterErr";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusWrongState"] = -3] = "ByteRTCReturnStatusWrongState";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusHasInRoom"] = -4] = "ByteRTCReturnStatusHasInRoom";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusHasInLogin"] = -5] = "ByteRTCReturnStatusHasInLogin";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusHasInEchoTest"] = -6] = "ByteRTCReturnStatusHasInEchoTest";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusNeitherVideoNorAudio"] = -7] = "ByteRTCReturnStatusNeitherVideoNorAudio";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusRoomIdInUse"] = -8] = "ByteRTCReturnStatusRoomIdInUse";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusScreenNotSupport"] = -9] = "ByteRTCReturnStatusScreenNotSupport";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusNotSupport"] = -10] = "ByteRTCReturnStatusNotSupport";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusResourceOverflow"] = -11] = "ByteRTCReturnStatusResourceOverflow";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusAudioNoFrame"] = -101] = "ByteRTCReturnStatusAudioNoFrame";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusAudioNotImplemented"] = -102] = "ByteRTCReturnStatusAudioNotImplemented";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusAudioNoPermission"] = -103] = "ByteRTCReturnStatusAudioNoPermission";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusAudioDeviceNotExists"] = -104] = "ByteRTCReturnStatusAudioDeviceNotExists";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusAudioDeviceFormatNotSupport"] = -105] = "ByteRTCReturnStatusAudioDeviceFormatNotSupport";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusAudioDeviceNoDevice"] = -106] = "ByteRTCReturnStatusAudioDeviceNoDevice";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusAudioDeviceCannotUse"] = -107] = "ByteRTCReturnStatusAudioDeviceCannotUse";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusAudioDeviceInitFailed"] = -108] = "ByteRTCReturnStatusAudioDeviceInitFailed";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusAudioDeviceStartFailed"] = -109] = "ByteRTCReturnStatusAudioDeviceStartFailed";
    ByteRTCReturnStatus[ByteRTCReturnStatus["ByteRTCReturnStatusNativeInValid"] = -201] = "ByteRTCReturnStatusNativeInValid";
})(ByteRTCReturnStatus || (ByteRTCReturnStatus = {}));
var ByteRTCAudioMixingType;
(function (ByteRTCAudioMixingType) {
    ByteRTCAudioMixingType[ByteRTCAudioMixingType["ByteRTCAudioMixingTypePlayout"] = 0] = "ByteRTCAudioMixingTypePlayout";
    ByteRTCAudioMixingType[ByteRTCAudioMixingType["ByteRTCAudioMixingTypePublish"] = 1] = "ByteRTCAudioMixingTypePublish";
    ByteRTCAudioMixingType[ByteRTCAudioMixingType["ByteRTCAudioMixingTypePlayoutAndPublish"] = 2] = "ByteRTCAudioMixingTypePlayoutAndPublish";
})(ByteRTCAudioMixingType || (ByteRTCAudioMixingType = {}));
var ByteRTCVideoEnhancementMode;
(function (ByteRTCVideoEnhancementMode) {
    ByteRTCVideoEnhancementMode[ByteRTCVideoEnhancementMode["ByteRTCVideoEnhancementModeDisabled"] = 0] = "ByteRTCVideoEnhancementModeDisabled";
    ByteRTCVideoEnhancementMode[ByteRTCVideoEnhancementMode["ByteRTCVideoEnhancementModeAuto"] = 1] = "ByteRTCVideoEnhancementModeAuto";
})(ByteRTCVideoEnhancementMode || (ByteRTCVideoEnhancementMode = {}));
var ByteRTCSubscribeMediaType;
(function (ByteRTCSubscribeMediaType) {
    ByteRTCSubscribeMediaType[ByteRTCSubscribeMediaType["ByteRTCSubscribeMediaTypeNone"] = 0] = "ByteRTCSubscribeMediaTypeNone";
    ByteRTCSubscribeMediaType[ByteRTCSubscribeMediaType["ByteRTCSubscribeMediaTypeAudioOnly"] = 1] = "ByteRTCSubscribeMediaTypeAudioOnly";
    ByteRTCSubscribeMediaType[ByteRTCSubscribeMediaType["ByteRTCSubscribeMediaTypeVideoOnly"] = 2] = "ByteRTCSubscribeMediaTypeVideoOnly";
    ByteRTCSubscribeMediaType[ByteRTCSubscribeMediaType["ByteRTCSubscribeMediaTypeAudioAndVideo"] = 3] = "ByteRTCSubscribeMediaTypeAudioAndVideo";
})(ByteRTCSubscribeMediaType || (ByteRTCSubscribeMediaType = {}));
var ByteRTCPushSingleStreamParam = function () {
    var _classDecorators = [NativeClass('ByteRTCPushSingleStreamParam')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _url_decorators;
    var _url_initializers = [];
    var _url_extraInitializers = [];
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCPushSingleStreamParam_1() {
            this.url = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _url_initializers, void 0));
            this.roomId = (__runInitializers(this, _url_extraInitializers), __runInitializers(this, _roomId_initializers, void 0));
            this.userId = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _userId_initializers, void 0));
            this.isScreen = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            __runInitializers(this, _isScreen_extraInitializers);
        }
        ByteRTCPushSingleStreamParam_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCPushSingleStreamParam_1;
    }());
    __setFunctionName(_classThis, "ByteRTCPushSingleStreamParam");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _url_decorators = [NativeMember()];
        _roomId_decorators = [NativeMember()];
        _userId_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _url_decorators, { kind: "field", name: "url", static: false, private: false, access: { has: function (obj) { return "url" in obj; }, get: function (obj) { return obj.url; }, set: function (obj, value) { obj.url = value; } }, metadata: _metadata }, _url_initializers, _url_extraInitializers);
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCMediaDeviceWarning;
(function (ByteRTCMediaDeviceWarning) {
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningOK"] = 0] = "ByteRTCMediaDeviceWarningOK";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningOperationDenied"] = 1] = "ByteRTCMediaDeviceWarningOperationDenied";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningCaptureSilence"] = 2] = "ByteRTCMediaDeviceWarningCaptureSilence";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningDetectClipping"] = 10] = "ByteRTCMediaDeviceWarningDetectClipping";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningDetectLeakEcho"] = 11] = "ByteRTCMediaDeviceWarningDetectLeakEcho";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningDetectLowSNR"] = 12] = "ByteRTCMediaDeviceWarningDetectLowSNR";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningDetectInsertSilence"] = 13] = "ByteRTCMediaDeviceWarningDetectInsertSilence";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningCaptureDetectSilence"] = 14] = "ByteRTCMediaDeviceWarningCaptureDetectSilence";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningCaptureDetectSilenceDisappear"] = 15] = "ByteRTCMediaDeviceWarningCaptureDetectSilenceDisappear";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningCaptureDetectHowling"] = 16] = "ByteRTCMediaDeviceWarningCaptureDetectHowling";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningSetAudioRouteInvalidScenario"] = 20] = "ByteRTCMediaDeviceWarningSetAudioRouteInvalidScenario";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningSetAudioRouteNotExists"] = 21] = "ByteRTCMediaDeviceWarningSetAudioRouteNotExists";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningSetAudioRouteFailedByPriority"] = 22] = "ByteRTCMediaDeviceWarningSetAudioRouteFailedByPriority";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningSetAudioRouteNotVoipMode"] = 23] = "ByteRTCMediaDeviceWarningSetAudioRouteNotVoipMode";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningSetAudioRouteDeviceNotStart"] = 24] = "ByteRTCMediaDeviceWarningSetAudioRouteDeviceNotStart";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningSetBluetoothModeScenarioUnsupport"] = 25] = "ByteRTCMediaDeviceWarningSetBluetoothModeScenarioUnsupport";
    ByteRTCMediaDeviceWarning[ByteRTCMediaDeviceWarning["ByteRTCMediaDeviceWarningSetBluetoothModeUnsupport"] = 26] = "ByteRTCMediaDeviceWarningSetBluetoothModeUnsupport";
})(ByteRTCMediaDeviceWarning || (ByteRTCMediaDeviceWarning = {}));
var ByteRTCVideoDenoiseMode;
(function (ByteRTCVideoDenoiseMode) {
    ByteRTCVideoDenoiseMode[ByteRTCVideoDenoiseMode["ByteRTCVideoDenoiseModeOff"] = 0] = "ByteRTCVideoDenoiseModeOff";
    ByteRTCVideoDenoiseMode[ByteRTCVideoDenoiseMode["ByteRTCVideoDenoiseModeAuto"] = 1] = "ByteRTCVideoDenoiseModeAuto";
})(ByteRTCVideoDenoiseMode || (ByteRTCVideoDenoiseMode = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCExpressionDetectConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _enableAgeDetect_decorators;
    var _enableAgeDetect_initializers = [];
    var _enableAgeDetect_extraInitializers = [];
    var _enableGenderDetect_decorators;
    var _enableGenderDetect_initializers = [];
    var _enableGenderDetect_extraInitializers = [];
    var _enableEmotionDetect_decorators;
    var _enableEmotionDetect_initializers = [];
    var _enableEmotionDetect_extraInitializers = [];
    var _enableAttractivenessDetect_decorators;
    var _enableAttractivenessDetect_initializers = [];
    var _enableAttractivenessDetect_extraInitializers = [];
    var _enableHappinessDetect_decorators;
    var _enableHappinessDetect_initializers = [];
    var _enableHappinessDetect_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCExpressionDetectConfig_1() {
            this.enableAgeDetect = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _enableAgeDetect_initializers, void 0));
            this.enableGenderDetect = (__runInitializers(this, _enableAgeDetect_extraInitializers), __runInitializers(this, _enableGenderDetect_initializers, void 0));
            this.enableEmotionDetect = (__runInitializers(this, _enableGenderDetect_extraInitializers), __runInitializers(this, _enableEmotionDetect_initializers, void 0));
            this.enableAttractivenessDetect = (__runInitializers(this, _enableEmotionDetect_extraInitializers), __runInitializers(this, _enableAttractivenessDetect_initializers, void 0));
            this.enableHappinessDetect = (__runInitializers(this, _enableAttractivenessDetect_extraInitializers), __runInitializers(this, _enableHappinessDetect_initializers, void 0));
            __runInitializers(this, _enableHappinessDetect_extraInitializers);
        }
        ByteRTCExpressionDetectConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCExpressionDetectConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCExpressionDetectConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enableAgeDetect_decorators = [NativeMember()];
        _enableGenderDetect_decorators = [NativeMember()];
        _enableEmotionDetect_decorators = [NativeMember()];
        _enableAttractivenessDetect_decorators = [NativeMember()];
        _enableHappinessDetect_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _enableAgeDetect_decorators, { kind: "field", name: "enableAgeDetect", static: false, private: false, access: { has: function (obj) { return "enableAgeDetect" in obj; }, get: function (obj) { return obj.enableAgeDetect; }, set: function (obj, value) { obj.enableAgeDetect = value; } }, metadata: _metadata }, _enableAgeDetect_initializers, _enableAgeDetect_extraInitializers);
        __esDecorate(null, null, _enableGenderDetect_decorators, { kind: "field", name: "enableGenderDetect", static: false, private: false, access: { has: function (obj) { return "enableGenderDetect" in obj; }, get: function (obj) { return obj.enableGenderDetect; }, set: function (obj, value) { obj.enableGenderDetect = value; } }, metadata: _metadata }, _enableGenderDetect_initializers, _enableGenderDetect_extraInitializers);
        __esDecorate(null, null, _enableEmotionDetect_decorators, { kind: "field", name: "enableEmotionDetect", static: false, private: false, access: { has: function (obj) { return "enableEmotionDetect" in obj; }, get: function (obj) { return obj.enableEmotionDetect; }, set: function (obj, value) { obj.enableEmotionDetect = value; } }, metadata: _metadata }, _enableEmotionDetect_initializers, _enableEmotionDetect_extraInitializers);
        __esDecorate(null, null, _enableAttractivenessDetect_decorators, { kind: "field", name: "enableAttractivenessDetect", static: false, private: false, access: { has: function (obj) { return "enableAttractivenessDetect" in obj; }, get: function (obj) { return obj.enableAttractivenessDetect; }, set: function (obj, value) { obj.enableAttractivenessDetect = value; } }, metadata: _metadata }, _enableAttractivenessDetect_initializers, _enableAttractivenessDetect_extraInitializers);
        __esDecorate(null, null, _enableHappinessDetect_decorators, { kind: "field", name: "enableHappinessDetect", static: false, private: false, access: { has: function (obj) { return "enableHappinessDetect" in obj; }, get: function (obj) { return obj.enableHappinessDetect; }, set: function (obj, value) { obj.enableHappinessDetect = value; } }, metadata: _metadata }, _enableHappinessDetect_initializers, _enableHappinessDetect_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCAudioReportMode;
(function (ByteRTCAudioReportMode) {
    ByteRTCAudioReportMode[ByteRTCAudioReportMode["ByteRTCAudioReportModeNormal"] = 0] = "ByteRTCAudioReportModeNormal";
    ByteRTCAudioReportMode[ByteRTCAudioReportMode["ByteRTCAudioReportModeDisconnect"] = 1] = "ByteRTCAudioReportModeDisconnect";
    ByteRTCAudioReportMode[ByteRTCAudioReportMode["ByteRTCAudioReportModeReset"] = 2] = "ByteRTCAudioReportModeReset";
})(ByteRTCAudioReportMode || (ByteRTCAudioReportMode = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCTranscodingClientMixParam')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _clientMixUseOriginalFrame_decorators;
    var _clientMixUseOriginalFrame_initializers = [];
    var _clientMixUseOriginalFrame_extraInitializers = [];
    var _clientMixUseAudioMixer_decorators;
    var _clientMixUseAudioMixer_initializers = [];
    var _clientMixUseAudioMixer_extraInitializers = [];
    var _clientMixVideoFormat_decorators;
    var _clientMixVideoFormat_initializers = [];
    var _clientMixVideoFormat_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCTranscodingClientMixParam_1() {
            this.clientMixUseOriginalFrame = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _clientMixUseOriginalFrame_initializers, void 0));
            this.clientMixUseAudioMixer = (__runInitializers(this, _clientMixUseOriginalFrame_extraInitializers), __runInitializers(this, _clientMixUseAudioMixer_initializers, void 0));
            this.clientMixVideoFormat = (__runInitializers(this, _clientMixUseAudioMixer_extraInitializers), __runInitializers(this, _clientMixVideoFormat_initializers, void 0));
            __runInitializers(this, _clientMixVideoFormat_extraInitializers);
        }
        ByteRTCTranscodingClientMixParam_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCTranscodingClientMixParam_1;
    }());
    __setFunctionName(_classThis, "ByteRTCTranscodingClientMixParam");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _clientMixUseOriginalFrame_decorators = [NativeMember()];
        _clientMixUseAudioMixer_decorators = [NativeMember()];
        _clientMixVideoFormat_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _clientMixUseOriginalFrame_decorators, { kind: "field", name: "clientMixUseOriginalFrame", static: false, private: false, access: { has: function (obj) { return "clientMixUseOriginalFrame" in obj; }, get: function (obj) { return obj.clientMixUseOriginalFrame; }, set: function (obj, value) { obj.clientMixUseOriginalFrame = value; } }, metadata: _metadata }, _clientMixUseOriginalFrame_initializers, _clientMixUseOriginalFrame_extraInitializers);
        __esDecorate(null, null, _clientMixUseAudioMixer_decorators, { kind: "field", name: "clientMixUseAudioMixer", static: false, private: false, access: { has: function (obj) { return "clientMixUseAudioMixer" in obj; }, get: function (obj) { return obj.clientMixUseAudioMixer; }, set: function (obj, value) { obj.clientMixUseAudioMixer = value; } }, metadata: _metadata }, _clientMixUseAudioMixer_initializers, _clientMixUseAudioMixer_extraInitializers);
        __esDecorate(null, null, _clientMixVideoFormat_decorators, { kind: "field", name: "clientMixVideoFormat", static: false, private: false, access: { has: function (obj) { return "clientMixVideoFormat" in obj; }, get: function (obj) { return obj.clientMixVideoFormat; }, set: function (obj, value) { obj.clientMixVideoFormat = value; } }, metadata: _metadata }, _clientMixVideoFormat_initializers, _clientMixVideoFormat_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCSourceWantedData = function () {
    var _classDecorators = [NativeClass('ByteRTCSourceWantedData')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _frameRate_decorators;
    var _frameRate_initializers = [];
    var _frameRate_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCSourceWantedData_1() {
            this.width = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.frameRate = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _frameRate_initializers, void 0));
            __runInitializers(this, _frameRate_extraInitializers);
        }
        ByteRTCSourceWantedData_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCSourceWantedData_1;
    }());
    __setFunctionName(_classThis, "ByteRTCSourceWantedData");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _frameRate_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _frameRate_decorators, { kind: "field", name: "frameRate", static: false, private: false, access: { has: function (obj) { return "frameRate" in obj; }, get: function (obj) { return obj.frameRate; }, set: function (obj, value) { obj.frameRate = value; } }, metadata: _metadata }, _frameRate_initializers, _frameRate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCLogConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCLogConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _logPath_decorators;
    var _logPath_initializers = [];
    var _logPath_extraInitializers = [];
    var _logLevel_decorators;
    var _logLevel_initializers = [];
    var _logLevel_extraInitializers = [];
    var _logFileSize_decorators;
    var _logFileSize_initializers = [];
    var _logFileSize_extraInitializers = [];
    var _logFilenamePrefix_decorators;
    var _logFilenamePrefix_initializers = [];
    var _logFilenamePrefix_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCLogConfig_1() {
            this.logPath = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _logPath_initializers, void 0));
            this.logLevel = (__runInitializers(this, _logPath_extraInitializers), __runInitializers(this, _logLevel_initializers, void 0));
            this.logFileSize = (__runInitializers(this, _logLevel_extraInitializers), __runInitializers(this, _logFileSize_initializers, void 0));
            this.logFilenamePrefix = (__runInitializers(this, _logFileSize_extraInitializers), __runInitializers(this, _logFilenamePrefix_initializers, void 0));
            __runInitializers(this, _logFilenamePrefix_extraInitializers);
        }
        ByteRTCLogConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCLogConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCLogConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _logPath_decorators = [NativeMember()];
        _logLevel_decorators = [NativeMember()];
        _logFileSize_decorators = [NativeMember()];
        _logFilenamePrefix_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _logPath_decorators, { kind: "field", name: "logPath", static: false, private: false, access: { has: function (obj) { return "logPath" in obj; }, get: function (obj) { return obj.logPath; }, set: function (obj, value) { obj.logPath = value; } }, metadata: _metadata }, _logPath_initializers, _logPath_extraInitializers);
        __esDecorate(null, null, _logLevel_decorators, { kind: "field", name: "logLevel", static: false, private: false, access: { has: function (obj) { return "logLevel" in obj; }, get: function (obj) { return obj.logLevel; }, set: function (obj, value) { obj.logLevel = value; } }, metadata: _metadata }, _logLevel_initializers, _logLevel_extraInitializers);
        __esDecorate(null, null, _logFileSize_decorators, { kind: "field", name: "logFileSize", static: false, private: false, access: { has: function (obj) { return "logFileSize" in obj; }, get: function (obj) { return obj.logFileSize; }, set: function (obj, value) { obj.logFileSize = value; } }, metadata: _metadata }, _logFileSize_initializers, _logFileSize_extraInitializers);
        __esDecorate(null, null, _logFilenamePrefix_decorators, { kind: "field", name: "logFilenamePrefix", static: false, private: false, access: { has: function (obj) { return "logFilenamePrefix" in obj; }, get: function (obj) { return obj.logFilenamePrefix; }, set: function (obj, value) { obj.logFilenamePrefix = value; } }, metadata: _metadata }, _logFilenamePrefix_initializers, _logFilenamePrefix_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('ByteRTCPublicStreamRegion')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _alternateImage_decorators;
    var _alternateImage_initializers = [];
    var _alternateImage_extraInitializers = [];
    var _x_decorators;
    var _x_initializers = [];
    var _x_extraInitializers = [];
    var _y_decorators;
    var _y_initializers = [];
    var _y_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _zOrder_decorators;
    var _zOrder_initializers = [];
    var _zOrder_extraInitializers = [];
    var _alpha_decorators;
    var _alpha_initializers = [];
    var _alpha_extraInitializers = [];
    var _mediaType_decorators;
    var _mediaType_initializers = [];
    var _mediaType_extraInitializers = [];
    var _streamType_decorators;
    var _streamType_initializers = [];
    var _streamType_extraInitializers = [];
    var _renderMode_decorators;
    var _renderMode_initializers = [];
    var _renderMode_extraInitializers = [];
    var _sourceCrop_decorators;
    var _sourceCrop_initializers = [];
    var _sourceCrop_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCPublicStreamRegion_1() {
            this.userId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _userId_initializers, void 0));
            this.roomId = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _roomId_initializers, void 0));
            this.alternateImage = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _alternateImage_initializers, void 0));
            this.x = (__runInitializers(this, _alternateImage_extraInitializers), __runInitializers(this, _x_initializers, void 0));
            this.y = (__runInitializers(this, _x_extraInitializers), __runInitializers(this, _y_initializers, void 0));
            this.width = (__runInitializers(this, _y_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.zOrder = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _zOrder_initializers, void 0));
            this.alpha = (__runInitializers(this, _zOrder_extraInitializers), __runInitializers(this, _alpha_initializers, void 0));
            this.mediaType = (__runInitializers(this, _alpha_extraInitializers), __runInitializers(this, _mediaType_initializers, void 0));
            this.streamType = (__runInitializers(this, _mediaType_extraInitializers), __runInitializers(this, _streamType_initializers, void 0));
            this.renderMode = (__runInitializers(this, _streamType_extraInitializers), __runInitializers(this, _renderMode_initializers, void 0));
            this.sourceCrop = (__runInitializers(this, _renderMode_extraInitializers), __runInitializers(this, _sourceCrop_initializers, void 0));
            __runInitializers(this, _sourceCrop_extraInitializers);
        }
        ByteRTCPublicStreamRegion_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCPublicStreamRegion_1;
    }());
    __setFunctionName(_classThis, "ByteRTCPublicStreamRegion");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _userId_decorators = [NativeMember()];
        _roomId_decorators = [NativeMember()];
        _alternateImage_decorators = [NativeMember()];
        _x_decorators = [NativeMember()];
        _y_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _zOrder_decorators = [NativeMember()];
        _alpha_decorators = [NativeMember()];
        _mediaType_decorators = [NativeMember()];
        _streamType_decorators = [NativeMember()];
        _renderMode_decorators = [NativeMember()];
        _sourceCrop_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _alternateImage_decorators, { kind: "field", name: "alternateImage", static: false, private: false, access: { has: function (obj) { return "alternateImage" in obj; }, get: function (obj) { return obj.alternateImage; }, set: function (obj, value) { obj.alternateImage = value; } }, metadata: _metadata }, _alternateImage_initializers, _alternateImage_extraInitializers);
        __esDecorate(null, null, _x_decorators, { kind: "field", name: "x", static: false, private: false, access: { has: function (obj) { return "x" in obj; }, get: function (obj) { return obj.x; }, set: function (obj, value) { obj.x = value; } }, metadata: _metadata }, _x_initializers, _x_extraInitializers);
        __esDecorate(null, null, _y_decorators, { kind: "field", name: "y", static: false, private: false, access: { has: function (obj) { return "y" in obj; }, get: function (obj) { return obj.y; }, set: function (obj, value) { obj.y = value; } }, metadata: _metadata }, _y_initializers, _y_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _zOrder_decorators, { kind: "field", name: "zOrder", static: false, private: false, access: { has: function (obj) { return "zOrder" in obj; }, get: function (obj) { return obj.zOrder; }, set: function (obj, value) { obj.zOrder = value; } }, metadata: _metadata }, _zOrder_initializers, _zOrder_extraInitializers);
        __esDecorate(null, null, _alpha_decorators, { kind: "field", name: "alpha", static: false, private: false, access: { has: function (obj) { return "alpha" in obj; }, get: function (obj) { return obj.alpha; }, set: function (obj, value) { obj.alpha = value; } }, metadata: _metadata }, _alpha_initializers, _alpha_extraInitializers);
        __esDecorate(null, null, _mediaType_decorators, { kind: "field", name: "mediaType", static: false, private: false, access: { has: function (obj) { return "mediaType" in obj; }, get: function (obj) { return obj.mediaType; }, set: function (obj, value) { obj.mediaType = value; } }, metadata: _metadata }, _mediaType_initializers, _mediaType_extraInitializers);
        __esDecorate(null, null, _streamType_decorators, { kind: "field", name: "streamType", static: false, private: false, access: { has: function (obj) { return "streamType" in obj; }, get: function (obj) { return obj.streamType; }, set: function (obj, value) { obj.streamType = value; } }, metadata: _metadata }, _streamType_initializers, _streamType_extraInitializers);
        __esDecorate(null, null, _renderMode_decorators, { kind: "field", name: "renderMode", static: false, private: false, access: { has: function (obj) { return "renderMode" in obj; }, get: function (obj) { return obj.renderMode; }, set: function (obj, value) { obj.renderMode = value; } }, metadata: _metadata }, _renderMode_initializers, _renderMode_extraInitializers);
        __esDecorate(null, null, _sourceCrop_decorators, { kind: "field", name: "sourceCrop", static: false, private: false, access: { has: function (obj) { return "sourceCrop" in obj; }, get: function (obj) { return obj.sourceCrop; }, set: function (obj, value) { obj.sourceCrop = value; } }, metadata: _metadata }, _sourceCrop_initializers, _sourceCrop_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCSubscribeVideoConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCSubscribeVideoConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _videoIndex_decorators;
    var _videoIndex_initializers = [];
    var _videoIndex_extraInitializers = [];
    var _priority_decorators;
    var _priority_initializers = [];
    var _priority_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCSubscribeVideoConfig_1() {
            this.videoIndex = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _videoIndex_initializers, void 0));
            this.priority = (__runInitializers(this, _videoIndex_extraInitializers), __runInitializers(this, _priority_initializers, void 0));
            __runInitializers(this, _priority_extraInitializers);
        }
        ByteRTCSubscribeVideoConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCSubscribeVideoConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCSubscribeVideoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _videoIndex_decorators = [NativeMember()];
        _priority_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _videoIndex_decorators, { kind: "field", name: "videoIndex", static: false, private: false, access: { has: function (obj) { return "videoIndex" in obj; }, get: function (obj) { return obj.videoIndex; }, set: function (obj, value) { obj.videoIndex = value; } }, metadata: _metadata }, _videoIndex_initializers, _videoIndex_extraInitializers);
        __esDecorate(null, null, _priority_decorators, { kind: "field", name: "priority", static: false, private: false, access: { has: function (obj) { return "priority" in obj; }, get: function (obj) { return obj.priority; }, set: function (obj, value) { obj.priority = value; } }, metadata: _metadata }, _priority_initializers, _priority_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioPlayType;
(function (ByteRTCAudioPlayType) {
    ByteRTCAudioPlayType[ByteRTCAudioPlayType["ByteRTCAudioPlayTypeLocal"] = 0] = "ByteRTCAudioPlayTypeLocal";
    ByteRTCAudioPlayType[ByteRTCAudioPlayType["ByteRTCAudioPlayTypeRemote"] = 1] = "ByteRTCAudioPlayTypeRemote";
    ByteRTCAudioPlayType[ByteRTCAudioPlayType["ByteRTCAudioPlayTypeLocalAndRemote"] = 2] = "ByteRTCAudioPlayTypeLocalAndRemote";
})(ByteRTCAudioPlayType || (ByteRTCAudioPlayType = {}));
var ByteRTCNetworkTimeInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCNetworkTimeInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _timestamp_decorators;
    var _timestamp_initializers = [];
    var _timestamp_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCNetworkTimeInfo_1() {
            this.timestamp = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _timestamp_initializers, void 0));
            __runInitializers(this, _timestamp_extraInitializers);
        }
        ByteRTCNetworkTimeInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCNetworkTimeInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCNetworkTimeInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _timestamp_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _timestamp_decorators, { kind: "field", name: "timestamp", static: false, private: false, access: { has: function (obj) { return "timestamp" in obj; }, get: function (obj) { return obj.timestamp; }, set: function (obj, value) { obj.timestamp = value; } }, metadata: _metadata }, _timestamp_initializers, _timestamp_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRemoteAudioPropertiesInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCRemoteAudioPropertiesInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _streamKey_decorators;
    var _streamKey_initializers = [];
    var _streamKey_extraInitializers = [];
    var _audioPropertiesInfo_decorators;
    var _audioPropertiesInfo_initializers = [];
    var _audioPropertiesInfo_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRemoteAudioPropertiesInfo_1() {
            this.streamKey = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _streamKey_initializers, void 0));
            this.audioPropertiesInfo = (__runInitializers(this, _streamKey_extraInitializers), __runInitializers(this, _audioPropertiesInfo_initializers, void 0));
            __runInitializers(this, _audioPropertiesInfo_extraInitializers);
        }
        ByteRTCRemoteAudioPropertiesInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRemoteAudioPropertiesInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRemoteAudioPropertiesInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _streamKey_decorators = [NativeMember()];
        _audioPropertiesInfo_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _streamKey_decorators, { kind: "field", name: "streamKey", static: false, private: false, access: { has: function (obj) { return "streamKey" in obj; }, get: function (obj) { return obj.streamKey; }, set: function (obj, value) { obj.streamKey = value; } }, metadata: _metadata }, _streamKey_initializers, _streamKey_extraInitializers);
        __esDecorate(null, null, _audioPropertiesInfo_decorators, { kind: "field", name: "audioPropertiesInfo", static: false, private: false, access: { has: function (obj) { return "audioPropertiesInfo" in obj; }, get: function (obj) { return obj.audioPropertiesInfo; }, set: function (obj, value) { obj.audioPropertiesInfo = value; } }, metadata: _metadata }, _audioPropertiesInfo_initializers, _audioPropertiesInfo_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCTranscodingAudioCodec;
(function (ByteRTCTranscodingAudioCodec) {
    ByteRTCTranscodingAudioCodec[ByteRTCTranscodingAudioCodec["ByteRTCTranscodingAudioCodecAAC"] = 0] = "ByteRTCTranscodingAudioCodecAAC";
})(ByteRTCTranscodingAudioCodec || (ByteRTCTranscodingAudioCodec = {}));
var ByteRTCSubtitleMessage = function () {
    var _classDecorators = [NativeClass('ByteRTCSubtitleMessage')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _text_decorators;
    var _text_initializers = [];
    var _text_extraInitializers = [];
    var _language_decorators;
    var _language_initializers = [];
    var _language_extraInitializers = [];
    var _mode_decorators;
    var _mode_initializers = [];
    var _mode_extraInitializers = [];
    var _sequence_decorators;
    var _sequence_initializers = [];
    var _sequence_extraInitializers = [];
    var _definite_decorators;
    var _definite_initializers = [];
    var _definite_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCSubtitleMessage_1() {
            this.userId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _userId_initializers, void 0));
            this.text = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _text_initializers, void 0));
            this.language = (__runInitializers(this, _text_extraInitializers), __runInitializers(this, _language_initializers, void 0));
            this.mode = (__runInitializers(this, _language_extraInitializers), __runInitializers(this, _mode_initializers, void 0));
            this.sequence = (__runInitializers(this, _mode_extraInitializers), __runInitializers(this, _sequence_initializers, void 0));
            this.definite = (__runInitializers(this, _sequence_extraInitializers), __runInitializers(this, _definite_initializers, void 0));
            __runInitializers(this, _definite_extraInitializers);
        }
        ByteRTCSubtitleMessage_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCSubtitleMessage_1;
    }());
    __setFunctionName(_classThis, "ByteRTCSubtitleMessage");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _userId_decorators = [NativeMember()];
        _text_decorators = [NativeMember()];
        _language_decorators = [NativeMember()];
        _mode_decorators = [NativeMember()];
        _sequence_decorators = [NativeMember()];
        _definite_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _text_decorators, { kind: "field", name: "text", static: false, private: false, access: { has: function (obj) { return "text" in obj; }, get: function (obj) { return obj.text; }, set: function (obj, value) { obj.text = value; } }, metadata: _metadata }, _text_initializers, _text_extraInitializers);
        __esDecorate(null, null, _language_decorators, { kind: "field", name: "language", static: false, private: false, access: { has: function (obj) { return "language" in obj; }, get: function (obj) { return obj.language; }, set: function (obj, value) { obj.language = value; } }, metadata: _metadata }, _language_initializers, _language_extraInitializers);
        __esDecorate(null, null, _mode_decorators, { kind: "field", name: "mode", static: false, private: false, access: { has: function (obj) { return "mode" in obj; }, get: function (obj) { return obj.mode; }, set: function (obj, value) { obj.mode = value; } }, metadata: _metadata }, _mode_initializers, _mode_extraInitializers);
        __esDecorate(null, null, _sequence_decorators, { kind: "field", name: "sequence", static: false, private: false, access: { has: function (obj) { return "sequence" in obj; }, get: function (obj) { return obj.sequence; }, set: function (obj, value) { obj.sequence = value; } }, metadata: _metadata }, _sequence_initializers, _sequence_extraInitializers);
        __esDecorate(null, null, _definite_decorators, { kind: "field", name: "definite", static: false, private: false, access: { has: function (obj) { return "definite" in obj; }, get: function (obj) { return obj.definite; }, set: function (obj, value) { obj.definite = value; } }, metadata: _metadata }, _definite_initializers, _definite_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCVirtualBackgroundSourceType;
(function (ByteRTCVirtualBackgroundSourceType) {
    ByteRTCVirtualBackgroundSourceType[ByteRTCVirtualBackgroundSourceType["ByteRTCVirtualBackgroundSourceTypeColor"] = 0] = "ByteRTCVirtualBackgroundSourceTypeColor";
    ByteRTCVirtualBackgroundSourceType[ByteRTCVirtualBackgroundSourceType["ByteRTCVirtualBackgroundSourceTypeImage"] = 1] = "ByteRTCVirtualBackgroundSourceTypeImage";
})(ByteRTCVirtualBackgroundSourceType || (ByteRTCVirtualBackgroundSourceType = {}));
var ByteRTCAudioPropertiesInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCAudioPropertiesInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _linearVolume_decorators;
    var _linearVolume_initializers = [];
    var _linearVolume_extraInitializers = [];
    var _nonlinearVolume_decorators;
    var _nonlinearVolume_initializers = [];
    var _nonlinearVolume_extraInitializers = [];
    var _vad_decorators;
    var _vad_initializers = [];
    var _vad_extraInitializers = [];
    var _spectrum_decorators;
    var _spectrum_initializers = [];
    var _spectrum_extraInitializers = [];
    var _voicePitch_decorators;
    var _voicePitch_initializers = [];
    var _voicePitch_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioPropertiesInfo_1() {
            this.linearVolume = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _linearVolume_initializers, void 0));
            this.nonlinearVolume = (__runInitializers(this, _linearVolume_extraInitializers), __runInitializers(this, _nonlinearVolume_initializers, void 0));
            this.vad = (__runInitializers(this, _nonlinearVolume_extraInitializers), __runInitializers(this, _vad_initializers, void 0));
            this.spectrum = (__runInitializers(this, _vad_extraInitializers), __runInitializers(this, _spectrum_initializers, void 0));
            this.voicePitch = (__runInitializers(this, _spectrum_extraInitializers), __runInitializers(this, _voicePitch_initializers, void 0));
            __runInitializers(this, _voicePitch_extraInitializers);
        }
        ByteRTCAudioPropertiesInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCAudioPropertiesInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioPropertiesInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _linearVolume_decorators = [NativeMember()];
        _nonlinearVolume_decorators = [NativeMember()];
        _vad_decorators = [NativeMember()];
        _spectrum_decorators = [NativeMember()];
        _voicePitch_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _linearVolume_decorators, { kind: "field", name: "linearVolume", static: false, private: false, access: { has: function (obj) { return "linearVolume" in obj; }, get: function (obj) { return obj.linearVolume; }, set: function (obj, value) { obj.linearVolume = value; } }, metadata: _metadata }, _linearVolume_initializers, _linearVolume_extraInitializers);
        __esDecorate(null, null, _nonlinearVolume_decorators, { kind: "field", name: "nonlinearVolume", static: false, private: false, access: { has: function (obj) { return "nonlinearVolume" in obj; }, get: function (obj) { return obj.nonlinearVolume; }, set: function (obj, value) { obj.nonlinearVolume = value; } }, metadata: _metadata }, _nonlinearVolume_initializers, _nonlinearVolume_extraInitializers);
        __esDecorate(null, null, _vad_decorators, { kind: "field", name: "vad", static: false, private: false, access: { has: function (obj) { return "vad" in obj; }, get: function (obj) { return obj.vad; }, set: function (obj, value) { obj.vad = value; } }, metadata: _metadata }, _vad_initializers, _vad_extraInitializers);
        __esDecorate(null, null, _spectrum_decorators, { kind: "field", name: "spectrum", static: false, private: false, access: { has: function (obj) { return "spectrum" in obj; }, get: function (obj) { return obj.spectrum; }, set: function (obj, value) { obj.spectrum = value; } }, metadata: _metadata }, _spectrum_initializers, _spectrum_extraInitializers);
        __esDecorate(null, null, _voicePitch_decorators, { kind: "field", name: "voicePitch", static: false, private: false, access: { has: function (obj) { return "voicePitch" in obj; }, get: function (obj) { return obj.voicePitch; }, set: function (obj, value) { obj.voicePitch = value; } }, metadata: _metadata }, _voicePitch_initializers, _voicePitch_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCLogoutReason;
(function (ByteRTCLogoutReason) {
    ByteRTCLogoutReason[ByteRTCLogoutReason["ByteRTCLogoutReasonLogout"] = 0] = "ByteRTCLogoutReasonLogout";
    ByteRTCLogoutReason[ByteRTCLogoutReason["ByteRTCLogoutReasonDuplicateLogin"] = 1] = "ByteRTCLogoutReasonDuplicateLogin";
})(ByteRTCLogoutReason || (ByteRTCLogoutReason = {}));
var ByteRTCMixedStreamLayoutConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCMixedStreamLayoutConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _backgroundColor_decorators;
    var _backgroundColor_initializers = [];
    var _backgroundColor_extraInitializers = [];
    var _regions_decorators;
    var _regions_initializers = [];
    var _regions_extraInitializers = [];
    var _userConfigExtraInfo_decorators;
    var _userConfigExtraInfo_initializers = [];
    var _userConfigExtraInfo_extraInitializers = [];
    var _backgroundImageUrl_decorators;
    var _backgroundImageUrl_initializers = [];
    var _backgroundImageUrl_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMixedStreamLayoutConfig_1() {
            this.backgroundColor = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _backgroundColor_initializers, void 0));
            this.regions = (__runInitializers(this, _backgroundColor_extraInitializers), __runInitializers(this, _regions_initializers, void 0));
            this.userConfigExtraInfo = (__runInitializers(this, _regions_extraInitializers), __runInitializers(this, _userConfigExtraInfo_initializers, void 0));
            this.backgroundImageUrl = (__runInitializers(this, _userConfigExtraInfo_extraInitializers), __runInitializers(this, _backgroundImageUrl_initializers, void 0));
            __runInitializers(this, _backgroundImageUrl_extraInitializers);
        }
        ByteRTCMixedStreamLayoutConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMixedStreamLayoutConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMixedStreamLayoutConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _backgroundColor_decorators = [NativeMember()];
        _regions_decorators = [NativeMember()];
        _userConfigExtraInfo_decorators = [NativeMember()];
        _backgroundImageUrl_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _backgroundColor_decorators, { kind: "field", name: "backgroundColor", static: false, private: false, access: { has: function (obj) { return "backgroundColor" in obj; }, get: function (obj) { return obj.backgroundColor; }, set: function (obj, value) { obj.backgroundColor = value; } }, metadata: _metadata }, _backgroundColor_initializers, _backgroundColor_extraInitializers);
        __esDecorate(null, null, _regions_decorators, { kind: "field", name: "regions", static: false, private: false, access: { has: function (obj) { return "regions" in obj; }, get: function (obj) { return obj.regions; }, set: function (obj, value) { obj.regions = value; } }, metadata: _metadata }, _regions_initializers, _regions_extraInitializers);
        __esDecorate(null, null, _userConfigExtraInfo_decorators, { kind: "field", name: "userConfigExtraInfo", static: false, private: false, access: { has: function (obj) { return "userConfigExtraInfo" in obj; }, get: function (obj) { return obj.userConfigExtraInfo; }, set: function (obj, value) { obj.userConfigExtraInfo = value; } }, metadata: _metadata }, _userConfigExtraInfo_initializers, _userConfigExtraInfo_extraInitializers);
        __esDecorate(null, null, _backgroundImageUrl_decorators, { kind: "field", name: "backgroundImageUrl", static: false, private: false, access: { has: function (obj) { return "backgroundImageUrl" in obj; }, get: function (obj) { return obj.backgroundImageUrl; }, set: function (obj, value) { obj.backgroundImageUrl = value; } }, metadata: _metadata }, _backgroundImageUrl_initializers, _backgroundImageUrl_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('ByteRTCVideoWatermarkConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _visibleInPreview_decorators;
    var _visibleInPreview_initializers = [];
    var _visibleInPreview_extraInitializers = [];
    var _positionInLandscapeMode_decorators;
    var _positionInLandscapeMode_initializers = [];
    var _positionInLandscapeMode_extraInitializers = [];
    var _positionInPortraitMode_decorators;
    var _positionInPortraitMode_initializers = [];
    var _positionInPortraitMode_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoWatermarkConfig_1() {
            this.visibleInPreview = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _visibleInPreview_initializers, void 0));
            this.positionInLandscapeMode = (__runInitializers(this, _visibleInPreview_extraInitializers), __runInitializers(this, _positionInLandscapeMode_initializers, void 0));
            this.positionInPortraitMode = (__runInitializers(this, _positionInLandscapeMode_extraInitializers), __runInitializers(this, _positionInPortraitMode_initializers, void 0));
            __runInitializers(this, _positionInPortraitMode_extraInitializers);
        }
        ByteRTCVideoWatermarkConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVideoWatermarkConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoWatermarkConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _visibleInPreview_decorators = [NativeMember()];
        _positionInLandscapeMode_decorators = [NativeMember()];
        _positionInPortraitMode_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _visibleInPreview_decorators, { kind: "field", name: "visibleInPreview", static: false, private: false, access: { has: function (obj) { return "visibleInPreview" in obj; }, get: function (obj) { return obj.visibleInPreview; }, set: function (obj, value) { obj.visibleInPreview = value; } }, metadata: _metadata }, _visibleInPreview_initializers, _visibleInPreview_extraInitializers);
        __esDecorate(null, null, _positionInLandscapeMode_decorators, { kind: "field", name: "positionInLandscapeMode", static: false, private: false, access: { has: function (obj) { return "positionInLandscapeMode" in obj; }, get: function (obj) { return obj.positionInLandscapeMode; }, set: function (obj, value) { obj.positionInLandscapeMode = value; } }, metadata: _metadata }, _positionInLandscapeMode_initializers, _positionInLandscapeMode_extraInitializers);
        __esDecorate(null, null, _positionInPortraitMode_decorators, { kind: "field", name: "positionInPortraitMode", static: false, private: false, access: { has: function (obj) { return "positionInPortraitMode" in obj; }, get: function (obj) { return obj.positionInPortraitMode; }, set: function (obj, value) { obj.positionInPortraitMode = value; } }, metadata: _metadata }, _positionInPortraitMode_initializers, _positionInPortraitMode_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCMixedStreamPushMode;
(function (ByteRTCMixedStreamPushMode) {
    ByteRTCMixedStreamPushMode[ByteRTCMixedStreamPushMode["ByteRTCMixedStreamPushModeOnStream"] = 0] = "ByteRTCMixedStreamPushModeOnStream";
    ByteRTCMixedStreamPushMode[ByteRTCMixedStreamPushMode["ByteRTCMixedStreamPushModeOnStartRequest"] = 1] = "ByteRTCMixedStreamPushModeOnStartRequest";
})(ByteRTCMixedStreamPushMode || (ByteRTCMixedStreamPushMode = {}));
var ByteRTCLocalVideoStats = function () {
    var _classDecorators = [NativeClass('ByteRTCLocalVideoStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _sentKBitrate_decorators;
    var _sentKBitrate_initializers = [];
    var _sentKBitrate_extraInitializers = [];
    var _inputFrameRate_decorators;
    var _inputFrameRate_initializers = [];
    var _inputFrameRate_extraInitializers = [];
    var _sentFrameRate_decorators;
    var _sentFrameRate_initializers = [];
    var _sentFrameRate_extraInitializers = [];
    var _encoderOutputFrameRate_decorators;
    var _encoderOutputFrameRate_initializers = [];
    var _encoderOutputFrameRate_extraInitializers = [];
    var _rendererOutputFrameRate_decorators;
    var _rendererOutputFrameRate_initializers = [];
    var _rendererOutputFrameRate_extraInitializers = [];
    var _statsInterval_decorators;
    var _statsInterval_initializers = [];
    var _statsInterval_extraInitializers = [];
    var _videoLossRate_decorators;
    var _videoLossRate_initializers = [];
    var _videoLossRate_extraInitializers = [];
    var _rtt_decorators;
    var _rtt_initializers = [];
    var _rtt_extraInitializers = [];
    var _encodedBitrate_decorators;
    var _encodedBitrate_initializers = [];
    var _encodedBitrate_extraInitializers = [];
    var _encodedFrameWidth_decorators;
    var _encodedFrameWidth_initializers = [];
    var _encodedFrameWidth_extraInitializers = [];
    var _encodedFrameHeight_decorators;
    var _encodedFrameHeight_initializers = [];
    var _encodedFrameHeight_extraInitializers = [];
    var _encodedFrameCount_decorators;
    var _encodedFrameCount_initializers = [];
    var _encodedFrameCount_extraInitializers = [];
    var _codecType_decorators;
    var _codecType_initializers = [];
    var _codecType_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _jitter_decorators;
    var _jitter_initializers = [];
    var _jitter_extraInitializers = [];
    var _videoDenoiseMode_decorators;
    var _videoDenoiseMode_initializers = [];
    var _videoDenoiseMode_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCLocalVideoStats_1() {
            this.sentKBitrate = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _sentKBitrate_initializers, void 0));
            this.inputFrameRate = (__runInitializers(this, _sentKBitrate_extraInitializers), __runInitializers(this, _inputFrameRate_initializers, void 0));
            this.sentFrameRate = (__runInitializers(this, _inputFrameRate_extraInitializers), __runInitializers(this, _sentFrameRate_initializers, void 0));
            this.encoderOutputFrameRate = (__runInitializers(this, _sentFrameRate_extraInitializers), __runInitializers(this, _encoderOutputFrameRate_initializers, void 0));
            this.rendererOutputFrameRate = (__runInitializers(this, _encoderOutputFrameRate_extraInitializers), __runInitializers(this, _rendererOutputFrameRate_initializers, void 0));
            this.statsInterval = (__runInitializers(this, _rendererOutputFrameRate_extraInitializers), __runInitializers(this, _statsInterval_initializers, void 0));
            this.videoLossRate = (__runInitializers(this, _statsInterval_extraInitializers), __runInitializers(this, _videoLossRate_initializers, void 0));
            this.rtt = (__runInitializers(this, _videoLossRate_extraInitializers), __runInitializers(this, _rtt_initializers, void 0));
            this.encodedBitrate = (__runInitializers(this, _rtt_extraInitializers), __runInitializers(this, _encodedBitrate_initializers, void 0));
            this.encodedFrameWidth = (__runInitializers(this, _encodedBitrate_extraInitializers), __runInitializers(this, _encodedFrameWidth_initializers, void 0));
            this.encodedFrameHeight = (__runInitializers(this, _encodedFrameWidth_extraInitializers), __runInitializers(this, _encodedFrameHeight_initializers, void 0));
            this.encodedFrameCount = (__runInitializers(this, _encodedFrameHeight_extraInitializers), __runInitializers(this, _encodedFrameCount_initializers, void 0));
            this.codecType = (__runInitializers(this, _encodedFrameCount_extraInitializers), __runInitializers(this, _codecType_initializers, void 0));
            this.isScreen = (__runInitializers(this, _codecType_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.jitter = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _jitter_initializers, void 0));
            this.videoDenoiseMode = (__runInitializers(this, _jitter_extraInitializers), __runInitializers(this, _videoDenoiseMode_initializers, void 0));
            __runInitializers(this, _videoDenoiseMode_extraInitializers);
        }
        ByteRTCLocalVideoStats_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCLocalVideoStats_1;
    }());
    __setFunctionName(_classThis, "ByteRTCLocalVideoStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _sentKBitrate_decorators = [NativeMember()];
        _inputFrameRate_decorators = [NativeMember()];
        _sentFrameRate_decorators = [NativeMember()];
        _encoderOutputFrameRate_decorators = [NativeMember()];
        _rendererOutputFrameRate_decorators = [NativeMember()];
        _statsInterval_decorators = [NativeMember()];
        _videoLossRate_decorators = [NativeMember()];
        _rtt_decorators = [NativeMember()];
        _encodedBitrate_decorators = [NativeMember()];
        _encodedFrameWidth_decorators = [NativeMember()];
        _encodedFrameHeight_decorators = [NativeMember()];
        _encodedFrameCount_decorators = [NativeMember()];
        _codecType_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _jitter_decorators = [NativeMember()];
        _videoDenoiseMode_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _sentKBitrate_decorators, { kind: "field", name: "sentKBitrate", static: false, private: false, access: { has: function (obj) { return "sentKBitrate" in obj; }, get: function (obj) { return obj.sentKBitrate; }, set: function (obj, value) { obj.sentKBitrate = value; } }, metadata: _metadata }, _sentKBitrate_initializers, _sentKBitrate_extraInitializers);
        __esDecorate(null, null, _inputFrameRate_decorators, { kind: "field", name: "inputFrameRate", static: false, private: false, access: { has: function (obj) { return "inputFrameRate" in obj; }, get: function (obj) { return obj.inputFrameRate; }, set: function (obj, value) { obj.inputFrameRate = value; } }, metadata: _metadata }, _inputFrameRate_initializers, _inputFrameRate_extraInitializers);
        __esDecorate(null, null, _sentFrameRate_decorators, { kind: "field", name: "sentFrameRate", static: false, private: false, access: { has: function (obj) { return "sentFrameRate" in obj; }, get: function (obj) { return obj.sentFrameRate; }, set: function (obj, value) { obj.sentFrameRate = value; } }, metadata: _metadata }, _sentFrameRate_initializers, _sentFrameRate_extraInitializers);
        __esDecorate(null, null, _encoderOutputFrameRate_decorators, { kind: "field", name: "encoderOutputFrameRate", static: false, private: false, access: { has: function (obj) { return "encoderOutputFrameRate" in obj; }, get: function (obj) { return obj.encoderOutputFrameRate; }, set: function (obj, value) { obj.encoderOutputFrameRate = value; } }, metadata: _metadata }, _encoderOutputFrameRate_initializers, _encoderOutputFrameRate_extraInitializers);
        __esDecorate(null, null, _rendererOutputFrameRate_decorators, { kind: "field", name: "rendererOutputFrameRate", static: false, private: false, access: { has: function (obj) { return "rendererOutputFrameRate" in obj; }, get: function (obj) { return obj.rendererOutputFrameRate; }, set: function (obj, value) { obj.rendererOutputFrameRate = value; } }, metadata: _metadata }, _rendererOutputFrameRate_initializers, _rendererOutputFrameRate_extraInitializers);
        __esDecorate(null, null, _statsInterval_decorators, { kind: "field", name: "statsInterval", static: false, private: false, access: { has: function (obj) { return "statsInterval" in obj; }, get: function (obj) { return obj.statsInterval; }, set: function (obj, value) { obj.statsInterval = value; } }, metadata: _metadata }, _statsInterval_initializers, _statsInterval_extraInitializers);
        __esDecorate(null, null, _videoLossRate_decorators, { kind: "field", name: "videoLossRate", static: false, private: false, access: { has: function (obj) { return "videoLossRate" in obj; }, get: function (obj) { return obj.videoLossRate; }, set: function (obj, value) { obj.videoLossRate = value; } }, metadata: _metadata }, _videoLossRate_initializers, _videoLossRate_extraInitializers);
        __esDecorate(null, null, _rtt_decorators, { kind: "field", name: "rtt", static: false, private: false, access: { has: function (obj) { return "rtt" in obj; }, get: function (obj) { return obj.rtt; }, set: function (obj, value) { obj.rtt = value; } }, metadata: _metadata }, _rtt_initializers, _rtt_extraInitializers);
        __esDecorate(null, null, _encodedBitrate_decorators, { kind: "field", name: "encodedBitrate", static: false, private: false, access: { has: function (obj) { return "encodedBitrate" in obj; }, get: function (obj) { return obj.encodedBitrate; }, set: function (obj, value) { obj.encodedBitrate = value; } }, metadata: _metadata }, _encodedBitrate_initializers, _encodedBitrate_extraInitializers);
        __esDecorate(null, null, _encodedFrameWidth_decorators, { kind: "field", name: "encodedFrameWidth", static: false, private: false, access: { has: function (obj) { return "encodedFrameWidth" in obj; }, get: function (obj) { return obj.encodedFrameWidth; }, set: function (obj, value) { obj.encodedFrameWidth = value; } }, metadata: _metadata }, _encodedFrameWidth_initializers, _encodedFrameWidth_extraInitializers);
        __esDecorate(null, null, _encodedFrameHeight_decorators, { kind: "field", name: "encodedFrameHeight", static: false, private: false, access: { has: function (obj) { return "encodedFrameHeight" in obj; }, get: function (obj) { return obj.encodedFrameHeight; }, set: function (obj, value) { obj.encodedFrameHeight = value; } }, metadata: _metadata }, _encodedFrameHeight_initializers, _encodedFrameHeight_extraInitializers);
        __esDecorate(null, null, _encodedFrameCount_decorators, { kind: "field", name: "encodedFrameCount", static: false, private: false, access: { has: function (obj) { return "encodedFrameCount" in obj; }, get: function (obj) { return obj.encodedFrameCount; }, set: function (obj, value) { obj.encodedFrameCount = value; } }, metadata: _metadata }, _encodedFrameCount_initializers, _encodedFrameCount_extraInitializers);
        __esDecorate(null, null, _codecType_decorators, { kind: "field", name: "codecType", static: false, private: false, access: { has: function (obj) { return "codecType" in obj; }, get: function (obj) { return obj.codecType; }, set: function (obj, value) { obj.codecType = value; } }, metadata: _metadata }, _codecType_initializers, _codecType_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _jitter_decorators, { kind: "field", name: "jitter", static: false, private: false, access: { has: function (obj) { return "jitter" in obj; }, get: function (obj) { return obj.jitter; }, set: function (obj, value) { obj.jitter = value; } }, metadata: _metadata }, _jitter_initializers, _jitter_extraInitializers);
        __esDecorate(null, null, _videoDenoiseMode_decorators, { kind: "field", name: "videoDenoiseMode", static: false, private: false, access: { has: function (obj) { return "videoDenoiseMode" in obj; }, get: function (obj) { return obj.videoDenoiseMode; }, set: function (obj, value) { obj.videoDenoiseMode = value; } }, metadata: _metadata }, _videoDenoiseMode_initializers, _videoDenoiseMode_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('ByteRTCStream')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _hasVideo_decorators;
    var _hasVideo_initializers = [];
    var _hasVideo_extraInitializers = [];
    var _hasAudio_decorators;
    var _hasAudio_initializers = [];
    var _hasAudio_extraInitializers = [];
    var _videoStreamDescriptions_decorators;
    var _videoStreamDescriptions_initializers = [];
    var _videoStreamDescriptions_extraInitializers = [];
    var _maxVideoStreamDescription_decorators;
    var _maxVideoStreamDescription_initializers = [];
    var _maxVideoStreamDescription_extraInitializers = [];
    var _index_decorators;
    var _index_initializers = [];
    var _index_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCStream_1() {
            this.userId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _userId_initializers, void 0));
            this.isScreen = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.hasVideo = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _hasVideo_initializers, void 0));
            this.hasAudio = (__runInitializers(this, _hasVideo_extraInitializers), __runInitializers(this, _hasAudio_initializers, void 0));
            this.videoStreamDescriptions = (__runInitializers(this, _hasAudio_extraInitializers), __runInitializers(this, _videoStreamDescriptions_initializers, void 0));
            this.maxVideoStreamDescription = (__runInitializers(this, _videoStreamDescriptions_extraInitializers), __runInitializers(this, _maxVideoStreamDescription_initializers, void 0));
            this.index = (__runInitializers(this, _maxVideoStreamDescription_extraInitializers), __runInitializers(this, _index_initializers, void 0));
            __runInitializers(this, _index_extraInitializers);
        }
        ByteRTCStream_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCStream_1;
    }());
    __setFunctionName(_classThis, "ByteRTCStream");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _userId_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _hasVideo_decorators = [NativeMember()];
        _hasAudio_decorators = [NativeMember()];
        _videoStreamDescriptions_decorators = [NativeMember()];
        _maxVideoStreamDescription_decorators = [NativeMember()];
        _index_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _hasVideo_decorators, { kind: "field", name: "hasVideo", static: false, private: false, access: { has: function (obj) { return "hasVideo" in obj; }, get: function (obj) { return obj.hasVideo; }, set: function (obj, value) { obj.hasVideo = value; } }, metadata: _metadata }, _hasVideo_initializers, _hasVideo_extraInitializers);
        __esDecorate(null, null, _hasAudio_decorators, { kind: "field", name: "hasAudio", static: false, private: false, access: { has: function (obj) { return "hasAudio" in obj; }, get: function (obj) { return obj.hasAudio; }, set: function (obj, value) { obj.hasAudio = value; } }, metadata: _metadata }, _hasAudio_initializers, _hasAudio_extraInitializers);
        __esDecorate(null, null, _videoStreamDescriptions_decorators, { kind: "field", name: "videoStreamDescriptions", static: false, private: false, access: { has: function (obj) { return "videoStreamDescriptions" in obj; }, get: function (obj) { return obj.videoStreamDescriptions; }, set: function (obj, value) { obj.videoStreamDescriptions = value; } }, metadata: _metadata }, _videoStreamDescriptions_initializers, _videoStreamDescriptions_extraInitializers);
        __esDecorate(null, null, _maxVideoStreamDescription_decorators, { kind: "field", name: "maxVideoStreamDescription", static: false, private: false, access: { has: function (obj) { return "maxVideoStreamDescription" in obj; }, get: function (obj) { return obj.maxVideoStreamDescription; }, set: function (obj, value) { obj.maxVideoStreamDescription = value; } }, metadata: _metadata }, _maxVideoStreamDescription_initializers, _maxVideoStreamDescription_extraInitializers);
        __esDecorate(null, null, _index_decorators, { kind: "field", name: "index", static: false, private: false, access: { has: function (obj) { return "index" in obj; }, get: function (obj) { return obj.index; }, set: function (obj, value) { obj.index = value; } }, metadata: _metadata }, _index_initializers, _index_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCPublicStreaming = function () {
    var _classDecorators = [NativeClass('ByteRTCPublicStreaming')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _instanceExtraInitializers = [];
    var _static_defaultPublicStreaming_decorators;
    var _layout_decorators;
    var _layout_initializers = [];
    var _layout_extraInitializers = [];
    var _video_decorators;
    var _video_initializers = [];
    var _video_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCPublicStreaming_1() {
            this.layout = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _layout_initializers, void 0));
            this.video = (__runInitializers(this, _layout_extraInitializers), __runInitializers(this, _video_initializers, void 0));
            __runInitializers(this, _video_extraInitializers);
        }
        ByteRTCPublicStreaming_1.defaultPublicStreaming = function () {
            throw new Error('not implement');
        };
        ByteRTCPublicStreaming_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCPublicStreaming_1;
    }());
    __setFunctionName(_classThis, "ByteRTCPublicStreaming");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_defaultPublicStreaming_decorators = [NativeStaticMethodSync('defaultPublicStreaming')];
        _layout_decorators = [NativeMember()];
        _video_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _static_defaultPublicStreaming_decorators, { kind: "method", name: "defaultPublicStreaming", static: true, private: false, access: { has: function (obj) { return "defaultPublicStreaming" in obj; }, get: function (obj) { return obj.defaultPublicStreaming; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _layout_decorators, { kind: "field", name: "layout", static: false, private: false, access: { has: function (obj) { return "layout" in obj; }, get: function (obj) { return obj.layout; }, set: function (obj, value) { obj.layout = value; } }, metadata: _metadata }, _layout_initializers, _layout_extraInitializers);
        __esDecorate(null, null, _video_decorators, { kind: "field", name: "video", static: false, private: false, access: { has: function (obj) { return "video" in obj; }, get: function (obj) { return obj.video; }, set: function (obj, value) { obj.video = value; } }, metadata: _metadata }, _video_initializers, _video_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _staticExtraInitializers);
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCScreenMediaType;
(function (ByteRTCScreenMediaType) {
    ByteRTCScreenMediaType[ByteRTCScreenMediaType["ByteRTCScreenMediaTypeVideoOnly"] = 0] = "ByteRTCScreenMediaTypeVideoOnly";
    ByteRTCScreenMediaType[ByteRTCScreenMediaType["ByteRTCScreenMediaTypeAudioOnly"] = 1] = "ByteRTCScreenMediaTypeAudioOnly";
    ByteRTCScreenMediaType[ByteRTCScreenMediaType["ByteRTCScreenMediaTypeVideoAndAudio"] = 2] = "ByteRTCScreenMediaTypeVideoAndAudio";
})(ByteRTCScreenMediaType || (ByteRTCScreenMediaType = {}));
var ByteRTCAudioRecordingConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCAudioRecordingConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _absoluteFileName_decorators;
    var _absoluteFileName_initializers = [];
    var _absoluteFileName_extraInitializers = [];
    var _frameSource_decorators;
    var _frameSource_initializers = [];
    var _frameSource_extraInitializers = [];
    var _sampleRate_decorators;
    var _sampleRate_initializers = [];
    var _sampleRate_extraInitializers = [];
    var _channel_decorators;
    var _channel_initializers = [];
    var _channel_extraInitializers = [];
    var _quality_decorators;
    var _quality_initializers = [];
    var _quality_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioRecordingConfig_1() {
            this.absoluteFileName = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _absoluteFileName_initializers, void 0));
            this.frameSource = (__runInitializers(this, _absoluteFileName_extraInitializers), __runInitializers(this, _frameSource_initializers, void 0));
            this.sampleRate = (__runInitializers(this, _frameSource_extraInitializers), __runInitializers(this, _sampleRate_initializers, void 0));
            this.channel = (__runInitializers(this, _sampleRate_extraInitializers), __runInitializers(this, _channel_initializers, void 0));
            this.quality = (__runInitializers(this, _channel_extraInitializers), __runInitializers(this, _quality_initializers, void 0));
            __runInitializers(this, _quality_extraInitializers);
        }
        ByteRTCAudioRecordingConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCAudioRecordingConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioRecordingConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _absoluteFileName_decorators = [NativeMember()];
        _frameSource_decorators = [NativeMember()];
        _sampleRate_decorators = [NativeMember()];
        _channel_decorators = [NativeMember()];
        _quality_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _absoluteFileName_decorators, { kind: "field", name: "absoluteFileName", static: false, private: false, access: { has: function (obj) { return "absoluteFileName" in obj; }, get: function (obj) { return obj.absoluteFileName; }, set: function (obj, value) { obj.absoluteFileName = value; } }, metadata: _metadata }, _absoluteFileName_initializers, _absoluteFileName_extraInitializers);
        __esDecorate(null, null, _frameSource_decorators, { kind: "field", name: "frameSource", static: false, private: false, access: { has: function (obj) { return "frameSource" in obj; }, get: function (obj) { return obj.frameSource; }, set: function (obj, value) { obj.frameSource = value; } }, metadata: _metadata }, _frameSource_initializers, _frameSource_extraInitializers);
        __esDecorate(null, null, _sampleRate_decorators, { kind: "field", name: "sampleRate", static: false, private: false, access: { has: function (obj) { return "sampleRate" in obj; }, get: function (obj) { return obj.sampleRate; }, set: function (obj, value) { obj.sampleRate = value; } }, metadata: _metadata }, _sampleRate_initializers, _sampleRate_extraInitializers);
        __esDecorate(null, null, _channel_decorators, { kind: "field", name: "channel", static: false, private: false, access: { has: function (obj) { return "channel" in obj; }, get: function (obj) { return obj.channel; }, set: function (obj, value) { obj.channel = value; } }, metadata: _metadata }, _channel_initializers, _channel_extraInitializers);
        __esDecorate(null, null, _quality_decorators, { kind: "field", name: "quality", static: false, private: false, access: { has: function (obj) { return "quality" in obj; }, get: function (obj) { return obj.quality; }, set: function (obj, value) { obj.quality = value; } }, metadata: _metadata }, _quality_initializers, _quality_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioFrameCallbackMethod;
(function (ByteRTCAudioFrameCallbackMethod) {
    ByteRTCAudioFrameCallbackMethod[ByteRTCAudioFrameCallbackMethod["ByteRTCAudioFrameCallbackRecord"] = 0] = "ByteRTCAudioFrameCallbackRecord";
    ByteRTCAudioFrameCallbackMethod[ByteRTCAudioFrameCallbackMethod["ByteRTCAudioFrameCallbackPlayback"] = 1] = "ByteRTCAudioFrameCallbackPlayback";
    ByteRTCAudioFrameCallbackMethod[ByteRTCAudioFrameCallbackMethod["ByteRTCAudioFrameCallbackMixed"] = 2] = "ByteRTCAudioFrameCallbackMixed";
    ByteRTCAudioFrameCallbackMethod[ByteRTCAudioFrameCallbackMethod["ByteRTCAudioFrameCallbackRemoteUser"] = 3] = "ByteRTCAudioFrameCallbackRemoteUser";
})(ByteRTCAudioFrameCallbackMethod || (ByteRTCAudioFrameCallbackMethod = {}));
var ByteRTCMixedStreamAlternateImageFillMode;
(function (ByteRTCMixedStreamAlternateImageFillMode) {
    ByteRTCMixedStreamAlternateImageFillMode[ByteRTCMixedStreamAlternateImageFillMode["ByteRTCMixedStreamAlternateImageFillModeFit"] = 0] = "ByteRTCMixedStreamAlternateImageFillModeFit";
    ByteRTCMixedStreamAlternateImageFillMode[ByteRTCMixedStreamAlternateImageFillMode["ByteRTCMixedStreamAlternateImageFillModeFill"] = 1] = "ByteRTCMixedStreamAlternateImageFillModeFill";
})(ByteRTCMixedStreamAlternateImageFillMode || (ByteRTCMixedStreamAlternateImageFillMode = {}));
var ByteRTCTranscoderLayoutRegionType;
(function (ByteRTCTranscoderLayoutRegionType) {
    ByteRTCTranscoderLayoutRegionType[ByteRTCTranscoderLayoutRegionType["ByteRTCTranscoderLayoutRegionTypeVideoStream"] = 0] = "ByteRTCTranscoderLayoutRegionTypeVideoStream";
    ByteRTCTranscoderLayoutRegionType[ByteRTCTranscoderLayoutRegionType["ByteRTCTranscoderLayoutRegionTypeImage"] = 1] = "ByteRTCTranscoderLayoutRegionTypeImage";
})(ByteRTCTranscoderLayoutRegionType || (ByteRTCTranscoderLayoutRegionType = {}));
var ByteRTCNetworkQuality;
(function (ByteRTCNetworkQuality) {
    ByteRTCNetworkQuality[ByteRTCNetworkQuality["ByteRTCNetworkQualityUnknown"] = 0] = "ByteRTCNetworkQualityUnknown";
    ByteRTCNetworkQuality[ByteRTCNetworkQuality["ByteRTCNetworkQualityExcellent"] = 1] = "ByteRTCNetworkQualityExcellent";
    ByteRTCNetworkQuality[ByteRTCNetworkQuality["ByteRTCNetworkQualityGood"] = 2] = "ByteRTCNetworkQualityGood";
    ByteRTCNetworkQuality[ByteRTCNetworkQuality["ByteRTCNetworkQualityPoor"] = 3] = "ByteRTCNetworkQualityPoor";
    ByteRTCNetworkQuality[ByteRTCNetworkQuality["ByteRTCNetworkQualityBad"] = 4] = "ByteRTCNetworkQualityBad";
    ByteRTCNetworkQuality[ByteRTCNetworkQuality["ByteRTCNetworkQualityVeryBad"] = 5] = "ByteRTCNetworkQualityVeryBad";
    ByteRTCNetworkQuality[ByteRTCNetworkQuality["ByteRTCNetworkQualityDown"] = 6] = "ByteRTCNetworkQualityDown";
})(ByteRTCNetworkQuality || (ByteRTCNetworkQuality = {}));
var ByteRTCStreamRemoveReason;
(function (ByteRTCStreamRemoveReason) {
    ByteRTCStreamRemoveReason[ByteRTCStreamRemoveReason["ByteRTCStreamRemoveReasonUnpublish"] = 0] = "ByteRTCStreamRemoveReasonUnpublish";
    ByteRTCStreamRemoveReason[ByteRTCStreamRemoveReason["ByteRTCStreamRemoveReasonPublishFailed"] = 1] = "ByteRTCStreamRemoveReasonPublishFailed";
    ByteRTCStreamRemoveReason[ByteRTCStreamRemoveReason["ByteRTCStreamRemoveReasonKeepLiveFailed"] = 2] = "ByteRTCStreamRemoveReasonKeepLiveFailed";
    ByteRTCStreamRemoveReason[ByteRTCStreamRemoveReason["ByteRTCStreamRemoveReasonClientDisconnected"] = 3] = "ByteRTCStreamRemoveReasonClientDisconnected";
    ByteRTCStreamRemoveReason[ByteRTCStreamRemoveReason["ByteRTCStreamRemoveReasonRepublish"] = 4] = "ByteRTCStreamRemoveReasonRepublish";
    ByteRTCStreamRemoveReason[ByteRTCStreamRemoveReason["ByteRTCStreamRemoveReasonOther"] = 5] = "ByteRTCStreamRemoveReasonOther";
    ByteRTCStreamRemoveReason[ByteRTCStreamRemoveReason["ByteRTCStreamRemoveReasonPublishPrivilegeExpired"] = 6] = "ByteRTCStreamRemoveReasonPublishPrivilegeExpired";
})(ByteRTCStreamRemoveReason || (ByteRTCStreamRemoveReason = {}));
var ByteRTCForwardStreamStateInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCForwardStreamStateInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _state_decorators;
    var _state_initializers = [];
    var _state_extraInitializers = [];
    var _error_decorators;
    var _error_initializers = [];
    var _error_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCForwardStreamStateInfo_1() {
            this.roomId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _roomId_initializers, void 0));
            this.state = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _state_initializers, void 0));
            this.error = (__runInitializers(this, _state_extraInitializers), __runInitializers(this, _error_initializers, void 0));
            __runInitializers(this, _error_extraInitializers);
        }
        ByteRTCForwardStreamStateInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCForwardStreamStateInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCForwardStreamStateInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _roomId_decorators = [NativeMember()];
        _state_decorators = [NativeMember()];
        _error_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _state_decorators, { kind: "field", name: "state", static: false, private: false, access: { has: function (obj) { return "state" in obj; }, get: function (obj) { return obj.state; }, set: function (obj, value) { obj.state = value; } }, metadata: _metadata }, _state_initializers, _state_extraInitializers);
        __esDecorate(null, null, _error_decorators, { kind: "field", name: "error", static: false, private: false, access: { has: function (obj) { return "error" in obj; }, get: function (obj) { return obj.error; }, set: function (obj, value) { obj.error = value; } }, metadata: _metadata }, _error_initializers, _error_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('ByteRTCSourceCropInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _locationX_decorators;
    var _locationX_initializers = [];
    var _locationX_extraInitializers = [];
    var _locationY_decorators;
    var _locationY_initializers = [];
    var _locationY_extraInitializers = [];
    var _widthProportion_decorators;
    var _widthProportion_initializers = [];
    var _widthProportion_extraInitializers = [];
    var _heightProportion_decorators;
    var _heightProportion_initializers = [];
    var _heightProportion_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCSourceCropInfo_1() {
            this.locationX = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _locationX_initializers, void 0));
            this.locationY = (__runInitializers(this, _locationX_extraInitializers), __runInitializers(this, _locationY_initializers, void 0));
            this.widthProportion = (__runInitializers(this, _locationY_extraInitializers), __runInitializers(this, _widthProportion_initializers, void 0));
            this.heightProportion = (__runInitializers(this, _widthProportion_extraInitializers), __runInitializers(this, _heightProportion_initializers, void 0));
            __runInitializers(this, _heightProportion_extraInitializers);
        }
        ByteRTCSourceCropInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCSourceCropInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCSourceCropInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _locationX_decorators = [NativeMember()];
        _locationY_decorators = [NativeMember()];
        _widthProportion_decorators = [NativeMember()];
        _heightProportion_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _locationX_decorators, { kind: "field", name: "locationX", static: false, private: false, access: { has: function (obj) { return "locationX" in obj; }, get: function (obj) { return obj.locationX; }, set: function (obj, value) { obj.locationX = value; } }, metadata: _metadata }, _locationX_initializers, _locationX_extraInitializers);
        __esDecorate(null, null, _locationY_decorators, { kind: "field", name: "locationY", static: false, private: false, access: { has: function (obj) { return "locationY" in obj; }, get: function (obj) { return obj.locationY; }, set: function (obj, value) { obj.locationY = value; } }, metadata: _metadata }, _locationY_initializers, _locationY_extraInitializers);
        __esDecorate(null, null, _widthProportion_decorators, { kind: "field", name: "widthProportion", static: false, private: false, access: { has: function (obj) { return "widthProportion" in obj; }, get: function (obj) { return obj.widthProportion; }, set: function (obj, value) { obj.widthProportion = value; } }, metadata: _metadata }, _widthProportion_initializers, _widthProportion_extraInitializers);
        __esDecorate(null, null, _heightProportion_decorators, { kind: "field", name: "heightProportion", static: false, private: false, access: { has: function (obj) { return "heightProportion" in obj; }, get: function (obj) { return obj.heightProportion; }, set: function (obj, value) { obj.heightProportion = value; } }, metadata: _metadata }, _heightProportion_initializers, _heightProportion_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCMulDimSingScoringMode;
(function (ByteRTCMulDimSingScoringMode) {
    ByteRTCMulDimSingScoringMode[ByteRTCMulDimSingScoringMode["ByteRTCMulDimSingScoringModeNote"] = 0] = "ByteRTCMulDimSingScoringModeNote";
})(ByteRTCMulDimSingScoringMode || (ByteRTCMulDimSingScoringMode = {}));
var ByteRTCAttenuationType;
(function (ByteRTCAttenuationType) {
    ByteRTCAttenuationType[ByteRTCAttenuationType["ByteRTCAttenuationTypeNone"] = 0] = "ByteRTCAttenuationTypeNone";
    ByteRTCAttenuationType[ByteRTCAttenuationType["ByteRTCAttenuationTypeLinear"] = 1] = "ByteRTCAttenuationTypeLinear";
    ByteRTCAttenuationType[ByteRTCAttenuationType["ByteRTCAttenuationTypeExponential"] = 2] = "ByteRTCAttenuationTypeExponential";
})(ByteRTCAttenuationType || (ByteRTCAttenuationType = {}));
var ByteRTCASRErrorCode;
(function (ByteRTCASRErrorCode) {
    ByteRTCASRErrorCode[ByteRTCASRErrorCode["ByteRTCASRErrorNetworkInterrupted"] = -1] = "ByteRTCASRErrorNetworkInterrupted";
    ByteRTCASRErrorCode[ByteRTCASRErrorCode["ByteRTCASRErrorAlreadyStarted"] = -2] = "ByteRTCASRErrorAlreadyStarted";
    ByteRTCASRErrorCode[ByteRTCASRErrorCode["ByteRTCASRErrorTokenEmpty"] = -3] = "ByteRTCASRErrorTokenEmpty";
    ByteRTCASRErrorCode[ByteRTCASRErrorCode["ByteRTCErrorSignatureKeyEmpty"] = -4] = "ByteRTCErrorSignatureKeyEmpty";
    ByteRTCASRErrorCode[ByteRTCASRErrorCode["ByteRTCASRErrorUserIdNull"] = -5] = "ByteRTCASRErrorUserIdNull";
    ByteRTCASRErrorCode[ByteRTCASRErrorCode["ByteRTCASRErrorAPPIDNull"] = -6] = "ByteRTCASRErrorAPPIDNull";
    ByteRTCASRErrorCode[ByteRTCASRErrorCode["ByteRTCASRErrorClusterNull"] = -7] = "ByteRTCASRErrorClusterNull";
    ByteRTCASRErrorCode[ByteRTCASRErrorCode["ByteRTCASRErrorOperationDenied"] = -8] = "ByteRTCASRErrorOperationDenied";
})(ByteRTCASRErrorCode || (ByteRTCASRErrorCode = {}));
var ByteRTCHotMusicInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCHotMusicInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _hotType_decorators;
    var _hotType_initializers = [];
    var _hotType_extraInitializers = [];
    var _hotName_decorators;
    var _hotName_initializers = [];
    var _hotName_extraInitializers = [];
    var _musics_decorators;
    var _musics_initializers = [];
    var _musics_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCHotMusicInfo_1() {
            this.hotType = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _hotType_initializers, void 0));
            this.hotName = (__runInitializers(this, _hotType_extraInitializers), __runInitializers(this, _hotName_initializers, void 0));
            this.musics = (__runInitializers(this, _hotName_extraInitializers), __runInitializers(this, _musics_initializers, void 0));
            __runInitializers(this, _musics_extraInitializers);
        }
        ByteRTCHotMusicInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCHotMusicInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCHotMusicInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _hotType_decorators = [NativeMember()];
        _hotName_decorators = [NativeMember()];
        _musics_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _hotType_decorators, { kind: "field", name: "hotType", static: false, private: false, access: { has: function (obj) { return "hotType" in obj; }, get: function (obj) { return obj.hotType; }, set: function (obj, value) { obj.hotType = value; } }, metadata: _metadata }, _hotType_initializers, _hotType_extraInitializers);
        __esDecorate(null, null, _hotName_decorators, { kind: "field", name: "hotName", static: false, private: false, access: { has: function (obj) { return "hotName" in obj; }, get: function (obj) { return obj.hotName; }, set: function (obj, value) { obj.hotName = value; } }, metadata: _metadata }, _hotName_initializers, _hotName_extraInitializers);
        __esDecorate(null, null, _musics_decorators, { kind: "field", name: "musics", static: false, private: false, access: { has: function (obj) { return "musics" in obj; }, get: function (obj) { return obj.musics; }, set: function (obj, value) { obj.musics = value; } }, metadata: _metadata }, _musics_initializers, _musics_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCLogLevel;
(function (ByteRTCLogLevel) {
    ByteRTCLogLevel[ByteRTCLogLevel["ByteRTCLogLevelTrace"] = 0] = "ByteRTCLogLevelTrace";
    ByteRTCLogLevel[ByteRTCLogLevel["ByteRTCLogLevelDebug"] = 1] = "ByteRTCLogLevelDebug";
    ByteRTCLogLevel[ByteRTCLogLevel["ByteRTCLogLevelInfo"] = 2] = "ByteRTCLogLevelInfo";
    ByteRTCLogLevel[ByteRTCLogLevel["ByteRTCLogLevelWarning"] = 3] = "ByteRTCLogLevelWarning";
    ByteRTCLogLevel[ByteRTCLogLevel["ByteRTCLogLevelError"] = 4] = "ByteRTCLogLevelError";
})(ByteRTCLogLevel || (ByteRTCLogLevel = {}));
var ByteRTCRemoteVideoRenderConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCRemoteVideoRenderConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _renderMode_decorators;
    var _renderMode_initializers = [];
    var _renderMode_extraInitializers = [];
    var _backgroundColor_decorators;
    var _backgroundColor_initializers = [];
    var _backgroundColor_extraInitializers = [];
    var _renderRotation_decorators;
    var _renderRotation_initializers = [];
    var _renderRotation_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRemoteVideoRenderConfig_1() {
            this.renderMode = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _renderMode_initializers, void 0));
            this.backgroundColor = (__runInitializers(this, _renderMode_extraInitializers), __runInitializers(this, _backgroundColor_initializers, void 0));
            this.renderRotation = (__runInitializers(this, _backgroundColor_extraInitializers), __runInitializers(this, _renderRotation_initializers, void 0));
            __runInitializers(this, _renderRotation_extraInitializers);
        }
        ByteRTCRemoteVideoRenderConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRemoteVideoRenderConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRemoteVideoRenderConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _renderMode_decorators = [NativeMember()];
        _backgroundColor_decorators = [NativeMember()];
        _renderRotation_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _renderMode_decorators, { kind: "field", name: "renderMode", static: false, private: false, access: { has: function (obj) { return "renderMode" in obj; }, get: function (obj) { return obj.renderMode; }, set: function (obj, value) { obj.renderMode = value; } }, metadata: _metadata }, _renderMode_initializers, _renderMode_extraInitializers);
        __esDecorate(null, null, _backgroundColor_decorators, { kind: "field", name: "backgroundColor", static: false, private: false, access: { has: function (obj) { return "backgroundColor" in obj; }, get: function (obj) { return obj.backgroundColor; }, set: function (obj, value) { obj.backgroundColor = value; } }, metadata: _metadata }, _backgroundColor_initializers, _backgroundColor_extraInitializers);
        __esDecorate(null, null, _renderRotation_decorators, { kind: "field", name: "renderRotation", static: false, private: false, access: { has: function (obj) { return "renderRotation" in obj; }, get: function (obj) { return obj.renderRotation; }, set: function (obj, value) { obj.renderRotation = value; } }, metadata: _metadata }, _renderRotation_initializers, _renderRotation_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioRenderType;
(function (ByteRTCAudioRenderType) {
    ByteRTCAudioRenderType[ByteRTCAudioRenderType["ByteRTCAudioRenderTypeExternal"] = 0] = "ByteRTCAudioRenderTypeExternal";
    ByteRTCAudioRenderType[ByteRTCAudioRenderType["ByteRTCAudioRenderTypeInternal"] = 1] = "ByteRTCAudioRenderTypeInternal";
})(ByteRTCAudioRenderType || (ByteRTCAudioRenderType = {}));
var ByteRTCVideoDeviceType;
(function (ByteRTCVideoDeviceType) {
    ByteRTCVideoDeviceType[ByteRTCVideoDeviceType["ByteRTCVideoDeviceTypeUnknown"] = -1] = "ByteRTCVideoDeviceTypeUnknown";
    ByteRTCVideoDeviceType[ByteRTCVideoDeviceType["ByteRTCVideoDeviceTypeRenderDevice"] = 0] = "ByteRTCVideoDeviceTypeRenderDevice";
    ByteRTCVideoDeviceType[ByteRTCVideoDeviceType["ByteRTCVideoDeviceTypeCaptureDevice"] = 1] = "ByteRTCVideoDeviceTypeCaptureDevice";
    ByteRTCVideoDeviceType[ByteRTCVideoDeviceType["ByteRTCVideoDeviceTypeScreenCaptureDevice"] = 2] = "ByteRTCVideoDeviceTypeScreenCaptureDevice";
})(ByteRTCVideoDeviceType || (ByteRTCVideoDeviceType = {}));
var ByteRTCVideoOrientation;
(function (ByteRTCVideoOrientation) {
    ByteRTCVideoOrientation[ByteRTCVideoOrientation["ByteRTCVideoOrientationAdaptive"] = 0] = "ByteRTCVideoOrientationAdaptive";
    ByteRTCVideoOrientation[ByteRTCVideoOrientation["ByteRTCVideoOrientationPortrait"] = 1] = "ByteRTCVideoOrientationPortrait";
    ByteRTCVideoOrientation[ByteRTCVideoOrientation["ByteRTCVideoOrientationLandscape"] = 2] = "ByteRTCVideoOrientationLandscape";
})(ByteRTCVideoOrientation || (ByteRTCVideoOrientation = {}));
var ByteRTCSingScoringRealtimeInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCSingScoringRealtimeInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _currentPosition_decorators;
    var _currentPosition_initializers = [];
    var _currentPosition_extraInitializers = [];
    var _userPitch_decorators;
    var _userPitch_initializers = [];
    var _userPitch_extraInitializers = [];
    var _standardPitch_decorators;
    var _standardPitch_initializers = [];
    var _standardPitch_extraInitializers = [];
    var _sentenceIndex_decorators;
    var _sentenceIndex_initializers = [];
    var _sentenceIndex_extraInitializers = [];
    var _sentenceScore_decorators;
    var _sentenceScore_initializers = [];
    var _sentenceScore_extraInitializers = [];
    var _totalScore_decorators;
    var _totalScore_initializers = [];
    var _totalScore_extraInitializers = [];
    var _averageScore_decorators;
    var _averageScore_initializers = [];
    var _averageScore_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCSingScoringRealtimeInfo_1() {
            this.currentPosition = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _currentPosition_initializers, void 0));
            this.userPitch = (__runInitializers(this, _currentPosition_extraInitializers), __runInitializers(this, _userPitch_initializers, void 0));
            this.standardPitch = (__runInitializers(this, _userPitch_extraInitializers), __runInitializers(this, _standardPitch_initializers, void 0));
            this.sentenceIndex = (__runInitializers(this, _standardPitch_extraInitializers), __runInitializers(this, _sentenceIndex_initializers, void 0));
            this.sentenceScore = (__runInitializers(this, _sentenceIndex_extraInitializers), __runInitializers(this, _sentenceScore_initializers, void 0));
            this.totalScore = (__runInitializers(this, _sentenceScore_extraInitializers), __runInitializers(this, _totalScore_initializers, void 0));
            this.averageScore = (__runInitializers(this, _totalScore_extraInitializers), __runInitializers(this, _averageScore_initializers, void 0));
            __runInitializers(this, _averageScore_extraInitializers);
        }
        ByteRTCSingScoringRealtimeInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCSingScoringRealtimeInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCSingScoringRealtimeInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _currentPosition_decorators = [NativeMember()];
        _userPitch_decorators = [NativeMember()];
        _standardPitch_decorators = [NativeMember()];
        _sentenceIndex_decorators = [NativeMember()];
        _sentenceScore_decorators = [NativeMember()];
        _totalScore_decorators = [NativeMember()];
        _averageScore_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _currentPosition_decorators, { kind: "field", name: "currentPosition", static: false, private: false, access: { has: function (obj) { return "currentPosition" in obj; }, get: function (obj) { return obj.currentPosition; }, set: function (obj, value) { obj.currentPosition = value; } }, metadata: _metadata }, _currentPosition_initializers, _currentPosition_extraInitializers);
        __esDecorate(null, null, _userPitch_decorators, { kind: "field", name: "userPitch", static: false, private: false, access: { has: function (obj) { return "userPitch" in obj; }, get: function (obj) { return obj.userPitch; }, set: function (obj, value) { obj.userPitch = value; } }, metadata: _metadata }, _userPitch_initializers, _userPitch_extraInitializers);
        __esDecorate(null, null, _standardPitch_decorators, { kind: "field", name: "standardPitch", static: false, private: false, access: { has: function (obj) { return "standardPitch" in obj; }, get: function (obj) { return obj.standardPitch; }, set: function (obj, value) { obj.standardPitch = value; } }, metadata: _metadata }, _standardPitch_initializers, _standardPitch_extraInitializers);
        __esDecorate(null, null, _sentenceIndex_decorators, { kind: "field", name: "sentenceIndex", static: false, private: false, access: { has: function (obj) { return "sentenceIndex" in obj; }, get: function (obj) { return obj.sentenceIndex; }, set: function (obj, value) { obj.sentenceIndex = value; } }, metadata: _metadata }, _sentenceIndex_initializers, _sentenceIndex_extraInitializers);
        __esDecorate(null, null, _sentenceScore_decorators, { kind: "field", name: "sentenceScore", static: false, private: false, access: { has: function (obj) { return "sentenceScore" in obj; }, get: function (obj) { return obj.sentenceScore; }, set: function (obj, value) { obj.sentenceScore = value; } }, metadata: _metadata }, _sentenceScore_initializers, _sentenceScore_extraInitializers);
        __esDecorate(null, null, _totalScore_decorators, { kind: "field", name: "totalScore", static: false, private: false, access: { has: function (obj) { return "totalScore" in obj; }, get: function (obj) { return obj.totalScore; }, set: function (obj, value) { obj.totalScore = value; } }, metadata: _metadata }, _totalScore_initializers, _totalScore_extraInitializers);
        __esDecorate(null, null, _averageScore_decorators, { kind: "field", name: "averageScore", static: false, private: false, access: { has: function (obj) { return "averageScore" in obj; }, get: function (obj) { return obj.averageScore; }, set: function (obj, value) { obj.averageScore = value; } }, metadata: _metadata }, _averageScore_initializers, _averageScore_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAlphaLayout;
(function (ByteRTCAlphaLayout) {
    ByteRTCAlphaLayout[ByteRTCAlphaLayout["ByteRTCAlphaLayoutTop"] = 0] = "ByteRTCAlphaLayoutTop";
    ByteRTCAlphaLayout[ByteRTCAlphaLayout["ByteRTCAlphaLayoutBottom"] = 1] = "ByteRTCAlphaLayoutBottom";
    ByteRTCAlphaLayout[ByteRTCAlphaLayout["ByteRTCAlphaLayoutLeft"] = 2] = "ByteRTCAlphaLayoutLeft";
    ByteRTCAlphaLayout[ByteRTCAlphaLayout["ByteRTCAlphaLayoutRight"] = 3] = "ByteRTCAlphaLayoutRight";
})(ByteRTCAlphaLayout || (ByteRTCAlphaLayout = {}));
var ByteRTCVideoFrameInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCVideoFrameInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _rotation_decorators;
    var _rotation_initializers = [];
    var _rotation_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoFrameInfo_1() {
            this.width = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.rotation = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _rotation_initializers, void 0));
            __runInitializers(this, _rotation_extraInitializers);
        }
        ByteRTCVideoFrameInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVideoFrameInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoFrameInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _rotation_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _rotation_decorators, { kind: "field", name: "rotation", static: false, private: false, access: { has: function (obj) { return "rotation" in obj; }, get: function (obj) { return obj.rotation; }, set: function (obj, value) { obj.rotation = value; } }, metadata: _metadata }, _rotation_initializers, _rotation_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCProblemFeedbackRoomInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCProblemFeedbackRoomInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCProblemFeedbackRoomInfo_1() {
            this.roomId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _roomId_initializers, void 0));
            this.userId = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _userId_initializers, void 0));
            __runInitializers(this, _userId_extraInitializers);
        }
        ByteRTCProblemFeedbackRoomInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCProblemFeedbackRoomInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCProblemFeedbackRoomInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _roomId_decorators = [NativeMember()];
        _userId_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCSetRoomExtraInfoResult;
(function (ByteRTCSetRoomExtraInfoResult) {
    ByteRTCSetRoomExtraInfoResult[ByteRTCSetRoomExtraInfoResult["ByteRTCSetRoomExtraInfoResultSuccess"] = 0] = "ByteRTCSetRoomExtraInfoResultSuccess";
    ByteRTCSetRoomExtraInfoResult[ByteRTCSetRoomExtraInfoResult["ByteRTCSetRoomExtraInfoResultNotJoinRoom"] = -1] = "ByteRTCSetRoomExtraInfoResultNotJoinRoom";
    ByteRTCSetRoomExtraInfoResult[ByteRTCSetRoomExtraInfoResult["ByteRTCSetRoomExtraInfoResultKeyIsNull"] = -2] = "ByteRTCSetRoomExtraInfoResultKeyIsNull";
    ByteRTCSetRoomExtraInfoResult[ByteRTCSetRoomExtraInfoResult["ByteRTCSetRoomExtraInfoResultValueIsNull"] = -3] = "ByteRTCSetRoomExtraInfoResultValueIsNull";
    ByteRTCSetRoomExtraInfoResult[ByteRTCSetRoomExtraInfoResult["ByteRTCSetRoomExtraInfoResultUnknow"] = -99] = "ByteRTCSetRoomExtraInfoResultUnknow";
    ByteRTCSetRoomExtraInfoResult[ByteRTCSetRoomExtraInfoResult["ByteRTCSetRoomExtraInfoResultKeyIsEmpty"] = -400] = "ByteRTCSetRoomExtraInfoResultKeyIsEmpty";
    ByteRTCSetRoomExtraInfoResult[ByteRTCSetRoomExtraInfoResult["ByteRTCSetRoomExtraInfoResultTooOften"] = -406] = "ByteRTCSetRoomExtraInfoResultTooOften";
    ByteRTCSetRoomExtraInfoResult[ByteRTCSetRoomExtraInfoResult["ByteRTCSetRoomExtraInfoResultSilentUser"] = -412] = "ByteRTCSetRoomExtraInfoResultSilentUser";
    ByteRTCSetRoomExtraInfoResult[ByteRTCSetRoomExtraInfoResult["ByteRTCSetRoomExtraInfoResultKeyTooLong"] = -413] = "ByteRTCSetRoomExtraInfoResultKeyTooLong";
    ByteRTCSetRoomExtraInfoResult[ByteRTCSetRoomExtraInfoResult["ByteRTCSetRoomExtraInfoResultValueTooLong"] = -414] = "ByteRTCSetRoomExtraInfoResultValueTooLong";
    ByteRTCSetRoomExtraInfoResult[ByteRTCSetRoomExtraInfoResult["ByteRTCSetRoomExtraInfoResultServerError"] = -500] = "ByteRTCSetRoomExtraInfoResultServerError";
})(ByteRTCSetRoomExtraInfoResult || (ByteRTCSetRoomExtraInfoResult = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCAudioVolumeInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _uid_decorators;
    var _uid_initializers = [];
    var _uid_extraInitializers = [];
    var _linearVolume_decorators;
    var _linearVolume_initializers = [];
    var _linearVolume_extraInitializers = [];
    var _nonlinearVolume_decorators;
    var _nonlinearVolume_initializers = [];
    var _nonlinearVolume_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioVolumeInfo_1() {
            this.uid = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _uid_initializers, void 0));
            this.linearVolume = (__runInitializers(this, _uid_extraInitializers), __runInitializers(this, _linearVolume_initializers, void 0));
            this.nonlinearVolume = (__runInitializers(this, _linearVolume_extraInitializers), __runInitializers(this, _nonlinearVolume_initializers, void 0));
            __runInitializers(this, _nonlinearVolume_extraInitializers);
        }
        ByteRTCAudioVolumeInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCAudioVolumeInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioVolumeInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _uid_decorators = [NativeMember()];
        _linearVolume_decorators = [NativeMember()];
        _nonlinearVolume_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _uid_decorators, { kind: "field", name: "uid", static: false, private: false, access: { has: function (obj) { return "uid" in obj; }, get: function (obj) { return obj.uid; }, set: function (obj, value) { obj.uid = value; } }, metadata: _metadata }, _uid_initializers, _uid_extraInitializers);
        __esDecorate(null, null, _linearVolume_decorators, { kind: "field", name: "linearVolume", static: false, private: false, access: { has: function (obj) { return "linearVolume" in obj; }, get: function (obj) { return obj.linearVolume; }, set: function (obj, value) { obj.linearVolume = value; } }, metadata: _metadata }, _linearVolume_initializers, _linearVolume_extraInitializers);
        __esDecorate(null, null, _nonlinearVolume_decorators, { kind: "field", name: "nonlinearVolume", static: false, private: false, access: { has: function (obj) { return "nonlinearVolume" in obj; }, get: function (obj) { return obj.nonlinearVolume; }, set: function (obj, value) { obj.nonlinearVolume = value; } }, metadata: _metadata }, _nonlinearVolume_initializers, _nonlinearVolume_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
(function () {
    var _classDecorators = [NativeClass('ByteRTCLocalProxyInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _localProxyType_decorators;
    var _localProxyType_initializers = [];
    var _localProxyType_extraInitializers = [];
    var _localProxyIp_decorators;
    var _localProxyIp_initializers = [];
    var _localProxyIp_extraInitializers = [];
    var _localProxyPort_decorators;
    var _localProxyPort_initializers = [];
    var _localProxyPort_extraInitializers = [];
    var _localProxyUsername_decorators;
    var _localProxyUsername_initializers = [];
    var _localProxyUsername_extraInitializers = [];
    var _localProxyPassword_decorators;
    var _localProxyPassword_initializers = [];
    var _localProxyPassword_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCLocalProxyInfo_1() {
            this.localProxyType = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _localProxyType_initializers, void 0));
            this.localProxyIp = (__runInitializers(this, _localProxyType_extraInitializers), __runInitializers(this, _localProxyIp_initializers, void 0));
            this.localProxyPort = (__runInitializers(this, _localProxyIp_extraInitializers), __runInitializers(this, _localProxyPort_initializers, void 0));
            this.localProxyUsername = (__runInitializers(this, _localProxyPort_extraInitializers), __runInitializers(this, _localProxyUsername_initializers, void 0));
            this.localProxyPassword = (__runInitializers(this, _localProxyUsername_extraInitializers), __runInitializers(this, _localProxyPassword_initializers, void 0));
            __runInitializers(this, _localProxyPassword_extraInitializers);
        }
        ByteRTCLocalProxyInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCLocalProxyInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCLocalProxyInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _localProxyType_decorators = [NativeMember()];
        _localProxyIp_decorators = [NativeMember()];
        _localProxyPort_decorators = [NativeMember()];
        _localProxyUsername_decorators = [NativeMember()];
        _localProxyPassword_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _localProxyType_decorators, { kind: "field", name: "localProxyType", static: false, private: false, access: { has: function (obj) { return "localProxyType" in obj; }, get: function (obj) { return obj.localProxyType; }, set: function (obj, value) { obj.localProxyType = value; } }, metadata: _metadata }, _localProxyType_initializers, _localProxyType_extraInitializers);
        __esDecorate(null, null, _localProxyIp_decorators, { kind: "field", name: "localProxyIp", static: false, private: false, access: { has: function (obj) { return "localProxyIp" in obj; }, get: function (obj) { return obj.localProxyIp; }, set: function (obj, value) { obj.localProxyIp = value; } }, metadata: _metadata }, _localProxyIp_initializers, _localProxyIp_extraInitializers);
        __esDecorate(null, null, _localProxyPort_decorators, { kind: "field", name: "localProxyPort", static: false, private: false, access: { has: function (obj) { return "localProxyPort" in obj; }, get: function (obj) { return obj.localProxyPort; }, set: function (obj, value) { obj.localProxyPort = value; } }, metadata: _metadata }, _localProxyPort_initializers, _localProxyPort_extraInitializers);
        __esDecorate(null, null, _localProxyUsername_decorators, { kind: "field", name: "localProxyUsername", static: false, private: false, access: { has: function (obj) { return "localProxyUsername" in obj; }, get: function (obj) { return obj.localProxyUsername; }, set: function (obj, value) { obj.localProxyUsername = value; } }, metadata: _metadata }, _localProxyUsername_initializers, _localProxyUsername_extraInitializers);
        __esDecorate(null, null, _localProxyPassword_decorators, { kind: "field", name: "localProxyPassword", static: false, private: false, access: { has: function (obj) { return "localProxyPassword" in obj; }, get: function (obj) { return obj.localProxyPassword; }, set: function (obj, value) { obj.localProxyPassword = value; } }, metadata: _metadata }, _localProxyPassword_initializers, _localProxyPassword_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCASRConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCASRConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _appId_decorators;
    var _appId_initializers = [];
    var _appId_extraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _accessToken_decorators;
    var _accessToken_initializers = [];
    var _accessToken_extraInitializers = [];
    var _secretKey_decorators;
    var _secretKey_initializers = [];
    var _secretKey_extraInitializers = [];
    var _cluster_decorators;
    var _cluster_initializers = [];
    var _cluster_extraInitializers = [];
    var _authorizationType_decorators;
    var _authorizationType_initializers = [];
    var _authorizationType_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCASRConfig_1() {
            this.appId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _appId_initializers, void 0));
            this.userId = (__runInitializers(this, _appId_extraInitializers), __runInitializers(this, _userId_initializers, void 0));
            this.accessToken = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _accessToken_initializers, void 0));
            this.secretKey = (__runInitializers(this, _accessToken_extraInitializers), __runInitializers(this, _secretKey_initializers, void 0));
            this.cluster = (__runInitializers(this, _secretKey_extraInitializers), __runInitializers(this, _cluster_initializers, void 0));
            this.authorizationType = (__runInitializers(this, _cluster_extraInitializers), __runInitializers(this, _authorizationType_initializers, void 0));
            __runInitializers(this, _authorizationType_extraInitializers);
        }
        ByteRTCASRConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCASRConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCASRConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _appId_decorators = [NativeMember()];
        _userId_decorators = [NativeMember()];
        _accessToken_decorators = [NativeMember()];
        _secretKey_decorators = [NativeMember()];
        _cluster_decorators = [NativeMember()];
        _authorizationType_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _appId_decorators, { kind: "field", name: "appId", static: false, private: false, access: { has: function (obj) { return "appId" in obj; }, get: function (obj) { return obj.appId; }, set: function (obj, value) { obj.appId = value; } }, metadata: _metadata }, _appId_initializers, _appId_extraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _accessToken_decorators, { kind: "field", name: "accessToken", static: false, private: false, access: { has: function (obj) { return "accessToken" in obj; }, get: function (obj) { return obj.accessToken; }, set: function (obj, value) { obj.accessToken = value; } }, metadata: _metadata }, _accessToken_initializers, _accessToken_extraInitializers);
        __esDecorate(null, null, _secretKey_decorators, { kind: "field", name: "secretKey", static: false, private: false, access: { has: function (obj) { return "secretKey" in obj; }, get: function (obj) { return obj.secretKey; }, set: function (obj, value) { obj.secretKey = value; } }, metadata: _metadata }, _secretKey_initializers, _secretKey_extraInitializers);
        __esDecorate(null, null, _cluster_decorators, { kind: "field", name: "cluster", static: false, private: false, access: { has: function (obj) { return "cluster" in obj; }, get: function (obj) { return obj.cluster; }, set: function (obj, value) { obj.cluster = value; } }, metadata: _metadata }, _cluster_initializers, _cluster_extraInitializers);
        __esDecorate(null, null, _authorizationType_decorators, { kind: "field", name: "authorizationType", static: false, private: false, access: { has: function (obj) { return "authorizationType" in obj; }, get: function (obj) { return obj.authorizationType; }, set: function (obj, value) { obj.authorizationType = value; } }, metadata: _metadata }, _authorizationType_initializers, _authorizationType_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCMixedStreamMediaType;
(function (ByteRTCMixedStreamMediaType) {
    ByteRTCMixedStreamMediaType[ByteRTCMixedStreamMediaType["ByteRTCMixedStreamMediaTypeAudioAndVideo"] = 0] = "ByteRTCMixedStreamMediaTypeAudioAndVideo";
    ByteRTCMixedStreamMediaType[ByteRTCMixedStreamMediaType["ByteRTCMixedStreamMediaTypeAudioOnly"] = 1] = "ByteRTCMixedStreamMediaTypeAudioOnly";
    ByteRTCMixedStreamMediaType[ByteRTCMixedStreamMediaType["ByteRTCMixedStreamMediaTypeVideoOnly"] = 2] = "ByteRTCMixedStreamMediaTypeVideoOnly";
})(ByteRTCMixedStreamMediaType || (ByteRTCMixedStreamMediaType = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCTranscodingAudioConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _instanceExtraInitializers = [];
    var _static_toStringWithProfile_decorators;
    var _codec_decorators;
    var _codec_initializers = [];
    var _codec_extraInitializers = [];
    var _sampleRate_decorators;
    var _sampleRate_initializers = [];
    var _sampleRate_extraInitializers = [];
    var _channels_decorators;
    var _channels_initializers = [];
    var _channels_extraInitializers = [];
    var _kBitRate_decorators;
    var _kBitRate_initializers = [];
    var _kBitRate_extraInitializers = [];
    var _profile_decorators;
    var _profile_initializers = [];
    var _profile_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCTranscodingAudioConfig_1() {
            this.codec = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _codec_initializers, void 0));
            this.sampleRate = (__runInitializers(this, _codec_extraInitializers), __runInitializers(this, _sampleRate_initializers, void 0));
            this.channels = (__runInitializers(this, _sampleRate_extraInitializers), __runInitializers(this, _channels_initializers, void 0));
            this.kBitRate = (__runInitializers(this, _channels_extraInitializers), __runInitializers(this, _kBitRate_initializers, void 0));
            this.profile = (__runInitializers(this, _kBitRate_extraInitializers), __runInitializers(this, _profile_initializers, void 0));
            __runInitializers(this, _profile_extraInitializers);
        }
        ByteRTCTranscodingAudioConfig_1.toStringWithProfile = function (aacProfile) {
            throw new Error('not implement');
        };
        ByteRTCTranscodingAudioConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCTranscodingAudioConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCTranscodingAudioConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_toStringWithProfile_decorators = [NativeStaticMethodSync('toStringWithProfile:')];
        _codec_decorators = [NativeMember()];
        _sampleRate_decorators = [NativeMember()];
        _channels_decorators = [NativeMember()];
        _kBitRate_decorators = [NativeMember()];
        _profile_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _static_toStringWithProfile_decorators, { kind: "method", name: "toStringWithProfile", static: true, private: false, access: { has: function (obj) { return "toStringWithProfile" in obj; }, get: function (obj) { return obj.toStringWithProfile; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _codec_decorators, { kind: "field", name: "codec", static: false, private: false, access: { has: function (obj) { return "codec" in obj; }, get: function (obj) { return obj.codec; }, set: function (obj, value) { obj.codec = value; } }, metadata: _metadata }, _codec_initializers, _codec_extraInitializers);
        __esDecorate(null, null, _sampleRate_decorators, { kind: "field", name: "sampleRate", static: false, private: false, access: { has: function (obj) { return "sampleRate" in obj; }, get: function (obj) { return obj.sampleRate; }, set: function (obj, value) { obj.sampleRate = value; } }, metadata: _metadata }, _sampleRate_initializers, _sampleRate_extraInitializers);
        __esDecorate(null, null, _channels_decorators, { kind: "field", name: "channels", static: false, private: false, access: { has: function (obj) { return "channels" in obj; }, get: function (obj) { return obj.channels; }, set: function (obj, value) { obj.channels = value; } }, metadata: _metadata }, _channels_initializers, _channels_extraInitializers);
        __esDecorate(null, null, _kBitRate_decorators, { kind: "field", name: "kBitRate", static: false, private: false, access: { has: function (obj) { return "kBitRate" in obj; }, get: function (obj) { return obj.kBitRate; }, set: function (obj, value) { obj.kBitRate = value; } }, metadata: _metadata }, _kBitRate_initializers, _kBitRate_extraInitializers);
        __esDecorate(null, null, _profile_decorators, { kind: "field", name: "profile", static: false, private: false, access: { has: function (obj) { return "profile" in obj; }, get: function (obj) { return obj.profile; }, set: function (obj, value) { obj.profile = value; } }, metadata: _metadata }, _profile_initializers, _profile_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _staticExtraInitializers);
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCMusicHotType;
(function (ByteRTCMusicHotType) {
    ByteRTCMusicHotType[ByteRTCMusicHotType["ByteRTCMusicHotTypeContentCenter"] = 1] = "ByteRTCMusicHotTypeContentCenter";
    ByteRTCMusicHotType[ByteRTCMusicHotType["ByteRTCMusicHotTypeProject"] = 2] = "ByteRTCMusicHotTypeProject";
})(ByteRTCMusicHotType || (ByteRTCMusicHotType = {}));
var ByteRTCRecordingProgress = function () {
    var _classDecorators = [NativeClass('ByteRTCRecordingProgress')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _duration_decorators;
    var _duration_initializers = [];
    var _duration_extraInitializers = [];
    var _fileSize_decorators;
    var _fileSize_initializers = [];
    var _fileSize_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRecordingProgress_1() {
            this.duration = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _duration_initializers, void 0));
            this.fileSize = (__runInitializers(this, _duration_extraInitializers), __runInitializers(this, _fileSize_initializers, void 0));
            __runInitializers(this, _fileSize_extraInitializers);
        }
        ByteRTCRecordingProgress_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRecordingProgress_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRecordingProgress");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _duration_decorators = [NativeMember()];
        _fileSize_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _duration_decorators, { kind: "field", name: "duration", static: false, private: false, access: { has: function (obj) { return "duration" in obj; }, get: function (obj) { return obj.duration; }, set: function (obj, value) { obj.duration = value; } }, metadata: _metadata }, _duration_initializers, _duration_extraInitializers);
        __esDecorate(null, null, _fileSize_decorators, { kind: "field", name: "fileSize", static: false, private: false, access: { has: function (obj) { return "fileSize" in obj; }, get: function (obj) { return obj.fileSize; }, set: function (obj, value) { obj.fileSize = value; } }, metadata: _metadata }, _fileSize_initializers, _fileSize_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioSelectionPriority;
(function (ByteRTCAudioSelectionPriority) {
    ByteRTCAudioSelectionPriority[ByteRTCAudioSelectionPriority["ByteRTCAudioSelectionPriorityNormal"] = 0] = "ByteRTCAudioSelectionPriorityNormal";
    ByteRTCAudioSelectionPriority[ByteRTCAudioSelectionPriority["ByteRTCAudioSelectionPriorityHigh"] = 1] = "ByteRTCAudioSelectionPriorityHigh";
})(ByteRTCAudioSelectionPriority || (ByteRTCAudioSelectionPriority = {}));
var ByteRTCStreamMixingEvent;
(function (ByteRTCStreamMixingEvent) {
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventBase"] = 0] = "ByteRTCStreamMixingEventBase";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStart"] = 1] = "ByteRTCStreamMixingEventStart";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStartSuccess"] = 2] = "ByteRTCStreamMixingEventStartSuccess";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStartFailed"] = 3] = "ByteRTCStreamMixingEventStartFailed";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventUpdate"] = 4] = "ByteRTCStreamMixingEventUpdate";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventUpdateSuccess"] = 5] = "ByteRTCStreamMixingEventUpdateSuccess";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventUpdateFailed"] = 6] = "ByteRTCStreamMixingEventUpdateFailed";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStop"] = 7] = "ByteRTCStreamMixingEventStop";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStopSuccess"] = 8] = "ByteRTCStreamMixingEventStopSuccess";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStopFailed"] = 9] = "ByteRTCStreamMixingEventStopFailed";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventChangeMixType"] = 10] = "ByteRTCStreamMixingEventChangeMixType";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventFirstAudioFrameByClientMixer"] = 11] = "ByteRTCStreamMixingEventFirstAudioFrameByClientMixer";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventFirstVideoFrameByClientMixer"] = 12] = "ByteRTCStreamMixingEventFirstVideoFrameByClientMixer";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventUpdateTimeout"] = 13] = "ByteRTCStreamMixingEventUpdateTimeout";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStartTimeout"] = 14] = "ByteRTCStreamMixingEventStartTimeout";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventRequestParamError"] = 15] = "ByteRTCStreamMixingEventRequestParamError";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventMixImage"] = 16] = "ByteRTCStreamMixingEventMixImage";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventSingleWayChorus"] = 17] = "ByteRTCStreamMixingEventSingleWayChorus";
})(ByteRTCStreamMixingEvent || (ByteRTCStreamMixingEvent = {}));
var ByteRTCAudioSampleRate;
(function (ByteRTCAudioSampleRate) {
    ByteRTCAudioSampleRate[ByteRTCAudioSampleRate["ByteRTCAudioSampleRateAuto"] = -1] = "ByteRTCAudioSampleRateAuto";
    ByteRTCAudioSampleRate[ByteRTCAudioSampleRate["ByteRTCAudioSampleRate8000"] = 8000] = "ByteRTCAudioSampleRate8000";
    ByteRTCAudioSampleRate[ByteRTCAudioSampleRate["ByteRTCAudioSampleRate16000"] = 16000] = "ByteRTCAudioSampleRate16000";
    ByteRTCAudioSampleRate[ByteRTCAudioSampleRate["ByteRTCAudioSampleRate32000"] = 32000] = "ByteRTCAudioSampleRate32000";
    ByteRTCAudioSampleRate[ByteRTCAudioSampleRate["ByteRTCAudioSampleRate44100"] = 44100] = "ByteRTCAudioSampleRate44100";
    ByteRTCAudioSampleRate[ByteRTCAudioSampleRate["ByteRTCAudioSampleRate48000"] = 48000] = "ByteRTCAudioSampleRate48000";
})(ByteRTCAudioSampleRate || (ByteRTCAudioSampleRate = {}));
var ByteRTCAudioChannel;
(function (ByteRTCAudioChannel) {
    ByteRTCAudioChannel[ByteRTCAudioChannel["ByteRTCAudioChannelAuto"] = -1] = "ByteRTCAudioChannelAuto";
    ByteRTCAudioChannel[ByteRTCAudioChannel["ByteRTCAudioChannelMono"] = 1] = "ByteRTCAudioChannelMono";
    ByteRTCAudioChannel[ByteRTCAudioChannel["ByteRTCAudioChannelStereo"] = 2] = "ByteRTCAudioChannelStereo";
})(ByteRTCAudioChannel || (ByteRTCAudioChannel = {}));
var ByteRTCHardwareEchoDetectionResult;
(function (ByteRTCHardwareEchoDetectionResult) {
    ByteRTCHardwareEchoDetectionResult[ByteRTCHardwareEchoDetectionResult["ByteRTCHardwareEchoDetectionCanceled"] = 0] = "ByteRTCHardwareEchoDetectionCanceled";
    ByteRTCHardwareEchoDetectionResult[ByteRTCHardwareEchoDetectionResult["ByteRTCHardwareEchoDetectionUnknown"] = 1] = "ByteRTCHardwareEchoDetectionUnknown";
    ByteRTCHardwareEchoDetectionResult[ByteRTCHardwareEchoDetectionResult["ByteRTCHardwareEchoDetectionNormal"] = 2] = "ByteRTCHardwareEchoDetectionNormal";
    ByteRTCHardwareEchoDetectionResult[ByteRTCHardwareEchoDetectionResult["ByteRTCHardwareEchoDetectionPoor"] = 3] = "ByteRTCHardwareEchoDetectionPoor";
})(ByteRTCHardwareEchoDetectionResult || (ByteRTCHardwareEchoDetectionResult = {}));
var ByteRTCEffectBeautyMode;
(function (ByteRTCEffectBeautyMode) {
    ByteRTCEffectBeautyMode[ByteRTCEffectBeautyMode["ByteRTCEffectBeautyModeWhite"] = 0] = "ByteRTCEffectBeautyModeWhite";
    ByteRTCEffectBeautyMode[ByteRTCEffectBeautyMode["ByteRTCEffectBeautyModeSmooth"] = 1] = "ByteRTCEffectBeautyModeSmooth";
    ByteRTCEffectBeautyMode[ByteRTCEffectBeautyMode["ByteRTCEffectBeautyModeSharpen"] = 2] = "ByteRTCEffectBeautyModeSharpen";
    ByteRTCEffectBeautyMode[ByteRTCEffectBeautyMode["ByteRTCEffectBeautyModeClear"] = 3] = "ByteRTCEffectBeautyModeClear";
})(ByteRTCEffectBeautyMode || (ByteRTCEffectBeautyMode = {}));
var ByteRTCVideoCanvas = function () {
    var _classDecorators = [NativeClass('ByteRTCVideoCanvas')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _view_decorators;
    var _view_initializers = [];
    var _view_extraInitializers = [];
    var _renderMode_decorators;
    var _renderMode_initializers = [];
    var _renderMode_extraInitializers = [];
    var _backgroundColor_decorators;
    var _backgroundColor_initializers = [];
    var _backgroundColor_extraInitializers = [];
    var _renderRotation_decorators;
    var _renderRotation_initializers = [];
    var _renderRotation_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoCanvas_1() {
            this.view = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _view_initializers, void 0));
            this.renderMode = (__runInitializers(this, _view_extraInitializers), __runInitializers(this, _renderMode_initializers, void 0));
            this.backgroundColor = (__runInitializers(this, _renderMode_extraInitializers), __runInitializers(this, _backgroundColor_initializers, void 0));
            this.renderRotation = (__runInitializers(this, _backgroundColor_extraInitializers), __runInitializers(this, _renderRotation_initializers, void 0));
            __runInitializers(this, _renderRotation_extraInitializers);
        }
        ByteRTCVideoCanvas_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVideoCanvas_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoCanvas");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _view_decorators = [NativeMember()];
        _renderMode_decorators = [NativeMember()];
        _backgroundColor_decorators = [NativeMember()];
        _renderRotation_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _view_decorators, { kind: "field", name: "view", static: false, private: false, access: { has: function (obj) { return "view" in obj; }, get: function (obj) { return obj.view; }, set: function (obj, value) { obj.view = value; } }, metadata: _metadata }, _view_initializers, _view_extraInitializers);
        __esDecorate(null, null, _renderMode_decorators, { kind: "field", name: "renderMode", static: false, private: false, access: { has: function (obj) { return "renderMode" in obj; }, get: function (obj) { return obj.renderMode; }, set: function (obj, value) { obj.renderMode = value; } }, metadata: _metadata }, _renderMode_initializers, _renderMode_extraInitializers);
        __esDecorate(null, null, _backgroundColor_decorators, { kind: "field", name: "backgroundColor", static: false, private: false, access: { has: function (obj) { return "backgroundColor" in obj; }, get: function (obj) { return obj.backgroundColor; }, set: function (obj, value) { obj.backgroundColor = value; } }, metadata: _metadata }, _backgroundColor_initializers, _backgroundColor_extraInitializers);
        __esDecorate(null, null, _renderRotation_decorators, { kind: "field", name: "renderRotation", static: false, private: false, access: { has: function (obj) { return "renderRotation" in obj; }, get: function (obj) { return obj.renderRotation; }, set: function (obj, value) { obj.renderRotation = value; } }, metadata: _metadata }, _renderRotation_initializers, _renderRotation_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRemoteAudioState;
(function (ByteRTCRemoteAudioState) {
    ByteRTCRemoteAudioState[ByteRTCRemoteAudioState["ByteRTCRemoteAudioStateStopped"] = 0] = "ByteRTCRemoteAudioStateStopped";
    ByteRTCRemoteAudioState[ByteRTCRemoteAudioState["ByteRTCRemoteAudioStateStarting"] = 1] = "ByteRTCRemoteAudioStateStarting";
    ByteRTCRemoteAudioState[ByteRTCRemoteAudioState["ByteRTCRemoteAudioStateDecoding"] = 2] = "ByteRTCRemoteAudioStateDecoding";
    ByteRTCRemoteAudioState[ByteRTCRemoteAudioState["ByteRTCRemoteAudioStateFrozen"] = 3] = "ByteRTCRemoteAudioStateFrozen";
    ByteRTCRemoteAudioState[ByteRTCRemoteAudioState["ByteRTCRemoteAudioStateFailed"] = 4] = "ByteRTCRemoteAudioStateFailed";
})(ByteRTCRemoteAudioState || (ByteRTCRemoteAudioState = {}));
var ByteRTCMuteState;
(function (ByteRTCMuteState) {
    ByteRTCMuteState[ByteRTCMuteState["ByteRTCMuteStateOff"] = 0] = "ByteRTCMuteStateOff";
    ByteRTCMuteState[ByteRTCMuteState["ByteRTCMuteStateOn"] = 1] = "ByteRTCMuteStateOn";
})(ByteRTCMuteState || (ByteRTCMuteState = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCTranscodingVideoConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _codec_decorators;
    var _codec_initializers = [];
    var _codec_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _fps_decorators;
    var _fps_initializers = [];
    var _fps_extraInitializers = [];
    var _gop_decorators;
    var _gop_initializers = [];
    var _gop_extraInitializers = [];
    var _kBitRate_decorators;
    var _kBitRate_initializers = [];
    var _kBitRate_extraInitializers = [];
    var _bFrame_decorators;
    var _bFrame_initializers = [];
    var _bFrame_extraInitializers = [];
    var _lowLatency_decorators;
    var _lowLatency_initializers = [];
    var _lowLatency_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCTranscodingVideoConfig_1() {
            this.codec = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _codec_initializers, void 0));
            this.width = (__runInitializers(this, _codec_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.fps = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _fps_initializers, void 0));
            this.gop = (__runInitializers(this, _fps_extraInitializers), __runInitializers(this, _gop_initializers, void 0));
            this.kBitRate = (__runInitializers(this, _gop_extraInitializers), __runInitializers(this, _kBitRate_initializers, void 0));
            this.bFrame = (__runInitializers(this, _kBitRate_extraInitializers), __runInitializers(this, _bFrame_initializers, void 0));
            this.lowLatency = (__runInitializers(this, _bFrame_extraInitializers), __runInitializers(this, _lowLatency_initializers, void 0));
            __runInitializers(this, _lowLatency_extraInitializers);
        }
        ByteRTCTranscodingVideoConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCTranscodingVideoConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCTranscodingVideoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _codec_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _fps_decorators = [NativeMember()];
        _gop_decorators = [NativeMember()];
        _kBitRate_decorators = [NativeMember()];
        _bFrame_decorators = [NativeMember()];
        _lowLatency_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _codec_decorators, { kind: "field", name: "codec", static: false, private: false, access: { has: function (obj) { return "codec" in obj; }, get: function (obj) { return obj.codec; }, set: function (obj, value) { obj.codec = value; } }, metadata: _metadata }, _codec_initializers, _codec_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _fps_decorators, { kind: "field", name: "fps", static: false, private: false, access: { has: function (obj) { return "fps" in obj; }, get: function (obj) { return obj.fps; }, set: function (obj, value) { obj.fps = value; } }, metadata: _metadata }, _fps_initializers, _fps_extraInitializers);
        __esDecorate(null, null, _gop_decorators, { kind: "field", name: "gop", static: false, private: false, access: { has: function (obj) { return "gop" in obj; }, get: function (obj) { return obj.gop; }, set: function (obj, value) { obj.gop = value; } }, metadata: _metadata }, _gop_initializers, _gop_extraInitializers);
        __esDecorate(null, null, _kBitRate_decorators, { kind: "field", name: "kBitRate", static: false, private: false, access: { has: function (obj) { return "kBitRate" in obj; }, get: function (obj) { return obj.kBitRate; }, set: function (obj, value) { obj.kBitRate = value; } }, metadata: _metadata }, _kBitRate_initializers, _kBitRate_extraInitializers);
        __esDecorate(null, null, _bFrame_decorators, { kind: "field", name: "bFrame", static: false, private: false, access: { has: function (obj) { return "bFrame" in obj; }, get: function (obj) { return obj.bFrame; }, set: function (obj, value) { obj.bFrame = value; } }, metadata: _metadata }, _bFrame_initializers, _bFrame_extraInitializers);
        __esDecorate(null, null, _lowLatency_decorators, { kind: "field", name: "lowLatency", static: false, private: false, access: { has: function (obj) { return "lowLatency" in obj; }, get: function (obj) { return obj.lowLatency; }, set: function (obj, value) { obj.lowLatency = value; } }, metadata: _metadata }, _lowLatency_initializers, _lowLatency_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCVideoPreprocessorConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCVideoPreprocessorConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _requiredPixelFormat_decorators;
    var _requiredPixelFormat_initializers = [];
    var _requiredPixelFormat_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoPreprocessorConfig_1() {
            this.requiredPixelFormat = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _requiredPixelFormat_initializers, void 0));
            __runInitializers(this, _requiredPixelFormat_extraInitializers);
        }
        ByteRTCVideoPreprocessorConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVideoPreprocessorConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoPreprocessorConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _requiredPixelFormat_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _requiredPixelFormat_decorators, { kind: "field", name: "requiredPixelFormat", static: false, private: false, access: { has: function (obj) { return "requiredPixelFormat" in obj; }, get: function (obj) { return obj.requiredPixelFormat; }, set: function (obj, value) { obj.requiredPixelFormat = value; } }, metadata: _metadata }, _requiredPixelFormat_initializers, _requiredPixelFormat_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRemoteAudioStateChangeReason;
(function (ByteRTCRemoteAudioStateChangeReason) {
    ByteRTCRemoteAudioStateChangeReason[ByteRTCRemoteAudioStateChangeReason["ByteRTCRemoteAudioStateChangeReasonInternal"] = 0] = "ByteRTCRemoteAudioStateChangeReasonInternal";
    ByteRTCRemoteAudioStateChangeReason[ByteRTCRemoteAudioStateChangeReason["ByteRTCRemoteAudioStateChangeReasonNetworkCongestion"] = 1] = "ByteRTCRemoteAudioStateChangeReasonNetworkCongestion";
    ByteRTCRemoteAudioStateChangeReason[ByteRTCRemoteAudioStateChangeReason["ByteRTCRemoteAudioStateChangeReasonNetworkRecovery"] = 2] = "ByteRTCRemoteAudioStateChangeReasonNetworkRecovery";
    ByteRTCRemoteAudioStateChangeReason[ByteRTCRemoteAudioStateChangeReason["ByteRTCRemoteAudioStateChangeReasonLocalMuted"] = 3] = "ByteRTCRemoteAudioStateChangeReasonLocalMuted";
    ByteRTCRemoteAudioStateChangeReason[ByteRTCRemoteAudioStateChangeReason["ByteRTCRemoteAudioStateChangeReasonLocalUnmuted"] = 4] = "ByteRTCRemoteAudioStateChangeReasonLocalUnmuted";
    ByteRTCRemoteAudioStateChangeReason[ByteRTCRemoteAudioStateChangeReason["ByteRTCRemoteAudioStateChangeReasonRemoteMuted"] = 5] = "ByteRTCRemoteAudioStateChangeReasonRemoteMuted";
    ByteRTCRemoteAudioStateChangeReason[ByteRTCRemoteAudioStateChangeReason["ByteRTCRemoteAudioStateChangeReasonRemoteUnmuted"] = 6] = "ByteRTCRemoteAudioStateChangeReasonRemoteUnmuted";
    ByteRTCRemoteAudioStateChangeReason[ByteRTCRemoteAudioStateChangeReason["ByteRTCRemoteAudioStateChangeReasonRemoteOffline"] = 7] = "ByteRTCRemoteAudioStateChangeReasonRemoteOffline";
})(ByteRTCRemoteAudioStateChangeReason || (ByteRTCRemoteAudioStateChangeReason = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCPublicStreamLayout')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _layoutMode_decorators;
    var _layoutMode_initializers = [];
    var _layoutMode_extraInitializers = [];
    var _interpolationMode_decorators;
    var _interpolationMode_initializers = [];
    var _interpolationMode_extraInitializers = [];
    var _backgroundColor_decorators;
    var _backgroundColor_initializers = [];
    var _backgroundColor_extraInitializers = [];
    var _backgroundImage_decorators;
    var _backgroundImage_initializers = [];
    var _backgroundImage_extraInitializers = [];
    var _regions_decorators;
    var _regions_initializers = [];
    var _regions_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCPublicStreamLayout_1() {
            this.layoutMode = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _layoutMode_initializers, void 0));
            this.interpolationMode = (__runInitializers(this, _layoutMode_extraInitializers), __runInitializers(this, _interpolationMode_initializers, void 0));
            this.backgroundColor = (__runInitializers(this, _interpolationMode_extraInitializers), __runInitializers(this, _backgroundColor_initializers, void 0));
            this.backgroundImage = (__runInitializers(this, _backgroundColor_extraInitializers), __runInitializers(this, _backgroundImage_initializers, void 0));
            this.regions = (__runInitializers(this, _backgroundImage_extraInitializers), __runInitializers(this, _regions_initializers, void 0));
            __runInitializers(this, _regions_extraInitializers);
        }
        ByteRTCPublicStreamLayout_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCPublicStreamLayout_1;
    }());
    __setFunctionName(_classThis, "ByteRTCPublicStreamLayout");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _layoutMode_decorators = [NativeMember()];
        _interpolationMode_decorators = [NativeMember()];
        _backgroundColor_decorators = [NativeMember()];
        _backgroundImage_decorators = [NativeMember()];
        _regions_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _layoutMode_decorators, { kind: "field", name: "layoutMode", static: false, private: false, access: { has: function (obj) { return "layoutMode" in obj; }, get: function (obj) { return obj.layoutMode; }, set: function (obj, value) { obj.layoutMode = value; } }, metadata: _metadata }, _layoutMode_initializers, _layoutMode_extraInitializers);
        __esDecorate(null, null, _interpolationMode_decorators, { kind: "field", name: "interpolationMode", static: false, private: false, access: { has: function (obj) { return "interpolationMode" in obj; }, get: function (obj) { return obj.interpolationMode; }, set: function (obj, value) { obj.interpolationMode = value; } }, metadata: _metadata }, _interpolationMode_initializers, _interpolationMode_extraInitializers);
        __esDecorate(null, null, _backgroundColor_decorators, { kind: "field", name: "backgroundColor", static: false, private: false, access: { has: function (obj) { return "backgroundColor" in obj; }, get: function (obj) { return obj.backgroundColor; }, set: function (obj, value) { obj.backgroundColor = value; } }, metadata: _metadata }, _backgroundColor_initializers, _backgroundColor_extraInitializers);
        __esDecorate(null, null, _backgroundImage_decorators, { kind: "field", name: "backgroundImage", static: false, private: false, access: { has: function (obj) { return "backgroundImage" in obj; }, get: function (obj) { return obj.backgroundImage; }, set: function (obj, value) { obj.backgroundImage = value; } }, metadata: _metadata }, _backgroundImage_initializers, _backgroundImage_extraInitializers);
        __esDecorate(null, null, _regions_decorators, { kind: "field", name: "regions", static: false, private: false, access: { has: function (obj) { return "regions" in obj; }, get: function (obj) { return obj.regions; }, set: function (obj, value) { obj.regions = value; } }, metadata: _metadata }, _regions_initializers, _regions_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCLocalVideoStreamState;
(function (ByteRTCLocalVideoStreamState) {
    ByteRTCLocalVideoStreamState[ByteRTCLocalVideoStreamState["ByteRTCLocalVideoStreamStateStopped"] = 0] = "ByteRTCLocalVideoStreamStateStopped";
    ByteRTCLocalVideoStreamState[ByteRTCLocalVideoStreamState["ByteRTCLocalVideoStreamStateRecording"] = 1] = "ByteRTCLocalVideoStreamStateRecording";
    ByteRTCLocalVideoStreamState[ByteRTCLocalVideoStreamState["ByteRTCLocalVideoStreamStateEncoding"] = 2] = "ByteRTCLocalVideoStreamStateEncoding";
    ByteRTCLocalVideoStreamState[ByteRTCLocalVideoStreamState["ByteRTCLocalVideoStreamStateFailed"] = 3] = "ByteRTCLocalVideoStreamStateFailed";
})(ByteRTCLocalVideoStreamState || (ByteRTCLocalVideoStreamState = {}));
var ByteRTCSingScoringConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCSingScoringConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _mode_decorators;
    var _mode_initializers = [];
    var _mode_extraInitializers = [];
    var _sampleRate_decorators;
    var _sampleRate_initializers = [];
    var _sampleRate_extraInitializers = [];
    var _lyricsFilepath_decorators;
    var _lyricsFilepath_initializers = [];
    var _lyricsFilepath_extraInitializers = [];
    var _midiFilepath_decorators;
    var _midiFilepath_initializers = [];
    var _midiFilepath_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCSingScoringConfig_1() {
            this.mode = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _mode_initializers, void 0));
            this.sampleRate = (__runInitializers(this, _mode_extraInitializers), __runInitializers(this, _sampleRate_initializers, void 0));
            this.lyricsFilepath = (__runInitializers(this, _sampleRate_extraInitializers), __runInitializers(this, _lyricsFilepath_initializers, void 0));
            this.midiFilepath = (__runInitializers(this, _lyricsFilepath_extraInitializers), __runInitializers(this, _midiFilepath_initializers, void 0));
            __runInitializers(this, _midiFilepath_extraInitializers);
        }
        ByteRTCSingScoringConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCSingScoringConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCSingScoringConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _mode_decorators = [NativeMember()];
        _sampleRate_decorators = [NativeMember()];
        _lyricsFilepath_decorators = [NativeMember()];
        _midiFilepath_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _mode_decorators, { kind: "field", name: "mode", static: false, private: false, access: { has: function (obj) { return "mode" in obj; }, get: function (obj) { return obj.mode; }, set: function (obj, value) { obj.mode = value; } }, metadata: _metadata }, _mode_initializers, _mode_extraInitializers);
        __esDecorate(null, null, _sampleRate_decorators, { kind: "field", name: "sampleRate", static: false, private: false, access: { has: function (obj) { return "sampleRate" in obj; }, get: function (obj) { return obj.sampleRate; }, set: function (obj, value) { obj.sampleRate = value; } }, metadata: _metadata }, _sampleRate_initializers, _sampleRate_extraInitializers);
        __esDecorate(null, null, _lyricsFilepath_decorators, { kind: "field", name: "lyricsFilepath", static: false, private: false, access: { has: function (obj) { return "lyricsFilepath" in obj; }, get: function (obj) { return obj.lyricsFilepath; }, set: function (obj, value) { obj.lyricsFilepath = value; } }, metadata: _metadata }, _lyricsFilepath_initializers, _lyricsFilepath_extraInitializers);
        __esDecorate(null, null, _midiFilepath_decorators, { kind: "field", name: "midiFilepath", static: false, private: false, access: { has: function (obj) { return "midiFilepath" in obj; }, get: function (obj) { return obj.midiFilepath; }, set: function (obj, value) { obj.midiFilepath = value; } }, metadata: _metadata }, _midiFilepath_initializers, _midiFilepath_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCFirstFrameSendState;
(function (ByteRTCFirstFrameSendState) {
    ByteRTCFirstFrameSendState[ByteRTCFirstFrameSendState["ByteRTCFirstFrameSendStateSending"] = 0] = "ByteRTCFirstFrameSendStateSending";
    ByteRTCFirstFrameSendState[ByteRTCFirstFrameSendState["ByteRTCFirstFrameSendStateSent"] = 1] = "ByteRTCFirstFrameSendStateSent";
    ByteRTCFirstFrameSendState[ByteRTCFirstFrameSendState["ByteRTCFirstFrameSendStateEnd"] = 2] = "ByteRTCFirstFrameSendStateEnd";
})(ByteRTCFirstFrameSendState || (ByteRTCFirstFrameSendState = {}));
var ByteRTCRemoteMirrorType;
(function (ByteRTCRemoteMirrorType) {
    ByteRTCRemoteMirrorType[ByteRTCRemoteMirrorType["ByteRTCRemoteMirrorTypeNone"] = 0] = "ByteRTCRemoteMirrorTypeNone";
    ByteRTCRemoteMirrorType[ByteRTCRemoteMirrorType["ByteRTCRemoteMirrorTypeRender"] = 1] = "ByteRTCRemoteMirrorTypeRender";
})(ByteRTCRemoteMirrorType || (ByteRTCRemoteMirrorType = {}));
var ByteRTCVoiceEqualizationConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCVoiceEqualizationConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _frequency_decorators;
    var _frequency_initializers = [];
    var _frequency_extraInitializers = [];
    var _gain_decorators;
    var _gain_initializers = [];
    var _gain_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVoiceEqualizationConfig_1() {
            this.frequency = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _frequency_initializers, void 0));
            this.gain = (__runInitializers(this, _frequency_extraInitializers), __runInitializers(this, _gain_initializers, void 0));
            __runInitializers(this, _gain_extraInitializers);
        }
        ByteRTCVoiceEqualizationConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVoiceEqualizationConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVoiceEqualizationConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _frequency_decorators = [NativeMember()];
        _gain_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _frequency_decorators, { kind: "field", name: "frequency", static: false, private: false, access: { has: function (obj) { return "frequency" in obj; }, get: function (obj) { return obj.frequency; }, set: function (obj, value) { obj.frequency = value; } }, metadata: _metadata }, _frequency_initializers, _frequency_extraInitializers);
        __esDecorate(null, null, _gain_decorators, { kind: "field", name: "gain", static: false, private: false, access: { has: function (obj) { return "gain" in obj; }, get: function (obj) { return obj.gain; }, set: function (obj, value) { obj.gain = value; } }, metadata: _metadata }, _gain_initializers, _gain_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCConnectionState;
(function (ByteRTCConnectionState) {
    ByteRTCConnectionState[ByteRTCConnectionState["ByteRTCConnectionStateDisconnected"] = 1] = "ByteRTCConnectionStateDisconnected";
    ByteRTCConnectionState[ByteRTCConnectionState["ByteRTCConnectionStateConnecting"] = 2] = "ByteRTCConnectionStateConnecting";
    ByteRTCConnectionState[ByteRTCConnectionState["ByteRTCConnectionStateConnected"] = 3] = "ByteRTCConnectionStateConnected";
    ByteRTCConnectionState[ByteRTCConnectionState["ByteRTCConnectionStateReconnecting"] = 4] = "ByteRTCConnectionStateReconnecting";
    ByteRTCConnectionState[ByteRTCConnectionState["ByteRTCConnectionStateReconnected"] = 5] = "ByteRTCConnectionStateReconnected";
    ByteRTCConnectionState[ByteRTCConnectionState["ByteRTCConnectionStateLost"] = 6] = "ByteRTCConnectionStateLost";
    ByteRTCConnectionState[ByteRTCConnectionState["ByteRTCConnectionStateFailed"] = 7] = "ByteRTCConnectionStateFailed";
})(ByteRTCConnectionState || (ByteRTCConnectionState = {}));
var ByteRTCLyricStatus;
(function (ByteRTCLyricStatus) {
    ByteRTCLyricStatus[ByteRTCLyricStatus["ByteRTCLyricStatusNone"] = 0] = "ByteRTCLyricStatusNone";
    ByteRTCLyricStatus[ByteRTCLyricStatus["ByteRTCLyricStatusKRC"] = 1] = "ByteRTCLyricStatusKRC";
    ByteRTCLyricStatus[ByteRTCLyricStatus["ByteRTCLyricStatusLRC"] = 2] = "ByteRTCLyricStatusLRC";
    ByteRTCLyricStatus[ByteRTCLyricStatus["ByteRTCLyricStatusKRCAndLRC"] = 3] = "ByteRTCLyricStatusKRCAndLRC";
})(ByteRTCLyricStatus || (ByteRTCLyricStatus = {}));
var ByteRTCFallbackOrRecoverReason;
(function (ByteRTCFallbackOrRecoverReason) {
    ByteRTCFallbackOrRecoverReason[ByteRTCFallbackOrRecoverReason["ByteRTCFallbackOrRecoverReasonUnknown"] = -1] = "ByteRTCFallbackOrRecoverReasonUnknown";
    ByteRTCFallbackOrRecoverReason[ByteRTCFallbackOrRecoverReason["ByteRTCFallbackOrRecoverReasonSubscribeFallbackByBandwidth"] = 0] = "ByteRTCFallbackOrRecoverReasonSubscribeFallbackByBandwidth";
    ByteRTCFallbackOrRecoverReason[ByteRTCFallbackOrRecoverReason["ByteRTCFallbackOrRecoverReasonSubscribeFallbackByPerformance"] = 1] = "ByteRTCFallbackOrRecoverReasonSubscribeFallbackByPerformance";
    ByteRTCFallbackOrRecoverReason[ByteRTCFallbackOrRecoverReason["ByteRTCFallbackOrRecoverReasonSubscribeRecoverByBandwidth"] = 2] = "ByteRTCFallbackOrRecoverReasonSubscribeRecoverByBandwidth";
    ByteRTCFallbackOrRecoverReason[ByteRTCFallbackOrRecoverReason["ByteRTCFallbackOrRecoverReasonSubscribeRecoverByPerformance"] = 3] = "ByteRTCFallbackOrRecoverReasonSubscribeRecoverByPerformance";
    ByteRTCFallbackOrRecoverReason[ByteRTCFallbackOrRecoverReason["ByteRTCFallbackOrRecoverReasonPublishFallbackByBandwidth"] = 4] = "ByteRTCFallbackOrRecoverReasonPublishFallbackByBandwidth";
    ByteRTCFallbackOrRecoverReason[ByteRTCFallbackOrRecoverReason["ByteRTCFallbackOrRecoverReasonPublishFallbackByPerformance"] = 5] = "ByteRTCFallbackOrRecoverReasonPublishFallbackByPerformance";
    ByteRTCFallbackOrRecoverReason[ByteRTCFallbackOrRecoverReason["ByteRTCFallbackOrRecoverReasonPublishRecoverByBandwidth"] = 6] = "ByteRTCFallbackOrRecoverReasonPublishRecoverByBandwidth";
    ByteRTCFallbackOrRecoverReason[ByteRTCFallbackOrRecoverReason["ByteRTCFallbackOrRecoverReasonPublishRecoverByPerformance"] = 7] = "ByteRTCFallbackOrRecoverReasonPublishRecoverByPerformance";
})(ByteRTCFallbackOrRecoverReason || (ByteRTCFallbackOrRecoverReason = {}));
var ByteRTCRecordingFileType;
(function (ByteRTCRecordingFileType) {
    ByteRTCRecordingFileType[ByteRTCRecordingFileType["ByteRTCRecordingFileTypeAAC"] = 0] = "ByteRTCRecordingFileTypeAAC";
    ByteRTCRecordingFileType[ByteRTCRecordingFileType["ByteRTCRecordingFileTypeMP4"] = 1] = "ByteRTCRecordingFileTypeMP4";
})(ByteRTCRecordingFileType || (ByteRTCRecordingFileType = {}));
var ByteRTCVideoPictureType;
(function (ByteRTCVideoPictureType) {
    ByteRTCVideoPictureType[ByteRTCVideoPictureType["ByteRTCVideoPictureTypeUnknown"] = 0] = "ByteRTCVideoPictureTypeUnknown";
    ByteRTCVideoPictureType[ByteRTCVideoPictureType["ByteRTCVideoPictureTypeI"] = 1] = "ByteRTCVideoPictureTypeI";
    ByteRTCVideoPictureType[ByteRTCVideoPictureType["ByteRTCVideoPictureTypeP"] = 2] = "ByteRTCVideoPictureTypeP";
    ByteRTCVideoPictureType[ByteRTCVideoPictureType["ByteRTCVideoPictureTypeB"] = 3] = "ByteRTCVideoPictureTypeB";
})(ByteRTCVideoPictureType || (ByteRTCVideoPictureType = {}));
var ByteRTCVideoStreamScaleMode;
(function (ByteRTCVideoStreamScaleMode) {
    ByteRTCVideoStreamScaleMode[ByteRTCVideoStreamScaleMode["ByteRTCVideoStreamScaleModeAuto"] = 0] = "ByteRTCVideoStreamScaleModeAuto";
    ByteRTCVideoStreamScaleMode[ByteRTCVideoStreamScaleMode["ByteRTCVideoStreamScaleModeStretch"] = 1] = "ByteRTCVideoStreamScaleModeStretch";
    ByteRTCVideoStreamScaleMode[ByteRTCVideoStreamScaleMode["ByteRTCVideoStreamScaleModeFitWithCropping"] = 2] = "ByteRTCVideoStreamScaleModeFitWithCropping";
    ByteRTCVideoStreamScaleMode[ByteRTCVideoStreamScaleMode["ByteRTCVideoStreamScaleModeFitWithFilling"] = 3] = "ByteRTCVideoStreamScaleModeFitWithFilling";
})(ByteRTCVideoStreamScaleMode || (ByteRTCVideoStreamScaleMode = {}));
var ByteRTCSubtitleConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCSubtitleConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _mode_decorators;
    var _mode_initializers = [];
    var _mode_extraInitializers = [];
    var _targetLanguage_decorators;
    var _targetLanguage_initializers = [];
    var _targetLanguage_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCSubtitleConfig_1() {
            this.mode = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _mode_initializers, void 0));
            this.targetLanguage = (__runInitializers(this, _mode_extraInitializers), __runInitializers(this, _targetLanguage_initializers, void 0));
            __runInitializers(this, _targetLanguage_extraInitializers);
        }
        ByteRTCSubtitleConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCSubtitleConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCSubtitleConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _mode_decorators = [NativeMember()];
        _targetLanguage_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _mode_decorators, { kind: "field", name: "mode", static: false, private: false, access: { has: function (obj) { return "mode" in obj; }, get: function (obj) { return obj.mode; }, set: function (obj, value) { obj.mode = value; } }, metadata: _metadata }, _mode_initializers, _mode_extraInitializers);
        __esDecorate(null, null, _targetLanguage_decorators, { kind: "field", name: "targetLanguage", static: false, private: false, access: { has: function (obj) { return "targetLanguage" in obj; }, get: function (obj) { return obj.targetLanguage; }, set: function (obj, value) { obj.targetLanguage = value; } }, metadata: _metadata }, _targetLanguage_initializers, _targetLanguage_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioMixingConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCAudioMixingConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _type_decorators;
    var _type_initializers = [];
    var _type_extraInitializers = [];
    var _playCount_decorators;
    var _playCount_initializers = [];
    var _playCount_extraInitializers = [];
    var _position_decorators;
    var _position_initializers = [];
    var _position_extraInitializers = [];
    var _callbackOnProgressInterval_decorators;
    var _callbackOnProgressInterval_initializers = [];
    var _callbackOnProgressInterval_extraInitializers = [];
    var _syncProgressToRecordFrame_decorators;
    var _syncProgressToRecordFrame_initializers = [];
    var _syncProgressToRecordFrame_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioMixingConfig_1() {
            this.type = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _type_initializers, void 0));
            this.playCount = (__runInitializers(this, _type_extraInitializers), __runInitializers(this, _playCount_initializers, void 0));
            this.position = (__runInitializers(this, _playCount_extraInitializers), __runInitializers(this, _position_initializers, void 0));
            this.callbackOnProgressInterval = (__runInitializers(this, _position_extraInitializers), __runInitializers(this, _callbackOnProgressInterval_initializers, void 0));
            this.syncProgressToRecordFrame = (__runInitializers(this, _callbackOnProgressInterval_extraInitializers), __runInitializers(this, _syncProgressToRecordFrame_initializers, void 0));
            __runInitializers(this, _syncProgressToRecordFrame_extraInitializers);
        }
        ByteRTCAudioMixingConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCAudioMixingConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioMixingConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _type_decorators = [NativeMember()];
        _playCount_decorators = [NativeMember()];
        _position_decorators = [NativeMember()];
        _callbackOnProgressInterval_decorators = [NativeMember()];
        _syncProgressToRecordFrame_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _type_decorators, { kind: "field", name: "type", static: false, private: false, access: { has: function (obj) { return "type" in obj; }, get: function (obj) { return obj.type; }, set: function (obj, value) { obj.type = value; } }, metadata: _metadata }, _type_initializers, _type_extraInitializers);
        __esDecorate(null, null, _playCount_decorators, { kind: "field", name: "playCount", static: false, private: false, access: { has: function (obj) { return "playCount" in obj; }, get: function (obj) { return obj.playCount; }, set: function (obj, value) { obj.playCount = value; } }, metadata: _metadata }, _playCount_initializers, _playCount_extraInitializers);
        __esDecorate(null, null, _position_decorators, { kind: "field", name: "position", static: false, private: false, access: { has: function (obj) { return "position" in obj; }, get: function (obj) { return obj.position; }, set: function (obj, value) { obj.position = value; } }, metadata: _metadata }, _position_initializers, _position_extraInitializers);
        __esDecorate(null, null, _callbackOnProgressInterval_decorators, { kind: "field", name: "callbackOnProgressInterval", static: false, private: false, access: { has: function (obj) { return "callbackOnProgressInterval" in obj; }, get: function (obj) { return obj.callbackOnProgressInterval; }, set: function (obj, value) { obj.callbackOnProgressInterval = value; } }, metadata: _metadata }, _callbackOnProgressInterval_initializers, _callbackOnProgressInterval_extraInitializers);
        __esDecorate(null, null, _syncProgressToRecordFrame_decorators, { kind: "field", name: "syncProgressToRecordFrame", static: false, private: false, access: { has: function (obj) { return "syncProgressToRecordFrame" in obj; }, get: function (obj) { return obj.syncProgressToRecordFrame; }, set: function (obj, value) { obj.syncProgressToRecordFrame = value; } }, metadata: _metadata }, _syncProgressToRecordFrame_initializers, _syncProgressToRecordFrame_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCVideoSinkPixelFormat;
(function (ByteRTCVideoSinkPixelFormat) {
    ByteRTCVideoSinkPixelFormat[ByteRTCVideoSinkPixelFormat["ByteRTCVideoSinkPixelFormatOriginal"] = 0] = "ByteRTCVideoSinkPixelFormatOriginal";
    ByteRTCVideoSinkPixelFormat[ByteRTCVideoSinkPixelFormat["ByteRTCVideoSinkPixelFormatI420"] = 1] = "ByteRTCVideoSinkPixelFormatI420";
    ByteRTCVideoSinkPixelFormat[ByteRTCVideoSinkPixelFormat["ByteRTCVideoSinkPixelFormatBGRA"] = 2] = "ByteRTCVideoSinkPixelFormatBGRA";
    ByteRTCVideoSinkPixelFormat[ByteRTCVideoSinkPixelFormat["ByteRTCVideoSinkPixelFormatRGBA"] = 5] = "ByteRTCVideoSinkPixelFormatRGBA";
    ByteRTCVideoSinkPixelFormat[ByteRTCVideoSinkPixelFormat["ByteRTCVideoSinkPixelFormatNV12"] = 8] = "ByteRTCVideoSinkPixelFormatNV12";
})(ByteRTCVideoSinkPixelFormat || (ByteRTCVideoSinkPixelFormat = {}));
var ByteRTCAudioMixingError;
(function (ByteRTCAudioMixingError) {
    ByteRTCAudioMixingError[ByteRTCAudioMixingError["ByteRTCAudioMixingErrorOk"] = 0] = "ByteRTCAudioMixingErrorOk";
    ByteRTCAudioMixingError[ByteRTCAudioMixingError["ByteRTCAudioMixingErrorPreloadFailed"] = 1] = "ByteRTCAudioMixingErrorPreloadFailed";
    ByteRTCAudioMixingError[ByteRTCAudioMixingError["ByteRTCAudioMixingErrorStartFailed"] = 2] = "ByteRTCAudioMixingErrorStartFailed";
    ByteRTCAudioMixingError[ByteRTCAudioMixingError["ByteRTCAudioMixingErrorIdNotFound"] = 3] = "ByteRTCAudioMixingErrorIdNotFound";
    ByteRTCAudioMixingError[ByteRTCAudioMixingError["ByteRTCAudioMixingErrorSetPositionFailed"] = 4] = "ByteRTCAudioMixingErrorSetPositionFailed";
    ByteRTCAudioMixingError[ByteRTCAudioMixingError["ByteRTCAudioMixingErrorInValidVolume"] = 5] = "ByteRTCAudioMixingErrorInValidVolume";
    ByteRTCAudioMixingError[ByteRTCAudioMixingError["ByteRTCAudioMixingErrorLoadConflict"] = 6] = "ByteRTCAudioMixingErrorLoadConflict";
    ByteRTCAudioMixingError[ByteRTCAudioMixingError["ByteRTCAudioMixingErrorIdTypeNotMatch"] = 7] = "ByteRTCAudioMixingErrorIdTypeNotMatch";
    ByteRTCAudioMixingError[ByteRTCAudioMixingError["ByteRTCAudioMixingErrorInValidPitch"] = 8] = "ByteRTCAudioMixingErrorInValidPitch";
    ByteRTCAudioMixingError[ByteRTCAudioMixingError["ByteRTCAudioMixingErrorInValidAudioTrack"] = 9] = "ByteRTCAudioMixingErrorInValidAudioTrack";
    ByteRTCAudioMixingError[ByteRTCAudioMixingError["ByteRTCAudioMixingErrorIsStarting"] = 10] = "ByteRTCAudioMixingErrorIsStarting";
    ByteRTCAudioMixingError[ByteRTCAudioMixingError["ByteRTCAudioMixingErrorInValidPlaybackSpeed"] = 11] = "ByteRTCAudioMixingErrorInValidPlaybackSpeed";
})(ByteRTCAudioMixingError || (ByteRTCAudioMixingError = {}));
var ByteRTCAudioTrackType;
(function (ByteRTCAudioTrackType) {
    ByteRTCAudioTrackType[ByteRTCAudioTrackType["ByteRTCAudioTrackTypeOriginal"] = 1] = "ByteRTCAudioTrackTypeOriginal";
    ByteRTCAudioTrackType[ByteRTCAudioTrackType["ByteRTCAudioTrackTypeAccompy"] = 2] = "ByteRTCAudioTrackTypeAccompy";
})(ByteRTCAudioTrackType || (ByteRTCAudioTrackType = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCMixedStreamSpatialAudioConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _enableSpatialRender_decorators;
    var _enableSpatialRender_initializers = [];
    var _enableSpatialRender_extraInitializers = [];
    var _audienceSpatialPosition_decorators;
    var _audienceSpatialPosition_initializers = [];
    var _audienceSpatialPosition_extraInitializers = [];
    var _audienceSpatialOrientation_decorators;
    var _audienceSpatialOrientation_initializers = [];
    var _audienceSpatialOrientation_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMixedStreamSpatialAudioConfig_1() {
            this.enableSpatialRender = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _enableSpatialRender_initializers, void 0));
            this.audienceSpatialPosition = (__runInitializers(this, _enableSpatialRender_extraInitializers), __runInitializers(this, _audienceSpatialPosition_initializers, void 0));
            this.audienceSpatialOrientation = (__runInitializers(this, _audienceSpatialPosition_extraInitializers), __runInitializers(this, _audienceSpatialOrientation_initializers, void 0));
            __runInitializers(this, _audienceSpatialOrientation_extraInitializers);
        }
        ByteRTCMixedStreamSpatialAudioConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMixedStreamSpatialAudioConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMixedStreamSpatialAudioConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enableSpatialRender_decorators = [NativeMember()];
        _audienceSpatialPosition_decorators = [NativeMember()];
        _audienceSpatialOrientation_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _enableSpatialRender_decorators, { kind: "field", name: "enableSpatialRender", static: false, private: false, access: { has: function (obj) { return "enableSpatialRender" in obj; }, get: function (obj) { return obj.enableSpatialRender; }, set: function (obj, value) { obj.enableSpatialRender = value; } }, metadata: _metadata }, _enableSpatialRender_initializers, _enableSpatialRender_extraInitializers);
        __esDecorate(null, null, _audienceSpatialPosition_decorators, { kind: "field", name: "audienceSpatialPosition", static: false, private: false, access: { has: function (obj) { return "audienceSpatialPosition" in obj; }, get: function (obj) { return obj.audienceSpatialPosition; }, set: function (obj, value) { obj.audienceSpatialPosition = value; } }, metadata: _metadata }, _audienceSpatialPosition_initializers, _audienceSpatialPosition_extraInitializers);
        __esDecorate(null, null, _audienceSpatialOrientation_decorators, { kind: "field", name: "audienceSpatialOrientation", static: false, private: false, access: { has: function (obj) { return "audienceSpatialOrientation" in obj; }, get: function (obj) { return obj.audienceSpatialOrientation; }, set: function (obj, value) { obj.audienceSpatialOrientation = value; } }, metadata: _metadata }, _audienceSpatialOrientation_initializers, _audienceSpatialOrientation_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
(function () {
    var _classDecorators = [NativeClass('ByteRTCTranscodingSpatialConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _enableSpatialRender_decorators;
    var _enableSpatialRender_initializers = [];
    var _enableSpatialRender_extraInitializers = [];
    var _audienceSpatialPosition_decorators;
    var _audienceSpatialPosition_initializers = [];
    var _audienceSpatialPosition_extraInitializers = [];
    var _audienceSpatialOrientation_decorators;
    var _audienceSpatialOrientation_initializers = [];
    var _audienceSpatialOrientation_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCTranscodingSpatialConfig_1() {
            this.enableSpatialRender = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _enableSpatialRender_initializers, void 0));
            this.audienceSpatialPosition = (__runInitializers(this, _enableSpatialRender_extraInitializers), __runInitializers(this, _audienceSpatialPosition_initializers, void 0));
            this.audienceSpatialOrientation = (__runInitializers(this, _audienceSpatialPosition_extraInitializers), __runInitializers(this, _audienceSpatialOrientation_initializers, void 0));
            __runInitializers(this, _audienceSpatialOrientation_extraInitializers);
        }
        ByteRTCTranscodingSpatialConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCTranscodingSpatialConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCTranscodingSpatialConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enableSpatialRender_decorators = [NativeMember()];
        _audienceSpatialPosition_decorators = [NativeMember()];
        _audienceSpatialOrientation_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _enableSpatialRender_decorators, { kind: "field", name: "enableSpatialRender", static: false, private: false, access: { has: function (obj) { return "enableSpatialRender" in obj; }, get: function (obj) { return obj.enableSpatialRender; }, set: function (obj, value) { obj.enableSpatialRender = value; } }, metadata: _metadata }, _enableSpatialRender_initializers, _enableSpatialRender_extraInitializers);
        __esDecorate(null, null, _audienceSpatialPosition_decorators, { kind: "field", name: "audienceSpatialPosition", static: false, private: false, access: { has: function (obj) { return "audienceSpatialPosition" in obj; }, get: function (obj) { return obj.audienceSpatialPosition; }, set: function (obj, value) { obj.audienceSpatialPosition = value; } }, metadata: _metadata }, _audienceSpatialPosition_initializers, _audienceSpatialPosition_extraInitializers);
        __esDecorate(null, null, _audienceSpatialOrientation_decorators, { kind: "field", name: "audienceSpatialOrientation", static: false, private: false, access: { has: function (obj) { return "audienceSpatialOrientation" in obj; }, get: function (obj) { return obj.audienceSpatialOrientation; }, set: function (obj, value) { obj.audienceSpatialOrientation = value; } }, metadata: _metadata }, _audienceSpatialOrientation_initializers, _audienceSpatialOrientation_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCProblemFeedbackInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCProblemFeedbackInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _problemDesc_decorators;
    var _problemDesc_initializers = [];
    var _problemDesc_extraInitializers = [];
    var _roomInfo_decorators;
    var _roomInfo_initializers = [];
    var _roomInfo_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCProblemFeedbackInfo_1() {
            this.problemDesc = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _problemDesc_initializers, void 0));
            this.roomInfo = (__runInitializers(this, _problemDesc_extraInitializers), __runInitializers(this, _roomInfo_initializers, void 0));
            __runInitializers(this, _roomInfo_extraInitializers);
        }
        ByteRTCProblemFeedbackInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCProblemFeedbackInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCProblemFeedbackInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _problemDesc_decorators = [NativeMember()];
        _roomInfo_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _problemDesc_decorators, { kind: "field", name: "problemDesc", static: false, private: false, access: { has: function (obj) { return "problemDesc" in obj; }, get: function (obj) { return obj.problemDesc; }, set: function (obj, value) { obj.problemDesc = value; } }, metadata: _metadata }, _problemDesc_initializers, _problemDesc_extraInitializers);
        __esDecorate(null, null, _roomInfo_decorators, { kind: "field", name: "roomInfo", static: false, private: false, access: { has: function (obj) { return "roomInfo" in obj; }, get: function (obj) { return obj.roomInfo; }, set: function (obj, value) { obj.roomInfo = value; } }, metadata: _metadata }, _roomInfo_initializers, _roomInfo_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRectangle = function () {
    var _classDecorators = [NativeClass('ByteRTCRectangle')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _x_decorators;
    var _x_initializers = [];
    var _x_extraInitializers = [];
    var _y_decorators;
    var _y_initializers = [];
    var _y_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRectangle_1() {
            this.x = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _x_initializers, void 0));
            this.y = (__runInitializers(this, _x_extraInitializers), __runInitializers(this, _y_initializers, void 0));
            this.width = (__runInitializers(this, _y_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            __runInitializers(this, _height_extraInitializers);
        }
        ByteRTCRectangle_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRectangle_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRectangle");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _x_decorators = [NativeMember()];
        _y_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _x_decorators, { kind: "field", name: "x", static: false, private: false, access: { has: function (obj) { return "x" in obj; }, get: function (obj) { return obj.x; }, set: function (obj, value) { obj.x = value; } }, metadata: _metadata }, _x_initializers, _x_extraInitializers);
        __esDecorate(null, null, _y_decorators, { kind: "field", name: "y", static: false, private: false, access: { has: function (obj) { return "y" in obj; }, get: function (obj) { return obj.y; }, set: function (obj, value) { obj.y = value; } }, metadata: _metadata }, _y_initializers, _y_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCColorSpace;
(function (ByteRTCColorSpace) {
    ByteRTCColorSpace[ByteRTCColorSpace["ByteRTCColorSpaceUnknown"] = 0] = "ByteRTCColorSpaceUnknown";
    ByteRTCColorSpace[ByteRTCColorSpace["ByteRTCColorSpaceYCbCrBT601LimitedRange"] = 1] = "ByteRTCColorSpaceYCbCrBT601LimitedRange";
    ByteRTCColorSpace[ByteRTCColorSpace["ByteRTCColorSpaceYCbCrBT601FullRange"] = 2] = "ByteRTCColorSpaceYCbCrBT601FullRange";
    ByteRTCColorSpace[ByteRTCColorSpace["ByteRTCColorSpaceYCbCrBT709LimitedRange"] = 3] = "ByteRTCColorSpaceYCbCrBT709LimitedRange";
    ByteRTCColorSpace[ByteRTCColorSpace["ByteRTCColorSpaceYCbCrBT709FullRange"] = 4] = "ByteRTCColorSpaceYCbCrBT709FullRange";
})(ByteRTCColorSpace || (ByteRTCColorSpace = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCExpressionDetectResult')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _detectResult_decorators;
    var _detectResult_initializers = [];
    var _detectResult_extraInitializers = [];
    var _faceCount_decorators;
    var _faceCount_initializers = [];
    var _faceCount_extraInitializers = [];
    var _detectInfo_decorators;
    var _detectInfo_initializers = [];
    var _detectInfo_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCExpressionDetectResult_1() {
            this.detectResult = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _detectResult_initializers, void 0));
            this.faceCount = (__runInitializers(this, _detectResult_extraInitializers), __runInitializers(this, _faceCount_initializers, void 0));
            this.detectInfo = (__runInitializers(this, _faceCount_extraInitializers), __runInitializers(this, _detectInfo_initializers, void 0));
            __runInitializers(this, _detectInfo_extraInitializers);
        }
        ByteRTCExpressionDetectResult_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCExpressionDetectResult_1;
    }());
    __setFunctionName(_classThis, "ByteRTCExpressionDetectResult");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _detectResult_decorators = [NativeMember()];
        _faceCount_decorators = [NativeMember()];
        _detectInfo_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _detectResult_decorators, { kind: "field", name: "detectResult", static: false, private: false, access: { has: function (obj) { return "detectResult" in obj; }, get: function (obj) { return obj.detectResult; }, set: function (obj, value) { obj.detectResult = value; } }, metadata: _metadata }, _detectResult_initializers, _detectResult_extraInitializers);
        __esDecorate(null, null, _faceCount_decorators, { kind: "field", name: "faceCount", static: false, private: false, access: { has: function (obj) { return "faceCount" in obj; }, get: function (obj) { return obj.faceCount; }, set: function (obj, value) { obj.faceCount = value; } }, metadata: _metadata }, _faceCount_initializers, _faceCount_extraInitializers);
        __esDecorate(null, null, _detectInfo_decorators, { kind: "field", name: "detectInfo", static: false, private: false, access: { has: function (obj) { return "detectInfo" in obj; }, get: function (obj) { return obj.detectInfo; }, set: function (obj, value) { obj.detectInfo = value; } }, metadata: _metadata }, _detectInfo_initializers, _detectInfo_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCEncodedVideoFrame = function () {
    var _classDecorators = [NativeClass('ByteRTCEncodedVideoFrame')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _codecType_decorators;
    var _codecType_initializers = [];
    var _codecType_extraInitializers = [];
    var _pictureType_decorators;
    var _pictureType_initializers = [];
    var _pictureType_extraInitializers = [];
    var _timestampUs_decorators;
    var _timestampUs_initializers = [];
    var _timestampUs_extraInitializers = [];
    var _timestampDtsUs_decorators;
    var _timestampDtsUs_initializers = [];
    var _timestampDtsUs_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _rotation_decorators;
    var _rotation_initializers = [];
    var _rotation_extraInitializers = [];
    var _data_decorators;
    var _data_initializers = [];
    var _data_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCEncodedVideoFrame_1() {
            this.codecType = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _codecType_initializers, void 0));
            this.pictureType = (__runInitializers(this, _codecType_extraInitializers), __runInitializers(this, _pictureType_initializers, void 0));
            this.timestampUs = (__runInitializers(this, _pictureType_extraInitializers), __runInitializers(this, _timestampUs_initializers, void 0));
            this.timestampDtsUs = (__runInitializers(this, _timestampUs_extraInitializers), __runInitializers(this, _timestampDtsUs_initializers, void 0));
            this.width = (__runInitializers(this, _timestampDtsUs_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.rotation = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _rotation_initializers, void 0));
            this.data = (__runInitializers(this, _rotation_extraInitializers), __runInitializers(this, _data_initializers, void 0));
            __runInitializers(this, _data_extraInitializers);
        }
        ByteRTCEncodedVideoFrame_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCEncodedVideoFrame_1;
    }());
    __setFunctionName(_classThis, "ByteRTCEncodedVideoFrame");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _codecType_decorators = [NativeMember()];
        _pictureType_decorators = [NativeMember()];
        _timestampUs_decorators = [NativeMember()];
        _timestampDtsUs_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _rotation_decorators = [NativeMember()];
        _data_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _codecType_decorators, { kind: "field", name: "codecType", static: false, private: false, access: { has: function (obj) { return "codecType" in obj; }, get: function (obj) { return obj.codecType; }, set: function (obj, value) { obj.codecType = value; } }, metadata: _metadata }, _codecType_initializers, _codecType_extraInitializers);
        __esDecorate(null, null, _pictureType_decorators, { kind: "field", name: "pictureType", static: false, private: false, access: { has: function (obj) { return "pictureType" in obj; }, get: function (obj) { return obj.pictureType; }, set: function (obj, value) { obj.pictureType = value; } }, metadata: _metadata }, _pictureType_initializers, _pictureType_extraInitializers);
        __esDecorate(null, null, _timestampUs_decorators, { kind: "field", name: "timestampUs", static: false, private: false, access: { has: function (obj) { return "timestampUs" in obj; }, get: function (obj) { return obj.timestampUs; }, set: function (obj, value) { obj.timestampUs = value; } }, metadata: _metadata }, _timestampUs_initializers, _timestampUs_extraInitializers);
        __esDecorate(null, null, _timestampDtsUs_decorators, { kind: "field", name: "timestampDtsUs", static: false, private: false, access: { has: function (obj) { return "timestampDtsUs" in obj; }, get: function (obj) { return obj.timestampDtsUs; }, set: function (obj, value) { obj.timestampDtsUs = value; } }, metadata: _metadata }, _timestampDtsUs_initializers, _timestampDtsUs_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _rotation_decorators, { kind: "field", name: "rotation", static: false, private: false, access: { has: function (obj) { return "rotation" in obj; }, get: function (obj) { return obj.rotation; }, set: function (obj, value) { obj.rotation = value; } }, metadata: _metadata }, _rotation_initializers, _rotation_extraInitializers);
        __esDecorate(null, null, _data_decorators, { kind: "field", name: "data", static: false, private: false, access: { has: function (obj) { return "data" in obj; }, get: function (obj) { return obj.data; }, set: function (obj, value) { obj.data = value; } }, metadata: _metadata }, _data_initializers, _data_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCMediaDeviceType;
(function (ByteRTCMediaDeviceType) {
    ByteRTCMediaDeviceType[ByteRTCMediaDeviceType["ByteRTCMediaDeviceTypeAudioUnknown"] = -1] = "ByteRTCMediaDeviceTypeAudioUnknown";
    ByteRTCMediaDeviceType[ByteRTCMediaDeviceType["ByteRTCMediaDeviceTypeAudioRenderDevice"] = 0] = "ByteRTCMediaDeviceTypeAudioRenderDevice";
    ByteRTCMediaDeviceType[ByteRTCMediaDeviceType["ByteRTCMediaDeviceTypeAudioCaptureDevice"] = 1] = "ByteRTCMediaDeviceTypeAudioCaptureDevice";
    ByteRTCMediaDeviceType[ByteRTCMediaDeviceType["ByteRTCMediaDeviceTypeVideoRenderDevice"] = 2] = "ByteRTCMediaDeviceTypeVideoRenderDevice";
    ByteRTCMediaDeviceType[ByteRTCMediaDeviceType["ByteRTCMediaDeviceTypeVideoCaptureDevice"] = 3] = "ByteRTCMediaDeviceTypeVideoCaptureDevice";
    ByteRTCMediaDeviceType[ByteRTCMediaDeviceType["ByteRTCMediaDeviceTypeScreenVideoCaptureDevice"] = 4] = "ByteRTCMediaDeviceTypeScreenVideoCaptureDevice";
    ByteRTCMediaDeviceType[ByteRTCMediaDeviceType["ByteRTCMediaDeviceTypeScreenAudioCaptureDevice"] = 5] = "ByteRTCMediaDeviceTypeScreenAudioCaptureDevice";
})(ByteRTCMediaDeviceType || (ByteRTCMediaDeviceType = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCFrameUpdateInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _pixel_decorators;
    var _pixel_initializers = [];
    var _pixel_extraInitializers = [];
    var _framerate_decorators;
    var _framerate_initializers = [];
    var _framerate_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCFrameUpdateInfo_1() {
            this.pixel = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _pixel_initializers, void 0));
            this.framerate = (__runInitializers(this, _pixel_extraInitializers), __runInitializers(this, _framerate_initializers, void 0));
            __runInitializers(this, _framerate_extraInitializers);
        }
        ByteRTCFrameUpdateInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCFrameUpdateInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCFrameUpdateInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _pixel_decorators = [NativeMember()];
        _framerate_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _pixel_decorators, { kind: "field", name: "pixel", static: false, private: false, access: { has: function (obj) { return "pixel" in obj; }, get: function (obj) { return obj.pixel; }, set: function (obj, value) { obj.pixel = value; } }, metadata: _metadata }, _pixel_initializers, _pixel_extraInitializers);
        __esDecorate(null, null, _framerate_decorators, { kind: "field", name: "framerate", static: false, private: false, access: { has: function (obj) { return "framerate" in obj; }, get: function (obj) { return obj.framerate; }, set: function (obj, value) { obj.framerate = value; } }, metadata: _metadata }, _framerate_initializers, _framerate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCAnsMode;
(function (ByteRTCAnsMode) {
    ByteRTCAnsMode[ByteRTCAnsMode["ByteRTCAnsModeDisable"] = 0] = "ByteRTCAnsModeDisable";
    ByteRTCAnsMode[ByteRTCAnsMode["ByteRTCAnsModeLow"] = 1] = "ByteRTCAnsModeLow";
    ByteRTCAnsMode[ByteRTCAnsMode["ByteRTCAnsModeMedium"] = 2] = "ByteRTCAnsModeMedium";
    ByteRTCAnsMode[ByteRTCAnsMode["ByteRTCAnsModeHigh"] = 3] = "ByteRTCAnsModeHigh";
    ByteRTCAnsMode[ByteRTCAnsMode["ByteRTCAnsModeAutomatic"] = 4] = "ByteRTCAnsModeAutomatic";
})(ByteRTCAnsMode || (ByteRTCAnsMode = {}));
var ByteRTCMixedStreamClientMixConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCMixedStreamClientMixConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _useAudioMixer_decorators;
    var _useAudioMixer_initializers = [];
    var _useAudioMixer_extraInitializers = [];
    var _videoFormat_decorators;
    var _videoFormat_initializers = [];
    var _videoFormat_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMixedStreamClientMixConfig_1() {
            this.useAudioMixer = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _useAudioMixer_initializers, void 0));
            this.videoFormat = (__runInitializers(this, _useAudioMixer_extraInitializers), __runInitializers(this, _videoFormat_initializers, void 0));
            __runInitializers(this, _videoFormat_extraInitializers);
        }
        ByteRTCMixedStreamClientMixConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMixedStreamClientMixConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMixedStreamClientMixConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _useAudioMixer_decorators = [NativeMember()];
        _videoFormat_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _useAudioMixer_decorators, { kind: "field", name: "useAudioMixer", static: false, private: false, access: { has: function (obj) { return "useAudioMixer" in obj; }, get: function (obj) { return obj.useAudioMixer; }, set: function (obj, value) { obj.useAudioMixer = value; } }, metadata: _metadata }, _useAudioMixer_initializers, _useAudioMixer_extraInitializers);
        __esDecorate(null, null, _videoFormat_decorators, { kind: "field", name: "videoFormat", static: false, private: false, access: { has: function (obj) { return "videoFormat" in obj; }, get: function (obj) { return obj.videoFormat; }, set: function (obj, value) { obj.videoFormat = value; } }, metadata: _metadata }, _videoFormat_initializers, _videoFormat_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRemoteUserPriority;
(function (ByteRTCRemoteUserPriority) {
    ByteRTCRemoteUserPriority[ByteRTCRemoteUserPriority["ByteRTCRemoteUserPriorityLow"] = 0] = "ByteRTCRemoteUserPriorityLow";
    ByteRTCRemoteUserPriority[ByteRTCRemoteUserPriority["ByteRTCRemoteUserPriorityMedium"] = 100] = "ByteRTCRemoteUserPriorityMedium";
    ByteRTCRemoteUserPriority[ByteRTCRemoteUserPriority["ByteRTCRemoteUserPriorityHigh"] = 200] = "ByteRTCRemoteUserPriorityHigh";
})(ByteRTCRemoteUserPriority || (ByteRTCRemoteUserPriority = {}));
var ByteRTCHumanOrientation = function () {
    var _classDecorators = [NativeClass('ByteRTCHumanOrientation')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _forward_decorators;
    var _forward_initializers = [];
    var _forward_extraInitializers = [];
    var _right_decorators;
    var _right_initializers = [];
    var _right_extraInitializers = [];
    var _up_decorators;
    var _up_initializers = [];
    var _up_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCHumanOrientation_1() {
            this.forward = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _forward_initializers, void 0));
            this.right = (__runInitializers(this, _forward_extraInitializers), __runInitializers(this, _right_initializers, void 0));
            this.up = (__runInitializers(this, _right_extraInitializers), __runInitializers(this, _up_initializers, void 0));
            __runInitializers(this, _up_extraInitializers);
        }
        ByteRTCHumanOrientation_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCHumanOrientation_1;
    }());
    __setFunctionName(_classThis, "ByteRTCHumanOrientation");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _forward_decorators = [NativeMember()];
        _right_decorators = [NativeMember()];
        _up_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _forward_decorators, { kind: "field", name: "forward", static: false, private: false, access: { has: function (obj) { return "forward" in obj; }, get: function (obj) { return obj.forward; }, set: function (obj, value) { obj.forward = value; } }, metadata: _metadata }, _forward_initializers, _forward_extraInitializers);
        __esDecorate(null, null, _right_decorators, { kind: "field", name: "right", static: false, private: false, access: { has: function (obj) { return "right" in obj; }, get: function (obj) { return obj.right; }, set: function (obj, value) { obj.right = value; } }, metadata: _metadata }, _right_initializers, _right_extraInitializers);
        __esDecorate(null, null, _up_decorators, { kind: "field", name: "up", static: false, private: false, access: { has: function (obj) { return "up" in obj; }, get: function (obj) { return obj.up; }, set: function (obj, value) { obj.up = value; } }, metadata: _metadata }, _up_initializers, _up_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRecordingErrorCode;
(function (ByteRTCRecordingErrorCode) {
    ByteRTCRecordingErrorCode[ByteRTCRecordingErrorCode["ByteRTCRecordingErrorCodeOk"] = 0] = "ByteRTCRecordingErrorCodeOk";
    ByteRTCRecordingErrorCode[ByteRTCRecordingErrorCode["ByteRTCRecordingErrorCodeNoPermission"] = -1] = "ByteRTCRecordingErrorCodeNoPermission";
    ByteRTCRecordingErrorCode[ByteRTCRecordingErrorCode["ByteRTCRecordingErrorCodeNotSupport"] = -2] = "ByteRTCRecordingErrorCodeNotSupport";
    ByteRTCRecordingErrorCode[ByteRTCRecordingErrorCode["ByteRTCRecordingErrorCodeOther"] = -3] = "ByteRTCRecordingErrorCodeOther";
})(ByteRTCRecordingErrorCode || (ByteRTCRecordingErrorCode = {}));
var ByteRTCTorchState;
(function (ByteRTCTorchState) {
    ByteRTCTorchState[ByteRTCTorchState["ByteRTCTorchStateOff"] = 0] = "ByteRTCTorchStateOff";
    ByteRTCTorchState[ByteRTCTorchState["ByteRTCTorchStateOn"] = 1] = "ByteRTCTorchStateOn";
})(ByteRTCTorchState || (ByteRTCTorchState = {}));
var ByteRTCAudioFrame = function () {
    var _classDecorators = [NativeClass('ByteRTCAudioFrame')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _buffer_decorators;
    var _buffer_initializers = [];
    var _buffer_extraInitializers = [];
    var _samples_decorators;
    var _samples_initializers = [];
    var _samples_extraInitializers = [];
    var _channel_decorators;
    var _channel_initializers = [];
    var _channel_extraInitializers = [];
    var _sampleRate_decorators;
    var _sampleRate_initializers = [];
    var _sampleRate_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioFrame_1() {
            this.buffer = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _buffer_initializers, void 0));
            this.samples = (__runInitializers(this, _buffer_extraInitializers), __runInitializers(this, _samples_initializers, void 0));
            this.channel = (__runInitializers(this, _samples_extraInitializers), __runInitializers(this, _channel_initializers, void 0));
            this.sampleRate = (__runInitializers(this, _channel_extraInitializers), __runInitializers(this, _sampleRate_initializers, void 0));
            __runInitializers(this, _sampleRate_extraInitializers);
        }
        ByteRTCAudioFrame_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCAudioFrame_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioFrame");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _buffer_decorators = [NativeMember()];
        _samples_decorators = [NativeMember()];
        _channel_decorators = [NativeMember()];
        _sampleRate_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _buffer_decorators, { kind: "field", name: "buffer", static: false, private: false, access: { has: function (obj) { return "buffer" in obj; }, get: function (obj) { return obj.buffer; }, set: function (obj, value) { obj.buffer = value; } }, metadata: _metadata }, _buffer_initializers, _buffer_extraInitializers);
        __esDecorate(null, null, _samples_decorators, { kind: "field", name: "samples", static: false, private: false, access: { has: function (obj) { return "samples" in obj; }, get: function (obj) { return obj.samples; }, set: function (obj, value) { obj.samples = value; } }, metadata: _metadata }, _samples_initializers, _samples_extraInitializers);
        __esDecorate(null, null, _channel_decorators, { kind: "field", name: "channel", static: false, private: false, access: { has: function (obj) { return "channel" in obj; }, get: function (obj) { return obj.channel; }, set: function (obj, value) { obj.channel = value; } }, metadata: _metadata }, _channel_initializers, _channel_extraInitializers);
        __esDecorate(null, null, _sampleRate_decorators, { kind: "field", name: "sampleRate", static: false, private: false, access: { has: function (obj) { return "sampleRate" in obj; }, get: function (obj) { return obj.sampleRate; }, set: function (obj, value) { obj.sampleRate = value; } }, metadata: _metadata }, _sampleRate_initializers, _sampleRate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRemoteAudioStats = function () {
    var _classDecorators = [NativeClass('ByteRTCRemoteAudioStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _audioLossRate_decorators;
    var _audioLossRate_initializers = [];
    var _audioLossRate_extraInitializers = [];
    var _receivedKBitrate_decorators;
    var _receivedKBitrate_initializers = [];
    var _receivedKBitrate_extraInitializers = [];
    var _stallCount_decorators;
    var _stallCount_initializers = [];
    var _stallCount_extraInitializers = [];
    var _stallDuration_decorators;
    var _stallDuration_initializers = [];
    var _stallDuration_extraInitializers = [];
    var _playoutSampleRate_decorators;
    var _playoutSampleRate_initializers = [];
    var _playoutSampleRate_extraInitializers = [];
    var _e2eDelay_decorators;
    var _e2eDelay_initializers = [];
    var _e2eDelay_extraInitializers = [];
    var _statsInterval_decorators;
    var _statsInterval_initializers = [];
    var _statsInterval_extraInitializers = [];
    var _rtt_decorators;
    var _rtt_initializers = [];
    var _rtt_extraInitializers = [];
    var _totalRtt_decorators;
    var _totalRtt_initializers = [];
    var _totalRtt_extraInitializers = [];
    var _quality_decorators;
    var _quality_initializers = [];
    var _quality_extraInitializers = [];
    var _jitterBufferDelay_decorators;
    var _jitterBufferDelay_initializers = [];
    var _jitterBufferDelay_extraInitializers = [];
    var _numChannels_decorators;
    var _numChannels_initializers = [];
    var _numChannels_extraInitializers = [];
    var _receivedSampleRate_decorators;
    var _receivedSampleRate_initializers = [];
    var _receivedSampleRate_extraInitializers = [];
    var _frozenRate_decorators;
    var _frozenRate_initializers = [];
    var _frozenRate_extraInitializers = [];
    var _concealedSamples_decorators;
    var _concealedSamples_initializers = [];
    var _concealedSamples_extraInitializers = [];
    var _concealmentEvent_decorators;
    var _concealmentEvent_initializers = [];
    var _concealmentEvent_extraInitializers = [];
    var _decSampleRate_decorators;
    var _decSampleRate_initializers = [];
    var _decSampleRate_extraInitializers = [];
    var _decDuration_decorators;
    var _decDuration_initializers = [];
    var _decDuration_extraInitializers = [];
    var _jitter_decorators;
    var _jitter_initializers = [];
    var _jitter_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRemoteAudioStats_1() {
            this.audioLossRate = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _audioLossRate_initializers, void 0));
            this.receivedKBitrate = (__runInitializers(this, _audioLossRate_extraInitializers), __runInitializers(this, _receivedKBitrate_initializers, void 0));
            this.stallCount = (__runInitializers(this, _receivedKBitrate_extraInitializers), __runInitializers(this, _stallCount_initializers, void 0));
            this.stallDuration = (__runInitializers(this, _stallCount_extraInitializers), __runInitializers(this, _stallDuration_initializers, void 0));
            this.playoutSampleRate = (__runInitializers(this, _stallDuration_extraInitializers), __runInitializers(this, _playoutSampleRate_initializers, void 0));
            this.e2eDelay = (__runInitializers(this, _playoutSampleRate_extraInitializers), __runInitializers(this, _e2eDelay_initializers, void 0));
            this.statsInterval = (__runInitializers(this, _e2eDelay_extraInitializers), __runInitializers(this, _statsInterval_initializers, void 0));
            this.rtt = (__runInitializers(this, _statsInterval_extraInitializers), __runInitializers(this, _rtt_initializers, void 0));
            this.totalRtt = (__runInitializers(this, _rtt_extraInitializers), __runInitializers(this, _totalRtt_initializers, void 0));
            this.quality = (__runInitializers(this, _totalRtt_extraInitializers), __runInitializers(this, _quality_initializers, void 0));
            this.jitterBufferDelay = (__runInitializers(this, _quality_extraInitializers), __runInitializers(this, _jitterBufferDelay_initializers, void 0));
            this.numChannels = (__runInitializers(this, _jitterBufferDelay_extraInitializers), __runInitializers(this, _numChannels_initializers, void 0));
            this.receivedSampleRate = (__runInitializers(this, _numChannels_extraInitializers), __runInitializers(this, _receivedSampleRate_initializers, void 0));
            this.frozenRate = (__runInitializers(this, _receivedSampleRate_extraInitializers), __runInitializers(this, _frozenRate_initializers, void 0));
            this.concealedSamples = (__runInitializers(this, _frozenRate_extraInitializers), __runInitializers(this, _concealedSamples_initializers, void 0));
            this.concealmentEvent = (__runInitializers(this, _concealedSamples_extraInitializers), __runInitializers(this, _concealmentEvent_initializers, void 0));
            this.decSampleRate = (__runInitializers(this, _concealmentEvent_extraInitializers), __runInitializers(this, _decSampleRate_initializers, void 0));
            this.decDuration = (__runInitializers(this, _decSampleRate_extraInitializers), __runInitializers(this, _decDuration_initializers, void 0));
            this.jitter = (__runInitializers(this, _decDuration_extraInitializers), __runInitializers(this, _jitter_initializers, void 0));
            __runInitializers(this, _jitter_extraInitializers);
        }
        ByteRTCRemoteAudioStats_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRemoteAudioStats_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRemoteAudioStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _audioLossRate_decorators = [NativeMember()];
        _receivedKBitrate_decorators = [NativeMember()];
        _stallCount_decorators = [NativeMember()];
        _stallDuration_decorators = [NativeMember()];
        _playoutSampleRate_decorators = [NativeMember()];
        _e2eDelay_decorators = [NativeMember()];
        _statsInterval_decorators = [NativeMember()];
        _rtt_decorators = [NativeMember()];
        _totalRtt_decorators = [NativeMember()];
        _quality_decorators = [NativeMember()];
        _jitterBufferDelay_decorators = [NativeMember()];
        _numChannels_decorators = [NativeMember()];
        _receivedSampleRate_decorators = [NativeMember()];
        _frozenRate_decorators = [NativeMember()];
        _concealedSamples_decorators = [NativeMember()];
        _concealmentEvent_decorators = [NativeMember()];
        _decSampleRate_decorators = [NativeMember()];
        _decDuration_decorators = [NativeMember()];
        _jitter_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _audioLossRate_decorators, { kind: "field", name: "audioLossRate", static: false, private: false, access: { has: function (obj) { return "audioLossRate" in obj; }, get: function (obj) { return obj.audioLossRate; }, set: function (obj, value) { obj.audioLossRate = value; } }, metadata: _metadata }, _audioLossRate_initializers, _audioLossRate_extraInitializers);
        __esDecorate(null, null, _receivedKBitrate_decorators, { kind: "field", name: "receivedKBitrate", static: false, private: false, access: { has: function (obj) { return "receivedKBitrate" in obj; }, get: function (obj) { return obj.receivedKBitrate; }, set: function (obj, value) { obj.receivedKBitrate = value; } }, metadata: _metadata }, _receivedKBitrate_initializers, _receivedKBitrate_extraInitializers);
        __esDecorate(null, null, _stallCount_decorators, { kind: "field", name: "stallCount", static: false, private: false, access: { has: function (obj) { return "stallCount" in obj; }, get: function (obj) { return obj.stallCount; }, set: function (obj, value) { obj.stallCount = value; } }, metadata: _metadata }, _stallCount_initializers, _stallCount_extraInitializers);
        __esDecorate(null, null, _stallDuration_decorators, { kind: "field", name: "stallDuration", static: false, private: false, access: { has: function (obj) { return "stallDuration" in obj; }, get: function (obj) { return obj.stallDuration; }, set: function (obj, value) { obj.stallDuration = value; } }, metadata: _metadata }, _stallDuration_initializers, _stallDuration_extraInitializers);
        __esDecorate(null, null, _playoutSampleRate_decorators, { kind: "field", name: "playoutSampleRate", static: false, private: false, access: { has: function (obj) { return "playoutSampleRate" in obj; }, get: function (obj) { return obj.playoutSampleRate; }, set: function (obj, value) { obj.playoutSampleRate = value; } }, metadata: _metadata }, _playoutSampleRate_initializers, _playoutSampleRate_extraInitializers);
        __esDecorate(null, null, _e2eDelay_decorators, { kind: "field", name: "e2eDelay", static: false, private: false, access: { has: function (obj) { return "e2eDelay" in obj; }, get: function (obj) { return obj.e2eDelay; }, set: function (obj, value) { obj.e2eDelay = value; } }, metadata: _metadata }, _e2eDelay_initializers, _e2eDelay_extraInitializers);
        __esDecorate(null, null, _statsInterval_decorators, { kind: "field", name: "statsInterval", static: false, private: false, access: { has: function (obj) { return "statsInterval" in obj; }, get: function (obj) { return obj.statsInterval; }, set: function (obj, value) { obj.statsInterval = value; } }, metadata: _metadata }, _statsInterval_initializers, _statsInterval_extraInitializers);
        __esDecorate(null, null, _rtt_decorators, { kind: "field", name: "rtt", static: false, private: false, access: { has: function (obj) { return "rtt" in obj; }, get: function (obj) { return obj.rtt; }, set: function (obj, value) { obj.rtt = value; } }, metadata: _metadata }, _rtt_initializers, _rtt_extraInitializers);
        __esDecorate(null, null, _totalRtt_decorators, { kind: "field", name: "totalRtt", static: false, private: false, access: { has: function (obj) { return "totalRtt" in obj; }, get: function (obj) { return obj.totalRtt; }, set: function (obj, value) { obj.totalRtt = value; } }, metadata: _metadata }, _totalRtt_initializers, _totalRtt_extraInitializers);
        __esDecorate(null, null, _quality_decorators, { kind: "field", name: "quality", static: false, private: false, access: { has: function (obj) { return "quality" in obj; }, get: function (obj) { return obj.quality; }, set: function (obj, value) { obj.quality = value; } }, metadata: _metadata }, _quality_initializers, _quality_extraInitializers);
        __esDecorate(null, null, _jitterBufferDelay_decorators, { kind: "field", name: "jitterBufferDelay", static: false, private: false, access: { has: function (obj) { return "jitterBufferDelay" in obj; }, get: function (obj) { return obj.jitterBufferDelay; }, set: function (obj, value) { obj.jitterBufferDelay = value; } }, metadata: _metadata }, _jitterBufferDelay_initializers, _jitterBufferDelay_extraInitializers);
        __esDecorate(null, null, _numChannels_decorators, { kind: "field", name: "numChannels", static: false, private: false, access: { has: function (obj) { return "numChannels" in obj; }, get: function (obj) { return obj.numChannels; }, set: function (obj, value) { obj.numChannels = value; } }, metadata: _metadata }, _numChannels_initializers, _numChannels_extraInitializers);
        __esDecorate(null, null, _receivedSampleRate_decorators, { kind: "field", name: "receivedSampleRate", static: false, private: false, access: { has: function (obj) { return "receivedSampleRate" in obj; }, get: function (obj) { return obj.receivedSampleRate; }, set: function (obj, value) { obj.receivedSampleRate = value; } }, metadata: _metadata }, _receivedSampleRate_initializers, _receivedSampleRate_extraInitializers);
        __esDecorate(null, null, _frozenRate_decorators, { kind: "field", name: "frozenRate", static: false, private: false, access: { has: function (obj) { return "frozenRate" in obj; }, get: function (obj) { return obj.frozenRate; }, set: function (obj, value) { obj.frozenRate = value; } }, metadata: _metadata }, _frozenRate_initializers, _frozenRate_extraInitializers);
        __esDecorate(null, null, _concealedSamples_decorators, { kind: "field", name: "concealedSamples", static: false, private: false, access: { has: function (obj) { return "concealedSamples" in obj; }, get: function (obj) { return obj.concealedSamples; }, set: function (obj, value) { obj.concealedSamples = value; } }, metadata: _metadata }, _concealedSamples_initializers, _concealedSamples_extraInitializers);
        __esDecorate(null, null, _concealmentEvent_decorators, { kind: "field", name: "concealmentEvent", static: false, private: false, access: { has: function (obj) { return "concealmentEvent" in obj; }, get: function (obj) { return obj.concealmentEvent; }, set: function (obj, value) { obj.concealmentEvent = value; } }, metadata: _metadata }, _concealmentEvent_initializers, _concealmentEvent_extraInitializers);
        __esDecorate(null, null, _decSampleRate_decorators, { kind: "field", name: "decSampleRate", static: false, private: false, access: { has: function (obj) { return "decSampleRate" in obj; }, get: function (obj) { return obj.decSampleRate; }, set: function (obj, value) { obj.decSampleRate = value; } }, metadata: _metadata }, _decSampleRate_initializers, _decSampleRate_extraInitializers);
        __esDecorate(null, null, _decDuration_decorators, { kind: "field", name: "decDuration", static: false, private: false, access: { has: function (obj) { return "decDuration" in obj; }, get: function (obj) { return obj.decDuration; }, set: function (obj, value) { obj.decDuration = value; } }, metadata: _metadata }, _decDuration_initializers, _decDuration_extraInitializers);
        __esDecorate(null, null, _jitter_decorators, { kind: "field", name: "jitter", static: false, private: false, access: { has: function (obj) { return "jitter" in obj; }, get: function (obj) { return obj.jitter; }, set: function (obj, value) { obj.jitter = value; } }, metadata: _metadata }, _jitter_initializers, _jitter_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCOrientation = function () {
    var _classDecorators = [NativeClass('ByteRTCOrientation')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _x_decorators;
    var _x_initializers = [];
    var _x_extraInitializers = [];
    var _y_decorators;
    var _y_initializers = [];
    var _y_extraInitializers = [];
    var _z_decorators;
    var _z_initializers = [];
    var _z_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCOrientation_1() {
            this.x = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _x_initializers, void 0));
            this.y = (__runInitializers(this, _x_extraInitializers), __runInitializers(this, _y_initializers, void 0));
            this.z = (__runInitializers(this, _y_extraInitializers), __runInitializers(this, _z_initializers, void 0));
            __runInitializers(this, _z_extraInitializers);
        }
        ByteRTCOrientation_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCOrientation_1;
    }());
    __setFunctionName(_classThis, "ByteRTCOrientation");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _x_decorators = [NativeMember()];
        _y_decorators = [NativeMember()];
        _z_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _x_decorators, { kind: "field", name: "x", static: false, private: false, access: { has: function (obj) { return "x" in obj; }, get: function (obj) { return obj.x; }, set: function (obj, value) { obj.x = value; } }, metadata: _metadata }, _x_initializers, _x_extraInitializers);
        __esDecorate(null, null, _y_decorators, { kind: "field", name: "y", static: false, private: false, access: { has: function (obj) { return "y" in obj; }, get: function (obj) { return obj.y; }, set: function (obj, value) { obj.y = value; } }, metadata: _metadata }, _y_initializers, _y_extraInitializers);
        __esDecorate(null, null, _z_decorators, { kind: "field", name: "z", static: false, private: false, access: { has: function (obj) { return "z" in obj; }, get: function (obj) { return obj.z; }, set: function (obj, value) { obj.z = value; } }, metadata: _metadata }, _z_initializers, _z_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCPerformanceAlarmReason;
(function (ByteRTCPerformanceAlarmReason) {
    ByteRTCPerformanceAlarmReason[ByteRTCPerformanceAlarmReason["ByteRTCPerformanceAlarmReasonBandwidthFallback"] = 0] = "ByteRTCPerformanceAlarmReasonBandwidthFallback";
    ByteRTCPerformanceAlarmReason[ByteRTCPerformanceAlarmReason["ByteRTCPerformanceAlarmReasonBandwidthResumed"] = 1] = "ByteRTCPerformanceAlarmReasonBandwidthResumed";
    ByteRTCPerformanceAlarmReason[ByteRTCPerformanceAlarmReason["ByteRTCPerformanceAlarmReasonFallback"] = 2] = "ByteRTCPerformanceAlarmReasonFallback";
    ByteRTCPerformanceAlarmReason[ByteRTCPerformanceAlarmReason["ByteRTCPerformanceAlarmReasonResumed"] = 3] = "ByteRTCPerformanceAlarmReasonResumed";
})(ByteRTCPerformanceAlarmReason || (ByteRTCPerformanceAlarmReason = {}));
var ByteRTCVideoApplyRotation;
(function (ByteRTCVideoApplyRotation) {
    ByteRTCVideoApplyRotation[ByteRTCVideoApplyRotation["ByteRTCVideoApplyRotationDefault"] = -1] = "ByteRTCVideoApplyRotationDefault";
    ByteRTCVideoApplyRotation[ByteRTCVideoApplyRotation["ByteRTCVideoApplyRotation0"] = 0] = "ByteRTCVideoApplyRotation0";
})(ByteRTCVideoApplyRotation || (ByteRTCVideoApplyRotation = {}));
var ByteRTCAACProfile;
(function (ByteRTCAACProfile) {
    ByteRTCAACProfile[ByteRTCAACProfile["ByteRTCAACProfileLC"] = 0] = "ByteRTCAACProfileLC";
    ByteRTCAACProfile[ByteRTCAACProfile["ByteRTCAACProfileHEv1"] = 1] = "ByteRTCAACProfileHEv1";
    ByteRTCAACProfile[ByteRTCAACProfile["ByteRTCAACProfileHEv2"] = 2] = "ByteRTCAACProfileHEv2";
})(ByteRTCAACProfile || (ByteRTCAACProfile = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCStreamEx')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _hasVideo_decorators;
    var _hasVideo_initializers = [];
    var _hasVideo_extraInitializers = [];
    var _hasAudio_decorators;
    var _hasAudio_initializers = [];
    var _hasAudio_extraInitializers = [];
    var _videoStreamDescriptions_decorators;
    var _videoStreamDescriptions_initializers = [];
    var _videoStreamDescriptions_extraInitializers = [];
    var _maxVideoStreamDescription_decorators;
    var _maxVideoStreamDescription_initializers = [];
    var _maxVideoStreamDescription_extraInitializers = [];
    var _index_decorators;
    var _index_initializers = [];
    var _index_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCStreamEx_1() {
            this.userId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _userId_initializers, void 0));
            this.isScreen = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.hasVideo = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _hasVideo_initializers, void 0));
            this.hasAudio = (__runInitializers(this, _hasVideo_extraInitializers), __runInitializers(this, _hasAudio_initializers, void 0));
            this.videoStreamDescriptions = (__runInitializers(this, _hasAudio_extraInitializers), __runInitializers(this, _videoStreamDescriptions_initializers, void 0));
            this.maxVideoStreamDescription = (__runInitializers(this, _videoStreamDescriptions_extraInitializers), __runInitializers(this, _maxVideoStreamDescription_initializers, void 0));
            this.index = (__runInitializers(this, _maxVideoStreamDescription_extraInitializers), __runInitializers(this, _index_initializers, void 0));
            __runInitializers(this, _index_extraInitializers);
        }
        ByteRTCStreamEx_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCStreamEx_1;
    }());
    __setFunctionName(_classThis, "ByteRTCStreamEx");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _userId_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _hasVideo_decorators = [NativeMember()];
        _hasAudio_decorators = [NativeMember()];
        _videoStreamDescriptions_decorators = [NativeMember()];
        _maxVideoStreamDescription_decorators = [NativeMember()];
        _index_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _hasVideo_decorators, { kind: "field", name: "hasVideo", static: false, private: false, access: { has: function (obj) { return "hasVideo" in obj; }, get: function (obj) { return obj.hasVideo; }, set: function (obj, value) { obj.hasVideo = value; } }, metadata: _metadata }, _hasVideo_initializers, _hasVideo_extraInitializers);
        __esDecorate(null, null, _hasAudio_decorators, { kind: "field", name: "hasAudio", static: false, private: false, access: { has: function (obj) { return "hasAudio" in obj; }, get: function (obj) { return obj.hasAudio; }, set: function (obj, value) { obj.hasAudio = value; } }, metadata: _metadata }, _hasAudio_initializers, _hasAudio_extraInitializers);
        __esDecorate(null, null, _videoStreamDescriptions_decorators, { kind: "field", name: "videoStreamDescriptions", static: false, private: false, access: { has: function (obj) { return "videoStreamDescriptions" in obj; }, get: function (obj) { return obj.videoStreamDescriptions; }, set: function (obj, value) { obj.videoStreamDescriptions = value; } }, metadata: _metadata }, _videoStreamDescriptions_initializers, _videoStreamDescriptions_extraInitializers);
        __esDecorate(null, null, _maxVideoStreamDescription_decorators, { kind: "field", name: "maxVideoStreamDescription", static: false, private: false, access: { has: function (obj) { return "maxVideoStreamDescription" in obj; }, get: function (obj) { return obj.maxVideoStreamDescription; }, set: function (obj, value) { obj.maxVideoStreamDescription = value; } }, metadata: _metadata }, _maxVideoStreamDescription_initializers, _maxVideoStreamDescription_extraInitializers);
        __esDecorate(null, null, _index_decorators, { kind: "field", name: "index", static: false, private: false, access: { has: function (obj) { return "index" in obj; }, get: function (obj) { return obj.index; }, set: function (obj, value) { obj.index = value; } }, metadata: _metadata }, _index_initializers, _index_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCSyncInfoStreamType;
(function (ByteRTCSyncInfoStreamType) {
    ByteRTCSyncInfoStreamType[ByteRTCSyncInfoStreamType["ByteRTCSyncInfoStreamTypeAudio"] = 0] = "ByteRTCSyncInfoStreamTypeAudio";
})(ByteRTCSyncInfoStreamType || (ByteRTCSyncInfoStreamType = {}));
var ByteRTCMixedStreamType;
(function (ByteRTCMixedStreamType) {
    ByteRTCMixedStreamType[ByteRTCMixedStreamType["ByteRTCMixedStreamByServer"] = 0] = "ByteRTCMixedStreamByServer";
    ByteRTCMixedStreamType[ByteRTCMixedStreamType["ByteRTCMixedStreamByClient"] = 1] = "ByteRTCMixedStreamByClient";
})(ByteRTCMixedStreamType || (ByteRTCMixedStreamType = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCPublicStreamVideoConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _fps_decorators;
    var _fps_initializers = [];
    var _fps_extraInitializers = [];
    var _bitrate_decorators;
    var _bitrate_initializers = [];
    var _bitrate_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCPublicStreamVideoConfig_1() {
            this.width = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            this.fps = (__runInitializers(this, _height_extraInitializers), __runInitializers(this, _fps_initializers, void 0));
            this.bitrate = (__runInitializers(this, _fps_extraInitializers), __runInitializers(this, _bitrate_initializers, void 0));
            __runInitializers(this, _bitrate_extraInitializers);
        }
        ByteRTCPublicStreamVideoConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCPublicStreamVideoConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCPublicStreamVideoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _fps_decorators = [NativeMember()];
        _bitrate_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, null, _fps_decorators, { kind: "field", name: "fps", static: false, private: false, access: { has: function (obj) { return "fps" in obj; }, get: function (obj) { return obj.fps; }, set: function (obj, value) { obj.fps = value; } }, metadata: _metadata }, _fps_initializers, _fps_extraInitializers);
        __esDecorate(null, null, _bitrate_decorators, { kind: "field", name: "bitrate", static: false, private: false, access: { has: function (obj) { return "bitrate" in obj; }, get: function (obj) { return obj.bitrate; }, set: function (obj, value) { obj.bitrate = value; } }, metadata: _metadata }, _bitrate_initializers, _bitrate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCVoiceChangerType;
(function (ByteRTCVoiceChangerType) {
    ByteRTCVoiceChangerType[ByteRTCVoiceChangerType["ByteRTCVoiceChangerOriginal"] = 0] = "ByteRTCVoiceChangerOriginal";
    ByteRTCVoiceChangerType[ByteRTCVoiceChangerType["ByteRTCVoiceChangerGiant"] = 1] = "ByteRTCVoiceChangerGiant";
    ByteRTCVoiceChangerType[ByteRTCVoiceChangerType["ByteRTCVoiceChangerChipmunk"] = 2] = "ByteRTCVoiceChangerChipmunk";
    ByteRTCVoiceChangerType[ByteRTCVoiceChangerType["ByteRTCVoiceChangerMinionst"] = 3] = "ByteRTCVoiceChangerMinionst";
    ByteRTCVoiceChangerType[ByteRTCVoiceChangerType["ByteRTCVoiceChangerVibrato"] = 4] = "ByteRTCVoiceChangerVibrato";
    ByteRTCVoiceChangerType[ByteRTCVoiceChangerType["ByteRTCVoiceChangerRobot"] = 5] = "ByteRTCVoiceChangerRobot";
})(ByteRTCVoiceChangerType || (ByteRTCVoiceChangerType = {}));
var ByteRTCStandardPitchInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCStandardPitchInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _startTime_decorators;
    var _startTime_initializers = [];
    var _startTime_extraInitializers = [];
    var _duration_decorators;
    var _duration_initializers = [];
    var _duration_extraInitializers = [];
    var _pitch_decorators;
    var _pitch_initializers = [];
    var _pitch_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCStandardPitchInfo_1() {
            this.startTime = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _startTime_initializers, void 0));
            this.duration = (__runInitializers(this, _startTime_extraInitializers), __runInitializers(this, _duration_initializers, void 0));
            this.pitch = (__runInitializers(this, _duration_extraInitializers), __runInitializers(this, _pitch_initializers, void 0));
            __runInitializers(this, _pitch_extraInitializers);
        }
        ByteRTCStandardPitchInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCStandardPitchInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCStandardPitchInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _startTime_decorators = [NativeMember()];
        _duration_decorators = [NativeMember()];
        _pitch_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _startTime_decorators, { kind: "field", name: "startTime", static: false, private: false, access: { has: function (obj) { return "startTime" in obj; }, get: function (obj) { return obj.startTime; }, set: function (obj, value) { obj.startTime = value; } }, metadata: _metadata }, _startTime_initializers, _startTime_extraInitializers);
        __esDecorate(null, null, _duration_decorators, { kind: "field", name: "duration", static: false, private: false, access: { has: function (obj) { return "duration" in obj; }, get: function (obj) { return obj.duration; }, set: function (obj, value) { obj.duration = value; } }, metadata: _metadata }, _duration_initializers, _duration_extraInitializers);
        __esDecorate(null, null, _pitch_decorators, { kind: "field", name: "pitch", static: false, private: false, access: { has: function (obj) { return "pitch" in obj; }, get: function (obj) { return obj.pitch; }, set: function (obj, value) { obj.pitch = value; } }, metadata: _metadata }, _pitch_initializers, _pitch_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCPlayState;
(function (ByteRTCPlayState) {
    ByteRTCPlayState[ByteRTCPlayState["ByteRTCPlayStatePlaying"] = 1] = "ByteRTCPlayStatePlaying";
    ByteRTCPlayState[ByteRTCPlayState["ByteRTCPlayStatePaused"] = 2] = "ByteRTCPlayStatePaused";
    ByteRTCPlayState[ByteRTCPlayState["ByteRTCPlayStateStoped"] = 3] = "ByteRTCPlayStateStoped";
    ByteRTCPlayState[ByteRTCPlayState["ByteRTCPlayStateFailed"] = 4] = "ByteRTCPlayStateFailed";
    ByteRTCPlayState[ByteRTCPlayState["ByteRTCPlayStateFinished"] = 5] = "ByteRTCPlayStateFinished";
})(ByteRTCPlayState || (ByteRTCPlayState = {}));
var ByteRTCMixedStreamAudioProfile;
(function (ByteRTCMixedStreamAudioProfile) {
    ByteRTCMixedStreamAudioProfile[ByteRTCMixedStreamAudioProfile["ByteRTCMixedStreamAudioProfileLC"] = 0] = "ByteRTCMixedStreamAudioProfileLC";
    ByteRTCMixedStreamAudioProfile[ByteRTCMixedStreamAudioProfile["ByteRTCMixedStreamAudioProfileHEv1"] = 1] = "ByteRTCMixedStreamAudioProfileHEv1";
    ByteRTCMixedStreamAudioProfile[ByteRTCMixedStreamAudioProfile["ByteRTCMixedStreamAudioProfileHEv2"] = 2] = "ByteRTCMixedStreamAudioProfileHEv2";
})(ByteRTCMixedStreamAudioProfile || (ByteRTCMixedStreamAudioProfile = {}));
var ByteRTCVoiceReverbConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCVoiceReverbConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _roomSize_decorators;
    var _roomSize_initializers = [];
    var _roomSize_extraInitializers = [];
    var _decayTime_decorators;
    var _decayTime_initializers = [];
    var _decayTime_extraInitializers = [];
    var _damping_decorators;
    var _damping_initializers = [];
    var _damping_extraInitializers = [];
    var _wetGain_decorators;
    var _wetGain_initializers = [];
    var _wetGain_extraInitializers = [];
    var _dryGain_decorators;
    var _dryGain_initializers = [];
    var _dryGain_extraInitializers = [];
    var _preDelay_decorators;
    var _preDelay_initializers = [];
    var _preDelay_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVoiceReverbConfig_1() {
            this.roomSize = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _roomSize_initializers, void 0));
            this.decayTime = (__runInitializers(this, _roomSize_extraInitializers), __runInitializers(this, _decayTime_initializers, void 0));
            this.damping = (__runInitializers(this, _decayTime_extraInitializers), __runInitializers(this, _damping_initializers, void 0));
            this.wetGain = (__runInitializers(this, _damping_extraInitializers), __runInitializers(this, _wetGain_initializers, void 0));
            this.dryGain = (__runInitializers(this, _wetGain_extraInitializers), __runInitializers(this, _dryGain_initializers, void 0));
            this.preDelay = (__runInitializers(this, _dryGain_extraInitializers), __runInitializers(this, _preDelay_initializers, void 0));
            __runInitializers(this, _preDelay_extraInitializers);
        }
        ByteRTCVoiceReverbConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVoiceReverbConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVoiceReverbConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _roomSize_decorators = [NativeMember()];
        _decayTime_decorators = [NativeMember()];
        _damping_decorators = [NativeMember()];
        _wetGain_decorators = [NativeMember()];
        _dryGain_decorators = [NativeMember()];
        _preDelay_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _roomSize_decorators, { kind: "field", name: "roomSize", static: false, private: false, access: { has: function (obj) { return "roomSize" in obj; }, get: function (obj) { return obj.roomSize; }, set: function (obj, value) { obj.roomSize = value; } }, metadata: _metadata }, _roomSize_initializers, _roomSize_extraInitializers);
        __esDecorate(null, null, _decayTime_decorators, { kind: "field", name: "decayTime", static: false, private: false, access: { has: function (obj) { return "decayTime" in obj; }, get: function (obj) { return obj.decayTime; }, set: function (obj, value) { obj.decayTime = value; } }, metadata: _metadata }, _decayTime_initializers, _decayTime_extraInitializers);
        __esDecorate(null, null, _damping_decorators, { kind: "field", name: "damping", static: false, private: false, access: { has: function (obj) { return "damping" in obj; }, get: function (obj) { return obj.damping; }, set: function (obj, value) { obj.damping = value; } }, metadata: _metadata }, _damping_initializers, _damping_extraInitializers);
        __esDecorate(null, null, _wetGain_decorators, { kind: "field", name: "wetGain", static: false, private: false, access: { has: function (obj) { return "wetGain" in obj; }, get: function (obj) { return obj.wetGain; }, set: function (obj, value) { obj.wetGain = value; } }, metadata: _metadata }, _wetGain_initializers, _wetGain_extraInitializers);
        __esDecorate(null, null, _dryGain_decorators, { kind: "field", name: "dryGain", static: false, private: false, access: { has: function (obj) { return "dryGain" in obj; }, get: function (obj) { return obj.dryGain; }, set: function (obj, value) { obj.dryGain = value; } }, metadata: _metadata }, _dryGain_initializers, _dryGain_extraInitializers);
        __esDecorate(null, null, _preDelay_decorators, { kind: "field", name: "preDelay", static: false, private: false, access: { has: function (obj) { return "preDelay" in obj; }, get: function (obj) { return obj.preDelay; }, set: function (obj, value) { obj.preDelay = value; } }, metadata: _metadata }, _preDelay_initializers, _preDelay_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCSEICountPerFrame;
(function (ByteRTCSEICountPerFrame) {
    ByteRTCSEICountPerFrame[ByteRTCSEICountPerFrame["ByteRTCSEICountPerFrameSingle"] = 0] = "ByteRTCSEICountPerFrameSingle";
    ByteRTCSEICountPerFrame[ByteRTCSEICountPerFrame["ByteRTCSEICountPerFrameMulti"] = 1] = "ByteRTCSEICountPerFrameMulti";
})(ByteRTCSEICountPerFrame || (ByteRTCSEICountPerFrame = {}));
var ByteRTCSubtitleMode;
(function (ByteRTCSubtitleMode) {
    ByteRTCSubtitleMode[ByteRTCSubtitleMode["ByteRTCSubtitleModeRecognition"] = 0] = "ByteRTCSubtitleModeRecognition";
    ByteRTCSubtitleMode[ByteRTCSubtitleMode["ByteRTCSubtitleModeTranslation"] = 1] = "ByteRTCSubtitleModeTranslation";
})(ByteRTCSubtitleMode || (ByteRTCSubtitleMode = {}));
var ByteRTCPublishFallbackOption;
(function (ByteRTCPublishFallbackOption) {
    ByteRTCPublishFallbackOption[ByteRTCPublishFallbackOption["ByteRTCPublishFallbackOptionDisabled"] = 0] = "ByteRTCPublishFallbackOptionDisabled";
    ByteRTCPublishFallbackOption[ByteRTCPublishFallbackOption["ByteRTCPublishFallbackOptionSimulcast"] = 1] = "ByteRTCPublishFallbackOptionSimulcast";
})(ByteRTCPublishFallbackOption || (ByteRTCPublishFallbackOption = {}));
var ByteRTCPosition = function () {
    var _classDecorators = [NativeClass('ByteRTCPosition')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _x_decorators;
    var _x_initializers = [];
    var _x_extraInitializers = [];
    var _y_decorators;
    var _y_initializers = [];
    var _y_extraInitializers = [];
    var _z_decorators;
    var _z_initializers = [];
    var _z_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCPosition_1() {
            this.x = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _x_initializers, void 0));
            this.y = (__runInitializers(this, _x_extraInitializers), __runInitializers(this, _y_initializers, void 0));
            this.z = (__runInitializers(this, _y_extraInitializers), __runInitializers(this, _z_initializers, void 0));
            __runInitializers(this, _z_extraInitializers);
        }
        ByteRTCPosition_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCPosition_1;
    }());
    __setFunctionName(_classThis, "ByteRTCPosition");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _x_decorators = [NativeMember()];
        _y_decorators = [NativeMember()];
        _z_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _x_decorators, { kind: "field", name: "x", static: false, private: false, access: { has: function (obj) { return "x" in obj; }, get: function (obj) { return obj.x; }, set: function (obj, value) { obj.x = value; } }, metadata: _metadata }, _x_initializers, _x_extraInitializers);
        __esDecorate(null, null, _y_decorators, { kind: "field", name: "y", static: false, private: false, access: { has: function (obj) { return "y" in obj; }, get: function (obj) { return obj.y; }, set: function (obj, value) { obj.y = value; } }, metadata: _metadata }, _y_initializers, _y_extraInitializers);
        __esDecorate(null, null, _z_decorators, { kind: "field", name: "z", static: false, private: false, access: { has: function (obj) { return "z" in obj; }, get: function (obj) { return obj.z; }, set: function (obj, value) { obj.z = value; } }, metadata: _metadata }, _z_initializers, _z_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('ByteRTCVideoSolution')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _videoSize_decorators;
    var _videoSize_initializers = [];
    var _videoSize_extraInitializers = [];
    var _frameRate_decorators;
    var _frameRate_initializers = [];
    var _frameRate_extraInitializers = [];
    var _maxKbps_decorators;
    var _maxKbps_initializers = [];
    var _maxKbps_extraInitializers = [];
    var _minKbps_decorators;
    var _minKbps_initializers = [];
    var _minKbps_extraInitializers = [];
    var _encoderPreference_decorators;
    var _encoderPreference_initializers = [];
    var _encoderPreference_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoSolution_1() {
            this.videoSize = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _videoSize_initializers, void 0));
            this.frameRate = (__runInitializers(this, _videoSize_extraInitializers), __runInitializers(this, _frameRate_initializers, void 0));
            this.maxKbps = (__runInitializers(this, _frameRate_extraInitializers), __runInitializers(this, _maxKbps_initializers, void 0));
            this.minKbps = (__runInitializers(this, _maxKbps_extraInitializers), __runInitializers(this, _minKbps_initializers, void 0));
            this.encoderPreference = (__runInitializers(this, _minKbps_extraInitializers), __runInitializers(this, _encoderPreference_initializers, void 0));
            __runInitializers(this, _encoderPreference_extraInitializers);
        }
        ByteRTCVideoSolution_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVideoSolution_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoSolution");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _videoSize_decorators = [NativeMember()];
        _frameRate_decorators = [NativeMember()];
        _maxKbps_decorators = [NativeMember()];
        _minKbps_decorators = [NativeMember()];
        _encoderPreference_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _videoSize_decorators, { kind: "field", name: "videoSize", static: false, private: false, access: { has: function (obj) { return "videoSize" in obj; }, get: function (obj) { return obj.videoSize; }, set: function (obj, value) { obj.videoSize = value; } }, metadata: _metadata }, _videoSize_initializers, _videoSize_extraInitializers);
        __esDecorate(null, null, _frameRate_decorators, { kind: "field", name: "frameRate", static: false, private: false, access: { has: function (obj) { return "frameRate" in obj; }, get: function (obj) { return obj.frameRate; }, set: function (obj, value) { obj.frameRate = value; } }, metadata: _metadata }, _frameRate_initializers, _frameRate_extraInitializers);
        __esDecorate(null, null, _maxKbps_decorators, { kind: "field", name: "maxKbps", static: false, private: false, access: { has: function (obj) { return "maxKbps" in obj; }, get: function (obj) { return obj.maxKbps; }, set: function (obj, value) { obj.maxKbps = value; } }, metadata: _metadata }, _maxKbps_initializers, _maxKbps_extraInitializers);
        __esDecorate(null, null, _minKbps_decorators, { kind: "field", name: "minKbps", static: false, private: false, access: { has: function (obj) { return "minKbps" in obj; }, get: function (obj) { return obj.minKbps; }, set: function (obj, value) { obj.minKbps = value; } }, metadata: _metadata }, _minKbps_initializers, _minKbps_extraInitializers);
        __esDecorate(null, null, _encoderPreference_decorators, { kind: "field", name: "encoderPreference", static: false, private: false, access: { has: function (obj) { return "encoderPreference" in obj; }, get: function (obj) { return obj.encoderPreference; }, set: function (obj, value) { obj.encoderPreference = value; } }, metadata: _metadata }, _encoderPreference_initializers, _encoderPreference_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCRemoteVideoConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCRemoteVideoConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _framerate_decorators;
    var _framerate_initializers = [];
    var _framerate_extraInitializers = [];
    var _width_decorators;
    var _width_initializers = [];
    var _width_extraInitializers = [];
    var _height_decorators;
    var _height_initializers = [];
    var _height_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRemoteVideoConfig_1() {
            this.framerate = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _framerate_initializers, void 0));
            this.width = (__runInitializers(this, _framerate_extraInitializers), __runInitializers(this, _width_initializers, void 0));
            this.height = (__runInitializers(this, _width_extraInitializers), __runInitializers(this, _height_initializers, void 0));
            __runInitializers(this, _height_extraInitializers);
        }
        ByteRTCRemoteVideoConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRemoteVideoConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRemoteVideoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _framerate_decorators = [NativeMember()];
        _width_decorators = [NativeMember()];
        _height_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _framerate_decorators, { kind: "field", name: "framerate", static: false, private: false, access: { has: function (obj) { return "framerate" in obj; }, get: function (obj) { return obj.framerate; }, set: function (obj, value) { obj.framerate = value; } }, metadata: _metadata }, _framerate_initializers, _framerate_extraInitializers);
        __esDecorate(null, null, _width_decorators, { kind: "field", name: "width", static: false, private: false, access: { has: function (obj) { return "width" in obj; }, get: function (obj) { return obj.width; }, set: function (obj, value) { obj.width = value; } }, metadata: _metadata }, _width_initializers, _width_extraInitializers);
        __esDecorate(null, null, _height_decorators, { kind: "field", name: "height", static: false, private: false, access: { has: function (obj) { return "height" in obj; }, get: function (obj) { return obj.height; }, set: function (obj, value) { obj.height = value; } }, metadata: _metadata }, _height_initializers, _height_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCLocalVideoStreamError;
(function (ByteRTCLocalVideoStreamError) {
    ByteRTCLocalVideoStreamError[ByteRTCLocalVideoStreamError["ByteRTCLocalVideoStreamErrorOk"] = 0] = "ByteRTCLocalVideoStreamErrorOk";
    ByteRTCLocalVideoStreamError[ByteRTCLocalVideoStreamError["ByteRTCLocalVideoStreamErrorFailure"] = 1] = "ByteRTCLocalVideoStreamErrorFailure";
    ByteRTCLocalVideoStreamError[ByteRTCLocalVideoStreamError["ByteRTCLocalVideoStreamErrorDeviceNoPermission"] = 2] = "ByteRTCLocalVideoStreamErrorDeviceNoPermission";
    ByteRTCLocalVideoStreamError[ByteRTCLocalVideoStreamError["ByteRTCLocalVideoStreamErrorDeviceBusy"] = 3] = "ByteRTCLocalVideoStreamErrorDeviceBusy";
    ByteRTCLocalVideoStreamError[ByteRTCLocalVideoStreamError["ByteRTCLocalVideoStreamErrorDeviceNotFound"] = 4] = "ByteRTCLocalVideoStreamErrorDeviceNotFound";
    ByteRTCLocalVideoStreamError[ByteRTCLocalVideoStreamError["ByteRTCLocalVideoStreamErrorCaptureFailure"] = 5] = "ByteRTCLocalVideoStreamErrorCaptureFailure";
    ByteRTCLocalVideoStreamError[ByteRTCLocalVideoStreamError["ByteRTCLocalVideoStreamErrorEncodeFailure"] = 6] = "ByteRTCLocalVideoStreamErrorEncodeFailure";
    ByteRTCLocalVideoStreamError[ByteRTCLocalVideoStreamError["ByteRTCLocalVideoStreamErrorDeviceDisconnected"] = 7] = "ByteRTCLocalVideoStreamErrorDeviceDisconnected";
})(ByteRTCLocalVideoStreamError || (ByteRTCLocalVideoStreamError = {}));
var ByteRTCRemoteVideoRenderPosition;
(function (ByteRTCRemoteVideoRenderPosition) {
    ByteRTCRemoteVideoRenderPosition[ByteRTCRemoteVideoRenderPosition["ByteRTCRemoteVideoRenderPositionAfterDecoder"] = 0] = "ByteRTCRemoteVideoRenderPositionAfterDecoder";
    ByteRTCRemoteVideoRenderPosition[ByteRTCRemoteVideoRenderPosition["ByteRTCRemoteVideoRenderPositionAfterPostprocess"] = 1] = "ByteRTCRemoteVideoRenderPositionAfterPostprocess";
})(ByteRTCRemoteVideoRenderPosition || (ByteRTCRemoteVideoRenderPosition = {}));
var ByteRTCAudioScenarioType;
(function (ByteRTCAudioScenarioType) {
    ByteRTCAudioScenarioType[ByteRTCAudioScenarioType["ByteRTCAudioScenarioMusic"] = 0] = "ByteRTCAudioScenarioMusic";
    ByteRTCAudioScenarioType[ByteRTCAudioScenarioType["ByteRTCAudioScenarioHighqualityCommunication"] = 1] = "ByteRTCAudioScenarioHighqualityCommunication";
    ByteRTCAudioScenarioType[ByteRTCAudioScenarioType["ByteRTCAudioScenarioCommunication"] = 2] = "ByteRTCAudioScenarioCommunication";
    ByteRTCAudioScenarioType[ByteRTCAudioScenarioType["ByteRTCAudioScenarioMedia"] = 3] = "ByteRTCAudioScenarioMedia";
    ByteRTCAudioScenarioType[ByteRTCAudioScenarioType["ByteRTCAudioScenarioGameStreaming"] = 4] = "ByteRTCAudioScenarioGameStreaming";
    ByteRTCAudioScenarioType[ByteRTCAudioScenarioType["ByteRTCAudioScenarioHighqualityChat"] = 5] = "ByteRTCAudioScenarioHighqualityChat";
})(ByteRTCAudioScenarioType || (ByteRTCAudioScenarioType = {}));
var ByteRTCZoomConfigType;
(function (ByteRTCZoomConfigType) {
    ByteRTCZoomConfigType[ByteRTCZoomConfigType["ByteRTCZoomConfigTypeFocusOffset"] = 0] = "ByteRTCZoomConfigTypeFocusOffset";
    ByteRTCZoomConfigType[ByteRTCZoomConfigType["ByteRTCZoomConfigTypeMoveOffset"] = 1] = "ByteRTCZoomConfigTypeMoveOffset";
})(ByteRTCZoomConfigType || (ByteRTCZoomConfigType = {}));
var ByteRTCMediaPlayerCustomSource = function () {
    var _classDecorators = [NativeClass('ByteRTCMediaPlayerCustomSource')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _provider_decorators;
    var _provider_initializers = [];
    var _provider_extraInitializers = [];
    var _mode_decorators;
    var _mode_initializers = [];
    var _mode_extraInitializers = [];
    var _type_decorators;
    var _type_initializers = [];
    var _type_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMediaPlayerCustomSource_1() {
            this.provider = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _provider_initializers, void 0));
            this.mode = (__runInitializers(this, _provider_extraInitializers), __runInitializers(this, _mode_initializers, void 0));
            this.type = (__runInitializers(this, _mode_extraInitializers), __runInitializers(this, _type_initializers, void 0));
            __runInitializers(this, _type_extraInitializers);
        }
        ByteRTCMediaPlayerCustomSource_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMediaPlayerCustomSource_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMediaPlayerCustomSource");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _provider_decorators = [NativeMember()];
        _mode_decorators = [NativeMember()];
        _type_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _provider_decorators, { kind: "field", name: "provider", static: false, private: false, access: { has: function (obj) { return "provider" in obj; }, get: function (obj) { return obj.provider; }, set: function (obj, value) { obj.provider = value; } }, metadata: _metadata }, _provider_initializers, _provider_extraInitializers);
        __esDecorate(null, null, _mode_decorators, { kind: "field", name: "mode", static: false, private: false, access: { has: function (obj) { return "mode" in obj; }, get: function (obj) { return obj.mode; }, set: function (obj, value) { obj.mode = value; } }, metadata: _metadata }, _mode_initializers, _mode_extraInitializers);
        __esDecorate(null, null, _type_decorators, { kind: "field", name: "type", static: false, private: false, access: { has: function (obj) { return "type" in obj; }, get: function (obj) { return obj.type; }, set: function (obj, value) { obj.type = value; } }, metadata: _metadata }, _type_initializers, _type_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCNetworkQualityStats = function () {
    var _classDecorators = [NativeClass('ByteRTCNetworkQualityStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _uid_decorators;
    var _uid_initializers = [];
    var _uid_extraInitializers = [];
    var _lossRatio_decorators;
    var _lossRatio_initializers = [];
    var _lossRatio_extraInitializers = [];
    var _rtt_decorators;
    var _rtt_initializers = [];
    var _rtt_extraInitializers = [];
    var _totalBandwidth_decorators;
    var _totalBandwidth_initializers = [];
    var _totalBandwidth_extraInitializers = [];
    var _txQuality_decorators;
    var _txQuality_initializers = [];
    var _txQuality_extraInitializers = [];
    var _rxQuality_decorators;
    var _rxQuality_initializers = [];
    var _rxQuality_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCNetworkQualityStats_1() {
            this.uid = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _uid_initializers, void 0));
            this.lossRatio = (__runInitializers(this, _uid_extraInitializers), __runInitializers(this, _lossRatio_initializers, void 0));
            this.rtt = (__runInitializers(this, _lossRatio_extraInitializers), __runInitializers(this, _rtt_initializers, void 0));
            this.totalBandwidth = (__runInitializers(this, _rtt_extraInitializers), __runInitializers(this, _totalBandwidth_initializers, void 0));
            this.txQuality = (__runInitializers(this, _totalBandwidth_extraInitializers), __runInitializers(this, _txQuality_initializers, void 0));
            this.rxQuality = (__runInitializers(this, _txQuality_extraInitializers), __runInitializers(this, _rxQuality_initializers, void 0));
            __runInitializers(this, _rxQuality_extraInitializers);
        }
        ByteRTCNetworkQualityStats_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCNetworkQualityStats_1;
    }());
    __setFunctionName(_classThis, "ByteRTCNetworkQualityStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _uid_decorators = [NativeMember()];
        _lossRatio_decorators = [NativeMember()];
        _rtt_decorators = [NativeMember()];
        _totalBandwidth_decorators = [NativeMember()];
        _txQuality_decorators = [NativeMember()];
        _rxQuality_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _uid_decorators, { kind: "field", name: "uid", static: false, private: false, access: { has: function (obj) { return "uid" in obj; }, get: function (obj) { return obj.uid; }, set: function (obj, value) { obj.uid = value; } }, metadata: _metadata }, _uid_initializers, _uid_extraInitializers);
        __esDecorate(null, null, _lossRatio_decorators, { kind: "field", name: "lossRatio", static: false, private: false, access: { has: function (obj) { return "lossRatio" in obj; }, get: function (obj) { return obj.lossRatio; }, set: function (obj, value) { obj.lossRatio = value; } }, metadata: _metadata }, _lossRatio_initializers, _lossRatio_extraInitializers);
        __esDecorate(null, null, _rtt_decorators, { kind: "field", name: "rtt", static: false, private: false, access: { has: function (obj) { return "rtt" in obj; }, get: function (obj) { return obj.rtt; }, set: function (obj, value) { obj.rtt = value; } }, metadata: _metadata }, _rtt_initializers, _rtt_extraInitializers);
        __esDecorate(null, null, _totalBandwidth_decorators, { kind: "field", name: "totalBandwidth", static: false, private: false, access: { has: function (obj) { return "totalBandwidth" in obj; }, get: function (obj) { return obj.totalBandwidth; }, set: function (obj, value) { obj.totalBandwidth = value; } }, metadata: _metadata }, _totalBandwidth_initializers, _totalBandwidth_extraInitializers);
        __esDecorate(null, null, _txQuality_decorators, { kind: "field", name: "txQuality", static: false, private: false, access: { has: function (obj) { return "txQuality" in obj; }, get: function (obj) { return obj.txQuality; }, set: function (obj, value) { obj.txQuality = value; } }, metadata: _metadata }, _txQuality_initializers, _txQuality_extraInitializers);
        __esDecorate(null, null, _rxQuality_decorators, { kind: "field", name: "rxQuality", static: false, private: false, access: { has: function (obj) { return "rxQuality" in obj; }, get: function (obj) { return obj.rxQuality; }, set: function (obj, value) { obj.rxQuality = value; } }, metadata: _metadata }, _rxQuality_initializers, _rxQuality_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCStreamMixingType;
(function (ByteRTCStreamMixingType) {
    ByteRTCStreamMixingType[ByteRTCStreamMixingType["ByteRTCStreamMixingTypeByServer"] = 0] = "ByteRTCStreamMixingTypeByServer";
    ByteRTCStreamMixingType[ByteRTCStreamMixingType["ByteRTCStreamMixingTypeByClient"] = 1] = "ByteRTCStreamMixingTypeByClient";
})(ByteRTCStreamMixingType || (ByteRTCStreamMixingType = {}));
var ByteRTCMixedStreamLayoutRegionType;
(function (ByteRTCMixedStreamLayoutRegionType) {
    ByteRTCMixedStreamLayoutRegionType[ByteRTCMixedStreamLayoutRegionType["ByteRTCMixedStreamLayoutRegionTypeVideoStream"] = 0] = "ByteRTCMixedStreamLayoutRegionTypeVideoStream";
    ByteRTCMixedStreamLayoutRegionType[ByteRTCMixedStreamLayoutRegionType["ByteRTCMixedStreamLayoutRegionTypeImage"] = 1] = "ByteRTCMixedStreamLayoutRegionTypeImage";
})(ByteRTCMixedStreamLayoutRegionType || (ByteRTCMixedStreamLayoutRegionType = {}));
var ByteRTCAudioFrameMethod;
(function (ByteRTCAudioFrameMethod) {
    ByteRTCAudioFrameMethod[ByteRTCAudioFrameMethod["ByteRTCAudioFrameProcessorRecord"] = 0] = "ByteRTCAudioFrameProcessorRecord";
    ByteRTCAudioFrameMethod[ByteRTCAudioFrameMethod["ByteRTCAudioFrameProcessorPlayback"] = 1] = "ByteRTCAudioFrameProcessorPlayback";
    ByteRTCAudioFrameMethod[ByteRTCAudioFrameMethod["ByteRTCAudioFrameProcessorRemoteUser"] = 2] = "ByteRTCAudioFrameProcessorRemoteUser";
    ByteRTCAudioFrameMethod[ByteRTCAudioFrameMethod["ByteRTCAudioFrameProcessorEarMonitor"] = 3] = "ByteRTCAudioFrameProcessorEarMonitor";
    ByteRTCAudioFrameMethod[ByteRTCAudioFrameMethod["ByteRTCAudioFrameProcessorScreen"] = 4] = "ByteRTCAudioFrameProcessorScreen";
})(ByteRTCAudioFrameMethod || (ByteRTCAudioFrameMethod = {}));
var ByteRTCEarMonitorMode;
(function (ByteRTCEarMonitorMode) {
    ByteRTCEarMonitorMode[ByteRTCEarMonitorMode["ByteRTCEarMonitorModeOff"] = 0] = "ByteRTCEarMonitorModeOff";
    ByteRTCEarMonitorMode[ByteRTCEarMonitorMode["ByteRTCEarMonitorModeOn"] = 1] = "ByteRTCEarMonitorModeOn";
})(ByteRTCEarMonitorMode || (ByteRTCEarMonitorMode = {}));
var ByteRTCVideoCodecType;
(function (ByteRTCVideoCodecType) {
    ByteRTCVideoCodecType[ByteRTCVideoCodecType["ByteRTCVideoCodecTypeUnknown"] = 0] = "ByteRTCVideoCodecTypeUnknown";
    ByteRTCVideoCodecType[ByteRTCVideoCodecType["ByteRTCVideoCodecTypeH264"] = 1] = "ByteRTCVideoCodecTypeH264";
    ByteRTCVideoCodecType[ByteRTCVideoCodecType["ByteRTCVideoCodecTypeByteVC1"] = 2] = "ByteRTCVideoCodecTypeByteVC1";
})(ByteRTCVideoCodecType || (ByteRTCVideoCodecType = {}));
var ByteRTCLocalStreamStats = function () {
    var _classDecorators = [NativeClass('ByteRTCLocalStreamStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _audioStats_decorators;
    var _audioStats_initializers = [];
    var _audioStats_extraInitializers = [];
    var _videoStats_decorators;
    var _videoStats_initializers = [];
    var _videoStats_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _txQuality_decorators;
    var _txQuality_initializers = [];
    var _txQuality_extraInitializers = [];
    var _rxQuality_decorators;
    var _rxQuality_initializers = [];
    var _rxQuality_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCLocalStreamStats_1() {
            this.audioStats = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _audioStats_initializers, void 0));
            this.videoStats = (__runInitializers(this, _audioStats_extraInitializers), __runInitializers(this, _videoStats_initializers, void 0));
            this.isScreen = (__runInitializers(this, _videoStats_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.txQuality = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _txQuality_initializers, void 0));
            this.rxQuality = (__runInitializers(this, _txQuality_extraInitializers), __runInitializers(this, _rxQuality_initializers, void 0));
            __runInitializers(this, _rxQuality_extraInitializers);
        }
        ByteRTCLocalStreamStats_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCLocalStreamStats_1;
    }());
    __setFunctionName(_classThis, "ByteRTCLocalStreamStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _audioStats_decorators = [NativeMember()];
        _videoStats_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _txQuality_decorators = [NativeMember()];
        _rxQuality_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _audioStats_decorators, { kind: "field", name: "audioStats", static: false, private: false, access: { has: function (obj) { return "audioStats" in obj; }, get: function (obj) { return obj.audioStats; }, set: function (obj, value) { obj.audioStats = value; } }, metadata: _metadata }, _audioStats_initializers, _audioStats_extraInitializers);
        __esDecorate(null, null, _videoStats_decorators, { kind: "field", name: "videoStats", static: false, private: false, access: { has: function (obj) { return "videoStats" in obj; }, get: function (obj) { return obj.videoStats; }, set: function (obj, value) { obj.videoStats = value; } }, metadata: _metadata }, _videoStats_initializers, _videoStats_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _txQuality_decorators, { kind: "field", name: "txQuality", static: false, private: false, access: { has: function (obj) { return "txQuality" in obj; }, get: function (obj) { return obj.txQuality; }, set: function (obj, value) { obj.txQuality = value; } }, metadata: _metadata }, _txQuality_initializers, _txQuality_extraInitializers);
        __esDecorate(null, null, _rxQuality_decorators, { kind: "field", name: "rxQuality", static: false, private: false, access: { has: function (obj) { return "rxQuality" in obj; }, get: function (obj) { return obj.rxQuality; }, set: function (obj, value) { obj.rxQuality = value; } }, metadata: _metadata }, _rxQuality_initializers, _rxQuality_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCVideoRotation;
(function (ByteRTCVideoRotation) {
    ByteRTCVideoRotation[ByteRTCVideoRotation["ByteRTCVideoRotation0"] = 0] = "ByteRTCVideoRotation0";
    ByteRTCVideoRotation[ByteRTCVideoRotation["ByteRTCVideoRotation90"] = 90] = "ByteRTCVideoRotation90";
    ByteRTCVideoRotation[ByteRTCVideoRotation["ByteRTCVideoRotation180"] = 180] = "ByteRTCVideoRotation180";
    ByteRTCVideoRotation[ByteRTCVideoRotation["ByteRTCVideoRotation270"] = 270] = "ByteRTCVideoRotation270";
})(ByteRTCVideoRotation || (ByteRTCVideoRotation = {}));
var ByteRTCDataFrameType;
(function (ByteRTCDataFrameType) {
    ByteRTCDataFrameType[ByteRTCDataFrameType["ByteRTCDataFrameTypeSei"] = 0] = "ByteRTCDataFrameTypeSei";
    ByteRTCDataFrameType[ByteRTCDataFrameType["ByteRTCDataFrameTypeRoi"] = 1] = "ByteRTCDataFrameTypeRoi";
    ByteRTCDataFrameType[ByteRTCDataFrameType["ByteRTCDataFrameTypeOther"] = 2] = "ByteRTCDataFrameTypeOther";
})(ByteRTCDataFrameType || (ByteRTCDataFrameType = {}));
var ByteRTCTranscodingVideoCodec;
(function (ByteRTCTranscodingVideoCodec) {
    ByteRTCTranscodingVideoCodec[ByteRTCTranscodingVideoCodec["ByteRTCTranscodingVideoCodecH264"] = 0] = "ByteRTCTranscodingVideoCodecH264";
    ByteRTCTranscodingVideoCodec[ByteRTCTranscodingVideoCodec["ByteRTCTranscodingVideoCodecH265"] = 1] = "ByteRTCTranscodingVideoCodecH265";
})(ByteRTCTranscodingVideoCodec || (ByteRTCTranscodingVideoCodec = {}));
var ByteRTCMouseCursorCaptureState;
(function (ByteRTCMouseCursorCaptureState) {
    ByteRTCMouseCursorCaptureState[ByteRTCMouseCursorCaptureState["ByteRTCMouseCursorCaptureStateOn"] = 0] = "ByteRTCMouseCursorCaptureStateOn";
    ByteRTCMouseCursorCaptureState[ByteRTCMouseCursorCaptureState["ByteRTCMouseCursorCaptureStateOff"] = 1] = "ByteRTCMouseCursorCaptureStateOff";
})(ByteRTCMouseCursorCaptureState || (ByteRTCMouseCursorCaptureState = {}));
var ByteRTCSubscribeFallbackOption;
(function (ByteRTCSubscribeFallbackOption) {
    ByteRTCSubscribeFallbackOption[ByteRTCSubscribeFallbackOption["ByteRTCSubscribeFallbackOptionDisabled"] = 0] = "ByteRTCSubscribeFallbackOptionDisabled";
    ByteRTCSubscribeFallbackOption[ByteRTCSubscribeFallbackOption["ByteRTCSubscribeFallbackOptionVideoStreamLow"] = 1] = "ByteRTCSubscribeFallbackOptionVideoStreamLow";
    ByteRTCSubscribeFallbackOption[ByteRTCSubscribeFallbackOption["ByteRTCSubscribeFallbackOptionAudioOnly"] = 2] = "ByteRTCSubscribeFallbackOptionAudioOnly";
})(ByteRTCSubscribeFallbackOption || (ByteRTCSubscribeFallbackOption = {}));
var ByteRTCAudioSourceType;
(function (ByteRTCAudioSourceType) {
    ByteRTCAudioSourceType[ByteRTCAudioSourceType["ByteRTCAudioSourceTypeExternal"] = 0] = "ByteRTCAudioSourceTypeExternal";
    ByteRTCAudioSourceType[ByteRTCAudioSourceType["ByteRTCAudioSourceTypeInternal"] = 1] = "ByteRTCAudioSourceTypeInternal";
})(ByteRTCAudioSourceType || (ByteRTCAudioSourceType = {}));
var ByteRTCRemoteStreamKey = function () {
    var _classDecorators = [NativeClass('ByteRTCRemoteStreamKey')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _userId_decorators;
    var _userId_initializers = [];
    var _userId_extraInitializers = [];
    var _roomId_decorators;
    var _roomId_initializers = [];
    var _roomId_extraInitializers = [];
    var _streamIndex_decorators;
    var _streamIndex_initializers = [];
    var _streamIndex_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRemoteStreamKey_1() {
            this.userId = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _userId_initializers, void 0));
            this.roomId = (__runInitializers(this, _userId_extraInitializers), __runInitializers(this, _roomId_initializers, void 0));
            this.streamIndex = (__runInitializers(this, _roomId_extraInitializers), __runInitializers(this, _streamIndex_initializers, void 0));
            __runInitializers(this, _streamIndex_extraInitializers);
        }
        ByteRTCRemoteStreamKey_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRemoteStreamKey_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRemoteStreamKey");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _userId_decorators = [NativeMember()];
        _roomId_decorators = [NativeMember()];
        _streamIndex_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _userId_decorators, { kind: "field", name: "userId", static: false, private: false, access: { has: function (obj) { return "userId" in obj; }, get: function (obj) { return obj.userId; }, set: function (obj, value) { obj.userId = value; } }, metadata: _metadata }, _userId_initializers, _userId_extraInitializers);
        __esDecorate(null, null, _roomId_decorators, { kind: "field", name: "roomId", static: false, private: false, access: { has: function (obj) { return "roomId" in obj; }, get: function (obj) { return obj.roomId; }, set: function (obj, value) { obj.roomId = value; } }, metadata: _metadata }, _roomId_initializers, _roomId_extraInitializers);
        __esDecorate(null, null, _streamIndex_decorators, { kind: "field", name: "streamIndex", static: false, private: false, access: { has: function (obj) { return "streamIndex" in obj; }, get: function (obj) { return obj.streamIndex; }, set: function (obj, value) { obj.streamIndex = value; } }, metadata: _metadata }, _streamIndex_initializers, _streamIndex_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCPlayerState;
(function (ByteRTCPlayerState) {
    ByteRTCPlayerState[ByteRTCPlayerState["ByteRTCPlayerStateIdle"] = 0] = "ByteRTCPlayerStateIdle";
    ByteRTCPlayerState[ByteRTCPlayerState["ByteRTCPlayerStatePreloaded"] = 1] = "ByteRTCPlayerStatePreloaded";
    ByteRTCPlayerState[ByteRTCPlayerState["ByteRTCPlayerStateOpened"] = 2] = "ByteRTCPlayerStateOpened";
    ByteRTCPlayerState[ByteRTCPlayerState["ByteRTCPlayerStatePlaying"] = 3] = "ByteRTCPlayerStatePlaying";
    ByteRTCPlayerState[ByteRTCPlayerState["ByteRTCPlayerStatePaused"] = 4] = "ByteRTCPlayerStatePaused";
    ByteRTCPlayerState[ByteRTCPlayerState["ByteRTCPlayerStateStopped"] = 5] = "ByteRTCPlayerStateStopped";
    ByteRTCPlayerState[ByteRTCPlayerState["ByteRTCPlayerStateFailed"] = 6] = "ByteRTCPlayerStateFailed";
    ByteRTCPlayerState[ByteRTCPlayerState["ByteRTCPlayerStateFinished"] = 7] = "ByteRTCPlayerStateFinished";
})(ByteRTCPlayerState || (ByteRTCPlayerState = {}));
var ByteRTCMediaPlayerConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCMediaPlayerConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _type_decorators;
    var _type_initializers = [];
    var _type_extraInitializers = [];
    var _playCount_decorators;
    var _playCount_initializers = [];
    var _playCount_extraInitializers = [];
    var _startPos_decorators;
    var _startPos_initializers = [];
    var _startPos_extraInitializers = [];
    var _callbackOnProgressInterval_decorators;
    var _callbackOnProgressInterval_initializers = [];
    var _callbackOnProgressInterval_extraInitializers = [];
    var _syncProgressToRecordFrame_decorators;
    var _syncProgressToRecordFrame_initializers = [];
    var _syncProgressToRecordFrame_extraInitializers = [];
    var _autoPlay_decorators;
    var _autoPlay_initializers = [];
    var _autoPlay_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMediaPlayerConfig_1() {
            this.type = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _type_initializers, void 0));
            this.playCount = (__runInitializers(this, _type_extraInitializers), __runInitializers(this, _playCount_initializers, void 0));
            this.startPos = (__runInitializers(this, _playCount_extraInitializers), __runInitializers(this, _startPos_initializers, void 0));
            this.callbackOnProgressInterval = (__runInitializers(this, _startPos_extraInitializers), __runInitializers(this, _callbackOnProgressInterval_initializers, void 0));
            this.syncProgressToRecordFrame = (__runInitializers(this, _callbackOnProgressInterval_extraInitializers), __runInitializers(this, _syncProgressToRecordFrame_initializers, void 0));
            this.autoPlay = (__runInitializers(this, _syncProgressToRecordFrame_extraInitializers), __runInitializers(this, _autoPlay_initializers, void 0));
            __runInitializers(this, _autoPlay_extraInitializers);
        }
        ByteRTCMediaPlayerConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMediaPlayerConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMediaPlayerConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _type_decorators = [NativeMember()];
        _playCount_decorators = [NativeMember()];
        _startPos_decorators = [NativeMember()];
        _callbackOnProgressInterval_decorators = [NativeMember()];
        _syncProgressToRecordFrame_decorators = [NativeMember()];
        _autoPlay_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _type_decorators, { kind: "field", name: "type", static: false, private: false, access: { has: function (obj) { return "type" in obj; }, get: function (obj) { return obj.type; }, set: function (obj, value) { obj.type = value; } }, metadata: _metadata }, _type_initializers, _type_extraInitializers);
        __esDecorate(null, null, _playCount_decorators, { kind: "field", name: "playCount", static: false, private: false, access: { has: function (obj) { return "playCount" in obj; }, get: function (obj) { return obj.playCount; }, set: function (obj, value) { obj.playCount = value; } }, metadata: _metadata }, _playCount_initializers, _playCount_extraInitializers);
        __esDecorate(null, null, _startPos_decorators, { kind: "field", name: "startPos", static: false, private: false, access: { has: function (obj) { return "startPos" in obj; }, get: function (obj) { return obj.startPos; }, set: function (obj, value) { obj.startPos = value; } }, metadata: _metadata }, _startPos_initializers, _startPos_extraInitializers);
        __esDecorate(null, null, _callbackOnProgressInterval_decorators, { kind: "field", name: "callbackOnProgressInterval", static: false, private: false, access: { has: function (obj) { return "callbackOnProgressInterval" in obj; }, get: function (obj) { return obj.callbackOnProgressInterval; }, set: function (obj, value) { obj.callbackOnProgressInterval = value; } }, metadata: _metadata }, _callbackOnProgressInterval_initializers, _callbackOnProgressInterval_extraInitializers);
        __esDecorate(null, null, _syncProgressToRecordFrame_decorators, { kind: "field", name: "syncProgressToRecordFrame", static: false, private: false, access: { has: function (obj) { return "syncProgressToRecordFrame" in obj; }, get: function (obj) { return obj.syncProgressToRecordFrame; }, set: function (obj, value) { obj.syncProgressToRecordFrame = value; } }, metadata: _metadata }, _syncProgressToRecordFrame_initializers, _syncProgressToRecordFrame_extraInitializers);
        __esDecorate(null, null, _autoPlay_decorators, { kind: "field", name: "autoPlay", static: false, private: false, access: { has: function (obj) { return "autoPlay" in obj; }, get: function (obj) { return obj.autoPlay; }, set: function (obj, value) { obj.autoPlay = value; } }, metadata: _metadata }, _autoPlay_initializers, _autoPlay_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCVideoRotationMode;
(function (ByteRTCVideoRotationMode) {
    ByteRTCVideoRotationMode[ByteRTCVideoRotationMode["ByteRTCVideoRotationModeFollowApp"] = 0] = "ByteRTCVideoRotationModeFollowApp";
    ByteRTCVideoRotationMode[ByteRTCVideoRotationMode["ByteRTCVideoRotationModeFollowGSensor"] = 1] = "ByteRTCVideoRotationModeFollowGSensor";
})(ByteRTCVideoRotationMode || (ByteRTCVideoRotationMode = {}));
var ByteRTCForwardStreamEvent;
(function (ByteRTCForwardStreamEvent) {
    ByteRTCForwardStreamEvent[ByteRTCForwardStreamEvent["ByteRTCForwardStreamEventDisconnected"] = 0] = "ByteRTCForwardStreamEventDisconnected";
    ByteRTCForwardStreamEvent[ByteRTCForwardStreamEvent["ByteRTCForwardStreamEventConnected"] = 1] = "ByteRTCForwardStreamEventConnected";
    ByteRTCForwardStreamEvent[ByteRTCForwardStreamEvent["ByteRTCForwardStreamEventInterrupt"] = 2] = "ByteRTCForwardStreamEventInterrupt";
    ByteRTCForwardStreamEvent[ByteRTCForwardStreamEvent["ByteRTCForwardStreamEventDstRoomUpdated"] = 3] = "ByteRTCForwardStreamEventDstRoomUpdated";
    ByteRTCForwardStreamEvent[ByteRTCForwardStreamEvent["ByteRTCForwardStreamEventUnExpectAPICall"] = 4] = "ByteRTCForwardStreamEventUnExpectAPICall";
})(ByteRTCForwardStreamEvent || (ByteRTCForwardStreamEvent = {}));
var ByteRTCVideoFrameType;
(function (ByteRTCVideoFrameType) {
    ByteRTCVideoFrameType[ByteRTCVideoFrameType["ByteRTCVideoFrameTypeRawMemory"] = 0] = "ByteRTCVideoFrameTypeRawMemory";
    ByteRTCVideoFrameType[ByteRTCVideoFrameType["ByteRTCVideoFrameTypePixelBuffer"] = 1] = "ByteRTCVideoFrameTypePixelBuffer";
})(ByteRTCVideoFrameType || (ByteRTCVideoFrameType = {}));
var ByteRTCLocalAudioPropertiesInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCLocalAudioPropertiesInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _streamIndex_decorators;
    var _streamIndex_initializers = [];
    var _streamIndex_extraInitializers = [];
    var _audioPropertiesInfo_decorators;
    var _audioPropertiesInfo_initializers = [];
    var _audioPropertiesInfo_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCLocalAudioPropertiesInfo_1() {
            this.streamIndex = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _streamIndex_initializers, void 0));
            this.audioPropertiesInfo = (__runInitializers(this, _streamIndex_extraInitializers), __runInitializers(this, _audioPropertiesInfo_initializers, void 0));
            __runInitializers(this, _audioPropertiesInfo_extraInitializers);
        }
        ByteRTCLocalAudioPropertiesInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCLocalAudioPropertiesInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCLocalAudioPropertiesInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _streamIndex_decorators = [NativeMember()];
        _audioPropertiesInfo_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _streamIndex_decorators, { kind: "field", name: "streamIndex", static: false, private: false, access: { has: function (obj) { return "streamIndex" in obj; }, get: function (obj) { return obj.streamIndex; }, set: function (obj, value) { obj.streamIndex = value; } }, metadata: _metadata }, _streamIndex_initializers, _streamIndex_extraInitializers);
        __esDecorate(null, null, _audioPropertiesInfo_decorators, { kind: "field", name: "audioPropertiesInfo", static: false, private: false, access: { has: function (obj) { return "audioPropertiesInfo" in obj; }, get: function (obj) { return obj.audioPropertiesInfo; }, set: function (obj, value) { obj.audioPropertiesInfo = value; } }, metadata: _metadata }, _audioPropertiesInfo_initializers, _audioPropertiesInfo_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCCameraID;
(function (ByteRTCCameraID) {
    ByteRTCCameraID[ByteRTCCameraID["ByteRTCCameraIDFront"] = 0] = "ByteRTCCameraIDFront";
    ByteRTCCameraID[ByteRTCCameraID["ByteRTCCameraIDBack"] = 1] = "ByteRTCCameraIDBack";
    ByteRTCCameraID[ByteRTCCameraID["ByteRTCCameraIDExternal"] = 2] = "ByteRTCCameraIDExternal";
    ByteRTCCameraID[ByteRTCCameraID["ByteRTCCameraIDInvalid"] = 3] = "ByteRTCCameraIDInvalid";
})(ByteRTCCameraID || (ByteRTCCameraID = {}));
var ByteRTCCloudProxyInfo = function () {
    var _classDecorators = [NativeClass('ByteRTCCloudProxyInfo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _cloudProxyIp_decorators;
    var _cloudProxyIp_initializers = [];
    var _cloudProxyIp_extraInitializers = [];
    var _cloudProxyPort_decorators;
    var _cloudProxyPort_initializers = [];
    var _cloudProxyPort_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCCloudProxyInfo_1() {
            this.cloudProxyIp = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _cloudProxyIp_initializers, void 0));
            this.cloudProxyPort = (__runInitializers(this, _cloudProxyIp_extraInitializers), __runInitializers(this, _cloudProxyPort_initializers, void 0));
            __runInitializers(this, _cloudProxyPort_extraInitializers);
        }
        ByteRTCCloudProxyInfo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCCloudProxyInfo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCCloudProxyInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _cloudProxyIp_decorators = [NativeMember()];
        _cloudProxyPort_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _cloudProxyIp_decorators, { kind: "field", name: "cloudProxyIp", static: false, private: false, access: { has: function (obj) { return "cloudProxyIp" in obj; }, get: function (obj) { return obj.cloudProxyIp; }, set: function (obj, value) { obj.cloudProxyIp = value; } }, metadata: _metadata }, _cloudProxyIp_initializers, _cloudProxyIp_extraInitializers);
        __esDecorate(null, null, _cloudProxyPort_decorators, { kind: "field", name: "cloudProxyPort", static: false, private: false, access: { has: function (obj) { return "cloudProxyPort" in obj; }, get: function (obj) { return obj.cloudProxyPort; }, set: function (obj, value) { obj.cloudProxyPort = value; } }, metadata: _metadata }, _cloudProxyPort_initializers, _cloudProxyPort_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCMixedStreamAudioConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCMixedStreamAudioConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _audioCodec_decorators;
    var _audioCodec_initializers = [];
    var _audioCodec_extraInitializers = [];
    var _sampleRate_decorators;
    var _sampleRate_initializers = [];
    var _sampleRate_extraInitializers = [];
    var _channels_decorators;
    var _channels_initializers = [];
    var _channels_extraInitializers = [];
    var _bitrate_decorators;
    var _bitrate_initializers = [];
    var _bitrate_extraInitializers = [];
    var _audioProfile_decorators;
    var _audioProfile_initializers = [];
    var _audioProfile_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMixedStreamAudioConfig_1() {
            this.audioCodec = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _audioCodec_initializers, void 0));
            this.sampleRate = (__runInitializers(this, _audioCodec_extraInitializers), __runInitializers(this, _sampleRate_initializers, void 0));
            this.channels = (__runInitializers(this, _sampleRate_extraInitializers), __runInitializers(this, _channels_initializers, void 0));
            this.bitrate = (__runInitializers(this, _channels_extraInitializers), __runInitializers(this, _bitrate_initializers, void 0));
            this.audioProfile = (__runInitializers(this, _bitrate_extraInitializers), __runInitializers(this, _audioProfile_initializers, void 0));
            __runInitializers(this, _audioProfile_extraInitializers);
        }
        ByteRTCMixedStreamAudioConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMixedStreamAudioConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMixedStreamAudioConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _audioCodec_decorators = [NativeMember()];
        _sampleRate_decorators = [NativeMember()];
        _channels_decorators = [NativeMember()];
        _bitrate_decorators = [NativeMember()];
        _audioProfile_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _audioCodec_decorators, { kind: "field", name: "audioCodec", static: false, private: false, access: { has: function (obj) { return "audioCodec" in obj; }, get: function (obj) { return obj.audioCodec; }, set: function (obj, value) { obj.audioCodec = value; } }, metadata: _metadata }, _audioCodec_initializers, _audioCodec_extraInitializers);
        __esDecorate(null, null, _sampleRate_decorators, { kind: "field", name: "sampleRate", static: false, private: false, access: { has: function (obj) { return "sampleRate" in obj; }, get: function (obj) { return obj.sampleRate; }, set: function (obj, value) { obj.sampleRate = value; } }, metadata: _metadata }, _sampleRate_initializers, _sampleRate_extraInitializers);
        __esDecorate(null, null, _channels_decorators, { kind: "field", name: "channels", static: false, private: false, access: { has: function (obj) { return "channels" in obj; }, get: function (obj) { return obj.channels; }, set: function (obj, value) { obj.channels = value; } }, metadata: _metadata }, _channels_initializers, _channels_extraInitializers);
        __esDecorate(null, null, _bitrate_decorators, { kind: "field", name: "bitrate", static: false, private: false, access: { has: function (obj) { return "bitrate" in obj; }, get: function (obj) { return obj.bitrate; }, set: function (obj, value) { obj.bitrate = value; } }, metadata: _metadata }, _bitrate_initializers, _bitrate_extraInitializers);
        __esDecorate(null, null, _audioProfile_decorators, { kind: "field", name: "audioProfile", static: false, private: false, access: { has: function (obj) { return "audioProfile" in obj; }, get: function (obj) { return obj.audioProfile; }, set: function (obj, value) { obj.audioProfile = value; } }, metadata: _metadata }, _audioProfile_initializers, _audioProfile_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCSubscribeState;
(function (ByteRTCSubscribeState) {
    ByteRTCSubscribeState[ByteRTCSubscribeState["ByteRTCSubscribeStateSuccess"] = 0] = "ByteRTCSubscribeStateSuccess";
    ByteRTCSubscribeState[ByteRTCSubscribeState["ByteRTCSubscribeStateFailedNotInRoom"] = 1] = "ByteRTCSubscribeStateFailedNotInRoom";
    ByteRTCSubscribeState[ByteRTCSubscribeState["ByteRTCSubscribeStateFailedStreamNotFound"] = 2] = "ByteRTCSubscribeStateFailedStreamNotFound";
    ByteRTCSubscribeState[ByteRTCSubscribeState["ByteRTCSubscribeStateFailedOverLimit"] = 3] = "ByteRTCSubscribeStateFailedOverLimit";
})(ByteRTCSubscribeState || (ByteRTCSubscribeState = {}));
var ByteRTCVideoEncoderPreference;
(function (ByteRTCVideoEncoderPreference) {
    ByteRTCVideoEncoderPreference[ByteRTCVideoEncoderPreference["ByteRTCVideoEncoderPreferenceDisabled"] = 0] = "ByteRTCVideoEncoderPreferenceDisabled";
    ByteRTCVideoEncoderPreference[ByteRTCVideoEncoderPreference["ByteRTCVideoEncoderPreferenceMaintainFramerate"] = 1] = "ByteRTCVideoEncoderPreferenceMaintainFramerate";
    ByteRTCVideoEncoderPreference[ByteRTCVideoEncoderPreference["ByteRTCVideoEncoderPreferenceMaintainQuality"] = 2] = "ByteRTCVideoEncoderPreferenceMaintainQuality";
    ByteRTCVideoEncoderPreference[ByteRTCVideoEncoderPreference["ByteRTCVideoEncoderPreferenceBalance"] = 3] = "ByteRTCVideoEncoderPreferenceBalance";
})(ByteRTCVideoEncoderPreference || (ByteRTCVideoEncoderPreference = {}));
var ByteRTCAudioMixingState;
(function (ByteRTCAudioMixingState) {
    ByteRTCAudioMixingState[ByteRTCAudioMixingState["ByteRTCAudioMixingStatePreloaded"] = 0] = "ByteRTCAudioMixingStatePreloaded";
    ByteRTCAudioMixingState[ByteRTCAudioMixingState["ByteRTCAudioMixingStatePlaying"] = 1] = "ByteRTCAudioMixingStatePlaying";
    ByteRTCAudioMixingState[ByteRTCAudioMixingState["ByteRTCAudioMixingStatePaused"] = 2] = "ByteRTCAudioMixingStatePaused";
    ByteRTCAudioMixingState[ByteRTCAudioMixingState["ByteRTCAudioMixingStateStopped"] = 3] = "ByteRTCAudioMixingStateStopped";
    ByteRTCAudioMixingState[ByteRTCAudioMixingState["ByteRTCAudioMixingStateFailed"] = 4] = "ByteRTCAudioMixingStateFailed";
    ByteRTCAudioMixingState[ByteRTCAudioMixingState["ByteRTCAudioMixingStateFinished"] = 5] = "ByteRTCAudioMixingStateFinished";
    ByteRTCAudioMixingState[ByteRTCAudioMixingState["ByteRTCAudioMixingStatePCMEnabled"] = 6] = "ByteRTCAudioMixingStatePCMEnabled";
    ByteRTCAudioMixingState[ByteRTCAudioMixingState["ByteRTCAudioMixingStatePCMDisabled"] = 7] = "ByteRTCAudioMixingStatePCMDisabled";
})(ByteRTCAudioMixingState || (ByteRTCAudioMixingState = {}));
var ByteRTCMixedStreamAudioCodecType;
(function (ByteRTCMixedStreamAudioCodecType) {
    ByteRTCMixedStreamAudioCodecType[ByteRTCMixedStreamAudioCodecType["ByteRTCMixedStreamAudioCodecTypeAAC"] = 0] = "ByteRTCMixedStreamAudioCodecTypeAAC";
})(ByteRTCMixedStreamAudioCodecType || (ByteRTCMixedStreamAudioCodecType = {}));
var ByteRTCSubtitleState;
(function (ByteRTCSubtitleState) {
    ByteRTCSubtitleState[ByteRTCSubtitleState["ByteRTCSubtitleStateStarted"] = 0] = "ByteRTCSubtitleStateStarted";
    ByteRTCSubtitleState[ByteRTCSubtitleState["ByteRTCSubtitleStateStoped"] = 1] = "ByteRTCSubtitleStateStoped";
    ByteRTCSubtitleState[ByteRTCSubtitleState["ByteRTCSubtitleStateError"] = 2] = "ByteRTCSubtitleStateError";
})(ByteRTCSubtitleState || (ByteRTCSubtitleState = {}));
var ByteRTCMixedStreamServerControlConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCMixedStreamServerControlConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _enableVolumeIndication_decorators;
    var _enableVolumeIndication_initializers = [];
    var _enableVolumeIndication_extraInitializers = [];
    var _volumeIndicationInterval_decorators;
    var _volumeIndicationInterval_initializers = [];
    var _volumeIndicationInterval_extraInitializers = [];
    var _talkVolume_decorators;
    var _talkVolume_initializers = [];
    var _talkVolume_extraInitializers = [];
    var _isAddVolumeValue_decorators;
    var _isAddVolumeValue_initializers = [];
    var _isAddVolumeValue_extraInitializers = [];
    var _seiContentMode_decorators;
    var _seiContentMode_initializers = [];
    var _seiContentMode_extraInitializers = [];
    var _seiPayloadType_decorators;
    var _seiPayloadType_initializers = [];
    var _seiPayloadType_extraInitializers = [];
    var _seiPayloadUUID_decorators;
    var _seiPayloadUUID_initializers = [];
    var _seiPayloadUUID_extraInitializers = [];
    var _mediaType_decorators;
    var _mediaType_initializers = [];
    var _mediaType_extraInitializers = [];
    var _pushStreamMode_decorators;
    var _pushStreamMode_initializers = [];
    var _pushStreamMode_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMixedStreamServerControlConfig_1() {
            this.enableVolumeIndication = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _enableVolumeIndication_initializers, void 0));
            this.volumeIndicationInterval = (__runInitializers(this, _enableVolumeIndication_extraInitializers), __runInitializers(this, _volumeIndicationInterval_initializers, void 0));
            this.talkVolume = (__runInitializers(this, _volumeIndicationInterval_extraInitializers), __runInitializers(this, _talkVolume_initializers, void 0));
            this.isAddVolumeValue = (__runInitializers(this, _talkVolume_extraInitializers), __runInitializers(this, _isAddVolumeValue_initializers, void 0));
            this.seiContentMode = (__runInitializers(this, _isAddVolumeValue_extraInitializers), __runInitializers(this, _seiContentMode_initializers, void 0));
            this.seiPayloadType = (__runInitializers(this, _seiContentMode_extraInitializers), __runInitializers(this, _seiPayloadType_initializers, void 0));
            this.seiPayloadUUID = (__runInitializers(this, _seiPayloadType_extraInitializers), __runInitializers(this, _seiPayloadUUID_initializers, void 0));
            this.mediaType = (__runInitializers(this, _seiPayloadUUID_extraInitializers), __runInitializers(this, _mediaType_initializers, void 0));
            this.pushStreamMode = (__runInitializers(this, _mediaType_extraInitializers), __runInitializers(this, _pushStreamMode_initializers, void 0));
            __runInitializers(this, _pushStreamMode_extraInitializers);
        }
        ByteRTCMixedStreamServerControlConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMixedStreamServerControlConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMixedStreamServerControlConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enableVolumeIndication_decorators = [NativeMember()];
        _volumeIndicationInterval_decorators = [NativeMember()];
        _talkVolume_decorators = [NativeMember()];
        _isAddVolumeValue_decorators = [NativeMember()];
        _seiContentMode_decorators = [NativeMember()];
        _seiPayloadType_decorators = [NativeMember()];
        _seiPayloadUUID_decorators = [NativeMember()];
        _mediaType_decorators = [NativeMember()];
        _pushStreamMode_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _enableVolumeIndication_decorators, { kind: "field", name: "enableVolumeIndication", static: false, private: false, access: { has: function (obj) { return "enableVolumeIndication" in obj; }, get: function (obj) { return obj.enableVolumeIndication; }, set: function (obj, value) { obj.enableVolumeIndication = value; } }, metadata: _metadata }, _enableVolumeIndication_initializers, _enableVolumeIndication_extraInitializers);
        __esDecorate(null, null, _volumeIndicationInterval_decorators, { kind: "field", name: "volumeIndicationInterval", static: false, private: false, access: { has: function (obj) { return "volumeIndicationInterval" in obj; }, get: function (obj) { return obj.volumeIndicationInterval; }, set: function (obj, value) { obj.volumeIndicationInterval = value; } }, metadata: _metadata }, _volumeIndicationInterval_initializers, _volumeIndicationInterval_extraInitializers);
        __esDecorate(null, null, _talkVolume_decorators, { kind: "field", name: "talkVolume", static: false, private: false, access: { has: function (obj) { return "talkVolume" in obj; }, get: function (obj) { return obj.talkVolume; }, set: function (obj, value) { obj.talkVolume = value; } }, metadata: _metadata }, _talkVolume_initializers, _talkVolume_extraInitializers);
        __esDecorate(null, null, _isAddVolumeValue_decorators, { kind: "field", name: "isAddVolumeValue", static: false, private: false, access: { has: function (obj) { return "isAddVolumeValue" in obj; }, get: function (obj) { return obj.isAddVolumeValue; }, set: function (obj, value) { obj.isAddVolumeValue = value; } }, metadata: _metadata }, _isAddVolumeValue_initializers, _isAddVolumeValue_extraInitializers);
        __esDecorate(null, null, _seiContentMode_decorators, { kind: "field", name: "seiContentMode", static: false, private: false, access: { has: function (obj) { return "seiContentMode" in obj; }, get: function (obj) { return obj.seiContentMode; }, set: function (obj, value) { obj.seiContentMode = value; } }, metadata: _metadata }, _seiContentMode_initializers, _seiContentMode_extraInitializers);
        __esDecorate(null, null, _seiPayloadType_decorators, { kind: "field", name: "seiPayloadType", static: false, private: false, access: { has: function (obj) { return "seiPayloadType" in obj; }, get: function (obj) { return obj.seiPayloadType; }, set: function (obj, value) { obj.seiPayloadType = value; } }, metadata: _metadata }, _seiPayloadType_initializers, _seiPayloadType_extraInitializers);
        __esDecorate(null, null, _seiPayloadUUID_decorators, { kind: "field", name: "seiPayloadUUID", static: false, private: false, access: { has: function (obj) { return "seiPayloadUUID" in obj; }, get: function (obj) { return obj.seiPayloadUUID; }, set: function (obj, value) { obj.seiPayloadUUID = value; } }, metadata: _metadata }, _seiPayloadUUID_initializers, _seiPayloadUUID_extraInitializers);
        __esDecorate(null, null, _mediaType_decorators, { kind: "field", name: "mediaType", static: false, private: false, access: { has: function (obj) { return "mediaType" in obj; }, get: function (obj) { return obj.mediaType; }, set: function (obj, value) { obj.mediaType = value; } }, metadata: _metadata }, _mediaType_initializers, _mediaType_extraInitializers);
        __esDecorate(null, null, _pushStreamMode_decorators, { kind: "field", name: "pushStreamMode", static: false, private: false, access: { has: function (obj) { return "pushStreamMode" in obj; }, get: function (obj) { return obj.pushStreamMode; }, set: function (obj, value) { obj.pushStreamMode = value; } }, metadata: _metadata }, _pushStreamMode_initializers, _pushStreamMode_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCScreenVideoEncoderPreference;
(function (ByteRTCScreenVideoEncoderPreference) {
    ByteRTCScreenVideoEncoderPreference[ByteRTCScreenVideoEncoderPreference["ByteRTCScreenVideoEncodePreferenceAuto"] = 0] = "ByteRTCScreenVideoEncodePreferenceAuto";
    ByteRTCScreenVideoEncoderPreference[ByteRTCScreenVideoEncoderPreference["ByteRTCScreenVideoEncodePreferenceFramerate"] = 1] = "ByteRTCScreenVideoEncodePreferenceFramerate";
    ByteRTCScreenVideoEncoderPreference[ByteRTCScreenVideoEncoderPreference["ByteRTCScreenVideoEncodePreferenceQuality"] = 2] = "ByteRTCScreenVideoEncodePreferenceQuality";
})(ByteRTCScreenVideoEncoderPreference || (ByteRTCScreenVideoEncoderPreference = {}));
var ByteRTCRemoteStreamStats = function () {
    var _classDecorators = [NativeClass('ByteRTCRemoteStreamStats')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _uid_decorators;
    var _uid_initializers = [];
    var _uid_extraInitializers = [];
    var _audioStats_decorators;
    var _audioStats_initializers = [];
    var _audioStats_extraInitializers = [];
    var _videoStats_decorators;
    var _videoStats_initializers = [];
    var _videoStats_extraInitializers = [];
    var _isScreen_decorators;
    var _isScreen_initializers = [];
    var _isScreen_extraInitializers = [];
    var _txQuality_decorators;
    var _txQuality_initializers = [];
    var _txQuality_extraInitializers = [];
    var _rxQuality_decorators;
    var _rxQuality_initializers = [];
    var _rxQuality_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRemoteStreamStats_1() {
            this.uid = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _uid_initializers, void 0));
            this.audioStats = (__runInitializers(this, _uid_extraInitializers), __runInitializers(this, _audioStats_initializers, void 0));
            this.videoStats = (__runInitializers(this, _audioStats_extraInitializers), __runInitializers(this, _videoStats_initializers, void 0));
            this.isScreen = (__runInitializers(this, _videoStats_extraInitializers), __runInitializers(this, _isScreen_initializers, void 0));
            this.txQuality = (__runInitializers(this, _isScreen_extraInitializers), __runInitializers(this, _txQuality_initializers, void 0));
            this.rxQuality = (__runInitializers(this, _txQuality_extraInitializers), __runInitializers(this, _rxQuality_initializers, void 0));
            __runInitializers(this, _rxQuality_extraInitializers);
        }
        ByteRTCRemoteStreamStats_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRemoteStreamStats_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRemoteStreamStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _uid_decorators = [NativeMember()];
        _audioStats_decorators = [NativeMember()];
        _videoStats_decorators = [NativeMember()];
        _isScreen_decorators = [NativeMember()];
        _txQuality_decorators = [NativeMember()];
        _rxQuality_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _uid_decorators, { kind: "field", name: "uid", static: false, private: false, access: { has: function (obj) { return "uid" in obj; }, get: function (obj) { return obj.uid; }, set: function (obj, value) { obj.uid = value; } }, metadata: _metadata }, _uid_initializers, _uid_extraInitializers);
        __esDecorate(null, null, _audioStats_decorators, { kind: "field", name: "audioStats", static: false, private: false, access: { has: function (obj) { return "audioStats" in obj; }, get: function (obj) { return obj.audioStats; }, set: function (obj, value) { obj.audioStats = value; } }, metadata: _metadata }, _audioStats_initializers, _audioStats_extraInitializers);
        __esDecorate(null, null, _videoStats_decorators, { kind: "field", name: "videoStats", static: false, private: false, access: { has: function (obj) { return "videoStats" in obj; }, get: function (obj) { return obj.videoStats; }, set: function (obj, value) { obj.videoStats = value; } }, metadata: _metadata }, _videoStats_initializers, _videoStats_extraInitializers);
        __esDecorate(null, null, _isScreen_decorators, { kind: "field", name: "isScreen", static: false, private: false, access: { has: function (obj) { return "isScreen" in obj; }, get: function (obj) { return obj.isScreen; }, set: function (obj, value) { obj.isScreen = value; } }, metadata: _metadata }, _isScreen_initializers, _isScreen_extraInitializers);
        __esDecorate(null, null, _txQuality_decorators, { kind: "field", name: "txQuality", static: false, private: false, access: { has: function (obj) { return "txQuality" in obj; }, get: function (obj) { return obj.txQuality; }, set: function (obj, value) { obj.txQuality = value; } }, metadata: _metadata }, _txQuality_initializers, _txQuality_extraInitializers);
        __esDecorate(null, null, _rxQuality_decorators, { kind: "field", name: "rxQuality", static: false, private: false, access: { has: function (obj) { return "rxQuality" in obj; }, get: function (obj) { return obj.rxQuality; }, set: function (obj, value) { obj.rxQuality = value; } }, metadata: _metadata }, _rxQuality_initializers, _rxQuality_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeClass('ByteRTCHighlightConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _enableHighlight_decorators;
    var _enableHighlight_initializers = [];
    var _enableHighlight_extraInitializers = [];
    var _borderColor_decorators;
    var _borderColor_initializers = [];
    var _borderColor_extraInitializers = [];
    var _borderWidth_decorators;
    var _borderWidth_initializers = [];
    var _borderWidth_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCHighlightConfig_1() {
            this.enableHighlight = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _enableHighlight_initializers, void 0));
            this.borderColor = (__runInitializers(this, _enableHighlight_extraInitializers), __runInitializers(this, _borderColor_initializers, void 0));
            this.borderWidth = (__runInitializers(this, _borderColor_extraInitializers), __runInitializers(this, _borderWidth_initializers, void 0));
            __runInitializers(this, _borderWidth_extraInitializers);
        }
        ByteRTCHighlightConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCHighlightConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCHighlightConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enableHighlight_decorators = [NativeMember()];
        _borderColor_decorators = [NativeMember()];
        _borderWidth_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _enableHighlight_decorators, { kind: "field", name: "enableHighlight", static: false, private: false, access: { has: function (obj) { return "enableHighlight" in obj; }, get: function (obj) { return obj.enableHighlight; }, set: function (obj, value) { obj.enableHighlight = value; } }, metadata: _metadata }, _enableHighlight_initializers, _enableHighlight_extraInitializers);
        __esDecorate(null, null, _borderColor_decorators, { kind: "field", name: "borderColor", static: false, private: false, access: { has: function (obj) { return "borderColor" in obj; }, get: function (obj) { return obj.borderColor; }, set: function (obj, value) { obj.borderColor = value; } }, metadata: _metadata }, _borderColor_initializers, _borderColor_extraInitializers);
        __esDecorate(null, null, _borderWidth_decorators, { kind: "field", name: "borderWidth", static: false, private: false, access: { has: function (obj) { return "borderWidth" in obj; }, get: function (obj) { return obj.borderWidth; }, set: function (obj, value) { obj.borderWidth = value; } }, metadata: _metadata }, _borderWidth_initializers, _borderWidth_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCRemoteVideoState;
(function (ByteRTCRemoteVideoState) {
    ByteRTCRemoteVideoState[ByteRTCRemoteVideoState["ByteRTCRemoteVideoStateStopped"] = 0] = "ByteRTCRemoteVideoStateStopped";
    ByteRTCRemoteVideoState[ByteRTCRemoteVideoState["ByteRTCRemoteVideoStateStarting"] = 1] = "ByteRTCRemoteVideoStateStarting";
    ByteRTCRemoteVideoState[ByteRTCRemoteVideoState["ByteRTCRemoteVideoStateDecoding"] = 2] = "ByteRTCRemoteVideoStateDecoding";
    ByteRTCRemoteVideoState[ByteRTCRemoteVideoState["ByteRTCRemoteVideoStateFrozen"] = 3] = "ByteRTCRemoteVideoStateFrozen";
    ByteRTCRemoteVideoState[ByteRTCRemoteVideoState["ByteRTCRemoteVideoStateFailed"] = 4] = "ByteRTCRemoteVideoStateFailed";
})(ByteRTCRemoteVideoState || (ByteRTCRemoteVideoState = {}));
var ByteRTCMediaDeviceError;
(function (ByteRTCMediaDeviceError) {
    ByteRTCMediaDeviceError[ByteRTCMediaDeviceError["ByteRTCMediaDeviceErrorOK"] = 0] = "ByteRTCMediaDeviceErrorOK";
    ByteRTCMediaDeviceError[ByteRTCMediaDeviceError["ByteRTCMediaDeviceErrorDeviceNoPermission"] = 1] = "ByteRTCMediaDeviceErrorDeviceNoPermission";
    ByteRTCMediaDeviceError[ByteRTCMediaDeviceError["ByteRTCMediaDeviceErrorDeviceBusy"] = 2] = "ByteRTCMediaDeviceErrorDeviceBusy";
    ByteRTCMediaDeviceError[ByteRTCMediaDeviceError["ByteRTCMediaDeviceErrorDeviceFailure"] = 3] = "ByteRTCMediaDeviceErrorDeviceFailure";
    ByteRTCMediaDeviceError[ByteRTCMediaDeviceError["ByteRTCMediaDeviceErrorDeviceNotFound"] = 4] = "ByteRTCMediaDeviceErrorDeviceNotFound";
    ByteRTCMediaDeviceError[ByteRTCMediaDeviceError["ByteRTCMediaDeviceErrorDeviceDisconnected"] = 5] = "ByteRTCMediaDeviceErrorDeviceDisconnected";
    ByteRTCMediaDeviceError[ByteRTCMediaDeviceError["ByteRTCMediaDeviceErrorDeviceNoCallback"] = 6] = "ByteRTCMediaDeviceErrorDeviceNoCallback";
    ByteRTCMediaDeviceError[ByteRTCMediaDeviceError["ByteRTCMediaDeviceErrorUNSupportFormat"] = 7] = "ByteRTCMediaDeviceErrorUNSupportFormat";
    ByteRTCMediaDeviceError[ByteRTCMediaDeviceError["ByteRTCMediaDeviceErrorNotFindGroupId"] = 8] = "ByteRTCMediaDeviceErrorNotFindGroupId";
    ByteRTCMediaDeviceError[ByteRTCMediaDeviceError["ByteRTCMediaDeviceErrorNotAvailableInBackground"] = 9] = "ByteRTCMediaDeviceErrorNotAvailableInBackground";
    ByteRTCMediaDeviceError[ByteRTCMediaDeviceError["ByteRTCMediaDeviceErrorVideoInUseByAnotherClient"] = 10] = "ByteRTCMediaDeviceErrorVideoInUseByAnotherClient";
    ByteRTCMediaDeviceError[ByteRTCMediaDeviceError["ByteRTCMediaDeviceErrorNotAvailableWithMultipleForegroundApps"] = 11] = "ByteRTCMediaDeviceErrorNotAvailableWithMultipleForegroundApps";
    ByteRTCMediaDeviceError[ByteRTCMediaDeviceError["ByteRTCMediaDeviceErrorNotAvailableDueToSystemPressure"] = 12] = "ByteRTCMediaDeviceErrorNotAvailableDueToSystemPressure";
})(ByteRTCMediaDeviceError || (ByteRTCMediaDeviceError = {}));
var ByteRTCMixedStreamSEIContentMode;
(function (ByteRTCMixedStreamSEIContentMode) {
    ByteRTCMixedStreamSEIContentMode[ByteRTCMixedStreamSEIContentMode["ByteRTCMixedStreamSEIContentModeDefault"] = 0] = "ByteRTCMixedStreamSEIContentModeDefault";
    ByteRTCMixedStreamSEIContentMode[ByteRTCMixedStreamSEIContentMode["ByteRTCMixedStreamSEIContentModeEnableVolumeIndication"] = 1] = "ByteRTCMixedStreamSEIContentModeEnableVolumeIndication";
})(ByteRTCMixedStreamSEIContentMode || (ByteRTCMixedStreamSEIContentMode = {}));
var ByteRTCMediaTypeEnhancementConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCMediaTypeEnhancementConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _enhanceSignaling_decorators;
    var _enhanceSignaling_initializers = [];
    var _enhanceSignaling_extraInitializers = [];
    var _enhanceAudio_decorators;
    var _enhanceAudio_initializers = [];
    var _enhanceAudio_extraInitializers = [];
    var _enhanceVideo_decorators;
    var _enhanceVideo_initializers = [];
    var _enhanceVideo_extraInitializers = [];
    var _enhanceScreenAudio_decorators;
    var _enhanceScreenAudio_initializers = [];
    var _enhanceScreenAudio_extraInitializers = [];
    var _enhanceScreenVideo_decorators;
    var _enhanceScreenVideo_initializers = [];
    var _enhanceScreenVideo_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMediaTypeEnhancementConfig_1() {
            this.enhanceSignaling = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _enhanceSignaling_initializers, void 0));
            this.enhanceAudio = (__runInitializers(this, _enhanceSignaling_extraInitializers), __runInitializers(this, _enhanceAudio_initializers, void 0));
            this.enhanceVideo = (__runInitializers(this, _enhanceAudio_extraInitializers), __runInitializers(this, _enhanceVideo_initializers, void 0));
            this.enhanceScreenAudio = (__runInitializers(this, _enhanceVideo_extraInitializers), __runInitializers(this, _enhanceScreenAudio_initializers, void 0));
            this.enhanceScreenVideo = (__runInitializers(this, _enhanceScreenAudio_extraInitializers), __runInitializers(this, _enhanceScreenVideo_initializers, void 0));
            __runInitializers(this, _enhanceScreenVideo_extraInitializers);
        }
        ByteRTCMediaTypeEnhancementConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMediaTypeEnhancementConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMediaTypeEnhancementConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enhanceSignaling_decorators = [NativeMember()];
        _enhanceAudio_decorators = [NativeMember()];
        _enhanceVideo_decorators = [NativeMember()];
        _enhanceScreenAudio_decorators = [NativeMember()];
        _enhanceScreenVideo_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _enhanceSignaling_decorators, { kind: "field", name: "enhanceSignaling", static: false, private: false, access: { has: function (obj) { return "enhanceSignaling" in obj; }, get: function (obj) { return obj.enhanceSignaling; }, set: function (obj, value) { obj.enhanceSignaling = value; } }, metadata: _metadata }, _enhanceSignaling_initializers, _enhanceSignaling_extraInitializers);
        __esDecorate(null, null, _enhanceAudio_decorators, { kind: "field", name: "enhanceAudio", static: false, private: false, access: { has: function (obj) { return "enhanceAudio" in obj; }, get: function (obj) { return obj.enhanceAudio; }, set: function (obj, value) { obj.enhanceAudio = value; } }, metadata: _metadata }, _enhanceAudio_initializers, _enhanceAudio_extraInitializers);
        __esDecorate(null, null, _enhanceVideo_decorators, { kind: "field", name: "enhanceVideo", static: false, private: false, access: { has: function (obj) { return "enhanceVideo" in obj; }, get: function (obj) { return obj.enhanceVideo; }, set: function (obj, value) { obj.enhanceVideo = value; } }, metadata: _metadata }, _enhanceVideo_initializers, _enhanceVideo_extraInitializers);
        __esDecorate(null, null, _enhanceScreenAudio_decorators, { kind: "field", name: "enhanceScreenAudio", static: false, private: false, access: { has: function (obj) { return "enhanceScreenAudio" in obj; }, get: function (obj) { return obj.enhanceScreenAudio; }, set: function (obj, value) { obj.enhanceScreenAudio = value; } }, metadata: _metadata }, _enhanceScreenAudio_initializers, _enhanceScreenAudio_extraInitializers);
        __esDecorate(null, null, _enhanceScreenVideo_decorators, { kind: "field", name: "enhanceScreenVideo", static: false, private: false, access: { has: function (obj) { return "enhanceScreenVideo" in obj; }, get: function (obj) { return obj.enhanceScreenVideo; }, set: function (obj, value) { obj.enhanceScreenVideo = value; } }, metadata: _metadata }, _enhanceScreenVideo_initializers, _enhanceScreenVideo_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCDownloadFileType;
(function (ByteRTCDownloadFileType) {
    ByteRTCDownloadFileType[ByteRTCDownloadFileType["ByteRTCDownloadFileTypeMusic"] = 1] = "ByteRTCDownloadFileTypeMusic";
    ByteRTCDownloadFileType[ByteRTCDownloadFileType["ByteRTCDownloadFileTypeKRC"] = 2] = "ByteRTCDownloadFileTypeKRC";
    ByteRTCDownloadFileType[ByteRTCDownloadFileType["ByteRTCDownloadFileTypeLRC"] = 3] = "ByteRTCDownloadFileTypeLRC";
    ByteRTCDownloadFileType[ByteRTCDownloadFileType["ByteRTCDownloadFileTypeMIDI"] = 4] = "ByteRTCDownloadFileTypeMIDI";
})(ByteRTCDownloadFileType || (ByteRTCDownloadFileType = {}));
var ByteRTCAudioPropertiesMode;
(function (ByteRTCAudioPropertiesMode) {
    ByteRTCAudioPropertiesMode[ByteRTCAudioPropertiesMode["ByteRTCAudioPropertiesModeMicrohone"] = 0] = "ByteRTCAudioPropertiesModeMicrohone";
    ByteRTCAudioPropertiesMode[ByteRTCAudioPropertiesMode["ByteRTCAudioPropertiesModeAudioMixing"] = 1] = "ByteRTCAudioPropertiesModeAudioMixing";
})(ByteRTCAudioPropertiesMode || (ByteRTCAudioPropertiesMode = {}));
(function () {
    var _classDecorators = [NativeClass('ByteRTCTranscoderLayoutRegionDataParam')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _imageWidth_decorators;
    var _imageWidth_initializers = [];
    var _imageWidth_extraInitializers = [];
    var _imageHeight_decorators;
    var _imageHeight_initializers = [];
    var _imageHeight_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCTranscoderLayoutRegionDataParam_1() {
            this.imageWidth = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _imageWidth_initializers, void 0));
            this.imageHeight = (__runInitializers(this, _imageWidth_extraInitializers), __runInitializers(this, _imageHeight_initializers, void 0));
            __runInitializers(this, _imageHeight_extraInitializers);
        }
        ByteRTCTranscoderLayoutRegionDataParam_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCTranscoderLayoutRegionDataParam_1;
    }());
    __setFunctionName(_classThis, "ByteRTCTranscoderLayoutRegionDataParam");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _imageWidth_decorators = [NativeMember()];
        _imageHeight_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _imageWidth_decorators, { kind: "field", name: "imageWidth", static: false, private: false, access: { has: function (obj) { return "imageWidth" in obj; }, get: function (obj) { return obj.imageWidth; }, set: function (obj, value) { obj.imageWidth = value; } }, metadata: _metadata }, _imageWidth_initializers, _imageWidth_extraInitializers);
        __esDecorate(null, null, _imageHeight_decorators, { kind: "field", name: "imageHeight", static: false, private: false, access: { has: function (obj) { return "imageHeight" in obj; }, get: function (obj) { return obj.imageHeight; }, set: function (obj, value) { obj.imageHeight = value; } }, metadata: _metadata }, _imageHeight_initializers, _imageHeight_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCAudioDeviceType;
(function (ByteRTCAudioDeviceType) {
    ByteRTCAudioDeviceType[ByteRTCAudioDeviceType["ByteRTCAudioDeviceTypeUnknown"] = -1] = "ByteRTCAudioDeviceTypeUnknown";
    ByteRTCAudioDeviceType[ByteRTCAudioDeviceType["ByteRTCAudioDeviceTypeRenderDevice"] = 0] = "ByteRTCAudioDeviceTypeRenderDevice";
    ByteRTCAudioDeviceType[ByteRTCAudioDeviceType["ByteRTCAudioDeviceTypeCaptureDevice"] = 1] = "ByteRTCAudioDeviceTypeCaptureDevice";
    ByteRTCAudioDeviceType[ByteRTCAudioDeviceType["ByteRTCAudioDeviceTypeScreenCaptureDevice"] = 2] = "ByteRTCAudioDeviceTypeScreenCaptureDevice";
})(ByteRTCAudioDeviceType || (ByteRTCAudioDeviceType = {}));
var ByteRTCMediaPlayerCustomSourceStreamType;
(function (ByteRTCMediaPlayerCustomSourceStreamType) {
    ByteRTCMediaPlayerCustomSourceStreamType[ByteRTCMediaPlayerCustomSourceStreamType["ByteRTCMediaPlayerCustomSourceStreamTypeRaw"] = 0] = "ByteRTCMediaPlayerCustomSourceStreamTypeRaw";
    ByteRTCMediaPlayerCustomSourceStreamType[ByteRTCMediaPlayerCustomSourceStreamType["ByteRTCMediaPlayerCustomSourceStreamTypeEncoded"] = 1] = "ByteRTCMediaPlayerCustomSourceStreamTypeEncoded";
})(ByteRTCMediaPlayerCustomSourceStreamType || (ByteRTCMediaPlayerCustomSourceStreamType = {}));
var ByteRTCAudioPropertiesConfig = function () {
    var _classDecorators = [NativeClass('ByteRTCAudioPropertiesConfig')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _interval_decorators;
    var _interval_initializers = [];
    var _interval_extraInitializers = [];
    var _enableSpectrum_decorators;
    var _enableSpectrum_initializers = [];
    var _enableSpectrum_extraInitializers = [];
    var _enableVad_decorators;
    var _enableVad_initializers = [];
    var _enableVad_extraInitializers = [];
    var _localMainReportMode_decorators;
    var _localMainReportMode_initializers = [];
    var _localMainReportMode_extraInitializers = [];
    var _smooth_decorators;
    var _smooth_initializers = [];
    var _smooth_extraInitializers = [];
    var _audioReportMode_decorators;
    var _audioReportMode_initializers = [];
    var _audioReportMode_extraInitializers = [];
    var _enableVoicePitch_decorators;
    var _enableVoicePitch_initializers = [];
    var _enableVoicePitch_extraInitializers = [];
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioPropertiesConfig_1() {
            this.interval = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _interval_initializers, void 0));
            this.enableSpectrum = (__runInitializers(this, _interval_extraInitializers), __runInitializers(this, _enableSpectrum_initializers, void 0));
            this.enableVad = (__runInitializers(this, _enableSpectrum_extraInitializers), __runInitializers(this, _enableVad_initializers, void 0));
            this.localMainReportMode = (__runInitializers(this, _enableVad_extraInitializers), __runInitializers(this, _localMainReportMode_initializers, void 0));
            this.smooth = (__runInitializers(this, _localMainReportMode_extraInitializers), __runInitializers(this, _smooth_initializers, void 0));
            this.audioReportMode = (__runInitializers(this, _smooth_extraInitializers), __runInitializers(this, _audioReportMode_initializers, void 0));
            this.enableVoicePitch = (__runInitializers(this, _audioReportMode_extraInitializers), __runInitializers(this, _enableVoicePitch_initializers, void 0));
            __runInitializers(this, _enableVoicePitch_extraInitializers);
        }
        ByteRTCAudioPropertiesConfig_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCAudioPropertiesConfig_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioPropertiesConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _interval_decorators = [NativeMember()];
        _enableSpectrum_decorators = [NativeMember()];
        _enableVad_decorators = [NativeMember()];
        _localMainReportMode_decorators = [NativeMember()];
        _smooth_decorators = [NativeMember()];
        _audioReportMode_decorators = [NativeMember()];
        _enableVoicePitch_decorators = [NativeMember()];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _interval_decorators, { kind: "field", name: "interval", static: false, private: false, access: { has: function (obj) { return "interval" in obj; }, get: function (obj) { return obj.interval; }, set: function (obj, value) { obj.interval = value; } }, metadata: _metadata }, _interval_initializers, _interval_extraInitializers);
        __esDecorate(null, null, _enableSpectrum_decorators, { kind: "field", name: "enableSpectrum", static: false, private: false, access: { has: function (obj) { return "enableSpectrum" in obj; }, get: function (obj) { return obj.enableSpectrum; }, set: function (obj, value) { obj.enableSpectrum = value; } }, metadata: _metadata }, _enableSpectrum_initializers, _enableSpectrum_extraInitializers);
        __esDecorate(null, null, _enableVad_decorators, { kind: "field", name: "enableVad", static: false, private: false, access: { has: function (obj) { return "enableVad" in obj; }, get: function (obj) { return obj.enableVad; }, set: function (obj, value) { obj.enableVad = value; } }, metadata: _metadata }, _enableVad_initializers, _enableVad_extraInitializers);
        __esDecorate(null, null, _localMainReportMode_decorators, { kind: "field", name: "localMainReportMode", static: false, private: false, access: { has: function (obj) { return "localMainReportMode" in obj; }, get: function (obj) { return obj.localMainReportMode; }, set: function (obj, value) { obj.localMainReportMode = value; } }, metadata: _metadata }, _localMainReportMode_initializers, _localMainReportMode_extraInitializers);
        __esDecorate(null, null, _smooth_decorators, { kind: "field", name: "smooth", static: false, private: false, access: { has: function (obj) { return "smooth" in obj; }, get: function (obj) { return obj.smooth; }, set: function (obj, value) { obj.smooth = value; } }, metadata: _metadata }, _smooth_initializers, _smooth_extraInitializers);
        __esDecorate(null, null, _audioReportMode_decorators, { kind: "field", name: "audioReportMode", static: false, private: false, access: { has: function (obj) { return "audioReportMode" in obj; }, get: function (obj) { return obj.audioReportMode; }, set: function (obj, value) { obj.audioReportMode = value; } }, metadata: _metadata }, _audioReportMode_initializers, _audioReportMode_extraInitializers);
        __esDecorate(null, null, _enableVoicePitch_decorators, { kind: "field", name: "enableVoicePitch", static: false, private: false, access: { has: function (obj) { return "enableVoicePitch" in obj; }, get: function (obj) { return obj.enableVoicePitch; }, set: function (obj, value) { obj.enableVoicePitch = value; } }, metadata: _metadata }, _enableVoicePitch_initializers, _enableVoicePitch_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();

var ByteRTCMediaPlayer = function () {
    var _classDecorators = [NativeClass('ByteRTCMediaPlayer')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _open_decorators;
    var _start_decorators;
    var _openWithCustomSource_decorators;
    var _stop_decorators;
    var _pause_decorators;
    var _resume_decorators;
    var _setVolume_decorators;
    var _getVolume_decorators;
    var _getTotalDuration_decorators;
    var _getPlaybackDuration_decorators;
    var _getPosition_decorators;
    var _setAudioPitch_decorators;
    var _setPosition_decorators;
    var _setAudioDualMonoMode_decorators;
    var _getAudioTrackCount_decorators;
    var _selectAudioTrack_decorators;
    var _setPlaybackSpeed_decorators;
    var _setProgressInterval_decorators;
    var _setLoudness_decorators;
    var _registerAudioFrameObserver_decorators;
    var _pushExternalAudioFrame_decorators;
    var _setEventHandler_decorators;
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCMediaPlayer_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        ByteRTCMediaPlayer_1.prototype.open = function (filePath, config) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.start = function () {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.openWithCustomSource = function (source, config) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.stop = function () {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.pause = function () {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.resume = function () {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.setVolume = function (volume, type) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.getVolume = function (type) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.getTotalDuration = function () {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.getPlaybackDuration = function () {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.getPosition = function () {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.setAudioPitch = function (pitch) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.setPosition = function (position) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.setAudioDualMonoMode = function (mode) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.getAudioTrackCount = function () {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.selectAudioTrack = function (index) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.setPlaybackSpeed = function (speed) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.setProgressInterval = function (interval) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.setLoudness = function (loudness) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.registerAudioFrameObserver = function (observer) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.pushExternalAudioFrame = function (audioFrame) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.setEventHandler = function (handler) {
            throw new Error('not implement');
        };
        ByteRTCMediaPlayer_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCMediaPlayer_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMediaPlayer");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _open_decorators = [NativeMethodSync('open:config:')];
        _start_decorators = [NativeMethodSync('start')];
        _openWithCustomSource_decorators = [NativeMethodSync('openWithCustomSource:config:')];
        _stop_decorators = [NativeMethodSync('stop')];
        _pause_decorators = [NativeMethodSync('pause')];
        _resume_decorators = [NativeMethodSync('resume')];
        _setVolume_decorators = [NativeMethodSync('setVolume:type:')];
        _getVolume_decorators = [NativeMethodSync('getVolume:')];
        _getTotalDuration_decorators = [NativeMethodSync('getTotalDuration')];
        _getPlaybackDuration_decorators = [NativeMethodSync('getPlaybackDuration')];
        _getPosition_decorators = [NativeMethodSync('getPosition')];
        _setAudioPitch_decorators = [NativeMethodSync('setAudioPitch:')];
        _setPosition_decorators = [NativeMethodSync('setPosition:')];
        _setAudioDualMonoMode_decorators = [NativeMethodSync('setAudioDualMonoMode:')];
        _getAudioTrackCount_decorators = [NativeMethodSync('getAudioTrackCount')];
        _selectAudioTrack_decorators = [NativeMethodSync('selectAudioTrack:')];
        _setPlaybackSpeed_decorators = [NativeMethodSync('setPlaybackSpeed:')];
        _setProgressInterval_decorators = [NativeMethodSync('setProgressInterval:')];
        _setLoudness_decorators = [NativeMethodSync('setLoudness:')];
        _registerAudioFrameObserver_decorators = [NativeMethodSync('registerAudioFrameObserver:')];
        _pushExternalAudioFrame_decorators = [NativeMethodSync('pushExternalAudioFrame:')];
        _setEventHandler_decorators = [NativeMethodSync('setEventHandler:')];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _open_decorators, { kind: "method", name: "open", static: false, private: false, access: { has: function (obj) { return "open" in obj; }, get: function (obj) { return obj.open; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _start_decorators, { kind: "method", name: "start", static: false, private: false, access: { has: function (obj) { return "start" in obj; }, get: function (obj) { return obj.start; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _openWithCustomSource_decorators, { kind: "method", name: "openWithCustomSource", static: false, private: false, access: { has: function (obj) { return "openWithCustomSource" in obj; }, get: function (obj) { return obj.openWithCustomSource; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stop_decorators, { kind: "method", name: "stop", static: false, private: false, access: { has: function (obj) { return "stop" in obj; }, get: function (obj) { return obj.stop; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pause_decorators, { kind: "method", name: "pause", static: false, private: false, access: { has: function (obj) { return "pause" in obj; }, get: function (obj) { return obj.pause; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resume_decorators, { kind: "method", name: "resume", static: false, private: false, access: { has: function (obj) { return "resume" in obj; }, get: function (obj) { return obj.resume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVolume_decorators, { kind: "method", name: "setVolume", static: false, private: false, access: { has: function (obj) { return "setVolume" in obj; }, get: function (obj) { return obj.setVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getVolume_decorators, { kind: "method", name: "getVolume", static: false, private: false, access: { has: function (obj) { return "getVolume" in obj; }, get: function (obj) { return obj.getVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getTotalDuration_decorators, { kind: "method", name: "getTotalDuration", static: false, private: false, access: { has: function (obj) { return "getTotalDuration" in obj; }, get: function (obj) { return obj.getTotalDuration; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getPlaybackDuration_decorators, { kind: "method", name: "getPlaybackDuration", static: false, private: false, access: { has: function (obj) { return "getPlaybackDuration" in obj; }, get: function (obj) { return obj.getPlaybackDuration; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getPosition_decorators, { kind: "method", name: "getPosition", static: false, private: false, access: { has: function (obj) { return "getPosition" in obj; }, get: function (obj) { return obj.getPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioPitch_decorators, { kind: "method", name: "setAudioPitch", static: false, private: false, access: { has: function (obj) { return "setAudioPitch" in obj; }, get: function (obj) { return obj.setAudioPitch; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPosition_decorators, { kind: "method", name: "setPosition", static: false, private: false, access: { has: function (obj) { return "setPosition" in obj; }, get: function (obj) { return obj.setPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioDualMonoMode_decorators, { kind: "method", name: "setAudioDualMonoMode", static: false, private: false, access: { has: function (obj) { return "setAudioDualMonoMode" in obj; }, get: function (obj) { return obj.setAudioDualMonoMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioTrackCount_decorators, { kind: "method", name: "getAudioTrackCount", static: false, private: false, access: { has: function (obj) { return "getAudioTrackCount" in obj; }, get: function (obj) { return obj.getAudioTrackCount; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _selectAudioTrack_decorators, { kind: "method", name: "selectAudioTrack", static: false, private: false, access: { has: function (obj) { return "selectAudioTrack" in obj; }, get: function (obj) { return obj.selectAudioTrack; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPlaybackSpeed_decorators, { kind: "method", name: "setPlaybackSpeed", static: false, private: false, access: { has: function (obj) { return "setPlaybackSpeed" in obj; }, get: function (obj) { return obj.setPlaybackSpeed; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setProgressInterval_decorators, { kind: "method", name: "setProgressInterval", static: false, private: false, access: { has: function (obj) { return "setProgressInterval" in obj; }, get: function (obj) { return obj.setProgressInterval; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLoudness_decorators, { kind: "method", name: "setLoudness", static: false, private: false, access: { has: function (obj) { return "setLoudness" in obj; }, get: function (obj) { return obj.setLoudness; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerAudioFrameObserver_decorators, { kind: "method", name: "registerAudioFrameObserver", static: false, private: false, access: { has: function (obj) { return "registerAudioFrameObserver" in obj; }, get: function (obj) { return obj.registerAudioFrameObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushExternalAudioFrame_decorators, { kind: "method", name: "pushExternalAudioFrame", static: false, private: false, access: { has: function (obj) { return "pushExternalAudioFrame" in obj; }, get: function (obj) { return obj.pushExternalAudioFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEventHandler_decorators, { kind: "method", name: "setEventHandler", static: false, private: false, access: { has: function (obj) { return "setEventHandler" in obj; }, get: function (obj) { return obj.setEventHandler; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioEffectPlayer = function () {
    var _classDecorators = [NativeClass('ByteRTCAudioEffectPlayer')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _start_decorators;
    var _stop_decorators;
    var _stopAll_decorators;
    var _preload_decorators;
    var _unload_decorators;
    var _unloadAll_decorators;
    var _pause_decorators;
    var _pauseAll_decorators;
    var _resume_decorators;
    var _resumeAll_decorators;
    var _setPosition_decorators;
    var _getPosition_decorators;
    var _setVolume_decorators;
    var _setVolumeAll_decorators;
    var _getVolume_decorators;
    var _getDuration_decorators;
    var _setEventHandler_decorators;
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioEffectPlayer_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        ByteRTCAudioEffectPlayer_1.prototype.start = function (effectId, filePath, config) {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.stop = function (effectId) {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.stopAll = function () {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.preload = function (effectId, filePath) {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.unload = function (effectId) {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.unloadAll = function () {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.pause = function (effectId) {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.pauseAll = function () {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.resume = function (effectId) {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.resumeAll = function () {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.setPosition = function (effectId, position) {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.getPosition = function (effectId) {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.setVolume = function (effectId, volume) {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.setVolumeAll = function (volume) {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.getVolume = function (effectId) {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.getDuration = function (effectId) {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.setEventHandler = function (handler) {
            throw new Error('not implement');
        };
        ByteRTCAudioEffectPlayer_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCAudioEffectPlayer_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioEffectPlayer");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _start_decorators = [NativeMethodSync('start:filePath:config:')];
        _stop_decorators = [NativeMethodSync('stop:')];
        _stopAll_decorators = [NativeMethodSync('stopAll')];
        _preload_decorators = [NativeMethodSync('preload:filePath:')];
        _unload_decorators = [NativeMethodSync('unload:')];
        _unloadAll_decorators = [NativeMethodSync('unloadAll')];
        _pause_decorators = [NativeMethodSync('pause:')];
        _pauseAll_decorators = [NativeMethodSync('pauseAll')];
        _resume_decorators = [NativeMethodSync('resume:')];
        _resumeAll_decorators = [NativeMethodSync('resumeAll')];
        _setPosition_decorators = [NativeMethodSync('setPosition:position:')];
        _getPosition_decorators = [NativeMethodSync('getPosition:')];
        _setVolume_decorators = [NativeMethodSync('setVolume:volume:')];
        _setVolumeAll_decorators = [NativeMethodSync('setVolumeAll:')];
        _getVolume_decorators = [NativeMethodSync('getVolume:')];
        _getDuration_decorators = [NativeMethodSync('getDuration:')];
        _setEventHandler_decorators = [NativeMethodSync('setEventHandler:')];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _start_decorators, { kind: "method", name: "start", static: false, private: false, access: { has: function (obj) { return "start" in obj; }, get: function (obj) { return obj.start; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stop_decorators, { kind: "method", name: "stop", static: false, private: false, access: { has: function (obj) { return "stop" in obj; }, get: function (obj) { return obj.stop; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopAll_decorators, { kind: "method", name: "stopAll", static: false, private: false, access: { has: function (obj) { return "stopAll" in obj; }, get: function (obj) { return obj.stopAll; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _preload_decorators, { kind: "method", name: "preload", static: false, private: false, access: { has: function (obj) { return "preload" in obj; }, get: function (obj) { return obj.preload; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unload_decorators, { kind: "method", name: "unload", static: false, private: false, access: { has: function (obj) { return "unload" in obj; }, get: function (obj) { return obj.unload; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unloadAll_decorators, { kind: "method", name: "unloadAll", static: false, private: false, access: { has: function (obj) { return "unloadAll" in obj; }, get: function (obj) { return obj.unloadAll; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pause_decorators, { kind: "method", name: "pause", static: false, private: false, access: { has: function (obj) { return "pause" in obj; }, get: function (obj) { return obj.pause; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pauseAll_decorators, { kind: "method", name: "pauseAll", static: false, private: false, access: { has: function (obj) { return "pauseAll" in obj; }, get: function (obj) { return obj.pauseAll; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resume_decorators, { kind: "method", name: "resume", static: false, private: false, access: { has: function (obj) { return "resume" in obj; }, get: function (obj) { return obj.resume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resumeAll_decorators, { kind: "method", name: "resumeAll", static: false, private: false, access: { has: function (obj) { return "resumeAll" in obj; }, get: function (obj) { return obj.resumeAll; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPosition_decorators, { kind: "method", name: "setPosition", static: false, private: false, access: { has: function (obj) { return "setPosition" in obj; }, get: function (obj) { return obj.setPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getPosition_decorators, { kind: "method", name: "getPosition", static: false, private: false, access: { has: function (obj) { return "getPosition" in obj; }, get: function (obj) { return obj.getPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVolume_decorators, { kind: "method", name: "setVolume", static: false, private: false, access: { has: function (obj) { return "setVolume" in obj; }, get: function (obj) { return obj.setVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVolumeAll_decorators, { kind: "method", name: "setVolumeAll", static: false, private: false, access: { has: function (obj) { return "setVolumeAll" in obj; }, get: function (obj) { return obj.setVolumeAll; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getVolume_decorators, { kind: "method", name: "getVolume", static: false, private: false, access: { has: function (obj) { return "getVolume" in obj; }, get: function (obj) { return obj.getVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getDuration_decorators, { kind: "method", name: "getDuration", static: false, private: false, access: { has: function (obj) { return "getDuration" in obj; }, get: function (obj) { return obj.getDuration; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEventHandler_decorators, { kind: "method", name: "setEventHandler", static: false, private: false, access: { has: function (obj) { return "setEventHandler" in obj; }, get: function (obj) { return obj.setEventHandler; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCSpatialAudio = function () {
    var _classDecorators = [NativeClass('ByteRTCSpatialAudio')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _enableSpatialAudio_decorators;
    var _disableRemoteOrientation_decorators;
    var _updateSelfPosition_decorators;
    var _updateRemotePosition_decorators;
    var _removeRemotePosition_decorators;
    var _removeAllRemotePosition_decorators;
    var _updatePosition_decorators;
    var _updateSelfOrientation_decorators;
    var _updateListenerPosition_decorators;
    var _updateListenerOrientation_decorators;
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCSpatialAudio_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        ByteRTCSpatialAudio_1.prototype.enableSpatialAudio = function (enable) {
            throw new Error('not implement');
        };
        ByteRTCSpatialAudio_1.prototype.disableRemoteOrientation = function () {
            throw new Error('not implement');
        };
        ByteRTCSpatialAudio_1.prototype.updateSelfPosition = function (positionInfo) {
            throw new Error('not implement');
        };
        ByteRTCSpatialAudio_1.prototype.updateRemotePosition = function (uid, positionInfo) {
            throw new Error('not implement');
        };
        ByteRTCSpatialAudio_1.prototype.removeRemotePosition = function (uid) {
            throw new Error('not implement');
        };
        ByteRTCSpatialAudio_1.prototype.removeAllRemotePosition = function () {
            throw new Error('not implement');
        };
        ByteRTCSpatialAudio_1.prototype.updatePosition = function (pos) {
            throw new Error('not implement');
        };
        ByteRTCSpatialAudio_1.prototype.updateSelfOrientation = function (orientation) {
            throw new Error('not implement');
        };
        ByteRTCSpatialAudio_1.prototype.updateListenerPosition = function (pos) {
            throw new Error('not implement');
        };
        ByteRTCSpatialAudio_1.prototype.updateListenerOrientation = function (orientation) {
            throw new Error('not implement');
        };
        ByteRTCSpatialAudio_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCSpatialAudio_1;
    }());
    __setFunctionName(_classThis, "ByteRTCSpatialAudio");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enableSpatialAudio_decorators = [NativeMethodSync('enableSpatialAudio:')];
        _disableRemoteOrientation_decorators = [NativeMethodSync('disableRemoteOrientation')];
        _updateSelfPosition_decorators = [NativeMethodSync('updateSelfPosition:')];
        _updateRemotePosition_decorators = [NativeMethodSync('updateRemotePosition:positionInfo:')];
        _removeRemotePosition_decorators = [NativeMethodSync('removeRemotePosition:')];
        _removeAllRemotePosition_decorators = [NativeMethodSync('removeAllRemotePosition')];
        _updatePosition_decorators = [NativeMethodSync('updatePosition:')];
        _updateSelfOrientation_decorators = [NativeMethodSync('updateSelfOrientation:')];
        _updateListenerPosition_decorators = [NativeMethodSync('updateListenerPosition:')];
        _updateListenerOrientation_decorators = [NativeMethodSync('updateListenerOrientation:')];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _enableSpatialAudio_decorators, { kind: "method", name: "enableSpatialAudio", static: false, private: false, access: { has: function (obj) { return "enableSpatialAudio" in obj; }, get: function (obj) { return obj.enableSpatialAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableRemoteOrientation_decorators, { kind: "method", name: "disableRemoteOrientation", static: false, private: false, access: { has: function (obj) { return "disableRemoteOrientation" in obj; }, get: function (obj) { return obj.disableRemoteOrientation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateSelfPosition_decorators, { kind: "method", name: "updateSelfPosition", static: false, private: false, access: { has: function (obj) { return "updateSelfPosition" in obj; }, get: function (obj) { return obj.updateSelfPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateRemotePosition_decorators, { kind: "method", name: "updateRemotePosition", static: false, private: false, access: { has: function (obj) { return "updateRemotePosition" in obj; }, get: function (obj) { return obj.updateRemotePosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _removeRemotePosition_decorators, { kind: "method", name: "removeRemotePosition", static: false, private: false, access: { has: function (obj) { return "removeRemotePosition" in obj; }, get: function (obj) { return obj.removeRemotePosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _removeAllRemotePosition_decorators, { kind: "method", name: "removeAllRemotePosition", static: false, private: false, access: { has: function (obj) { return "removeAllRemotePosition" in obj; }, get: function (obj) { return obj.removeAllRemotePosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updatePosition_decorators, { kind: "method", name: "updatePosition", static: false, private: false, access: { has: function (obj) { return "updatePosition" in obj; }, get: function (obj) { return obj.updatePosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateSelfOrientation_decorators, { kind: "method", name: "updateSelfOrientation", static: false, private: false, access: { has: function (obj) { return "updateSelfOrientation" in obj; }, get: function (obj) { return obj.updateSelfOrientation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateListenerPosition_decorators, { kind: "method", name: "updateListenerPosition", static: false, private: false, access: { has: function (obj) { return "updateListenerPosition" in obj; }, get: function (obj) { return obj.updateListenerPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateListenerOrientation_decorators, { kind: "method", name: "updateListenerOrientation", static: false, private: false, access: { has: function (obj) { return "updateListenerOrientation" in obj; }, get: function (obj) { return obj.updateListenerOrientation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCSingScoringManager = function () {
    var _classDecorators = [NativeClass('ByteRTCSingScoringManager')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _initSingScoring_decorators;
    var _setSingScoringConfig_decorators;
    var _getStandardPitchInfo_decorators;
    var _startSingScoring_decorators;
    var _stopSingScoring_decorators;
    var _getLastSentenceScore_decorators;
    var _getTotalScore_decorators;
    var _getAverageScore_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCSingScoringManager_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        ByteRTCSingScoringManager_1.prototype.initSingScoring = function (singScoringAppkey, singScoringToken, delegate) {
            throw new Error('not implement');
        };
        ByteRTCSingScoringManager_1.prototype.setSingScoringConfig = function (config) {
            throw new Error('not implement');
        };
        ByteRTCSingScoringManager_1.prototype.getStandardPitchInfo = function (midiFilepath) {
            throw new Error('not implement');
        };
        ByteRTCSingScoringManager_1.prototype.startSingScoring = function (position, scoringInfoInterval) {
            throw new Error('not implement');
        };
        ByteRTCSingScoringManager_1.prototype.stopSingScoring = function () {
            throw new Error('not implement');
        };
        ByteRTCSingScoringManager_1.prototype.getLastSentenceScore = function () {
            throw new Error('not implement');
        };
        ByteRTCSingScoringManager_1.prototype.getTotalScore = function () {
            throw new Error('not implement');
        };
        ByteRTCSingScoringManager_1.prototype.getAverageScore = function () {
            throw new Error('not implement');
        };
        return ByteRTCSingScoringManager_1;
    }());
    __setFunctionName(_classThis, "ByteRTCSingScoringManager");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _initSingScoring_decorators = [NativeMethodSync('initSingScoring:singScoringToken:delegate:')];
        _setSingScoringConfig_decorators = [NativeMethodSync('setSingScoringConfig:')];
        _getStandardPitchInfo_decorators = [ReturnClass(function () { return ByteRTCStandardPitchInfo; }), NativeMethodSync('getStandardPitchInfo:')];
        _startSingScoring_decorators = [NativeMethodSync('startSingScoring:scoringInfoInterval:')];
        _stopSingScoring_decorators = [NativeMethodSync('stopSingScoring')];
        _getLastSentenceScore_decorators = [NativeMethodSync('getLastSentenceScore')];
        _getTotalScore_decorators = [NativeMethodSync('getTotalScore')];
        _getAverageScore_decorators = [NativeMethodSync('getAverageScore')];
        __esDecorate(_classThis, null, _initSingScoring_decorators, { kind: "method", name: "initSingScoring", static: false, private: false, access: { has: function (obj) { return "initSingScoring" in obj; }, get: function (obj) { return obj.initSingScoring; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setSingScoringConfig_decorators, { kind: "method", name: "setSingScoringConfig", static: false, private: false, access: { has: function (obj) { return "setSingScoringConfig" in obj; }, get: function (obj) { return obj.setSingScoringConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getStandardPitchInfo_decorators, { kind: "method", name: "getStandardPitchInfo", static: false, private: false, access: { has: function (obj) { return "getStandardPitchInfo" in obj; }, get: function (obj) { return obj.getStandardPitchInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startSingScoring_decorators, { kind: "method", name: "startSingScoring", static: false, private: false, access: { has: function (obj) { return "startSingScoring" in obj; }, get: function (obj) { return obj.startSingScoring; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopSingScoring_decorators, { kind: "method", name: "stopSingScoring", static: false, private: false, access: { has: function (obj) { return "stopSingScoring" in obj; }, get: function (obj) { return obj.stopSingScoring; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getLastSentenceScore_decorators, { kind: "method", name: "getLastSentenceScore", static: false, private: false, access: { has: function (obj) { return "getLastSentenceScore" in obj; }, get: function (obj) { return obj.getLastSentenceScore; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getTotalScore_decorators, { kind: "method", name: "getTotalScore", static: false, private: false, access: { has: function (obj) { return "getTotalScore" in obj; }, get: function (obj) { return obj.getTotalScore; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAverageScore_decorators, { kind: "method", name: "getAverageScore", static: false, private: false, access: { has: function (obj) { return "getAverageScore" in obj; }, get: function (obj) { return obj.getAverageScore; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCKTVManager = function () {
    var _classDecorators = [NativeClass('ByteRTCKTVManager')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _delegate_decorators;
    var _delegate_initializers = [];
    var _delegate_extraInitializers = [];
    var _getMusicList_decorators;
    var _searchMusic_decorators;
    var _getHotMusic_decorators;
    var _getMusicDetail_decorators;
    var _downloadMusic_decorators;
    var _downloadLyric_decorators;
    var _downloadMidi_decorators;
    var _cancelDownload_decorators;
    var _clearCache_decorators;
    var _setMaxCacheSize_decorators;
    var _getKTVPlayer_decorators;
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCKTVManager_1() {
            this.delegate = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _delegate_initializers, void 0));
            __runInitializers(this, _delegate_extraInitializers);
        }
        ByteRTCKTVManager_1.prototype.getMusicList = function (pageNumber, pageSize, filterType) {
            throw new Error('not implement');
        };
        ByteRTCKTVManager_1.prototype.searchMusic = function (keyWord, pageNumber, pageSize, filterType) {
            throw new Error('not implement');
        };
        ByteRTCKTVManager_1.prototype.getHotMusic = function (hotType, filterType) {
            throw new Error('not implement');
        };
        ByteRTCKTVManager_1.prototype.getMusicDetail = function (musicId) {
            throw new Error('not implement');
        };
        ByteRTCKTVManager_1.prototype.downloadMusic = function (musicId) {
            throw new Error('not implement');
        };
        ByteRTCKTVManager_1.prototype.downloadLyric = function (musicId, lyricType) {
            throw new Error('not implement');
        };
        ByteRTCKTVManager_1.prototype.downloadMidi = function (musicId) {
            throw new Error('not implement');
        };
        ByteRTCKTVManager_1.prototype.cancelDownload = function (downloadId) {
            throw new Error('not implement');
        };
        ByteRTCKTVManager_1.prototype.clearCache = function () {
            throw new Error('not implement');
        };
        ByteRTCKTVManager_1.prototype.setMaxCacheSize = function (maxCacheSizeMB) {
            throw new Error('not implement');
        };
        ByteRTCKTVManager_1.prototype.getKTVPlayer = function () {
            throw new Error('not implement');
        };
        ByteRTCKTVManager_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCKTVManager_1;
    }());
    __setFunctionName(_classThis, "ByteRTCKTVManager");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _delegate_decorators = [NativeMember()];
        _getMusicList_decorators = [NativeMethodSync('getMusicList:pageSize:filterType:')];
        _searchMusic_decorators = [NativeMethodSync('searchMusic:pageNumber:pageSize:filterType:')];
        _getHotMusic_decorators = [NativeMethodSync('getHotMusic:filterType:')];
        _getMusicDetail_decorators = [NativeMethodSync('getMusicDetail:')];
        _downloadMusic_decorators = [NativeMethodSync('downloadMusic:')];
        _downloadLyric_decorators = [NativeMethodSync('downloadLyric:lyricType:')];
        _downloadMidi_decorators = [NativeMethodSync('downloadMidi:')];
        _cancelDownload_decorators = [NativeMethodSync('cancelDownload:')];
        _clearCache_decorators = [NativeMethodSync('clearCache')];
        _setMaxCacheSize_decorators = [NativeMethodSync('setMaxCacheSize:')];
        _getKTVPlayer_decorators = [ReturnClass(function () { return ByteRTCKTVPlayer; }), NativeMethodSync('getKTVPlayer')];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _getMusicList_decorators, { kind: "method", name: "getMusicList", static: false, private: false, access: { has: function (obj) { return "getMusicList" in obj; }, get: function (obj) { return obj.getMusicList; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _searchMusic_decorators, { kind: "method", name: "searchMusic", static: false, private: false, access: { has: function (obj) { return "searchMusic" in obj; }, get: function (obj) { return obj.searchMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getHotMusic_decorators, { kind: "method", name: "getHotMusic", static: false, private: false, access: { has: function (obj) { return "getHotMusic" in obj; }, get: function (obj) { return obj.getHotMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getMusicDetail_decorators, { kind: "method", name: "getMusicDetail", static: false, private: false, access: { has: function (obj) { return "getMusicDetail" in obj; }, get: function (obj) { return obj.getMusicDetail; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _downloadMusic_decorators, { kind: "method", name: "downloadMusic", static: false, private: false, access: { has: function (obj) { return "downloadMusic" in obj; }, get: function (obj) { return obj.downloadMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _downloadLyric_decorators, { kind: "method", name: "downloadLyric", static: false, private: false, access: { has: function (obj) { return "downloadLyric" in obj; }, get: function (obj) { return obj.downloadLyric; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _downloadMidi_decorators, { kind: "method", name: "downloadMidi", static: false, private: false, access: { has: function (obj) { return "downloadMidi" in obj; }, get: function (obj) { return obj.downloadMidi; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _cancelDownload_decorators, { kind: "method", name: "cancelDownload", static: false, private: false, access: { has: function (obj) { return "cancelDownload" in obj; }, get: function (obj) { return obj.cancelDownload; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _clearCache_decorators, { kind: "method", name: "clearCache", static: false, private: false, access: { has: function (obj) { return "clearCache" in obj; }, get: function (obj) { return obj.clearCache; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setMaxCacheSize_decorators, { kind: "method", name: "setMaxCacheSize", static: false, private: false, access: { has: function (obj) { return "setMaxCacheSize" in obj; }, get: function (obj) { return obj.setMaxCacheSize; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getKTVPlayer_decorators, { kind: "method", name: "getKTVPlayer", static: false, private: false, access: { has: function (obj) { return "getKTVPlayer" in obj; }, get: function (obj) { return obj.getKTVPlayer; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _delegate_decorators, { kind: "field", name: "delegate", static: false, private: false, access: { has: function (obj) { return "delegate" in obj; }, get: function (obj) { return obj.delegate; }, set: function (obj, value) { obj.delegate = value; } }, metadata: _metadata }, _delegate_initializers, _delegate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCVideoEffect = function () {
    var _classDecorators = [NativeClass('ByteRTCVideoEffect')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _initCVResource_decorators;
    var _enableVideoEffect_decorators;
    var _disableVideoEffect_decorators;
    var _setEffectNodes_decorators;
    var _updateEffectNode_decorators;
    var _setColorFilter_decorators;
    var _setColorFilterIntensity_decorators;
    var _enableVirtualBackground_decorators;
    var _disableVirtualBackground_decorators;
    var _enableFaceDetection_decorators;
    var _disableFaceDetection_decorators;
    var _registerFaceDetectionObserver_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoEffect_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        ByteRTCVideoEffect_1.prototype.initCVResource = function (licenseFile, algoModelDir) {
            throw new Error('not implement');
        };
        ByteRTCVideoEffect_1.prototype.enableVideoEffect = function () {
            throw new Error('not implement');
        };
        ByteRTCVideoEffect_1.prototype.disableVideoEffect = function () {
            throw new Error('not implement');
        };
        ByteRTCVideoEffect_1.prototype.setEffectNodes = function (effectNodes) {
            throw new Error('not implement');
        };
        ByteRTCVideoEffect_1.prototype.updateEffectNode = function (node, key, value) {
            throw new Error('not implement');
        };
        ByteRTCVideoEffect_1.prototype.setColorFilter = function (filterRes) {
            throw new Error('not implement');
        };
        ByteRTCVideoEffect_1.prototype.setColorFilterIntensity = function (intensity) {
            throw new Error('not implement');
        };
        ByteRTCVideoEffect_1.prototype.enableVirtualBackground = function (backgroundStickerPath, source) {
            throw new Error('not implement');
        };
        ByteRTCVideoEffect_1.prototype.disableVirtualBackground = function () {
            throw new Error('not implement');
        };
        ByteRTCVideoEffect_1.prototype.enableFaceDetection = function (observer, interval, path) {
            throw new Error('not implement');
        };
        ByteRTCVideoEffect_1.prototype.disableFaceDetection = function () {
            throw new Error('not implement');
        };
        ByteRTCVideoEffect_1.prototype.registerFaceDetectionObserver = function (observer, interval) {
            throw new Error('not implement');
        };
        return ByteRTCVideoEffect_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoEffect");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _initCVResource_decorators = [NativeMethodSync('initCVResource:withAlgoModelDir:')];
        _enableVideoEffect_decorators = [NativeMethodSync('enableVideoEffect')];
        _disableVideoEffect_decorators = [NativeMethodSync('disableVideoEffect')];
        _setEffectNodes_decorators = [NativeMethodSync('setEffectNodes:')];
        _updateEffectNode_decorators = [NativeMethodSync('updateEffectNode:key:value:')];
        _setColorFilter_decorators = [NativeMethodSync('setColorFilter:')];
        _setColorFilterIntensity_decorators = [NativeMethodSync('setColorFilterIntensity:')];
        _enableVirtualBackground_decorators = [NativeMethodSync('enableVirtualBackground:withSource:')];
        _disableVirtualBackground_decorators = [NativeMethodSync('disableVirtualBackground')];
        _enableFaceDetection_decorators = [NativeMethodSync('enableFaceDetection:withInterval:withModelPath:')];
        _disableFaceDetection_decorators = [NativeMethodSync('disableFaceDetection')];
        _registerFaceDetectionObserver_decorators = [NativeMethodSync('registerFaceDetectionObserver:withInterval:')];
        __esDecorate(_classThis, null, _initCVResource_decorators, { kind: "method", name: "initCVResource", static: false, private: false, access: { has: function (obj) { return "initCVResource" in obj; }, get: function (obj) { return obj.initCVResource; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableVideoEffect_decorators, { kind: "method", name: "enableVideoEffect", static: false, private: false, access: { has: function (obj) { return "enableVideoEffect" in obj; }, get: function (obj) { return obj.enableVideoEffect; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableVideoEffect_decorators, { kind: "method", name: "disableVideoEffect", static: false, private: false, access: { has: function (obj) { return "disableVideoEffect" in obj; }, get: function (obj) { return obj.disableVideoEffect; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEffectNodes_decorators, { kind: "method", name: "setEffectNodes", static: false, private: false, access: { has: function (obj) { return "setEffectNodes" in obj; }, get: function (obj) { return obj.setEffectNodes; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateEffectNode_decorators, { kind: "method", name: "updateEffectNode", static: false, private: false, access: { has: function (obj) { return "updateEffectNode" in obj; }, get: function (obj) { return obj.updateEffectNode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setColorFilter_decorators, { kind: "method", name: "setColorFilter", static: false, private: false, access: { has: function (obj) { return "setColorFilter" in obj; }, get: function (obj) { return obj.setColorFilter; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setColorFilterIntensity_decorators, { kind: "method", name: "setColorFilterIntensity", static: false, private: false, access: { has: function (obj) { return "setColorFilterIntensity" in obj; }, get: function (obj) { return obj.setColorFilterIntensity; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableVirtualBackground_decorators, { kind: "method", name: "enableVirtualBackground", static: false, private: false, access: { has: function (obj) { return "enableVirtualBackground" in obj; }, get: function (obj) { return obj.enableVirtualBackground; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableVirtualBackground_decorators, { kind: "method", name: "disableVirtualBackground", static: false, private: false, access: { has: function (obj) { return "disableVirtualBackground" in obj; }, get: function (obj) { return obj.disableVirtualBackground; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableFaceDetection_decorators, { kind: "method", name: "enableFaceDetection", static: false, private: false, access: { has: function (obj) { return "enableFaceDetection" in obj; }, get: function (obj) { return obj.enableFaceDetection; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableFaceDetection_decorators, { kind: "method", name: "disableFaceDetection", static: false, private: false, access: { has: function (obj) { return "disableFaceDetection" in obj; }, get: function (obj) { return obj.disableFaceDetection; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerFaceDetectionObserver_decorators, { kind: "method", name: "registerFaceDetectionObserver", static: false, private: false, access: { has: function (obj) { return "registerFaceDetectionObserver" in obj; }, get: function (obj) { return obj.registerFaceDetectionObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRoom = function () {
    var _classDecorators = [NativeClass('ByteRTCRoom')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _delegate_decorators;
    var _delegate_initializers = [];
    var _delegate_extraInitializers = [];
    var _destroy_decorators;
    var _getRoomId_decorators;
    var _setRTCRoomDelegate_decorators;
    var _joinRoom_decorators;
    var _setUserVisibility_decorators;
    var _setMultiDeviceAVSync_decorators;
    var _leaveRoom_decorators;
    var _updateToken_decorators;
    var _setRemoteVideoConfig_decorators;
    var _publishStream_decorators;
    var _unpublishStream_decorators;
    var _publishScreen_decorators;
    var _unpublishScreen_decorators;
    var _subscribeStream_decorators;
    var _subscribeAllStreamsWithMediaStreamType_decorators;
    var _unsubscribeStream_decorators;
    var _unsubscribeAllStreamsWithMediaStreamType_decorators;
    var _subscribeScreen_decorators;
    var _unsubscribeScreen_decorators;
    var _pauseAllSubscribedStream_decorators;
    var _resumeAllSubscribedStream_decorators;
    var _sendUserMessage_decorators;
    var _sendUserBinaryMessage_decorators;
    var _sendRoomMessage_decorators;
    var _sendRoomBinaryMessage_decorators;
    var _startForwardStreamToRooms_decorators;
    var _updateForwardStreamToRooms_decorators;
    var _stopForwardStreamToRooms_decorators;
    var _pauseForwardStreamToAllRooms_decorators;
    var _resumeForwardStreamToAllRooms_decorators;
    var _getRangeAudio_decorators;
    var _getSpatialAudio_decorators;
    var _setRemoteRoomAudioPlaybackVolume_decorators;
    var _setAudioSelectionConfig_decorators;
    var _setRoomExtraInfo_decorators;
    var _startSubtitle_decorators;
    var _stopSubtitle_decorators;
    var _subscribeUserStream_decorators;
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRoom_1() {
            this.delegate = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _delegate_initializers, void 0));
            __runInitializers(this, _delegate_extraInitializers);
        }
        ByteRTCRoom_1.prototype.destroy = function () {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.getRoomId = function () {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.setRTCRoomDelegate = function (roomDelegate) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.joinRoom = function (token, userInfo, roomConfig) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.setUserVisibility = function (enable) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.setMultiDeviceAVSync = function (audioUserId) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.leaveRoom = function () {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.updateToken = function (token) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.setRemoteVideoConfig = function (userId, remoteVideoConfig) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.publishStream = function (type) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.unpublishStream = function (type) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.publishScreen = function (type) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.unpublishScreen = function (type) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.subscribeStream = function (userId, mediaStreamType) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.subscribeAllStreamsWithMediaStreamType = function (mediaStreamType) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.unsubscribeStream = function (userId, mediaStreamType) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.unsubscribeAllStreamsWithMediaStreamType = function (mediaStreamType) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.subscribeScreen = function (userId, mediaStreamType) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.unsubscribeScreen = function (userId, mediaStreamType) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.pauseAllSubscribedStream = function (mediaType) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.resumeAllSubscribedStream = function (mediaType) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.sendUserMessage = function (userId, message, config) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.sendUserBinaryMessage = function (uid, message, config) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.sendRoomMessage = function (message) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.sendRoomBinaryMessage = function (message) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.startForwardStreamToRooms = function (configurations) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.updateForwardStreamToRooms = function (configurations) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.stopForwardStreamToRooms = function () {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.pauseForwardStreamToAllRooms = function () {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.resumeForwardStreamToAllRooms = function () {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.getRangeAudio = function () {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.getSpatialAudio = function () {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.setRemoteRoomAudioPlaybackVolume = function (volume) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.setAudioSelectionConfig = function (audioSelectionPriority) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.setRoomExtraInfo = function (key, value) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.startSubtitle = function (subtitleConfig) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.stopSubtitle = function () {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.subscribeUserStream = function (userId, streamType, mediaType, videoConfig) {
            throw new Error('not implement');
        };
        ByteRTCRoom_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRoom_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRoom");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _delegate_decorators = [NativeMember()];
        _destroy_decorators = [NativeMethodSync('destroy')];
        _getRoomId_decorators = [NativeMethodSync('getRoomId')];
        _setRTCRoomDelegate_decorators = [NativeMethodSync('setRTCRoomDelegate:')];
        _joinRoom_decorators = [NativeMethodSync('joinRoom:userInfo:roomConfig:')];
        _setUserVisibility_decorators = [NativeMethodSync('setUserVisibility:')];
        _setMultiDeviceAVSync_decorators = [NativeMethodSync('setMultiDeviceAVSync:')];
        _leaveRoom_decorators = [NativeMethodSync('leaveRoom')];
        _updateToken_decorators = [NativeMethodSync('updateToken:')];
        _setRemoteVideoConfig_decorators = [NativeMethodSync('setRemoteVideoConfig:remoteVideoConfig:')];
        _publishStream_decorators = [NativeMethodSync('publishStream:')];
        _unpublishStream_decorators = [NativeMethodSync('unpublishStream:')];
        _publishScreen_decorators = [NativeMethodSync('publishScreen:')];
        _unpublishScreen_decorators = [NativeMethodSync('unpublishScreen:')];
        _subscribeStream_decorators = [NativeMethodSync('subscribeStream:mediaStreamType:')];
        _subscribeAllStreamsWithMediaStreamType_decorators = [NativeMethodSync('subscribeAllStreamsWithMediaStreamType:')];
        _unsubscribeStream_decorators = [NativeMethodSync('unsubscribeStream:mediaStreamType:')];
        _unsubscribeAllStreamsWithMediaStreamType_decorators = [NativeMethodSync('unsubscribeAllStreamsWithMediaStreamType:')];
        _subscribeScreen_decorators = [NativeMethodSync('subscribeScreen:mediaStreamType:')];
        _unsubscribeScreen_decorators = [NativeMethodSync('unsubscribeScreen:mediaStreamType:')];
        _pauseAllSubscribedStream_decorators = [NativeMethodSync('pauseAllSubscribedStream:')];
        _resumeAllSubscribedStream_decorators = [NativeMethodSync('resumeAllSubscribedStream:')];
        _sendUserMessage_decorators = [NativeMethodSync('sendUserMessage:message:config:')];
        _sendUserBinaryMessage_decorators = [NativeMethodSync('sendUserBinaryMessage:message:config:')];
        _sendRoomMessage_decorators = [NativeMethodSync('sendRoomMessage:')];
        _sendRoomBinaryMessage_decorators = [NativeMethodSync('sendRoomBinaryMessage:')];
        _startForwardStreamToRooms_decorators = [NativeMethodSync('startForwardStreamToRooms:')];
        _updateForwardStreamToRooms_decorators = [NativeMethodSync('updateForwardStreamToRooms:')];
        _stopForwardStreamToRooms_decorators = [NativeMethodSync('stopForwardStreamToRooms')];
        _pauseForwardStreamToAllRooms_decorators = [NativeMethodSync('pauseForwardStreamToAllRooms')];
        _resumeForwardStreamToAllRooms_decorators = [NativeMethodSync('resumeForwardStreamToAllRooms')];
        _getRangeAudio_decorators = [ReturnClass(function () { return ByteRTCRangeAudio; }), NativeMethodSync('getRangeAudio')];
        _getSpatialAudio_decorators = [ReturnClass(function () { return ByteRTCSpatialAudio; }), NativeMethodSync('getSpatialAudio')];
        _setRemoteRoomAudioPlaybackVolume_decorators = [NativeMethodSync('setRemoteRoomAudioPlaybackVolume:')];
        _setAudioSelectionConfig_decorators = [NativeMethodSync('setAudioSelectionConfig:')];
        _setRoomExtraInfo_decorators = [NativeMethodSync('setRoomExtraInfo:value:')];
        _startSubtitle_decorators = [NativeMethodSync('startSubtitle:')];
        _stopSubtitle_decorators = [NativeMethodSync('stopSubtitle')];
        _subscribeUserStream_decorators = [NativeMethodSync('subscribeUserStream:streamType:mediaType:videoConfig:')];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _destroy_decorators, { kind: "method", name: "destroy", static: false, private: false, access: { has: function (obj) { return "destroy" in obj; }, get: function (obj) { return obj.destroy; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getRoomId_decorators, { kind: "method", name: "getRoomId", static: false, private: false, access: { has: function (obj) { return "getRoomId" in obj; }, get: function (obj) { return obj.getRoomId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRTCRoomDelegate_decorators, { kind: "method", name: "setRTCRoomDelegate", static: false, private: false, access: { has: function (obj) { return "setRTCRoomDelegate" in obj; }, get: function (obj) { return obj.setRTCRoomDelegate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _joinRoom_decorators, { kind: "method", name: "joinRoom", static: false, private: false, access: { has: function (obj) { return "joinRoom" in obj; }, get: function (obj) { return obj.joinRoom; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setUserVisibility_decorators, { kind: "method", name: "setUserVisibility", static: false, private: false, access: { has: function (obj) { return "setUserVisibility" in obj; }, get: function (obj) { return obj.setUserVisibility; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setMultiDeviceAVSync_decorators, { kind: "method", name: "setMultiDeviceAVSync", static: false, private: false, access: { has: function (obj) { return "setMultiDeviceAVSync" in obj; }, get: function (obj) { return obj.setMultiDeviceAVSync; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _leaveRoom_decorators, { kind: "method", name: "leaveRoom", static: false, private: false, access: { has: function (obj) { return "leaveRoom" in obj; }, get: function (obj) { return obj.leaveRoom; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateToken_decorators, { kind: "method", name: "updateToken", static: false, private: false, access: { has: function (obj) { return "updateToken" in obj; }, get: function (obj) { return obj.updateToken; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteVideoConfig_decorators, { kind: "method", name: "setRemoteVideoConfig", static: false, private: false, access: { has: function (obj) { return "setRemoteVideoConfig" in obj; }, get: function (obj) { return obj.setRemoteVideoConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _publishStream_decorators, { kind: "method", name: "publishStream", static: false, private: false, access: { has: function (obj) { return "publishStream" in obj; }, get: function (obj) { return obj.publishStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unpublishStream_decorators, { kind: "method", name: "unpublishStream", static: false, private: false, access: { has: function (obj) { return "unpublishStream" in obj; }, get: function (obj) { return obj.unpublishStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _publishScreen_decorators, { kind: "method", name: "publishScreen", static: false, private: false, access: { has: function (obj) { return "publishScreen" in obj; }, get: function (obj) { return obj.publishScreen; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unpublishScreen_decorators, { kind: "method", name: "unpublishScreen", static: false, private: false, access: { has: function (obj) { return "unpublishScreen" in obj; }, get: function (obj) { return obj.unpublishScreen; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _subscribeStream_decorators, { kind: "method", name: "subscribeStream", static: false, private: false, access: { has: function (obj) { return "subscribeStream" in obj; }, get: function (obj) { return obj.subscribeStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _subscribeAllStreamsWithMediaStreamType_decorators, { kind: "method", name: "subscribeAllStreamsWithMediaStreamType", static: false, private: false, access: { has: function (obj) { return "subscribeAllStreamsWithMediaStreamType" in obj; }, get: function (obj) { return obj.subscribeAllStreamsWithMediaStreamType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unsubscribeStream_decorators, { kind: "method", name: "unsubscribeStream", static: false, private: false, access: { has: function (obj) { return "unsubscribeStream" in obj; }, get: function (obj) { return obj.unsubscribeStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unsubscribeAllStreamsWithMediaStreamType_decorators, { kind: "method", name: "unsubscribeAllStreamsWithMediaStreamType", static: false, private: false, access: { has: function (obj) { return "unsubscribeAllStreamsWithMediaStreamType" in obj; }, get: function (obj) { return obj.unsubscribeAllStreamsWithMediaStreamType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _subscribeScreen_decorators, { kind: "method", name: "subscribeScreen", static: false, private: false, access: { has: function (obj) { return "subscribeScreen" in obj; }, get: function (obj) { return obj.subscribeScreen; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unsubscribeScreen_decorators, { kind: "method", name: "unsubscribeScreen", static: false, private: false, access: { has: function (obj) { return "unsubscribeScreen" in obj; }, get: function (obj) { return obj.unsubscribeScreen; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pauseAllSubscribedStream_decorators, { kind: "method", name: "pauseAllSubscribedStream", static: false, private: false, access: { has: function (obj) { return "pauseAllSubscribedStream" in obj; }, get: function (obj) { return obj.pauseAllSubscribedStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resumeAllSubscribedStream_decorators, { kind: "method", name: "resumeAllSubscribedStream", static: false, private: false, access: { has: function (obj) { return "resumeAllSubscribedStream" in obj; }, get: function (obj) { return obj.resumeAllSubscribedStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendUserMessage_decorators, { kind: "method", name: "sendUserMessage", static: false, private: false, access: { has: function (obj) { return "sendUserMessage" in obj; }, get: function (obj) { return obj.sendUserMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendUserBinaryMessage_decorators, { kind: "method", name: "sendUserBinaryMessage", static: false, private: false, access: { has: function (obj) { return "sendUserBinaryMessage" in obj; }, get: function (obj) { return obj.sendUserBinaryMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendRoomMessage_decorators, { kind: "method", name: "sendRoomMessage", static: false, private: false, access: { has: function (obj) { return "sendRoomMessage" in obj; }, get: function (obj) { return obj.sendRoomMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendRoomBinaryMessage_decorators, { kind: "method", name: "sendRoomBinaryMessage", static: false, private: false, access: { has: function (obj) { return "sendRoomBinaryMessage" in obj; }, get: function (obj) { return obj.sendRoomBinaryMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startForwardStreamToRooms_decorators, { kind: "method", name: "startForwardStreamToRooms", static: false, private: false, access: { has: function (obj) { return "startForwardStreamToRooms" in obj; }, get: function (obj) { return obj.startForwardStreamToRooms; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateForwardStreamToRooms_decorators, { kind: "method", name: "updateForwardStreamToRooms", static: false, private: false, access: { has: function (obj) { return "updateForwardStreamToRooms" in obj; }, get: function (obj) { return obj.updateForwardStreamToRooms; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopForwardStreamToRooms_decorators, { kind: "method", name: "stopForwardStreamToRooms", static: false, private: false, access: { has: function (obj) { return "stopForwardStreamToRooms" in obj; }, get: function (obj) { return obj.stopForwardStreamToRooms; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pauseForwardStreamToAllRooms_decorators, { kind: "method", name: "pauseForwardStreamToAllRooms", static: false, private: false, access: { has: function (obj) { return "pauseForwardStreamToAllRooms" in obj; }, get: function (obj) { return obj.pauseForwardStreamToAllRooms; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resumeForwardStreamToAllRooms_decorators, { kind: "method", name: "resumeForwardStreamToAllRooms", static: false, private: false, access: { has: function (obj) { return "resumeForwardStreamToAllRooms" in obj; }, get: function (obj) { return obj.resumeForwardStreamToAllRooms; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getRangeAudio_decorators, { kind: "method", name: "getRangeAudio", static: false, private: false, access: { has: function (obj) { return "getRangeAudio" in obj; }, get: function (obj) { return obj.getRangeAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getSpatialAudio_decorators, { kind: "method", name: "getSpatialAudio", static: false, private: false, access: { has: function (obj) { return "getSpatialAudio" in obj; }, get: function (obj) { return obj.getSpatialAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteRoomAudioPlaybackVolume_decorators, { kind: "method", name: "setRemoteRoomAudioPlaybackVolume", static: false, private: false, access: { has: function (obj) { return "setRemoteRoomAudioPlaybackVolume" in obj; }, get: function (obj) { return obj.setRemoteRoomAudioPlaybackVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioSelectionConfig_decorators, { kind: "method", name: "setAudioSelectionConfig", static: false, private: false, access: { has: function (obj) { return "setAudioSelectionConfig" in obj; }, get: function (obj) { return obj.setAudioSelectionConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRoomExtraInfo_decorators, { kind: "method", name: "setRoomExtraInfo", static: false, private: false, access: { has: function (obj) { return "setRoomExtraInfo" in obj; }, get: function (obj) { return obj.setRoomExtraInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startSubtitle_decorators, { kind: "method", name: "startSubtitle", static: false, private: false, access: { has: function (obj) { return "startSubtitle" in obj; }, get: function (obj) { return obj.startSubtitle; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopSubtitle_decorators, { kind: "method", name: "stopSubtitle", static: false, private: false, access: { has: function (obj) { return "stopSubtitle" in obj; }, get: function (obj) { return obj.stopSubtitle; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _subscribeUserStream_decorators, { kind: "method", name: "subscribeUserStream", static: false, private: false, access: { has: function (obj) { return "subscribeUserStream" in obj; }, get: function (obj) { return obj.subscribeUserStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _delegate_decorators, { kind: "field", name: "delegate", static: false, private: false, access: { has: function (obj) { return "delegate" in obj; }, get: function (obj) { return obj.delegate; }, set: function (obj, value) { obj.delegate = value; } }, metadata: _metadata }, _delegate_initializers, _delegate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCVideo = function () {
    var _classDecorators = [NativeClass('ByteRTCVideo')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _staticExtraInitializers = [];
    var _instanceExtraInitializers = [];
    var _static_createRTCVideo_decorators;
    var _static_destroyRTCVideo_decorators;
    var _static_getSDKVersion_decorators;
    var _static_setLogConfig_decorators;
    var _static_getErrorDescription_decorators;
    var _delegate_decorators;
    var _delegate_initializers = [];
    var _delegate_extraInitializers = [];
    var _setAudioSourceType_decorators;
    var _setAudioRenderType_decorators;
    var _startAudioCapture_decorators;
    var _stopAudioCapture_decorators;
    var _setAudioScenario_decorators;
    var _setAudioProfile_decorators;
    var _setAnsMode_decorators;
    var _setVoiceChangerType_decorators;
    var _setVoiceReverbType_decorators;
    var _setLocalVoiceEqualization_decorators;
    var _setLocalVoiceReverbParam_decorators;
    var _enableLocalVoiceReverb_decorators;
    var _muteAudioCapture_decorators;
    var _setCaptureVolume_decorators;
    var _setPlaybackVolume_decorators;
    var _enableAudioPropertiesReport_decorators;
    var _setRemoteAudioPlaybackVolume_decorators;
    var _setEarMonitorMode_decorators;
    var _setEarMonitorVolume_decorators;
    var _setBluetoothMode_decorators;
    var _setLocalVoicePitch_decorators;
    var _enableVocalInstrumentBalance_decorators;
    var _enablePlaybackDucking_decorators;
    var _setLocalVideoRender_decorators;
    var _setRemoteVideoRender_decorators;
    var _setRemoteVideoSuperResolution_decorators;
    var _setVideoCaptureRotation_decorators;
    var _enableSimulcastMode_decorators;
    var _setMaxVideoEncoderConfig_decorators;
    var _setVideoEncoderConfig_decorators;
    var _setScreenVideoEncoderConfig_decorators;
    var _enableAlphaChannelVideoEncode_decorators;
    var _disableAlphaChannelVideoEncode_decorators;
    var _setVideoCaptureConfig_decorators;
    var _setLocalVideoCanvas_decorators;
    var _updateLocalVideoCanvas_decorators;
    var _setRemoteVideoCanvas_decorators;
    var _updateRemoteStreamVideoCanvas_decorators;
    var _startVideoCapture_decorators;
    var _stopVideoCapture_decorators;
    var _setLocalVideoMirrorType_decorators;
    var _setRemoteVideoMirrorType_decorators;
    var _setVideoRotationMode_decorators;
    var _setVideoOrientation_decorators;
    var _switchCamera_decorators;
    var _getVideoEffectInterface_decorators;
    var _enableEffectBeauty_decorators;
    var _setBeautyIntensity_decorators;
    var _setCameraZoomRatio_decorators;
    var _getCameraZoomMaxRatio_decorators;
    var _isCameraZoomSupported_decorators;
    var _isCameraTorchSupported_decorators;
    var _setCameraTorch_decorators;
    var _isCameraFocusPositionSupported_decorators;
    var _setCameraFocusPosition_decorators;
    var _isCameraExposurePositionSupported_decorators;
    var _setCameraExposurePosition_decorators;
    var _setCameraExposureCompensation_decorators;
    var _enableCameraAutoExposureFaceMode_decorators;
    var _setCameraAdaptiveMinimumFrameRate_decorators;
    var _sendSEIMessage_decorators;
    var _setVideoDigitalZoomConfig_decorators;
    var _setVideoDigitalZoomControl_decorators;
    var _startVideoDigitalZoomControl_decorators;
    var _stopVideoDigitalZoomControl_decorators;
    var _registerLocalVideoProcessor_decorators;
    var _registerLocalEncodedVideoFrameObserver_decorators;
    var _setAudioRoute_decorators;
    var _getAudioRoute_decorators;
    var _enableExternalSoundCard_decorators;
    var _setDefaultAudioRoute_decorators;
    var _startPushMixedStreamToCDN_decorators;
    var _updatePushMixedStreamToCDN_decorators;
    var _startPushSingleStreamToCDN_decorators;
    var _stopPushStreamToCDN_decorators;
    var _startPushPublicStream_decorators;
    var _stopPushPublicStream_decorators;
    var _updatePublicStreamParam_decorators;
    var _startPlayPublicStream_decorators;
    var _stopPlayPublicStream_decorators;
    var _setPublicStreamVideoCanvas_decorators;
    var _setPublicStreamVideoSink_decorators;
    var _setPublicStreamAudioPlaybackVolume_decorators;
    var _pushExternalVideoFrame_decorators;
    var _enableAudioFrameCallback_decorators;
    var _disableAudioFrameCallback_decorators;
    var _registerAudioFrameObserver_decorators;
    var _registerAudioProcessor_decorators;
    var _enableAudioProcessor_decorators;
    var _disableAudioProcessor_decorators;
    var _pushExternalAudioFrame_decorators;
    var _pullExternalAudioFrame_decorators;
    var _setBusinessId_decorators;
    var _feedback_decorators;
    var _getNativeHandle_decorators;
    var _setPublishFallbackOption_decorators;
    var _setSubscribeFallbackOption_decorators;
    var _setRemoteUserPriority_decorators;
    var _setEncryptInfo_decorators;
    var _setCustomizeEncryptHandler_decorators;
    var _createRTCRoom_decorators;
    var _pushScreenVideoFrame_decorators;
    var _setExtensionConfig_decorators;
    var _startScreenCapture_decorators;
    var _updateScreenCapture_decorators;
    var _stopScreenCapture_decorators;
    var _sendScreenCaptureExtensionMessage_decorators;
    var _setRuntimeParameters_decorators;
    var _startASR_decorators;
    var _stopASR_decorators;
    var _startFileRecording_decorators;
    var _stopFileRecording_decorators;
    var _startAudioRecording_decorators;
    var _stopAudioRecording_decorators;
    var _getAudioEffectPlayer_decorators;
    var _getMediaPlayer_decorators;
    var _login_decorators;
    var _logout_decorators;
    var _updateLoginToken_decorators;
    var _setServerParams_decorators;
    var _getPeerOnlineStatus_decorators;
    var _sendUserMessageOutsideRoom_decorators;
    var _sendUserBinaryMessageOutsideRoom_decorators;
    var _sendServerMessage_decorators;
    var _sendServerBinaryMessage_decorators;
    var _startNetworkDetection_decorators;
    var _stopNetworkDetection_decorators;
    var _setScreenAudioSourceType_decorators;
    var _setScreenAudioStreamIndex_decorators;
    var _pushScreenAudioFrame_decorators;
    var _setVideoSourceType_decorators;
    var _setExternalVideoEncoderEventHandler_decorators;
    var _pushExternalEncodedVideoFrame_decorators;
    var _setVideoDecoderConfig_decorators;
    var _requestRemoteVideoKeyFrame_decorators;
    var _registerRemoteEncodedVideoFrameObserver_decorators;
    var _sendStreamSyncInfo_decorators;
    var _startEchoTest_decorators;
    var _stopEchoTest_decorators;
    var _setVideoWatermark_decorators;
    var _clearVideoWatermark_decorators;
    var _takeLocalSnapshot_decorators;
    var _takeRemoteSnapshot_decorators;
    var _startCloudProxy_decorators;
    var _stopCloudProxy_decorators;
    var _getSingScoringManager_decorators;
    var _setDummyCaptureImagePath_decorators;
    var _getNetworkTimeInfo_decorators;
    var _getKTVManager_decorators;
    var _startHardwareEchoDetection_decorators;
    var _stopHardwareEchoDetection_decorators;
    var _setCellularEnhancement_decorators;
    var _setLocalProxy_decorators;
    var _setLocalVideoSink_decorators;
    var _setRemoteVideoSink_decorators;
    var _setVideoEncoderConfig$config$_decorators;
    var _updateRemoteStreamVideoCanvas$withRenderMode$withBackgroundColor$_decorators;
    var _checkVideoEffectLicense_decorators;
    var _setVideoEffectAlgoModelPath_decorators;
    var _enableVideoEffect_decorators;
    var _setVideoEffectNodes_decorators;
    var _updateVideoEffectNode_decorators;
    var _setVideoEffectColorFilter_decorators;
    var _setVideoEffectColorFilterIntensity_decorators;
    var _setBackgroundSticker_decorators;
    var _registerFaceDetectionObserver_decorators;
    var _sendSEIMessage$andMessage$andRepeatCount$_decorators;
    var _setAudioPlaybackDevice_decorators;
    var _startLiveTranscoding_decorators;
    var _stopLiveTranscoding_decorators;
    var _updateLiveTranscoding_decorators;
    var _getAudioMixingManager_decorators;
    var _muteAudioPlayback_decorators;
    var _init_decorators;
    var ByteRTCVideo = _classThis = /** @class */ (function () {
        function ByteRTCVideo_1() {
            this.delegate = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _delegate_initializers, void 0));
            __runInitializers(this, _delegate_extraInitializers);
        }
        ByteRTCVideo_1.createRTCVideo = function (appId, delegate, parameters) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.destroyRTCVideo = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.getSDKVersion = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.setLogConfig = function (logConfig) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.getErrorDescription = function (code) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setAudioSourceType = function (type) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setAudioRenderType = function (type) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startAudioCapture = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopAudioCapture = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setAudioScenario = function (audioScenario) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setAudioProfile = function (audioProfile) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setAnsMode = function (ansMode) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVoiceChangerType = function (voiceChanger) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVoiceReverbType = function (voiceReverb) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setLocalVoiceEqualization = function (config) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setLocalVoiceReverbParam = function (param) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.enableLocalVoiceReverb = function (enable) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.muteAudioCapture = function (index, mute) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setCaptureVolume = function (index, volume) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setPlaybackVolume = function (volume) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.enableAudioPropertiesReport = function (config) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setRemoteAudioPlaybackVolume = function (streamKey, volume) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setEarMonitorMode = function (mode) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setEarMonitorVolume = function (volume) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setBluetoothMode = function (mode) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setLocalVoicePitch = function (pitch) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.enableVocalInstrumentBalance = function (enable) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.enablePlaybackDucking = function (enable) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setLocalVideoRender = function (index, videoSink, config) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setRemoteVideoRender = function (streamKey, videoSink, config) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setRemoteVideoSuperResolution = function (streamKey, mode) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoCaptureRotation = function (rotation) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.enableSimulcastMode = function (enabled) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setMaxVideoEncoderConfig = function (encoderConfig) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoEncoderConfig = function (encoderConfigs) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setScreenVideoEncoderConfig = function (encoderConfig) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.enableAlphaChannelVideoEncode = function (streamIndex, alphaLayout) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.disableAlphaChannelVideoEncode = function (streamIndex) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoCaptureConfig = function (captureConfig) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setLocalVideoCanvas = function (streamIndex, canvas) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.updateLocalVideoCanvas = function (streamIndex, renderMode, backgroundColor) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setRemoteVideoCanvas = function (key, canvas) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.updateRemoteStreamVideoCanvas = function (key, remoteVideoRenderConfig) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startVideoCapture = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopVideoCapture = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setLocalVideoMirrorType = function (mirrorType) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setRemoteVideoMirrorType = function (key, mirrorType) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoRotationMode = function (rotationMode) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoOrientation = function (orientation) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.switchCamera = function (cameraId) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.getVideoEffectInterface = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.enableEffectBeauty = function (enable) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setBeautyIntensity = function (beautyMode, intensity) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setCameraZoomRatio = function (zoomRatio) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.getCameraZoomMaxRatio = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.isCameraZoomSupported = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.isCameraTorchSupported = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setCameraTorch = function (torchState) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.isCameraFocusPositionSupported = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setCameraFocusPosition = function (position) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.isCameraExposurePositionSupported = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setCameraExposurePosition = function (position) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setCameraExposureCompensation = function (val) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.enableCameraAutoExposureFaceMode = function (enable) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setCameraAdaptiveMinimumFrameRate = function (framerate) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.sendSEIMessage = function (streamIndex, message, repeatCount, mode) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoDigitalZoomConfig = function (type, size) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoDigitalZoomControl = function (direction) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startVideoDigitalZoomControl = function (direction) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopVideoDigitalZoomControl = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.registerLocalVideoProcessor = function (processor, config) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.registerLocalEncodedVideoFrameObserver = function (frameObserver) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setAudioRoute = function (audioRoute) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.getAudioRoute = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.enableExternalSoundCard = function (enable) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setDefaultAudioRoute = function (audioRoute) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startPushMixedStreamToCDN = function (taskID, config, observer) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.updatePushMixedStreamToCDN = function (taskID, config) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startPushSingleStreamToCDN = function (taskID, singleStream, observer) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopPushStreamToCDN = function (taskID) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startPushPublicStream = function (publicStreamId, publicStream) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopPushPublicStream = function (publicStreamId) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.updatePublicStreamParam = function (publicStreamId, publicStream) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startPlayPublicStream = function (publicStreamId) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopPlayPublicStream = function (publicStreamId) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setPublicStreamVideoCanvas = function (publicStreamId, canvas) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setPublicStreamVideoSink = function (publicStreamId, videoSink, requiredFormat) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setPublicStreamAudioPlaybackVolume = function (publicStreamId, volume) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.pushExternalVideoFrame = function (frame) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.enableAudioFrameCallback = function (method, format) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.disableAudioFrameCallback = function (method) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.registerAudioFrameObserver = function (audioFrameObserver) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.registerAudioProcessor = function (processor) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.enableAudioProcessor = function (method, format) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.disableAudioProcessor = function (method) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.pushExternalAudioFrame = function (audioFrame) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.pullExternalAudioFrame = function (audioFrame) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setBusinessId = function (businessId) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.feedback = function (types, info) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.getNativeHandle = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setPublishFallbackOption = function (option) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setSubscribeFallbackOption = function (option) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setRemoteUserPriority = function (priority, roomId, uid) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setEncryptInfo = function (encrypt_type, key) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setCustomizeEncryptHandler = function (handler) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.createRTCRoom = function (roomId) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.pushScreenVideoFrame = function (frame, pts, rotation) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setExtensionConfig = function (groupId) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startScreenCapture = function (type, bundleId) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.updateScreenCapture = function (type) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopScreenCapture = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.sendScreenCaptureExtensionMessage = function (messsage) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setRuntimeParameters = function (parameters) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startASR = function (asrConfig, handler) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopASR = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startFileRecording = function (streamIndex, recordingConfig, recordingType) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopFileRecording = function (streamIndex) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startAudioRecording = function (recordingConfig) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopAudioRecording = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.getAudioEffectPlayer = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.getMediaPlayer = function (playerId) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.login = function (token, uid) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.logout = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.updateLoginToken = function (token) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setServerParams = function (signature, url) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.getPeerOnlineStatus = function (peerUserId) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.sendUserMessageOutsideRoom = function (userId, messageStr, config) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.sendUserBinaryMessageOutsideRoom = function (userId, messageStr, config) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.sendServerMessage = function (messageStr) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.sendServerBinaryMessage = function (messageStr) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startNetworkDetection = function (isTestUplink, expectedUplinkBitrate, isTestDownlink, expectedDownlinkBitrate) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopNetworkDetection = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setScreenAudioSourceType = function (sourceType) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setScreenAudioStreamIndex = function (index) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.pushScreenAudioFrame = function (audioFrame) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoSourceType = function (type, streamIndex) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setExternalVideoEncoderEventHandler = function (handler) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.pushExternalEncodedVideoFrame = function (streamIndex, videoIndex, videoFrame) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoDecoderConfig = function (key, config) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.requestRemoteVideoKeyFrame = function (key) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.registerRemoteEncodedVideoFrameObserver = function (observer) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.sendStreamSyncInfo = function (data, config) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startEchoTest = function (echoConfig, delayTime) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopEchoTest = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoWatermark = function (streamIndex, imagePath, rtcWatermarkConfig) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.clearVideoWatermark = function (streamIndex) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.takeLocalSnapshot = function (streamIndex, callback) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.takeRemoteSnapshot = function (streamKey, callback) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startCloudProxy = function (cloudProxiesInfo) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopCloudProxy = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.getSingScoringManager = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setDummyCaptureImagePath = function (filePath) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.getNetworkTimeInfo = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.getKTVManager = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startHardwareEchoDetection = function (testAudioFilePath) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopHardwareEchoDetection = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setCellularEnhancement = function (config) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setLocalProxy = function (configurations) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setLocalVideoSink = function (index, videoSink, requiredFormat) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setRemoteVideoSink = function (streamKey, videoSink, requiredFormat) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoEncoderConfig$config$ = function (streamIndex, videoSolutions) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.updateRemoteStreamVideoCanvas$withRenderMode$withBackgroundColor$ = function (key, renderMode, backgroundColor) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.checkVideoEffectLicense = function (licenseFile) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoEffectAlgoModelPath = function (modelPath) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.enableVideoEffect = function (enabled) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoEffectNodes = function (effectNodePaths) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.updateVideoEffectNode = function (nodePath, nodeKey, nodeValue) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoEffectColorFilter = function (resPath) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setVideoEffectColorFilterIntensity = function (intensity) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setBackgroundSticker = function (modelPath, source) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.registerFaceDetectionObserver = function (faceDetectionObserver, interval) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.sendSEIMessage$andMessage$andRepeatCount$ = function (streamIndex, message, repeatCount) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.setAudioPlaybackDevice = function (audioPlaybackDevice) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.startLiveTranscoding = function (taskID, transcoding, observer) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.stopLiveTranscoding = function (taskID) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.updateLiveTranscoding = function (taskID, transcoding) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.getAudioMixingManager = function () {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.muteAudioPlayback = function (muteState) {
            throw new Error('not implement');
        };
        ByteRTCVideo_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVideo_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _static_createRTCVideo_decorators = [ReturnClass(function () { return ByteRTCVideo; }), NativeStaticMethodSync('createRTCVideo:delegate:parameters:')];
        _static_destroyRTCVideo_decorators = [NativeStaticMethodSync('destroyRTCVideo')];
        _static_getSDKVersion_decorators = [NativeStaticMethodSync('getSDKVersion')];
        _static_setLogConfig_decorators = [NativeStaticMethodSync('setLogConfig:')];
        _static_getErrorDescription_decorators = [NativeStaticMethodSync('getErrorDescription:')];
        _delegate_decorators = [NativeMember()];
        _setAudioSourceType_decorators = [NativeMethodSync('setAudioSourceType:')];
        _setAudioRenderType_decorators = [NativeMethodSync('setAudioRenderType:')];
        _startAudioCapture_decorators = [NativeMethodSync('startAudioCapture')];
        _stopAudioCapture_decorators = [NativeMethodSync('stopAudioCapture')];
        _setAudioScenario_decorators = [NativeMethodSync('setAudioScenario:')];
        _setAudioProfile_decorators = [NativeMethodSync('setAudioProfile:')];
        _setAnsMode_decorators = [NativeMethodSync('setAnsMode:')];
        _setVoiceChangerType_decorators = [NativeMethodSync('setVoiceChangerType:')];
        _setVoiceReverbType_decorators = [NativeMethodSync('setVoiceReverbType:')];
        _setLocalVoiceEqualization_decorators = [NativeMethodSync('setLocalVoiceEqualization:')];
        _setLocalVoiceReverbParam_decorators = [NativeMethodSync('setLocalVoiceReverbParam:')];
        _enableLocalVoiceReverb_decorators = [NativeMethodSync('enableLocalVoiceReverb:')];
        _muteAudioCapture_decorators = [NativeMethodSync('muteAudioCapture:mute:')];
        _setCaptureVolume_decorators = [NativeMethodSync('setCaptureVolume:volume:')];
        _setPlaybackVolume_decorators = [NativeMethodSync('setPlaybackVolume:')];
        _enableAudioPropertiesReport_decorators = [NativeMethodSync('enableAudioPropertiesReport:')];
        _setRemoteAudioPlaybackVolume_decorators = [NativeMethodSync('setRemoteAudioPlaybackVolume:volume:')];
        _setEarMonitorMode_decorators = [NativeMethodSync('setEarMonitorMode:')];
        _setEarMonitorVolume_decorators = [NativeMethodSync('setEarMonitorVolume:')];
        _setBluetoothMode_decorators = [NativeMethodSync('setBluetoothMode:')];
        _setLocalVoicePitch_decorators = [NativeMethodSync('setLocalVoicePitch:')];
        _enableVocalInstrumentBalance_decorators = [NativeMethodSync('enableVocalInstrumentBalance:')];
        _enablePlaybackDucking_decorators = [NativeMethodSync('enablePlaybackDucking:')];
        _setLocalVideoRender_decorators = [NativeMethodSync('setLocalVideoRender:withSink:withLocalRenderConfig:')];
        _setRemoteVideoRender_decorators = [NativeMethodSync('setRemoteVideoRender:withSink:withRemoteRenderConfig:')];
        _setRemoteVideoSuperResolution_decorators = [NativeMethodSync('setRemoteVideoSuperResolution:withMode:')];
        _setVideoCaptureRotation_decorators = [NativeMethodSync('setVideoCaptureRotation:')];
        _enableSimulcastMode_decorators = [NativeMethodSync('enableSimulcastMode:')];
        _setMaxVideoEncoderConfig_decorators = [NativeMethodSync('setMaxVideoEncoderConfig:')];
        _setVideoEncoderConfig_decorators = [NativeMethodSync('setVideoEncoderConfig:')];
        _setScreenVideoEncoderConfig_decorators = [NativeMethodSync('setScreenVideoEncoderConfig:')];
        _enableAlphaChannelVideoEncode_decorators = [NativeMethodSync('enableAlphaChannelVideoEncode:withAlphaLayout:')];
        _disableAlphaChannelVideoEncode_decorators = [NativeMethodSync('disableAlphaChannelVideoEncode:')];
        _setVideoCaptureConfig_decorators = [NativeMethodSync('setVideoCaptureConfig:')];
        _setLocalVideoCanvas_decorators = [NativeMethodSync('setLocalVideoCanvas:withCanvas:')];
        _updateLocalVideoCanvas_decorators = [NativeMethodSync('updateLocalVideoCanvas:withRenderMode:withBackgroundColor:')];
        _setRemoteVideoCanvas_decorators = [NativeMethodSync('setRemoteVideoCanvas:withCanvas:')];
        _updateRemoteStreamVideoCanvas_decorators = [NativeMethodSync('updateRemoteStreamVideoCanvas:withRemoteVideoRenderConfig:')];
        _startVideoCapture_decorators = [NativeMethodSync('startVideoCapture')];
        _stopVideoCapture_decorators = [NativeMethodSync('stopVideoCapture')];
        _setLocalVideoMirrorType_decorators = [NativeMethodSync('setLocalVideoMirrorType:')];
        _setRemoteVideoMirrorType_decorators = [NativeMethodSync('setRemoteVideoMirrorType:withMirrorType:')];
        _setVideoRotationMode_decorators = [NativeMethodSync('setVideoRotationMode:')];
        _setVideoOrientation_decorators = [NativeMethodSync('setVideoOrientation:')];
        _switchCamera_decorators = [NativeMethodSync('switchCamera:')];
        _getVideoEffectInterface_decorators = [ReturnClass(function () { return ByteRTCVideoEffect; }), NativeMethodSync('getVideoEffectInterface')];
        _enableEffectBeauty_decorators = [NativeMethodSync('enableEffectBeauty:')];
        _setBeautyIntensity_decorators = [NativeMethodSync('setBeautyIntensity:withIntensity:')];
        _setCameraZoomRatio_decorators = [NativeMethodSync('setCameraZoomRatio:')];
        _getCameraZoomMaxRatio_decorators = [NativeMethodSync('getCameraZoomMaxRatio')];
        _isCameraZoomSupported_decorators = [NativeMethodSync('isCameraZoomSupported')];
        _isCameraTorchSupported_decorators = [NativeMethodSync('isCameraTorchSupported')];
        _setCameraTorch_decorators = [NativeMethodSync('setCameraTorch:')];
        _isCameraFocusPositionSupported_decorators = [NativeMethodSync('isCameraFocusPositionSupported')];
        _setCameraFocusPosition_decorators = [NativeMethodSync('setCameraFocusPosition:')];
        _isCameraExposurePositionSupported_decorators = [NativeMethodSync('isCameraExposurePositionSupported')];
        _setCameraExposurePosition_decorators = [NativeMethodSync('setCameraExposurePosition:')];
        _setCameraExposureCompensation_decorators = [NativeMethodSync('setCameraExposureCompensation:')];
        _enableCameraAutoExposureFaceMode_decorators = [NativeMethodSync('enableCameraAutoExposureFaceMode:')];
        _setCameraAdaptiveMinimumFrameRate_decorators = [NativeMethodSync('setCameraAdaptiveMinimumFrameRate:')];
        _sendSEIMessage_decorators = [NativeMethodSync('sendSEIMessage:andMessage:andRepeatCount:andCountPerFrame:')];
        _setVideoDigitalZoomConfig_decorators = [NativeMethodSync('setVideoDigitalZoomConfig:size:')];
        _setVideoDigitalZoomControl_decorators = [NativeMethodSync('setVideoDigitalZoomControl:')];
        _startVideoDigitalZoomControl_decorators = [NativeMethodSync('startVideoDigitalZoomControl:')];
        _stopVideoDigitalZoomControl_decorators = [NativeMethodSync('stopVideoDigitalZoomControl')];
        _registerLocalVideoProcessor_decorators = [NativeMethodSync('registerLocalVideoProcessor:withConfig:')];
        _registerLocalEncodedVideoFrameObserver_decorators = [NativeMethodSync('registerLocalEncodedVideoFrameObserver:')];
        _setAudioRoute_decorators = [NativeMethodSync('setAudioRoute:')];
        _getAudioRoute_decorators = [NativeMethodSync('getAudioRoute')];
        _enableExternalSoundCard_decorators = [NativeMethodSync('enableExternalSoundCard:')];
        _setDefaultAudioRoute_decorators = [NativeMethodSync('setDefaultAudioRoute:')];
        _startPushMixedStreamToCDN_decorators = [NativeMethodSync('startPushMixedStreamToCDN:mixedConfig:observer:')];
        _updatePushMixedStreamToCDN_decorators = [NativeMethodSync('updatePushMixedStreamToCDN:mixedConfig:')];
        _startPushSingleStreamToCDN_decorators = [NativeMethodSync('startPushSingleStreamToCDN:singleStream:observer:')];
        _stopPushStreamToCDN_decorators = [NativeMethodSync('stopPushStreamToCDN:')];
        _startPushPublicStream_decorators = [NativeMethodSync('startPushPublicStream:withLayout:')];
        _stopPushPublicStream_decorators = [NativeMethodSync('stopPushPublicStream:')];
        _updatePublicStreamParam_decorators = [NativeMethodSync('updatePublicStreamParam:withLayout:')];
        _startPlayPublicStream_decorators = [NativeMethodSync('startPlayPublicStream:')];
        _stopPlayPublicStream_decorators = [NativeMethodSync('stopPlayPublicStream:')];
        _setPublicStreamVideoCanvas_decorators = [NativeMethodSync('setPublicStreamVideoCanvas:withCanvas:')];
        _setPublicStreamVideoSink_decorators = [NativeMethodSync('setPublicStreamVideoSink:withSink:withPixelFormat:')];
        _setPublicStreamAudioPlaybackVolume_decorators = [NativeMethodSync('setPublicStreamAudioPlaybackVolume:volume:')];
        _pushExternalVideoFrame_decorators = [NativeMethodSync('pushExternalVideoFrame:')];
        _enableAudioFrameCallback_decorators = [NativeMethodSync('enableAudioFrameCallback:format:')];
        _disableAudioFrameCallback_decorators = [NativeMethodSync('disableAudioFrameCallback:')];
        _registerAudioFrameObserver_decorators = [NativeMethodSync('registerAudioFrameObserver:')];
        _registerAudioProcessor_decorators = [NativeMethodSync('registerAudioProcessor:')];
        _enableAudioProcessor_decorators = [NativeMethodSync('enableAudioProcessor:audioFormat:')];
        _disableAudioProcessor_decorators = [NativeMethodSync('disableAudioProcessor:')];
        _pushExternalAudioFrame_decorators = [NativeMethodSync('pushExternalAudioFrame:')];
        _pullExternalAudioFrame_decorators = [NativeMethodSync('pullExternalAudioFrame:')];
        _setBusinessId_decorators = [NativeMethodSync('setBusinessId:')];
        _feedback_decorators = [NativeMethodSync('feedback:info:')];
        _getNativeHandle_decorators = [NativeMethodSync('getNativeHandle')];
        _setPublishFallbackOption_decorators = [NativeMethodSync('setPublishFallbackOption:')];
        _setSubscribeFallbackOption_decorators = [NativeMethodSync('setSubscribeFallbackOption:')];
        _setRemoteUserPriority_decorators = [NativeMethodSync('setRemoteUserPriority:InRoomId:uid:')];
        _setEncryptInfo_decorators = [NativeMethodSync('setEncryptInfo:key:')];
        _setCustomizeEncryptHandler_decorators = [NativeMethodSync('setCustomizeEncryptHandler:')];
        _createRTCRoom_decorators = [ReturnClass(function () { return ByteRTCRoom; }), NativeMethodSync('createRTCRoom:')];
        _pushScreenVideoFrame_decorators = [NativeMethodSync('pushScreenVideoFrame:time:rotation:')];
        _setExtensionConfig_decorators = [NativeMethodSync('setExtensionConfig:')];
        _startScreenCapture_decorators = [NativeMethodSync('startScreenCapture:bundleId:')];
        _updateScreenCapture_decorators = [NativeMethodSync('updateScreenCapture:')];
        _stopScreenCapture_decorators = [NativeMethodSync('stopScreenCapture')];
        _sendScreenCaptureExtensionMessage_decorators = [NativeMethodSync('sendScreenCaptureExtensionMessage:')];
        _setRuntimeParameters_decorators = [NativeMethodSync('setRuntimeParameters:')];
        _startASR_decorators = [NativeMethodSync('startASR:handler:')];
        _stopASR_decorators = [NativeMethodSync('stopASR')];
        _startFileRecording_decorators = [NativeMethodSync('startFileRecording:withRecordingConfig:type:')];
        _stopFileRecording_decorators = [NativeMethodSync('stopFileRecording:')];
        _startAudioRecording_decorators = [NativeMethodSync('startAudioRecording:')];
        _stopAudioRecording_decorators = [NativeMethodSync('stopAudioRecording')];
        _getAudioEffectPlayer_decorators = [ReturnClass(function () { return ByteRTCAudioEffectPlayer; }), NativeMethodSync('getAudioEffectPlayer')];
        _getMediaPlayer_decorators = [ReturnClass(function () { return ByteRTCMediaPlayer; }), NativeMethodSync('getMediaPlayer:')];
        _login_decorators = [NativeMethodSync('login:uid:')];
        _logout_decorators = [NativeMethodSync('logout')];
        _updateLoginToken_decorators = [NativeMethodSync('updateLoginToken:')];
        _setServerParams_decorators = [NativeMethodSync('setServerParams:url:')];
        _getPeerOnlineStatus_decorators = [NativeMethodSync('getPeerOnlineStatus:')];
        _sendUserMessageOutsideRoom_decorators = [NativeMethodSync('sendUserMessageOutsideRoom:message:config:')];
        _sendUserBinaryMessageOutsideRoom_decorators = [NativeMethodSync('sendUserBinaryMessageOutsideRoom:message:config:')];
        _sendServerMessage_decorators = [NativeMethodSync('sendServerMessage:')];
        _sendServerBinaryMessage_decorators = [NativeMethodSync('sendServerBinaryMessage:')];
        _startNetworkDetection_decorators = [NativeMethodSync('startNetworkDetection:uplinkBandwidth:downlink:downlinkBandwidth:')];
        _stopNetworkDetection_decorators = [NativeMethodSync('stopNetworkDetection')];
        _setScreenAudioSourceType_decorators = [NativeMethodSync('setScreenAudioSourceType:')];
        _setScreenAudioStreamIndex_decorators = [NativeMethodSync('setScreenAudioStreamIndex:')];
        _pushScreenAudioFrame_decorators = [NativeMethodSync('pushScreenAudioFrame:')];
        _setVideoSourceType_decorators = [NativeMethodSync('setVideoSourceType:WithStreamIndex:')];
        _setExternalVideoEncoderEventHandler_decorators = [NativeMethodSync('setExternalVideoEncoderEventHandler:')];
        _pushExternalEncodedVideoFrame_decorators = [NativeMethodSync('pushExternalEncodedVideoFrame:withVideoIndex:withEncodedVideoFrame:')];
        _setVideoDecoderConfig_decorators = [NativeMethodSync('setVideoDecoderConfig:withVideoDecoderConfig:')];
        _requestRemoteVideoKeyFrame_decorators = [NativeMethodSync('requestRemoteVideoKeyFrame:')];
        _registerRemoteEncodedVideoFrameObserver_decorators = [NativeMethodSync('registerRemoteEncodedVideoFrameObserver:')];
        _sendStreamSyncInfo_decorators = [NativeMethodSync('sendStreamSyncInfo:config:')];
        _startEchoTest_decorators = [NativeMethodSync('startEchoTest:playDelay:')];
        _stopEchoTest_decorators = [NativeMethodSync('stopEchoTest')];
        _setVideoWatermark_decorators = [NativeMethodSync('setVideoWatermark:withImagePath:withRtcWatermarkConfig:')];
        _clearVideoWatermark_decorators = [NativeMethodSync('clearVideoWatermark:')];
        _takeLocalSnapshot_decorators = [NativeMethodSync('takeLocalSnapshot:callback:')];
        _takeRemoteSnapshot_decorators = [NativeMethodSync('takeRemoteSnapshot:callback:')];
        _startCloudProxy_decorators = [NativeMethodSync('startCloudProxy:')];
        _stopCloudProxy_decorators = [NativeMethodSync('stopCloudProxy')];
        _getSingScoringManager_decorators = [ReturnClass(function () { return ByteRTCSingScoringManager; }), NativeMethodSync('getSingScoringManager')];
        _setDummyCaptureImagePath_decorators = [NativeMethodSync('setDummyCaptureImagePath:')];
        _getNetworkTimeInfo_decorators = [ReturnClass(function () { return ByteRTCNetworkTimeInfo; }), NativeMethodSync('getNetworkTimeInfo')];
        _getKTVManager_decorators = [ReturnClass(function () { return ByteRTCKTVManager; }), NativeMethodSync('getKTVManager')];
        _startHardwareEchoDetection_decorators = [NativeMethodSync('startHardwareEchoDetection:')];
        _stopHardwareEchoDetection_decorators = [NativeMethodSync('stopHardwareEchoDetection')];
        _setCellularEnhancement_decorators = [NativeMethodSync('setCellularEnhancement:')];
        _setLocalProxy_decorators = [NativeMethodSync('setLocalProxy:')];
        _setLocalVideoSink_decorators = [NativeMethodSync('setLocalVideoSink:withSink:withPixelFormat:')];
        _setRemoteVideoSink_decorators = [NativeMethodSync('setRemoteVideoSink:withSink:withPixelFormat:')];
        _setVideoEncoderConfig$config$_decorators = [NativeMethodSync('setVideoEncoderConfig:config:')];
        _updateRemoteStreamVideoCanvas$withRenderMode$withBackgroundColor$_decorators = [NativeMethodSync('updateRemoteStreamVideoCanvas:withRenderMode:withBackgroundColor:')];
        _checkVideoEffectLicense_decorators = [NativeMethodSync('checkVideoEffectLicense:')];
        _setVideoEffectAlgoModelPath_decorators = [NativeMethodSync('setVideoEffectAlgoModelPath:')];
        _enableVideoEffect_decorators = [NativeMethodSync('enableVideoEffect:')];
        _setVideoEffectNodes_decorators = [NativeMethodSync('setVideoEffectNodes:')];
        _updateVideoEffectNode_decorators = [NativeMethodSync('updateVideoEffectNode:nodeKey:nodeValue:')];
        _setVideoEffectColorFilter_decorators = [NativeMethodSync('setVideoEffectColorFilter:')];
        _setVideoEffectColorFilterIntensity_decorators = [NativeMethodSync('setVideoEffectColorFilterIntensity:')];
        _setBackgroundSticker_decorators = [NativeMethodSync('setBackgroundSticker:source:')];
        _registerFaceDetectionObserver_decorators = [NativeMethodSync('registerFaceDetectionObserver:withInterval:')];
        _sendSEIMessage$andMessage$andRepeatCount$_decorators = [NativeMethodSync('sendSEIMessage:andMessage:andRepeatCount:')];
        _setAudioPlaybackDevice_decorators = [NativeMethodSync('setAudioPlaybackDevice:')];
        _startLiveTranscoding_decorators = [NativeMethodSync('startLiveTranscoding:transcoding:observer:')];
        _stopLiveTranscoding_decorators = [NativeMethodSync('stopLiveTranscoding:')];
        _updateLiveTranscoding_decorators = [NativeMethodSync('updateLiveTranscoding:transcoding:')];
        _getAudioMixingManager_decorators = [ReturnClass(function () { return ByteRTCAudioMixingManager; }), NativeMethodSync('getAudioMixingManager')];
        _muteAudioPlayback_decorators = [NativeMethodSync('muteAudioPlayback:')];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _static_createRTCVideo_decorators, { kind: "method", name: "createRTCVideo", static: true, private: false, access: { has: function (obj) { return "createRTCVideo" in obj; }, get: function (obj) { return obj.createRTCVideo; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _static_destroyRTCVideo_decorators, { kind: "method", name: "destroyRTCVideo", static: true, private: false, access: { has: function (obj) { return "destroyRTCVideo" in obj; }, get: function (obj) { return obj.destroyRTCVideo; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _static_getSDKVersion_decorators, { kind: "method", name: "getSDKVersion", static: true, private: false, access: { has: function (obj) { return "getSDKVersion" in obj; }, get: function (obj) { return obj.getSDKVersion; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _static_setLogConfig_decorators, { kind: "method", name: "setLogConfig", static: true, private: false, access: { has: function (obj) { return "setLogConfig" in obj; }, get: function (obj) { return obj.setLogConfig; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _static_getErrorDescription_decorators, { kind: "method", name: "getErrorDescription", static: true, private: false, access: { has: function (obj) { return "getErrorDescription" in obj; }, get: function (obj) { return obj.getErrorDescription; } }, metadata: _metadata }, null, _staticExtraInitializers);
        __esDecorate(_classThis, null, _setAudioSourceType_decorators, { kind: "method", name: "setAudioSourceType", static: false, private: false, access: { has: function (obj) { return "setAudioSourceType" in obj; }, get: function (obj) { return obj.setAudioSourceType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioRenderType_decorators, { kind: "method", name: "setAudioRenderType", static: false, private: false, access: { has: function (obj) { return "setAudioRenderType" in obj; }, get: function (obj) { return obj.setAudioRenderType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startAudioCapture_decorators, { kind: "method", name: "startAudioCapture", static: false, private: false, access: { has: function (obj) { return "startAudioCapture" in obj; }, get: function (obj) { return obj.startAudioCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopAudioCapture_decorators, { kind: "method", name: "stopAudioCapture", static: false, private: false, access: { has: function (obj) { return "stopAudioCapture" in obj; }, get: function (obj) { return obj.stopAudioCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioScenario_decorators, { kind: "method", name: "setAudioScenario", static: false, private: false, access: { has: function (obj) { return "setAudioScenario" in obj; }, get: function (obj) { return obj.setAudioScenario; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioProfile_decorators, { kind: "method", name: "setAudioProfile", static: false, private: false, access: { has: function (obj) { return "setAudioProfile" in obj; }, get: function (obj) { return obj.setAudioProfile; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAnsMode_decorators, { kind: "method", name: "setAnsMode", static: false, private: false, access: { has: function (obj) { return "setAnsMode" in obj; }, get: function (obj) { return obj.setAnsMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVoiceChangerType_decorators, { kind: "method", name: "setVoiceChangerType", static: false, private: false, access: { has: function (obj) { return "setVoiceChangerType" in obj; }, get: function (obj) { return obj.setVoiceChangerType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVoiceReverbType_decorators, { kind: "method", name: "setVoiceReverbType", static: false, private: false, access: { has: function (obj) { return "setVoiceReverbType" in obj; }, get: function (obj) { return obj.setVoiceReverbType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVoiceEqualization_decorators, { kind: "method", name: "setLocalVoiceEqualization", static: false, private: false, access: { has: function (obj) { return "setLocalVoiceEqualization" in obj; }, get: function (obj) { return obj.setLocalVoiceEqualization; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVoiceReverbParam_decorators, { kind: "method", name: "setLocalVoiceReverbParam", static: false, private: false, access: { has: function (obj) { return "setLocalVoiceReverbParam" in obj; }, get: function (obj) { return obj.setLocalVoiceReverbParam; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableLocalVoiceReverb_decorators, { kind: "method", name: "enableLocalVoiceReverb", static: false, private: false, access: { has: function (obj) { return "enableLocalVoiceReverb" in obj; }, get: function (obj) { return obj.enableLocalVoiceReverb; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _muteAudioCapture_decorators, { kind: "method", name: "muteAudioCapture", static: false, private: false, access: { has: function (obj) { return "muteAudioCapture" in obj; }, get: function (obj) { return obj.muteAudioCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCaptureVolume_decorators, { kind: "method", name: "setCaptureVolume", static: false, private: false, access: { has: function (obj) { return "setCaptureVolume" in obj; }, get: function (obj) { return obj.setCaptureVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPlaybackVolume_decorators, { kind: "method", name: "setPlaybackVolume", static: false, private: false, access: { has: function (obj) { return "setPlaybackVolume" in obj; }, get: function (obj) { return obj.setPlaybackVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableAudioPropertiesReport_decorators, { kind: "method", name: "enableAudioPropertiesReport", static: false, private: false, access: { has: function (obj) { return "enableAudioPropertiesReport" in obj; }, get: function (obj) { return obj.enableAudioPropertiesReport; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteAudioPlaybackVolume_decorators, { kind: "method", name: "setRemoteAudioPlaybackVolume", static: false, private: false, access: { has: function (obj) { return "setRemoteAudioPlaybackVolume" in obj; }, get: function (obj) { return obj.setRemoteAudioPlaybackVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEarMonitorMode_decorators, { kind: "method", name: "setEarMonitorMode", static: false, private: false, access: { has: function (obj) { return "setEarMonitorMode" in obj; }, get: function (obj) { return obj.setEarMonitorMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEarMonitorVolume_decorators, { kind: "method", name: "setEarMonitorVolume", static: false, private: false, access: { has: function (obj) { return "setEarMonitorVolume" in obj; }, get: function (obj) { return obj.setEarMonitorVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBluetoothMode_decorators, { kind: "method", name: "setBluetoothMode", static: false, private: false, access: { has: function (obj) { return "setBluetoothMode" in obj; }, get: function (obj) { return obj.setBluetoothMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVoicePitch_decorators, { kind: "method", name: "setLocalVoicePitch", static: false, private: false, access: { has: function (obj) { return "setLocalVoicePitch" in obj; }, get: function (obj) { return obj.setLocalVoicePitch; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableVocalInstrumentBalance_decorators, { kind: "method", name: "enableVocalInstrumentBalance", static: false, private: false, access: { has: function (obj) { return "enableVocalInstrumentBalance" in obj; }, get: function (obj) { return obj.enableVocalInstrumentBalance; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enablePlaybackDucking_decorators, { kind: "method", name: "enablePlaybackDucking", static: false, private: false, access: { has: function (obj) { return "enablePlaybackDucking" in obj; }, get: function (obj) { return obj.enablePlaybackDucking; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVideoRender_decorators, { kind: "method", name: "setLocalVideoRender", static: false, private: false, access: { has: function (obj) { return "setLocalVideoRender" in obj; }, get: function (obj) { return obj.setLocalVideoRender; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteVideoRender_decorators, { kind: "method", name: "setRemoteVideoRender", static: false, private: false, access: { has: function (obj) { return "setRemoteVideoRender" in obj; }, get: function (obj) { return obj.setRemoteVideoRender; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteVideoSuperResolution_decorators, { kind: "method", name: "setRemoteVideoSuperResolution", static: false, private: false, access: { has: function (obj) { return "setRemoteVideoSuperResolution" in obj; }, get: function (obj) { return obj.setRemoteVideoSuperResolution; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoCaptureRotation_decorators, { kind: "method", name: "setVideoCaptureRotation", static: false, private: false, access: { has: function (obj) { return "setVideoCaptureRotation" in obj; }, get: function (obj) { return obj.setVideoCaptureRotation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableSimulcastMode_decorators, { kind: "method", name: "enableSimulcastMode", static: false, private: false, access: { has: function (obj) { return "enableSimulcastMode" in obj; }, get: function (obj) { return obj.enableSimulcastMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setMaxVideoEncoderConfig_decorators, { kind: "method", name: "setMaxVideoEncoderConfig", static: false, private: false, access: { has: function (obj) { return "setMaxVideoEncoderConfig" in obj; }, get: function (obj) { return obj.setMaxVideoEncoderConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoEncoderConfig_decorators, { kind: "method", name: "setVideoEncoderConfig", static: false, private: false, access: { has: function (obj) { return "setVideoEncoderConfig" in obj; }, get: function (obj) { return obj.setVideoEncoderConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setScreenVideoEncoderConfig_decorators, { kind: "method", name: "setScreenVideoEncoderConfig", static: false, private: false, access: { has: function (obj) { return "setScreenVideoEncoderConfig" in obj; }, get: function (obj) { return obj.setScreenVideoEncoderConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableAlphaChannelVideoEncode_decorators, { kind: "method", name: "enableAlphaChannelVideoEncode", static: false, private: false, access: { has: function (obj) { return "enableAlphaChannelVideoEncode" in obj; }, get: function (obj) { return obj.enableAlphaChannelVideoEncode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableAlphaChannelVideoEncode_decorators, { kind: "method", name: "disableAlphaChannelVideoEncode", static: false, private: false, access: { has: function (obj) { return "disableAlphaChannelVideoEncode" in obj; }, get: function (obj) { return obj.disableAlphaChannelVideoEncode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoCaptureConfig_decorators, { kind: "method", name: "setVideoCaptureConfig", static: false, private: false, access: { has: function (obj) { return "setVideoCaptureConfig" in obj; }, get: function (obj) { return obj.setVideoCaptureConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVideoCanvas_decorators, { kind: "method", name: "setLocalVideoCanvas", static: false, private: false, access: { has: function (obj) { return "setLocalVideoCanvas" in obj; }, get: function (obj) { return obj.setLocalVideoCanvas; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateLocalVideoCanvas_decorators, { kind: "method", name: "updateLocalVideoCanvas", static: false, private: false, access: { has: function (obj) { return "updateLocalVideoCanvas" in obj; }, get: function (obj) { return obj.updateLocalVideoCanvas; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteVideoCanvas_decorators, { kind: "method", name: "setRemoteVideoCanvas", static: false, private: false, access: { has: function (obj) { return "setRemoteVideoCanvas" in obj; }, get: function (obj) { return obj.setRemoteVideoCanvas; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateRemoteStreamVideoCanvas_decorators, { kind: "method", name: "updateRemoteStreamVideoCanvas", static: false, private: false, access: { has: function (obj) { return "updateRemoteStreamVideoCanvas" in obj; }, get: function (obj) { return obj.updateRemoteStreamVideoCanvas; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startVideoCapture_decorators, { kind: "method", name: "startVideoCapture", static: false, private: false, access: { has: function (obj) { return "startVideoCapture" in obj; }, get: function (obj) { return obj.startVideoCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopVideoCapture_decorators, { kind: "method", name: "stopVideoCapture", static: false, private: false, access: { has: function (obj) { return "stopVideoCapture" in obj; }, get: function (obj) { return obj.stopVideoCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVideoMirrorType_decorators, { kind: "method", name: "setLocalVideoMirrorType", static: false, private: false, access: { has: function (obj) { return "setLocalVideoMirrorType" in obj; }, get: function (obj) { return obj.setLocalVideoMirrorType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteVideoMirrorType_decorators, { kind: "method", name: "setRemoteVideoMirrorType", static: false, private: false, access: { has: function (obj) { return "setRemoteVideoMirrorType" in obj; }, get: function (obj) { return obj.setRemoteVideoMirrorType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoRotationMode_decorators, { kind: "method", name: "setVideoRotationMode", static: false, private: false, access: { has: function (obj) { return "setVideoRotationMode" in obj; }, get: function (obj) { return obj.setVideoRotationMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoOrientation_decorators, { kind: "method", name: "setVideoOrientation", static: false, private: false, access: { has: function (obj) { return "setVideoOrientation" in obj; }, get: function (obj) { return obj.setVideoOrientation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _switchCamera_decorators, { kind: "method", name: "switchCamera", static: false, private: false, access: { has: function (obj) { return "switchCamera" in obj; }, get: function (obj) { return obj.switchCamera; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getVideoEffectInterface_decorators, { kind: "method", name: "getVideoEffectInterface", static: false, private: false, access: { has: function (obj) { return "getVideoEffectInterface" in obj; }, get: function (obj) { return obj.getVideoEffectInterface; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableEffectBeauty_decorators, { kind: "method", name: "enableEffectBeauty", static: false, private: false, access: { has: function (obj) { return "enableEffectBeauty" in obj; }, get: function (obj) { return obj.enableEffectBeauty; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBeautyIntensity_decorators, { kind: "method", name: "setBeautyIntensity", static: false, private: false, access: { has: function (obj) { return "setBeautyIntensity" in obj; }, get: function (obj) { return obj.setBeautyIntensity; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCameraZoomRatio_decorators, { kind: "method", name: "setCameraZoomRatio", static: false, private: false, access: { has: function (obj) { return "setCameraZoomRatio" in obj; }, get: function (obj) { return obj.setCameraZoomRatio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getCameraZoomMaxRatio_decorators, { kind: "method", name: "getCameraZoomMaxRatio", static: false, private: false, access: { has: function (obj) { return "getCameraZoomMaxRatio" in obj; }, get: function (obj) { return obj.getCameraZoomMaxRatio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _isCameraZoomSupported_decorators, { kind: "method", name: "isCameraZoomSupported", static: false, private: false, access: { has: function (obj) { return "isCameraZoomSupported" in obj; }, get: function (obj) { return obj.isCameraZoomSupported; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _isCameraTorchSupported_decorators, { kind: "method", name: "isCameraTorchSupported", static: false, private: false, access: { has: function (obj) { return "isCameraTorchSupported" in obj; }, get: function (obj) { return obj.isCameraTorchSupported; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCameraTorch_decorators, { kind: "method", name: "setCameraTorch", static: false, private: false, access: { has: function (obj) { return "setCameraTorch" in obj; }, get: function (obj) { return obj.setCameraTorch; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _isCameraFocusPositionSupported_decorators, { kind: "method", name: "isCameraFocusPositionSupported", static: false, private: false, access: { has: function (obj) { return "isCameraFocusPositionSupported" in obj; }, get: function (obj) { return obj.isCameraFocusPositionSupported; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCameraFocusPosition_decorators, { kind: "method", name: "setCameraFocusPosition", static: false, private: false, access: { has: function (obj) { return "setCameraFocusPosition" in obj; }, get: function (obj) { return obj.setCameraFocusPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _isCameraExposurePositionSupported_decorators, { kind: "method", name: "isCameraExposurePositionSupported", static: false, private: false, access: { has: function (obj) { return "isCameraExposurePositionSupported" in obj; }, get: function (obj) { return obj.isCameraExposurePositionSupported; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCameraExposurePosition_decorators, { kind: "method", name: "setCameraExposurePosition", static: false, private: false, access: { has: function (obj) { return "setCameraExposurePosition" in obj; }, get: function (obj) { return obj.setCameraExposurePosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCameraExposureCompensation_decorators, { kind: "method", name: "setCameraExposureCompensation", static: false, private: false, access: { has: function (obj) { return "setCameraExposureCompensation" in obj; }, get: function (obj) { return obj.setCameraExposureCompensation; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableCameraAutoExposureFaceMode_decorators, { kind: "method", name: "enableCameraAutoExposureFaceMode", static: false, private: false, access: { has: function (obj) { return "enableCameraAutoExposureFaceMode" in obj; }, get: function (obj) { return obj.enableCameraAutoExposureFaceMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCameraAdaptiveMinimumFrameRate_decorators, { kind: "method", name: "setCameraAdaptiveMinimumFrameRate", static: false, private: false, access: { has: function (obj) { return "setCameraAdaptiveMinimumFrameRate" in obj; }, get: function (obj) { return obj.setCameraAdaptiveMinimumFrameRate; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendSEIMessage_decorators, { kind: "method", name: "sendSEIMessage", static: false, private: false, access: { has: function (obj) { return "sendSEIMessage" in obj; }, get: function (obj) { return obj.sendSEIMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoDigitalZoomConfig_decorators, { kind: "method", name: "setVideoDigitalZoomConfig", static: false, private: false, access: { has: function (obj) { return "setVideoDigitalZoomConfig" in obj; }, get: function (obj) { return obj.setVideoDigitalZoomConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoDigitalZoomControl_decorators, { kind: "method", name: "setVideoDigitalZoomControl", static: false, private: false, access: { has: function (obj) { return "setVideoDigitalZoomControl" in obj; }, get: function (obj) { return obj.setVideoDigitalZoomControl; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startVideoDigitalZoomControl_decorators, { kind: "method", name: "startVideoDigitalZoomControl", static: false, private: false, access: { has: function (obj) { return "startVideoDigitalZoomControl" in obj; }, get: function (obj) { return obj.startVideoDigitalZoomControl; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopVideoDigitalZoomControl_decorators, { kind: "method", name: "stopVideoDigitalZoomControl", static: false, private: false, access: { has: function (obj) { return "stopVideoDigitalZoomControl" in obj; }, get: function (obj) { return obj.stopVideoDigitalZoomControl; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerLocalVideoProcessor_decorators, { kind: "method", name: "registerLocalVideoProcessor", static: false, private: false, access: { has: function (obj) { return "registerLocalVideoProcessor" in obj; }, get: function (obj) { return obj.registerLocalVideoProcessor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerLocalEncodedVideoFrameObserver_decorators, { kind: "method", name: "registerLocalEncodedVideoFrameObserver", static: false, private: false, access: { has: function (obj) { return "registerLocalEncodedVideoFrameObserver" in obj; }, get: function (obj) { return obj.registerLocalEncodedVideoFrameObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioRoute_decorators, { kind: "method", name: "setAudioRoute", static: false, private: false, access: { has: function (obj) { return "setAudioRoute" in obj; }, get: function (obj) { return obj.setAudioRoute; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioRoute_decorators, { kind: "method", name: "getAudioRoute", static: false, private: false, access: { has: function (obj) { return "getAudioRoute" in obj; }, get: function (obj) { return obj.getAudioRoute; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableExternalSoundCard_decorators, { kind: "method", name: "enableExternalSoundCard", static: false, private: false, access: { has: function (obj) { return "enableExternalSoundCard" in obj; }, get: function (obj) { return obj.enableExternalSoundCard; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setDefaultAudioRoute_decorators, { kind: "method", name: "setDefaultAudioRoute", static: false, private: false, access: { has: function (obj) { return "setDefaultAudioRoute" in obj; }, get: function (obj) { return obj.setDefaultAudioRoute; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startPushMixedStreamToCDN_decorators, { kind: "method", name: "startPushMixedStreamToCDN", static: false, private: false, access: { has: function (obj) { return "startPushMixedStreamToCDN" in obj; }, get: function (obj) { return obj.startPushMixedStreamToCDN; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updatePushMixedStreamToCDN_decorators, { kind: "method", name: "updatePushMixedStreamToCDN", static: false, private: false, access: { has: function (obj) { return "updatePushMixedStreamToCDN" in obj; }, get: function (obj) { return obj.updatePushMixedStreamToCDN; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startPushSingleStreamToCDN_decorators, { kind: "method", name: "startPushSingleStreamToCDN", static: false, private: false, access: { has: function (obj) { return "startPushSingleStreamToCDN" in obj; }, get: function (obj) { return obj.startPushSingleStreamToCDN; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopPushStreamToCDN_decorators, { kind: "method", name: "stopPushStreamToCDN", static: false, private: false, access: { has: function (obj) { return "stopPushStreamToCDN" in obj; }, get: function (obj) { return obj.stopPushStreamToCDN; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startPushPublicStream_decorators, { kind: "method", name: "startPushPublicStream", static: false, private: false, access: { has: function (obj) { return "startPushPublicStream" in obj; }, get: function (obj) { return obj.startPushPublicStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopPushPublicStream_decorators, { kind: "method", name: "stopPushPublicStream", static: false, private: false, access: { has: function (obj) { return "stopPushPublicStream" in obj; }, get: function (obj) { return obj.stopPushPublicStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updatePublicStreamParam_decorators, { kind: "method", name: "updatePublicStreamParam", static: false, private: false, access: { has: function (obj) { return "updatePublicStreamParam" in obj; }, get: function (obj) { return obj.updatePublicStreamParam; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startPlayPublicStream_decorators, { kind: "method", name: "startPlayPublicStream", static: false, private: false, access: { has: function (obj) { return "startPlayPublicStream" in obj; }, get: function (obj) { return obj.startPlayPublicStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopPlayPublicStream_decorators, { kind: "method", name: "stopPlayPublicStream", static: false, private: false, access: { has: function (obj) { return "stopPlayPublicStream" in obj; }, get: function (obj) { return obj.stopPlayPublicStream; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPublicStreamVideoCanvas_decorators, { kind: "method", name: "setPublicStreamVideoCanvas", static: false, private: false, access: { has: function (obj) { return "setPublicStreamVideoCanvas" in obj; }, get: function (obj) { return obj.setPublicStreamVideoCanvas; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPublicStreamVideoSink_decorators, { kind: "method", name: "setPublicStreamVideoSink", static: false, private: false, access: { has: function (obj) { return "setPublicStreamVideoSink" in obj; }, get: function (obj) { return obj.setPublicStreamVideoSink; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPublicStreamAudioPlaybackVolume_decorators, { kind: "method", name: "setPublicStreamAudioPlaybackVolume", static: false, private: false, access: { has: function (obj) { return "setPublicStreamAudioPlaybackVolume" in obj; }, get: function (obj) { return obj.setPublicStreamAudioPlaybackVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushExternalVideoFrame_decorators, { kind: "method", name: "pushExternalVideoFrame", static: false, private: false, access: { has: function (obj) { return "pushExternalVideoFrame" in obj; }, get: function (obj) { return obj.pushExternalVideoFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableAudioFrameCallback_decorators, { kind: "method", name: "enableAudioFrameCallback", static: false, private: false, access: { has: function (obj) { return "enableAudioFrameCallback" in obj; }, get: function (obj) { return obj.enableAudioFrameCallback; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableAudioFrameCallback_decorators, { kind: "method", name: "disableAudioFrameCallback", static: false, private: false, access: { has: function (obj) { return "disableAudioFrameCallback" in obj; }, get: function (obj) { return obj.disableAudioFrameCallback; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerAudioFrameObserver_decorators, { kind: "method", name: "registerAudioFrameObserver", static: false, private: false, access: { has: function (obj) { return "registerAudioFrameObserver" in obj; }, get: function (obj) { return obj.registerAudioFrameObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerAudioProcessor_decorators, { kind: "method", name: "registerAudioProcessor", static: false, private: false, access: { has: function (obj) { return "registerAudioProcessor" in obj; }, get: function (obj) { return obj.registerAudioProcessor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableAudioProcessor_decorators, { kind: "method", name: "enableAudioProcessor", static: false, private: false, access: { has: function (obj) { return "enableAudioProcessor" in obj; }, get: function (obj) { return obj.enableAudioProcessor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableAudioProcessor_decorators, { kind: "method", name: "disableAudioProcessor", static: false, private: false, access: { has: function (obj) { return "disableAudioProcessor" in obj; }, get: function (obj) { return obj.disableAudioProcessor; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushExternalAudioFrame_decorators, { kind: "method", name: "pushExternalAudioFrame", static: false, private: false, access: { has: function (obj) { return "pushExternalAudioFrame" in obj; }, get: function (obj) { return obj.pushExternalAudioFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pullExternalAudioFrame_decorators, { kind: "method", name: "pullExternalAudioFrame", static: false, private: false, access: { has: function (obj) { return "pullExternalAudioFrame" in obj; }, get: function (obj) { return obj.pullExternalAudioFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBusinessId_decorators, { kind: "method", name: "setBusinessId", static: false, private: false, access: { has: function (obj) { return "setBusinessId" in obj; }, get: function (obj) { return obj.setBusinessId; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _feedback_decorators, { kind: "method", name: "feedback", static: false, private: false, access: { has: function (obj) { return "feedback" in obj; }, get: function (obj) { return obj.feedback; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getNativeHandle_decorators, { kind: "method", name: "getNativeHandle", static: false, private: false, access: { has: function (obj) { return "getNativeHandle" in obj; }, get: function (obj) { return obj.getNativeHandle; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setPublishFallbackOption_decorators, { kind: "method", name: "setPublishFallbackOption", static: false, private: false, access: { has: function (obj) { return "setPublishFallbackOption" in obj; }, get: function (obj) { return obj.setPublishFallbackOption; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setSubscribeFallbackOption_decorators, { kind: "method", name: "setSubscribeFallbackOption", static: false, private: false, access: { has: function (obj) { return "setSubscribeFallbackOption" in obj; }, get: function (obj) { return obj.setSubscribeFallbackOption; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteUserPriority_decorators, { kind: "method", name: "setRemoteUserPriority", static: false, private: false, access: { has: function (obj) { return "setRemoteUserPriority" in obj; }, get: function (obj) { return obj.setRemoteUserPriority; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setEncryptInfo_decorators, { kind: "method", name: "setEncryptInfo", static: false, private: false, access: { has: function (obj) { return "setEncryptInfo" in obj; }, get: function (obj) { return obj.setEncryptInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCustomizeEncryptHandler_decorators, { kind: "method", name: "setCustomizeEncryptHandler", static: false, private: false, access: { has: function (obj) { return "setCustomizeEncryptHandler" in obj; }, get: function (obj) { return obj.setCustomizeEncryptHandler; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _createRTCRoom_decorators, { kind: "method", name: "createRTCRoom", static: false, private: false, access: { has: function (obj) { return "createRTCRoom" in obj; }, get: function (obj) { return obj.createRTCRoom; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushScreenVideoFrame_decorators, { kind: "method", name: "pushScreenVideoFrame", static: false, private: false, access: { has: function (obj) { return "pushScreenVideoFrame" in obj; }, get: function (obj) { return obj.pushScreenVideoFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setExtensionConfig_decorators, { kind: "method", name: "setExtensionConfig", static: false, private: false, access: { has: function (obj) { return "setExtensionConfig" in obj; }, get: function (obj) { return obj.setExtensionConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startScreenCapture_decorators, { kind: "method", name: "startScreenCapture", static: false, private: false, access: { has: function (obj) { return "startScreenCapture" in obj; }, get: function (obj) { return obj.startScreenCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateScreenCapture_decorators, { kind: "method", name: "updateScreenCapture", static: false, private: false, access: { has: function (obj) { return "updateScreenCapture" in obj; }, get: function (obj) { return obj.updateScreenCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopScreenCapture_decorators, { kind: "method", name: "stopScreenCapture", static: false, private: false, access: { has: function (obj) { return "stopScreenCapture" in obj; }, get: function (obj) { return obj.stopScreenCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendScreenCaptureExtensionMessage_decorators, { kind: "method", name: "sendScreenCaptureExtensionMessage", static: false, private: false, access: { has: function (obj) { return "sendScreenCaptureExtensionMessage" in obj; }, get: function (obj) { return obj.sendScreenCaptureExtensionMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRuntimeParameters_decorators, { kind: "method", name: "setRuntimeParameters", static: false, private: false, access: { has: function (obj) { return "setRuntimeParameters" in obj; }, get: function (obj) { return obj.setRuntimeParameters; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startASR_decorators, { kind: "method", name: "startASR", static: false, private: false, access: { has: function (obj) { return "startASR" in obj; }, get: function (obj) { return obj.startASR; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopASR_decorators, { kind: "method", name: "stopASR", static: false, private: false, access: { has: function (obj) { return "stopASR" in obj; }, get: function (obj) { return obj.stopASR; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startFileRecording_decorators, { kind: "method", name: "startFileRecording", static: false, private: false, access: { has: function (obj) { return "startFileRecording" in obj; }, get: function (obj) { return obj.startFileRecording; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopFileRecording_decorators, { kind: "method", name: "stopFileRecording", static: false, private: false, access: { has: function (obj) { return "stopFileRecording" in obj; }, get: function (obj) { return obj.stopFileRecording; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startAudioRecording_decorators, { kind: "method", name: "startAudioRecording", static: false, private: false, access: { has: function (obj) { return "startAudioRecording" in obj; }, get: function (obj) { return obj.startAudioRecording; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopAudioRecording_decorators, { kind: "method", name: "stopAudioRecording", static: false, private: false, access: { has: function (obj) { return "stopAudioRecording" in obj; }, get: function (obj) { return obj.stopAudioRecording; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioEffectPlayer_decorators, { kind: "method", name: "getAudioEffectPlayer", static: false, private: false, access: { has: function (obj) { return "getAudioEffectPlayer" in obj; }, get: function (obj) { return obj.getAudioEffectPlayer; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getMediaPlayer_decorators, { kind: "method", name: "getMediaPlayer", static: false, private: false, access: { has: function (obj) { return "getMediaPlayer" in obj; }, get: function (obj) { return obj.getMediaPlayer; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _login_decorators, { kind: "method", name: "login", static: false, private: false, access: { has: function (obj) { return "login" in obj; }, get: function (obj) { return obj.login; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _logout_decorators, { kind: "method", name: "logout", static: false, private: false, access: { has: function (obj) { return "logout" in obj; }, get: function (obj) { return obj.logout; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateLoginToken_decorators, { kind: "method", name: "updateLoginToken", static: false, private: false, access: { has: function (obj) { return "updateLoginToken" in obj; }, get: function (obj) { return obj.updateLoginToken; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setServerParams_decorators, { kind: "method", name: "setServerParams", static: false, private: false, access: { has: function (obj) { return "setServerParams" in obj; }, get: function (obj) { return obj.setServerParams; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getPeerOnlineStatus_decorators, { kind: "method", name: "getPeerOnlineStatus", static: false, private: false, access: { has: function (obj) { return "getPeerOnlineStatus" in obj; }, get: function (obj) { return obj.getPeerOnlineStatus; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendUserMessageOutsideRoom_decorators, { kind: "method", name: "sendUserMessageOutsideRoom", static: false, private: false, access: { has: function (obj) { return "sendUserMessageOutsideRoom" in obj; }, get: function (obj) { return obj.sendUserMessageOutsideRoom; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendUserBinaryMessageOutsideRoom_decorators, { kind: "method", name: "sendUserBinaryMessageOutsideRoom", static: false, private: false, access: { has: function (obj) { return "sendUserBinaryMessageOutsideRoom" in obj; }, get: function (obj) { return obj.sendUserBinaryMessageOutsideRoom; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendServerMessage_decorators, { kind: "method", name: "sendServerMessage", static: false, private: false, access: { has: function (obj) { return "sendServerMessage" in obj; }, get: function (obj) { return obj.sendServerMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendServerBinaryMessage_decorators, { kind: "method", name: "sendServerBinaryMessage", static: false, private: false, access: { has: function (obj) { return "sendServerBinaryMessage" in obj; }, get: function (obj) { return obj.sendServerBinaryMessage; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startNetworkDetection_decorators, { kind: "method", name: "startNetworkDetection", static: false, private: false, access: { has: function (obj) { return "startNetworkDetection" in obj; }, get: function (obj) { return obj.startNetworkDetection; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopNetworkDetection_decorators, { kind: "method", name: "stopNetworkDetection", static: false, private: false, access: { has: function (obj) { return "stopNetworkDetection" in obj; }, get: function (obj) { return obj.stopNetworkDetection; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setScreenAudioSourceType_decorators, { kind: "method", name: "setScreenAudioSourceType", static: false, private: false, access: { has: function (obj) { return "setScreenAudioSourceType" in obj; }, get: function (obj) { return obj.setScreenAudioSourceType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setScreenAudioStreamIndex_decorators, { kind: "method", name: "setScreenAudioStreamIndex", static: false, private: false, access: { has: function (obj) { return "setScreenAudioStreamIndex" in obj; }, get: function (obj) { return obj.setScreenAudioStreamIndex; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushScreenAudioFrame_decorators, { kind: "method", name: "pushScreenAudioFrame", static: false, private: false, access: { has: function (obj) { return "pushScreenAudioFrame" in obj; }, get: function (obj) { return obj.pushScreenAudioFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoSourceType_decorators, { kind: "method", name: "setVideoSourceType", static: false, private: false, access: { has: function (obj) { return "setVideoSourceType" in obj; }, get: function (obj) { return obj.setVideoSourceType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setExternalVideoEncoderEventHandler_decorators, { kind: "method", name: "setExternalVideoEncoderEventHandler", static: false, private: false, access: { has: function (obj) { return "setExternalVideoEncoderEventHandler" in obj; }, get: function (obj) { return obj.setExternalVideoEncoderEventHandler; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushExternalEncodedVideoFrame_decorators, { kind: "method", name: "pushExternalEncodedVideoFrame", static: false, private: false, access: { has: function (obj) { return "pushExternalEncodedVideoFrame" in obj; }, get: function (obj) { return obj.pushExternalEncodedVideoFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoDecoderConfig_decorators, { kind: "method", name: "setVideoDecoderConfig", static: false, private: false, access: { has: function (obj) { return "setVideoDecoderConfig" in obj; }, get: function (obj) { return obj.setVideoDecoderConfig; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _requestRemoteVideoKeyFrame_decorators, { kind: "method", name: "requestRemoteVideoKeyFrame", static: false, private: false, access: { has: function (obj) { return "requestRemoteVideoKeyFrame" in obj; }, get: function (obj) { return obj.requestRemoteVideoKeyFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerRemoteEncodedVideoFrameObserver_decorators, { kind: "method", name: "registerRemoteEncodedVideoFrameObserver", static: false, private: false, access: { has: function (obj) { return "registerRemoteEncodedVideoFrameObserver" in obj; }, get: function (obj) { return obj.registerRemoteEncodedVideoFrameObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendStreamSyncInfo_decorators, { kind: "method", name: "sendStreamSyncInfo", static: false, private: false, access: { has: function (obj) { return "sendStreamSyncInfo" in obj; }, get: function (obj) { return obj.sendStreamSyncInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startEchoTest_decorators, { kind: "method", name: "startEchoTest", static: false, private: false, access: { has: function (obj) { return "startEchoTest" in obj; }, get: function (obj) { return obj.startEchoTest; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopEchoTest_decorators, { kind: "method", name: "stopEchoTest", static: false, private: false, access: { has: function (obj) { return "stopEchoTest" in obj; }, get: function (obj) { return obj.stopEchoTest; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoWatermark_decorators, { kind: "method", name: "setVideoWatermark", static: false, private: false, access: { has: function (obj) { return "setVideoWatermark" in obj; }, get: function (obj) { return obj.setVideoWatermark; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _clearVideoWatermark_decorators, { kind: "method", name: "clearVideoWatermark", static: false, private: false, access: { has: function (obj) { return "clearVideoWatermark" in obj; }, get: function (obj) { return obj.clearVideoWatermark; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _takeLocalSnapshot_decorators, { kind: "method", name: "takeLocalSnapshot", static: false, private: false, access: { has: function (obj) { return "takeLocalSnapshot" in obj; }, get: function (obj) { return obj.takeLocalSnapshot; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _takeRemoteSnapshot_decorators, { kind: "method", name: "takeRemoteSnapshot", static: false, private: false, access: { has: function (obj) { return "takeRemoteSnapshot" in obj; }, get: function (obj) { return obj.takeRemoteSnapshot; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startCloudProxy_decorators, { kind: "method", name: "startCloudProxy", static: false, private: false, access: { has: function (obj) { return "startCloudProxy" in obj; }, get: function (obj) { return obj.startCloudProxy; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopCloudProxy_decorators, { kind: "method", name: "stopCloudProxy", static: false, private: false, access: { has: function (obj) { return "stopCloudProxy" in obj; }, get: function (obj) { return obj.stopCloudProxy; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getSingScoringManager_decorators, { kind: "method", name: "getSingScoringManager", static: false, private: false, access: { has: function (obj) { return "getSingScoringManager" in obj; }, get: function (obj) { return obj.getSingScoringManager; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setDummyCaptureImagePath_decorators, { kind: "method", name: "setDummyCaptureImagePath", static: false, private: false, access: { has: function (obj) { return "setDummyCaptureImagePath" in obj; }, get: function (obj) { return obj.setDummyCaptureImagePath; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getNetworkTimeInfo_decorators, { kind: "method", name: "getNetworkTimeInfo", static: false, private: false, access: { has: function (obj) { return "getNetworkTimeInfo" in obj; }, get: function (obj) { return obj.getNetworkTimeInfo; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getKTVManager_decorators, { kind: "method", name: "getKTVManager", static: false, private: false, access: { has: function (obj) { return "getKTVManager" in obj; }, get: function (obj) { return obj.getKTVManager; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startHardwareEchoDetection_decorators, { kind: "method", name: "startHardwareEchoDetection", static: false, private: false, access: { has: function (obj) { return "startHardwareEchoDetection" in obj; }, get: function (obj) { return obj.startHardwareEchoDetection; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopHardwareEchoDetection_decorators, { kind: "method", name: "stopHardwareEchoDetection", static: false, private: false, access: { has: function (obj) { return "stopHardwareEchoDetection" in obj; }, get: function (obj) { return obj.stopHardwareEchoDetection; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setCellularEnhancement_decorators, { kind: "method", name: "setCellularEnhancement", static: false, private: false, access: { has: function (obj) { return "setCellularEnhancement" in obj; }, get: function (obj) { return obj.setCellularEnhancement; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalProxy_decorators, { kind: "method", name: "setLocalProxy", static: false, private: false, access: { has: function (obj) { return "setLocalProxy" in obj; }, get: function (obj) { return obj.setLocalProxy; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setLocalVideoSink_decorators, { kind: "method", name: "setLocalVideoSink", static: false, private: false, access: { has: function (obj) { return "setLocalVideoSink" in obj; }, get: function (obj) { return obj.setLocalVideoSink; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setRemoteVideoSink_decorators, { kind: "method", name: "setRemoteVideoSink", static: false, private: false, access: { has: function (obj) { return "setRemoteVideoSink" in obj; }, get: function (obj) { return obj.setRemoteVideoSink; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoEncoderConfig$config$_decorators, { kind: "method", name: "setVideoEncoderConfig$config$", static: false, private: false, access: { has: function (obj) { return "setVideoEncoderConfig$config$" in obj; }, get: function (obj) { return obj.setVideoEncoderConfig$config$; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateRemoteStreamVideoCanvas$withRenderMode$withBackgroundColor$_decorators, { kind: "method", name: "updateRemoteStreamVideoCanvas$withRenderMode$withBackgroundColor$", static: false, private: false, access: { has: function (obj) { return "updateRemoteStreamVideoCanvas$withRenderMode$withBackgroundColor$" in obj; }, get: function (obj) { return obj.updateRemoteStreamVideoCanvas$withRenderMode$withBackgroundColor$; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _checkVideoEffectLicense_decorators, { kind: "method", name: "checkVideoEffectLicense", static: false, private: false, access: { has: function (obj) { return "checkVideoEffectLicense" in obj; }, get: function (obj) { return obj.checkVideoEffectLicense; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoEffectAlgoModelPath_decorators, { kind: "method", name: "setVideoEffectAlgoModelPath", static: false, private: false, access: { has: function (obj) { return "setVideoEffectAlgoModelPath" in obj; }, get: function (obj) { return obj.setVideoEffectAlgoModelPath; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableVideoEffect_decorators, { kind: "method", name: "enableVideoEffect", static: false, private: false, access: { has: function (obj) { return "enableVideoEffect" in obj; }, get: function (obj) { return obj.enableVideoEffect; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoEffectNodes_decorators, { kind: "method", name: "setVideoEffectNodes", static: false, private: false, access: { has: function (obj) { return "setVideoEffectNodes" in obj; }, get: function (obj) { return obj.setVideoEffectNodes; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateVideoEffectNode_decorators, { kind: "method", name: "updateVideoEffectNode", static: false, private: false, access: { has: function (obj) { return "updateVideoEffectNode" in obj; }, get: function (obj) { return obj.updateVideoEffectNode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoEffectColorFilter_decorators, { kind: "method", name: "setVideoEffectColorFilter", static: false, private: false, access: { has: function (obj) { return "setVideoEffectColorFilter" in obj; }, get: function (obj) { return obj.setVideoEffectColorFilter; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoEffectColorFilterIntensity_decorators, { kind: "method", name: "setVideoEffectColorFilterIntensity", static: false, private: false, access: { has: function (obj) { return "setVideoEffectColorFilterIntensity" in obj; }, get: function (obj) { return obj.setVideoEffectColorFilterIntensity; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setBackgroundSticker_decorators, { kind: "method", name: "setBackgroundSticker", static: false, private: false, access: { has: function (obj) { return "setBackgroundSticker" in obj; }, get: function (obj) { return obj.setBackgroundSticker; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerFaceDetectionObserver_decorators, { kind: "method", name: "registerFaceDetectionObserver", static: false, private: false, access: { has: function (obj) { return "registerFaceDetectionObserver" in obj; }, get: function (obj) { return obj.registerFaceDetectionObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _sendSEIMessage$andMessage$andRepeatCount$_decorators, { kind: "method", name: "sendSEIMessage$andMessage$andRepeatCount$", static: false, private: false, access: { has: function (obj) { return "sendSEIMessage$andMessage$andRepeatCount$" in obj; }, get: function (obj) { return obj.sendSEIMessage$andMessage$andRepeatCount$; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioPlaybackDevice_decorators, { kind: "method", name: "setAudioPlaybackDevice", static: false, private: false, access: { has: function (obj) { return "setAudioPlaybackDevice" in obj; }, get: function (obj) { return obj.setAudioPlaybackDevice; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startLiveTranscoding_decorators, { kind: "method", name: "startLiveTranscoding", static: false, private: false, access: { has: function (obj) { return "startLiveTranscoding" in obj; }, get: function (obj) { return obj.startLiveTranscoding; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopLiveTranscoding_decorators, { kind: "method", name: "stopLiveTranscoding", static: false, private: false, access: { has: function (obj) { return "stopLiveTranscoding" in obj; }, get: function (obj) { return obj.stopLiveTranscoding; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateLiveTranscoding_decorators, { kind: "method", name: "updateLiveTranscoding", static: false, private: false, access: { has: function (obj) { return "updateLiveTranscoding" in obj; }, get: function (obj) { return obj.updateLiveTranscoding; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioMixingManager_decorators, { kind: "method", name: "getAudioMixingManager", static: false, private: false, access: { has: function (obj) { return "getAudioMixingManager" in obj; }, get: function (obj) { return obj.getAudioMixingManager; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _muteAudioPlayback_decorators, { kind: "method", name: "muteAudioPlayback", static: false, private: false, access: { has: function (obj) { return "muteAudioPlayback" in obj; }, get: function (obj) { return obj.muteAudioPlayback; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _delegate_decorators, { kind: "field", name: "delegate", static: false, private: false, access: { has: function (obj) { return "delegate" in obj; }, get: function (obj) { return obj.delegate; }, set: function (obj, value) { obj.delegate = value; } }, metadata: _metadata }, _delegate_initializers, _delegate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        ByteRTCVideo = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _staticExtraInitializers);
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return ByteRTCVideo = _classThis;
}();
var ByteRTCVideoDeviceManager = function () {
    var _classDecorators = [NativeClass('ByteRTCVideoDeviceManager')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _getVideoCaptureDevice_decorators;
    var _setVideoCaptureDevice_decorators;
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoDeviceManager_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        ByteRTCVideoDeviceManager_1.prototype.getVideoCaptureDevice = function (deviceID) {
            throw new Error('not implement');
        };
        ByteRTCVideoDeviceManager_1.prototype.setVideoCaptureDevice = function (deviceID) {
            throw new Error('not implement');
        };
        ByteRTCVideoDeviceManager_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCVideoDeviceManager_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoDeviceManager");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _getVideoCaptureDevice_decorators = [NativeMethodSync('getVideoCaptureDevice:')];
        _setVideoCaptureDevice_decorators = [NativeMethodSync('setVideoCaptureDevice:')];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _getVideoCaptureDevice_decorators, { kind: "method", name: "getVideoCaptureDevice", static: false, private: false, access: { has: function (obj) { return "getVideoCaptureDevice" in obj; }, get: function (obj) { return obj.getVideoCaptureDevice; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setVideoCaptureDevice_decorators, { kind: "method", name: "setVideoCaptureDevice", static: false, private: false, access: { has: function (obj) { return "setVideoCaptureDevice" in obj; }, get: function (obj) { return obj.setVideoCaptureDevice; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioMixingManager = function () {
    var _classDecorators = [NativeClass('ByteRTCAudioMixingManager')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _startAudioMixing_decorators;
    var _stopAudioMixing_decorators;
    var _stopAllAudioMixing_decorators;
    var _pauseAudioMixing_decorators;
    var _pauseAllAudioMixing_decorators;
    var _resumeAudioMixing_decorators;
    var _resumeAllAudioMixing_decorators;
    var _preloadAudioMixing_decorators;
    var _unloadAudioMixing_decorators;
    var _setAllAudioMixingVolume_decorators;
    var _setAudioMixingVolume_decorators;
    var _getAudioMixingDuration_decorators;
    var _getAudioMixingCurrentPosition_decorators;
    var _setAudioMixingPosition_decorators;
    var _setAudioMixingDualMonoMode_decorators;
    var _setAudioMixingPitch_decorators;
    var _setAudioMixingPlaybackSpeed_decorators;
    var _setAudioMixingLoudness_decorators;
    var _setAudioMixingProgressInterval_decorators;
    var _enableAudioMixingFrame_decorators;
    var _disableAudioMixingFrame_decorators;
    var _pushAudioMixingFrame_decorators;
    var _getAudioTrackCount_decorators;
    var _selectAudioTrack_decorators;
    var _registerAudioFileFrameObserver_decorators;
    var _getAudioMixingPlaybackDuration_decorators;
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioMixingManager_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        ByteRTCAudioMixingManager_1.prototype.startAudioMixing = function (mixId, filePath, config) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.stopAudioMixing = function (mixId) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.stopAllAudioMixing = function () {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.pauseAudioMixing = function (mixId) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.pauseAllAudioMixing = function () {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.resumeAudioMixing = function (mixId) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.resumeAllAudioMixing = function () {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.preloadAudioMixing = function (mixId, filePath) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.unloadAudioMixing = function (mixId) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.setAllAudioMixingVolume = function (volume, type) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.setAudioMixingVolume = function (mixId, volume, type) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.getAudioMixingDuration = function (mixId) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.getAudioMixingCurrentPosition = function (mixId) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.setAudioMixingPosition = function (mixId, position) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.setAudioMixingDualMonoMode = function (mixId, mode) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.setAudioMixingPitch = function (mixId, pitch) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.setAudioMixingPlaybackSpeed = function (mixId, speed) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.setAudioMixingLoudness = function (mixId, loudness) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.setAudioMixingProgressInterval = function (mixId, interval) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.enableAudioMixingFrame = function (mixId, type) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.disableAudioMixingFrame = function (mixId) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.pushAudioMixingFrame = function (mixId, audioFrame) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.getAudioTrackCount = function (mixId) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.selectAudioTrack = function (mixId, audioTrackIndex) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.registerAudioFileFrameObserver = function (observer) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.getAudioMixingPlaybackDuration = function (mixId) {
            throw new Error('not implement');
        };
        ByteRTCAudioMixingManager_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCAudioMixingManager_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioMixingManager");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _startAudioMixing_decorators = [NativeMethodSync('startAudioMixing:filePath:config:')];
        _stopAudioMixing_decorators = [NativeMethodSync('stopAudioMixing:')];
        _stopAllAudioMixing_decorators = [NativeMethodSync('stopAllAudioMixing')];
        _pauseAudioMixing_decorators = [NativeMethodSync('pauseAudioMixing:')];
        _pauseAllAudioMixing_decorators = [NativeMethodSync('pauseAllAudioMixing')];
        _resumeAudioMixing_decorators = [NativeMethodSync('resumeAudioMixing:')];
        _resumeAllAudioMixing_decorators = [NativeMethodSync('resumeAllAudioMixing')];
        _preloadAudioMixing_decorators = [NativeMethodSync('preloadAudioMixing:filePath:')];
        _unloadAudioMixing_decorators = [NativeMethodSync('unloadAudioMixing:')];
        _setAllAudioMixingVolume_decorators = [NativeMethodSync('setAllAudioMixingVolume:type:')];
        _setAudioMixingVolume_decorators = [NativeMethodSync('setAudioMixingVolume:volume:type:')];
        _getAudioMixingDuration_decorators = [NativeMethodSync('getAudioMixingDuration:')];
        _getAudioMixingCurrentPosition_decorators = [NativeMethodSync('getAudioMixingCurrentPosition:')];
        _setAudioMixingPosition_decorators = [NativeMethodSync('setAudioMixingPosition:position:')];
        _setAudioMixingDualMonoMode_decorators = [NativeMethodSync('setAudioMixingDualMonoMode:mode:')];
        _setAudioMixingPitch_decorators = [NativeMethodSync('setAudioMixingPitch:pitch:')];
        _setAudioMixingPlaybackSpeed_decorators = [NativeMethodSync('setAudioMixingPlaybackSpeed:speed:')];
        _setAudioMixingLoudness_decorators = [NativeMethodSync('setAudioMixingLoudness:loudness:')];
        _setAudioMixingProgressInterval_decorators = [NativeMethodSync('setAudioMixingProgressInterval:interval:')];
        _enableAudioMixingFrame_decorators = [NativeMethodSync('enableAudioMixingFrame:type:')];
        _disableAudioMixingFrame_decorators = [NativeMethodSync('disableAudioMixingFrame:')];
        _pushAudioMixingFrame_decorators = [NativeMethodSync('pushAudioMixingFrame:audioFrame:')];
        _getAudioTrackCount_decorators = [NativeMethodSync('getAudioTrackCount:')];
        _selectAudioTrack_decorators = [NativeMethodSync('selectAudioTrack:audioTrackIndex:')];
        _registerAudioFileFrameObserver_decorators = [NativeMethodSync('registerAudioFileFrameObserver:')];
        _getAudioMixingPlaybackDuration_decorators = [NativeMethodSync('getAudioMixingPlaybackDuration:')];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _startAudioMixing_decorators, { kind: "method", name: "startAudioMixing", static: false, private: false, access: { has: function (obj) { return "startAudioMixing" in obj; }, get: function (obj) { return obj.startAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopAudioMixing_decorators, { kind: "method", name: "stopAudioMixing", static: false, private: false, access: { has: function (obj) { return "stopAudioMixing" in obj; }, get: function (obj) { return obj.stopAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopAllAudioMixing_decorators, { kind: "method", name: "stopAllAudioMixing", static: false, private: false, access: { has: function (obj) { return "stopAllAudioMixing" in obj; }, get: function (obj) { return obj.stopAllAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pauseAudioMixing_decorators, { kind: "method", name: "pauseAudioMixing", static: false, private: false, access: { has: function (obj) { return "pauseAudioMixing" in obj; }, get: function (obj) { return obj.pauseAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pauseAllAudioMixing_decorators, { kind: "method", name: "pauseAllAudioMixing", static: false, private: false, access: { has: function (obj) { return "pauseAllAudioMixing" in obj; }, get: function (obj) { return obj.pauseAllAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resumeAudioMixing_decorators, { kind: "method", name: "resumeAudioMixing", static: false, private: false, access: { has: function (obj) { return "resumeAudioMixing" in obj; }, get: function (obj) { return obj.resumeAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resumeAllAudioMixing_decorators, { kind: "method", name: "resumeAllAudioMixing", static: false, private: false, access: { has: function (obj) { return "resumeAllAudioMixing" in obj; }, get: function (obj) { return obj.resumeAllAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _preloadAudioMixing_decorators, { kind: "method", name: "preloadAudioMixing", static: false, private: false, access: { has: function (obj) { return "preloadAudioMixing" in obj; }, get: function (obj) { return obj.preloadAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _unloadAudioMixing_decorators, { kind: "method", name: "unloadAudioMixing", static: false, private: false, access: { has: function (obj) { return "unloadAudioMixing" in obj; }, get: function (obj) { return obj.unloadAudioMixing; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAllAudioMixingVolume_decorators, { kind: "method", name: "setAllAudioMixingVolume", static: false, private: false, access: { has: function (obj) { return "setAllAudioMixingVolume" in obj; }, get: function (obj) { return obj.setAllAudioMixingVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingVolume_decorators, { kind: "method", name: "setAudioMixingVolume", static: false, private: false, access: { has: function (obj) { return "setAudioMixingVolume" in obj; }, get: function (obj) { return obj.setAudioMixingVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioMixingDuration_decorators, { kind: "method", name: "getAudioMixingDuration", static: false, private: false, access: { has: function (obj) { return "getAudioMixingDuration" in obj; }, get: function (obj) { return obj.getAudioMixingDuration; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioMixingCurrentPosition_decorators, { kind: "method", name: "getAudioMixingCurrentPosition", static: false, private: false, access: { has: function (obj) { return "getAudioMixingCurrentPosition" in obj; }, get: function (obj) { return obj.getAudioMixingCurrentPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingPosition_decorators, { kind: "method", name: "setAudioMixingPosition", static: false, private: false, access: { has: function (obj) { return "setAudioMixingPosition" in obj; }, get: function (obj) { return obj.setAudioMixingPosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingDualMonoMode_decorators, { kind: "method", name: "setAudioMixingDualMonoMode", static: false, private: false, access: { has: function (obj) { return "setAudioMixingDualMonoMode" in obj; }, get: function (obj) { return obj.setAudioMixingDualMonoMode; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingPitch_decorators, { kind: "method", name: "setAudioMixingPitch", static: false, private: false, access: { has: function (obj) { return "setAudioMixingPitch" in obj; }, get: function (obj) { return obj.setAudioMixingPitch; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingPlaybackSpeed_decorators, { kind: "method", name: "setAudioMixingPlaybackSpeed", static: false, private: false, access: { has: function (obj) { return "setAudioMixingPlaybackSpeed" in obj; }, get: function (obj) { return obj.setAudioMixingPlaybackSpeed; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingLoudness_decorators, { kind: "method", name: "setAudioMixingLoudness", static: false, private: false, access: { has: function (obj) { return "setAudioMixingLoudness" in obj; }, get: function (obj) { return obj.setAudioMixingLoudness; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAudioMixingProgressInterval_decorators, { kind: "method", name: "setAudioMixingProgressInterval", static: false, private: false, access: { has: function (obj) { return "setAudioMixingProgressInterval" in obj; }, get: function (obj) { return obj.setAudioMixingProgressInterval; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _enableAudioMixingFrame_decorators, { kind: "method", name: "enableAudioMixingFrame", static: false, private: false, access: { has: function (obj) { return "enableAudioMixingFrame" in obj; }, get: function (obj) { return obj.enableAudioMixingFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disableAudioMixingFrame_decorators, { kind: "method", name: "disableAudioMixingFrame", static: false, private: false, access: { has: function (obj) { return "disableAudioMixingFrame" in obj; }, get: function (obj) { return obj.disableAudioMixingFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pushAudioMixingFrame_decorators, { kind: "method", name: "pushAudioMixingFrame", static: false, private: false, access: { has: function (obj) { return "pushAudioMixingFrame" in obj; }, get: function (obj) { return obj.pushAudioMixingFrame; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioTrackCount_decorators, { kind: "method", name: "getAudioTrackCount", static: false, private: false, access: { has: function (obj) { return "getAudioTrackCount" in obj; }, get: function (obj) { return obj.getAudioTrackCount; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _selectAudioTrack_decorators, { kind: "method", name: "selectAudioTrack", static: false, private: false, access: { has: function (obj) { return "selectAudioTrack" in obj; }, get: function (obj) { return obj.selectAudioTrack; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _registerAudioFileFrameObserver_decorators, { kind: "method", name: "registerAudioFileFrameObserver", static: false, private: false, access: { has: function (obj) { return "registerAudioFileFrameObserver" in obj; }, get: function (obj) { return obj.registerAudioFileFrameObserver; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _getAudioMixingPlaybackDuration_decorators, { kind: "method", name: "getAudioMixingPlaybackDuration", static: false, private: false, access: { has: function (obj) { return "getAudioMixingPlaybackDuration" in obj; }, get: function (obj) { return obj.getAudioMixingPlaybackDuration; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCKTVPlayer = function () {
    var _classDecorators = [NativeClass('ByteRTCKTVPlayer')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _delegate_decorators;
    var _delegate_initializers = [];
    var _delegate_extraInitializers = [];
    var _playMusic_decorators;
    var _pauseMusic_decorators;
    var _resumeMusic_decorators;
    var _stopMusic_decorators;
    var _seekMusic_decorators;
    var _setMusicVolume_decorators;
    var _switchAudioTrackType_decorators;
    var _setMusicPitch_decorators;
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCKTVPlayer_1() {
            this.delegate = (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _delegate_initializers, void 0));
            __runInitializers(this, _delegate_extraInitializers);
        }
        ByteRTCKTVPlayer_1.prototype.playMusic = function (musicId, trackType, playType) {
            throw new Error('not implement');
        };
        ByteRTCKTVPlayer_1.prototype.pauseMusic = function (musicId) {
            throw new Error('not implement');
        };
        ByteRTCKTVPlayer_1.prototype.resumeMusic = function (musicId) {
            throw new Error('not implement');
        };
        ByteRTCKTVPlayer_1.prototype.stopMusic = function (musicId) {
            throw new Error('not implement');
        };
        ByteRTCKTVPlayer_1.prototype.seekMusic = function (musicId, position) {
            throw new Error('not implement');
        };
        ByteRTCKTVPlayer_1.prototype.setMusicVolume = function (musicId, volume) {
            throw new Error('not implement');
        };
        ByteRTCKTVPlayer_1.prototype.switchAudioTrackType = function (musicId) {
            throw new Error('not implement');
        };
        ByteRTCKTVPlayer_1.prototype.setMusicPitch = function (musicId, pitch) {
            throw new Error('not implement');
        };
        ByteRTCKTVPlayer_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCKTVPlayer_1;
    }());
    __setFunctionName(_classThis, "ByteRTCKTVPlayer");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _delegate_decorators = [NativeMember()];
        _playMusic_decorators = [NativeMethodSync('playMusic:audioTrackType:audioPlayType:')];
        _pauseMusic_decorators = [NativeMethodSync('pauseMusic:')];
        _resumeMusic_decorators = [NativeMethodSync('resumeMusic:')];
        _stopMusic_decorators = [NativeMethodSync('stopMusic:')];
        _seekMusic_decorators = [NativeMethodSync('seekMusic:position:')];
        _setMusicVolume_decorators = [NativeMethodSync('setMusicVolume:volume:')];
        _switchAudioTrackType_decorators = [NativeMethodSync('switchAudioTrackType:')];
        _setMusicPitch_decorators = [NativeMethodSync('setMusicPitch:pitch:')];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _playMusic_decorators, { kind: "method", name: "playMusic", static: false, private: false, access: { has: function (obj) { return "playMusic" in obj; }, get: function (obj) { return obj.playMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _pauseMusic_decorators, { kind: "method", name: "pauseMusic", static: false, private: false, access: { has: function (obj) { return "pauseMusic" in obj; }, get: function (obj) { return obj.pauseMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _resumeMusic_decorators, { kind: "method", name: "resumeMusic", static: false, private: false, access: { has: function (obj) { return "resumeMusic" in obj; }, get: function (obj) { return obj.resumeMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopMusic_decorators, { kind: "method", name: "stopMusic", static: false, private: false, access: { has: function (obj) { return "stopMusic" in obj; }, get: function (obj) { return obj.stopMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _seekMusic_decorators, { kind: "method", name: "seekMusic", static: false, private: false, access: { has: function (obj) { return "seekMusic" in obj; }, get: function (obj) { return obj.seekMusic; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setMusicVolume_decorators, { kind: "method", name: "setMusicVolume", static: false, private: false, access: { has: function (obj) { return "setMusicVolume" in obj; }, get: function (obj) { return obj.setMusicVolume; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _switchAudioTrackType_decorators, { kind: "method", name: "switchAudioTrackType", static: false, private: false, access: { has: function (obj) { return "switchAudioTrackType" in obj; }, get: function (obj) { return obj.switchAudioTrackType; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setMusicPitch_decorators, { kind: "method", name: "setMusicPitch", static: false, private: false, access: { has: function (obj) { return "setMusicPitch" in obj; }, get: function (obj) { return obj.setMusicPitch; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, null, _delegate_decorators, { kind: "field", name: "delegate", static: false, private: false, access: { has: function (obj) { return "delegate" in obj; }, get: function (obj) { return obj.delegate; }, set: function (obj, value) { obj.delegate = value; } }, metadata: _metadata }, _delegate_initializers, _delegate_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRangeAudio = function () {
    var _classDecorators = [NativeClass('ByteRTCRangeAudio')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _enableRangeAudio_decorators;
    var _updateReceiveRange_decorators;
    var _updatePosition_decorators;
    var _setAttenuationModel_decorators;
    var _setNoAttenuationFlags_decorators;
    var _init_decorators;
    _classThis = /** @class */ (function () {
        function ByteRTCRangeAudio_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        ByteRTCRangeAudio_1.prototype.enableRangeAudio = function (enable) {
            throw new Error('not implement');
        };
        ByteRTCRangeAudio_1.prototype.updateReceiveRange = function (range) {
            throw new Error('not implement');
        };
        ByteRTCRangeAudio_1.prototype.updatePosition = function (pos) {
            throw new Error('not implement');
        };
        ByteRTCRangeAudio_1.prototype.setAttenuationModel = function (type, coefficient) {
            throw new Error('not implement');
        };
        ByteRTCRangeAudio_1.prototype.setNoAttenuationFlags = function (flags) {
            throw new Error('not implement');
        };
        ByteRTCRangeAudio_1.prototype.init = function () {
            throw new Error('not implement');
        };
        return ByteRTCRangeAudio_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRangeAudio");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _enableRangeAudio_decorators = [NativeMethodSync('enableRangeAudio:')];
        _updateReceiveRange_decorators = [NativeMethodSync('updateReceiveRange:')];
        _updatePosition_decorators = [NativeMethodSync('updatePosition:')];
        _setAttenuationModel_decorators = [NativeMethodSync('setAttenuationModel:coefficient:')];
        _setNoAttenuationFlags_decorators = [NativeMethodSync('setNoAttenuationFlags:')];
        _init_decorators = [NativeMethodSync('init')];
        __esDecorate(_classThis, null, _enableRangeAudio_decorators, { kind: "method", name: "enableRangeAudio", static: false, private: false, access: { has: function (obj) { return "enableRangeAudio" in obj; }, get: function (obj) { return obj.enableRangeAudio; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updateReceiveRange_decorators, { kind: "method", name: "updateReceiveRange", static: false, private: false, access: { has: function (obj) { return "updateReceiveRange" in obj; }, get: function (obj) { return obj.updateReceiveRange; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _updatePosition_decorators, { kind: "method", name: "updatePosition", static: false, private: false, access: { has: function (obj) { return "updatePosition" in obj; }, get: function (obj) { return obj.updatePosition; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setAttenuationModel_decorators, { kind: "method", name: "setAttenuationModel", static: false, private: false, access: { has: function (obj) { return "setAttenuationModel" in obj; }, get: function (obj) { return obj.setAttenuationModel; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _setNoAttenuationFlags_decorators, { kind: "method", name: "setNoAttenuationFlags", static: false, private: false, access: { has: function (obj) { return "setNoAttenuationFlags" in obj; }, get: function (obj) { return obj.setNoAttenuationFlags; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();

var ByteRTCMediaPlayerAudioFrameObserver = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCMediaPlayerAudioFrameObserver', { onFrame$audioFrame: 'onFrame:audioFrame:' })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCMediaPlayerAudioFrameObserver_1() {
        }
        return ByteRTCMediaPlayerAudioFrameObserver_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMediaPlayerAudioFrameObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCFaceDetectionObserver = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCFaceDetectionObserver', { onFaceDetectResult: 'onFaceDetectResult:' })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCFaceDetectionObserver_1() {
        }
        return ByteRTCFaceDetectionObserver_1;
    }());
    __setFunctionName(_classThis, "ByteRTCFaceDetectionObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeObserverClass('ByteRTCEncryptHandler', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCEncryptHandler_1() {
        }
        return ByteRTCEncryptHandler_1;
    }());
    __setFunctionName(_classThis, "ByteRTCEncryptHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCPushSingleStreamToCDNObserver = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCPushSingleStreamToCDNObserver', {
            onStreamPushEvent$taskId$error: 'onStreamPushEvent:taskId:error:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCPushSingleStreamToCDNObserver_1() {
        }
        return ByteRTCPushSingleStreamToCDNObserver_1;
    }());
    __setFunctionName(_classThis, "ByteRTCPushSingleStreamToCDNObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeObserverClass('ByteRTCVideoSnapshotCallbackDelegate', {
            onTakeLocalSnapshotResult$streamIndex$image$errorCode: 'onTakeLocalSnapshotResult:streamIndex:image:errorCode:',
            onTakeRemoteSnapshotResult$streamKey$image$errorCode: 'onTakeRemoteSnapshotResult:streamKey:image:errorCode:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoSnapshotCallbackDelegate_1() {
        }
        return ByteRTCVideoSnapshotCallbackDelegate_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoSnapshotCallbackDelegate");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
(function () {
    var _classDecorators = [NativeObserverClass('ByteRTCSingScoringDelegate', { onCurrentScoringInfo: 'onCurrentScoringInfo:' })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCSingScoringDelegate_1() {
        }
        return ByteRTCSingScoringDelegate_1;
    }());
    __setFunctionName(_classThis, "ByteRTCSingScoringDelegate");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCMixedStreamObserver = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCMixedStreamObserver', {
            onMixingEvent$taskId$error$mixType: 'onMixingEvent:taskId:error:mixType:',
            onMixingAudioFrame$timestamp$taskId: 'onMixingAudioFrame:timestamp:taskId:',
            onMixingVideoFrame$taskId: 'onMixingVideoFrame:taskId:',
            onMixingDataFrame$taskId: 'onMixingDataFrame:taskId:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCMixedStreamObserver_1() {
        }
        return ByteRTCMixedStreamObserver_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMixedStreamObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioFrameObserver = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCAudioFrameObserver', {
            onRecordAudioFrame: 'onRecordAudioFrame:',
            onPlaybackAudioFrame: 'onPlaybackAudioFrame:',
            onRemoteUserAudioFrame$audioFrame: 'onRemoteUserAudioFrame:audioFrame:',
            onMixedAudioFrame: 'onMixedAudioFrame:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioFrameObserver_1() {
        }
        return ByteRTCAudioFrameObserver_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioFrameObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeObserverClass('ByteRtcScreenCapturerExtDelegate', {
            onQuitFromAp: 'onQuitFromApp',
            onReceiveMessageFromApp: 'onReceiveMessageFromApp:',
            onSocketDisconnec: 'onSocketDisconnect',
            onSocketConnec: 'onSocketConnect',
            onNotifyAppRunnin: 'onNotifyAppRunning',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRtcScreenCapturerExtDelegate_1() {
        }
        return ByteRtcScreenCapturerExtDelegate_1;
    }());
    __setFunctionName(_classThis, "ByteRtcScreenCapturerExtDelegate");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
(function () {
    var _classDecorators = [NativeObserverClass('ByteRTCKTVManagerDelegate', {
            ktvManager$onMusicListResult$totalSize$errorCode: 'ktvManager:onMusicListResult:totalSize:errorCode:',
            ktvManager$onSearchMusicResult$totalSize$errorCode: 'ktvManager:onSearchMusicResult:totalSize:errorCode:',
            ktvManager$onHotMusicResult$errorCode: 'ktvManager:onHotMusicResult:errorCode:',
            ktvManager$onMusicDetailResult$errorCode: 'ktvManager:onMusicDetailResult:errorCode:',
            ktvManager$onDownloadSuccess$downloadResult: 'ktvManager:onDownloadSuccess:downloadResult:',
            ktvManager$onDownloadFailed$errorCode: 'ktvManager:onDownloadFailed:errorCode:',
            ktvManager$onDownloadMusicProgress$progress: 'ktvManager:onDownloadMusicProgress:progress:',
            ktvManager$onClearCacheResult: 'ktvManager:onClearCacheResult:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCKTVManagerDelegate_1() {
        }
        return ByteRTCKTVManagerDelegate_1;
    }());
    __setFunctionName(_classThis, "ByteRTCKTVManagerDelegate");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
(function () {
    var _classDecorators = [NativeObserverClass('ByteRTCASREngineEventHandler', {
            onSucces: 'onSuccess',
            onMessage: 'onMessage:',
            onError$withErrorMessage: 'onError:withErrorMessage:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCASREngineEventHandler_1() {
        }
        return ByteRTCASREngineEventHandler_1;
    }());
    __setFunctionName(_classThis, "ByteRTCASREngineEventHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCAudioEffectPlayerEventHandler = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCAudioEffectPlayerEventHandler', {
            onAudioEffectPlayerStateChanged$state$error: 'onAudioEffectPlayerStateChanged:state:error:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioEffectPlayerEventHandler_1() {
        }
        return ByteRTCAudioEffectPlayerEventHandler_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioEffectPlayerEventHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioFrameProcessor = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCAudioFrameProcessor', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioFrameProcessor_1() {
        }
        return ByteRTCAudioFrameProcessor_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioFrameProcessor");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRoomDelegate = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCRoomDelegate', {
            rtcRoom$onRoomStateChanged$withUid$state$extraInfo: 'rtcRoom:onRoomStateChanged:withUid:state:extraInfo:',
            rtcRoom$onStreamStateChanged$withUid$state$extraInfo: 'rtcRoom:onStreamStateChanged:withUid:state:extraInfo:',
            rtcRoom$onLeaveRoom: 'rtcRoom:onLeaveRoom:',
            rtcRoom$onAVSyncStateChange: 'rtcRoom:onAVSyncStateChange:',
            rtcRoom$onRoomStats: 'rtcRoom:onRoomStats:',
            rtcRoom$onLocalStreamStats: 'rtcRoom:onLocalStreamStats:',
            rtcRoom$onRemoteStreamStats: 'rtcRoom:onRemoteStreamStats:',
            rtcRoom$onUserJoined$elapsed: 'rtcRoom:onUserJoined:elapsed:',
            rtcRoom$onUserLeave$reason: 'rtcRoom:onUserLeave:reason:',
            onTokenWillExpire: 'onTokenWillExpire:',
            onPublishPrivilegeTokenWillExpire: 'onPublishPrivilegeTokenWillExpire:',
            onSubscribePrivilegeTokenWillExpire: 'onSubscribePrivilegeTokenWillExpire:',
            rtcRoom$onUserPublishStream$type: 'rtcRoom:onUserPublishStream:type:',
            rtcRoom$onUserUnpublishStream$type$reason: 'rtcRoom:onUserUnpublishStream:type:reason:',
            rtcRoom$onUserPublishScreen$type: 'rtcRoom:onUserPublishScreen:type:',
            rtcRoom$onUserUnpublishScreen$type$reason: 'rtcRoom:onUserUnpublishScreen:type:reason:',
            rtcRoom$onStreamSubscribed$userId$subscribeConfig: 'rtcRoom:onStreamSubscribed:userId:subscribeConfig:',
            rtcRoom$onRoomMessageReceived$message: 'rtcRoom:onRoomMessageReceived:message:',
            rtcRoom$onRoomBinaryMessageReceived$message: 'rtcRoom:onRoomBinaryMessageReceived:message:',
            rtcRoom$onUserMessageReceived$message: 'rtcRoom:onUserMessageReceived:message:',
            rtcRoom$onUserBinaryMessageReceived$message: 'rtcRoom:onUserBinaryMessageReceived:message:',
            rtcRoom$onUserMessageSendResult$error: 'rtcRoom:onUserMessageSendResult:error:',
            rtcRoom$onRoomMessageSendResult$error: 'rtcRoom:onRoomMessageSendResult:error:',
            rtcRoom$onSetRoomExtraInfoResult$error: 'rtcRoom:onSetRoomExtraInfoResult:error:',
            rtcRoom$onRoomExtraInfoUpdate$value$lastUpdateUserId$lastUpdateTimeMs: 'rtcRoom:onRoomExtraInfoUpdate:value:lastUpdateUserId:lastUpdateTimeMs:',
            rtcRoom$onUserVisibilityChanged$errorCode: 'rtcRoom:onUserVisibilityChanged:errorCode:',
            rtcRoom$onVideoStreamBanned$isBanned: 'rtcRoom:onVideoStreamBanned:isBanned:',
            rtcRoom$onAudioStreamBanned$isBanned: 'rtcRoom:onAudioStreamBanned:isBanned:',
            rtcRoom$onForwardStreamStateChanged: 'rtcRoom:onForwardStreamStateChanged:',
            rtcRoom$onForwardStreamEvent: 'rtcRoom:onForwardStreamEvent:',
            rtcRoom$onNetworkQuality$remoteQualities: 'rtcRoom:onNetworkQuality:remoteQualities:',
            rtcRoom$onSubtitleStateChanged$errorCode$errorMessage: 'rtcRoom:onSubtitleStateChanged:errorCode:errorMessage:',
            rtcRoom$onSubtitleMessageReceived: 'rtcRoom:onSubtitleMessageReceived:',
            rtcRoom$onRoomWarning: 'rtcRoom:onRoomWarning:',
            rtcRoom$onRoomError: 'rtcRoom:onRoomError:',
            rtcRoom$onStreamAdd: 'rtcRoom:onStreamAdd:',
            rtcRoom$onStreamRemove$stream$reason: 'rtcRoom:onStreamRemove:stream:reason:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCRoomDelegate_1() {
        }
        return ByteRTCRoomDelegate_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRoomDelegate");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCExternalVideoEncoderEventHandler = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCExternalVideoEncoderEventHandler', {
            onStart: 'onStart:',
            onStop: 'onStop:',
            onRateUpdate$withVideoIndex$withFps$withBitRate: 'onRateUpdate:withVideoIndex:withFps:withBitRate:',
            onRequestKeyFrame$withVideoIndex: 'onRequestKeyFrame:withVideoIndex:',
            onActiveVideoLayer$withVideoIndex$withActive: 'onActiveVideoLayer:withVideoIndex:withActive:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCExternalVideoEncoderEventHandler_1() {
        }
        return ByteRTCExternalVideoEncoderEventHandler_1;
    }());
    __setFunctionName(_classThis, "ByteRTCExternalVideoEncoderEventHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCAudioFileFrameObserver = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCAudioFileFrameObserver', {
            onAudioFileFrame$audioFrame: 'onAudioFileFrame:audioFrame:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCAudioFileFrameObserver_1() {
        }
        return ByteRTCAudioFileFrameObserver_1;
    }());
    __setFunctionName(_classThis, "ByteRTCAudioFileFrameObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeObserverClass('ByteRTCVideoProcessorDelegate', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoProcessorDelegate_1() {
        }
        return ByteRTCVideoProcessorDelegate_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoProcessorDelegate");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCMediaPlayerEventHandler = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCMediaPlayerEventHandler', {
            onMediaPlayerStateChanged$state$error: 'onMediaPlayerStateChanged:state:error:',
            onMediaPlayerPlayingProgress$progress: 'onMediaPlayerPlayingProgress:progress:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCMediaPlayerEventHandler_1() {
        }
        return ByteRTCMediaPlayerEventHandler_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMediaPlayerEventHandler");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCVideoDelegate = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCVideoDelegate', {
            rtcEngine$onWarning: 'rtcEngine:onWarning:',
            rtcEngine$onError: 'rtcEngine:onError:',
            rtcEngine$onExtensionAccessError$msg: 'rtcEngine:onExtensionAccessError:msg:',
            rtcEngine$onCreateRoomStateChanged$errorCode: 'rtcEngine:onCreateRoomStateChanged:errorCode:',
            rtcEngine$onConnectionStateChanged: 'rtcEngine:onConnectionStateChanged:',
            rtcEngine$onNetworkTypeChanged: 'rtcEngine:onNetworkTypeChanged:',
            rtcEngine$onUserStartAudioCapture$uid: 'rtcEngine:onUserStartAudioCapture:uid:',
            rtcEngine$onUserStopAudioCapture$uid: 'rtcEngine:onUserStopAudioCapture:uid:',
            rtcEngine$onFirstRemoteAudioFrame: 'rtcEngine:onFirstRemoteAudioFrame:',
            rtcEngine$onLocalAudioPropertiesReport: 'rtcEngine:onLocalAudioPropertiesReport:',
            rtcEngine$onRemoteAudioPropertiesReport$totalRemoteVolume: 'rtcEngine:onRemoteAudioPropertiesReport:totalRemoteVolume:',
            rtcEngine$onActiveSpeaker$uid: 'rtcEngine:onActiveSpeaker:uid:',
            rtcEngine$onUserStartVideoCapture$uid: 'rtcEngine:onUserStartVideoCapture:uid:',
            rtcEngine$onUserStopVideoCapture$uid: 'rtcEngine:onUserStopVideoCapture:uid:',
            rtcEngine$onFirstLocalVideoFrameCaptured$withFrameInfo: 'rtcEngine:onFirstLocalVideoFrameCaptured:withFrameInfo:',
            rtcEngine$onFirstRemoteVideoFrameRendered$withFrameInfo: 'rtcEngine:onFirstRemoteVideoFrameRendered:withFrameInfo:',
            rtcEngine$onFirstRemoteVideoFrameDecoded$withFrameInfo: 'rtcEngine:onFirstRemoteVideoFrameDecoded:withFrameInfo:',
            rtcEngine$onRemoteVideoSizeChanged$withFrameInfo: 'rtcEngine:onRemoteVideoSizeChanged:withFrameInfo:',
            rtcEngine$onLocalVideoSizeChanged$withFrameInfo: 'rtcEngine:onLocalVideoSizeChanged:withFrameInfo:',
            rtcEngine$onAudioDeviceStateChanged$device_type$device_state$device_error: 'rtcEngine:onAudioDeviceStateChanged:device_type:device_state:device_error:',
            rtcEngine$onVideoDeviceStateChanged$device_type$device_state$device_error: 'rtcEngine:onVideoDeviceStateChanged:device_type:device_state:device_error:',
            rtcEngine$onAudioDeviceWarning$deviceType$deviceWarning: 'rtcEngine:onAudioDeviceWarning:deviceType:deviceWarning:',
            rtcEngine$onVideoDeviceWarning$deviceType$deviceWarning: 'rtcEngine:onVideoDeviceWarning:deviceType:deviceWarning:',
            rtcEngine$onAudioFrameSendStateChanged$rtcUser$state: 'rtcEngine:onAudioFrameSendStateChanged:rtcUser:state:',
            rtcEngine$onVideoFrameSendStateChanged$rtcUser$state: 'rtcEngine:onVideoFrameSendStateChanged:rtcUser:state:',
            rtcEngine$onScreenVideoFrameSendStateChanged$rtcUser$state: 'rtcEngine:onScreenVideoFrameSendStateChanged:rtcUser:state:',
            rtcEngine$onAudioFramePlayStateChanged$rtcUser$state: 'rtcEngine:onAudioFramePlayStateChanged:rtcUser:state:',
            rtcEngine$onVideoFramePlayStateChanged$rtcUser$state: 'rtcEngine:onVideoFramePlayStateChanged:rtcUser:state:',
            rtcEngine$onScreenVideoFramePlayStateChanged$rtcUser$state: 'rtcEngine:onScreenVideoFramePlayStateChanged:rtcUser:state:',
            rtcEngine$onFirstLocalAudioFrame: 'rtcEngine:onFirstLocalAudioFrame:',
            rtcEngine$onAudioRouteChanged: 'rtcEngine:onAudioRouteChanged:',
            rtcEngine$onSEIMessageReceived$andMessage: 'rtcEngine:onSEIMessageReceived:andMessage:',
            rtcEngine$onSEIStreamUpdate$eventType: 'rtcEngine:onSEIStreamUpdate:eventType:',
            rtcEngine$onStreamSyncInfoReceived$streamType$data: 'rtcEngine:onStreamSyncInfoReceived:streamType:data:',
            rtcEngine$onSysStats: 'rtcEngine:onSysStats:',
            rtcEngine$onLocalAudioStateChanged$error: 'rtcEngine:onLocalAudioStateChanged:error:',
            rtcEngine$onRemoteAudioStateChanged$state$reason: 'rtcEngine:onRemoteAudioStateChanged:state:reason:',
            rtcEngine$onLocalVideoStateChanged$withStreamState$withStreamError: 'rtcEngine:onLocalVideoStateChanged:withStreamState:withStreamError:',
            rtcEngine$onRemoteVideoStateChanged$withVideoState$withVideoStateReason: 'rtcEngine:onRemoteVideoStateChanged:withVideoState:withVideoStateReason:',
            rtcEngine$onLoginResult$errorCode$elapsed: 'rtcEngine:onLoginResult:errorCode:elapsed:',
            rtcEngine$onLogout: 'rtcEngine:onLogout:',
            rtcEngine$onServerParamsSetResult: 'rtcEngine:onServerParamsSetResult:',
            rtcEngine$onGetPeerOnlineStatus$status: 'rtcEngine:onGetPeerOnlineStatus:status:',
            rtcEngine$onUserMessageReceivedOutsideRoom$message: 'rtcEngine:onUserMessageReceivedOutsideRoom:message:',
            rtcEngine$onUserBinaryMessageReceivedOutsideRoom$message: 'rtcEngine:onUserBinaryMessageReceivedOutsideRoom:message:',
            rtcEngine$onUserMessageSendResultOutsideRoom$error: 'rtcEngine:onUserMessageSendResultOutsideRoom:error:',
            rtcEngine$onServerMessageSendResult$error$message: 'rtcEngine:onServerMessageSendResult:error:message:',
            rtcEngine$onNetworkDetectionResult$quality$rtt$lostRate$bitrate$jitter: 'rtcEngine:onNetworkDetectionResult:quality:rtt:lostRate:bitrate:jitter:',
            rtcEngine$onNetworkDetectionStopped: 'rtcEngine:onNetworkDetectionStopped:',
            rtcEngine$onAudioMixingPlayingProgress$progress: 'rtcEngine:onAudioMixingPlayingProgress:progress:',
            rtcEngine$onPerformanceAlarms$roomId$reason$sourceWantedData: 'rtcEngine:onPerformanceAlarms:roomId:reason:sourceWantedData:',
            rtcEngine$onSimulcastSubscribeFallback: 'rtcEngine:onSimulcastSubscribeFallback:',
            rtcEngine$onRecordingStateUpdate$state$error_code$recording_info: 'rtcEngine:onRecordingStateUpdate:state:error_code:recording_info:',
            rtcEngine$onRecordingProgressUpdate$process$recording_info: 'rtcEngine:onRecordingProgressUpdate:process:recording_info:',
            rtcEngine$onAudioRecordingStateUpdate$error_code: 'rtcEngine:onAudioRecordingStateUpdate:error_code:',
            rtcEngine$onPushPublicStreamResult$publicStreamId$errorCode: 'rtcEngine:onPushPublicStreamResult:publicStreamId:errorCode:',
            rtcEngine$onPlayPublicStreamResult$errorCode: 'rtcEngine:onPlayPublicStreamResult:errorCode:',
            rtcEngine$onPublicStreamSEIMessageReceived$andMessage$andSourceType: 'rtcEngine:onPublicStreamSEIMessageReceived:andMessage:andSourceType:',
            rtcEngine$onPublicStreamDataMessageReceived$andMessage$andSourceType: 'rtcEngine:onPublicStreamDataMessageReceived:andMessage:andSourceType:',
            rtcEngine$onFirstPublicStreamVideoFrameDecoded$withFrameInfo: 'rtcEngine:onFirstPublicStreamVideoFrameDecoded:withFrameInfo:',
            rtcEngine$onFirstPublicStreamAudioFrame: 'rtcEngine:onFirstPublicStreamAudioFrame:',
            rtcEngine$onCloudProxyConnected: 'rtcEngine:onCloudProxyConnected:',
            rtcEngine$onEchoTestResult: 'rtcEngine:onEchoTestResult:',
            rtcEngineOnNetworkTimeSynchronized: 'rtcEngineOnNetworkTimeSynchronized:',
            rtcEngine$onHardwareEchoDetectionResult: 'rtcEngine:onHardwareEchoDetectionResult:',
            rtcEngine$onLocalProxyStateChanged$withProxyState$withProxyError: 'rtcEngine:onLocalProxyStateChanged:withProxyState:withProxyError:',
            rtcEngine$onUserMuteAudio$uid$muteState: 'rtcEngine:onUserMuteAudio:uid:muteState:',
            rtcEngine$onUserMuteVideo$uid$withMuteState: 'rtcEngine:onUserMuteVideo:uid:withMuteState:',
            rtcEngine$onMediaDeviceStateChanged$device_type$device_state$device_error: 'rtcEngine:onMediaDeviceStateChanged:device_type:device_state:device_error:',
            rtcEngine$onMediaDeviceWarning$deviceType$deviceWarning: 'rtcEngine:onMediaDeviceWarning:deviceType:deviceWarning:',
            rtcEngine$onAudioPlaybackDeviceChanged: 'rtcEngine:onAudioPlaybackDeviceChanged:',
            rtcEngine$log: 'rtcEngine:log:',
            rtcEngine$onAudioMixingStateChanged$state$error: 'rtcEngine:onAudioMixingStateChanged:state:error:',
            rtcEngine$onHttpProxyState: 'rtcEngine:onHttpProxyState:',
            rtcEngine$onHttpsProxyState: 'rtcEngine:onHttpsProxyState:',
            rtcEngine$onSocks5ProxyState$cmd$proxy_address$local_address$remote_address: 'rtcEngine:onSocks5ProxyState:cmd:proxy_address:local_address:remote_address:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCVideoDelegate_1() {
        }
        return ByteRTCVideoDelegate_1;
    }());
    __setFunctionName(_classThis, "ByteRTCVideoDelegate");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeObserverClass('LiveTranscodingDelegate', {
            onStreamMixingEvent$taskId$error$mixType: 'onStreamMixingEvent:taskId:error:mixType:',
            onMixingAudioFrame$timestamp$taskId: 'onMixingAudioFrame:timestamp:taskId:',
            onMixingVideoFrame$taskId: 'onMixingVideoFrame:taskId:',
            onMixingDataFrame$taskId: 'onMixingDataFrame:taskId:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function LiveTranscodingDelegate_1() {
        }
        return LiveTranscodingDelegate_1;
    }());
    __setFunctionName(_classThis, "LiveTranscodingDelegate");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCLocalEncodedVideoFrameObserver = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCLocalEncodedVideoFrameObserver', {
            onLocalEncodedVideoFrame$Frame: 'onLocalEncodedVideoFrame:Frame:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCLocalEncodedVideoFrameObserver_1() {
        }
        return ByteRTCLocalEncodedVideoFrameObserver_1;
    }());
    __setFunctionName(_classThis, "ByteRTCLocalEncodedVideoFrameObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ByteRTCRemoteEncodedVideoFrameObserver = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCRemoteEncodedVideoFrameObserver', {
            onRemoteEncodedVideoFrame$withEncodedVideoFrame: 'onRemoteEncodedVideoFrame:withEncodedVideoFrame:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCRemoteEncodedVideoFrameObserver_1() {
        }
        return ByteRTCRemoteEncodedVideoFrameObserver_1;
    }());
    __setFunctionName(_classThis, "ByteRTCRemoteEncodedVideoFrameObserver");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
(function () {
    var _classDecorators = [NativeObserverClass('ByteRTCKTVPlayerDelegate', {
            ktvPlayer$onPlayProgress$progress: 'ktvPlayer:onPlayProgress:progress:',
            ktvPlayer$onPlayStateChanged$state$error: 'ktvPlayer:onPlayStateChanged:state:error:',
        })];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCKTVPlayerDelegate_1() {
        }
        return ByteRTCKTVPlayerDelegate_1;
    }());
    __setFunctionName(_classThis, "ByteRTCKTVPlayerDelegate");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();
var ByteRTCMediaPlayerCustomSourceProvider = function () {
    var _classDecorators = [NativeObserverClass('ByteRTCMediaPlayerCustomSourceProvider', {})];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ByteRTCMediaPlayerCustomSourceProvider_1() {
        }
        return ByteRTCMediaPlayerCustomSourceProvider_1;
    }());
    __setFunctionName(_classThis, "ByteRTCMediaPlayerCustomSourceProvider");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();

var ByteRTCKTVErrorCode;
(function (ByteRTCKTVErrorCode) {
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeOK"] = 0] = "ByteRTCKTVErrorCodeOK";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeAppidInValid"] = -3000] = "ByteRTCKTVErrorCodeAppidInValid";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeParasInValid"] = -3001] = "ByteRTCKTVErrorCodeParasInValid";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeGetMusicFailed"] = -3002] = "ByteRTCKTVErrorCodeGetMusicFailed";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeGetLyricFailed"] = -3003] = "ByteRTCKTVErrorCodeGetLyricFailed";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeMusicTakedown"] = -3004] = "ByteRTCKTVErrorCodeMusicTakedown";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeMusicDownload"] = -3005] = "ByteRTCKTVErrorCodeMusicDownload";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeMidiDownloadFailed"] = -3006] = "ByteRTCKTVErrorCodeMidiDownloadFailed";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeSystemBusy"] = -3007] = "ByteRTCKTVErrorCodeSystemBusy";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeNetwork"] = -3008] = "ByteRTCKTVErrorCodeNetwork";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeNotJoinRoom"] = -3009] = "ByteRTCKTVErrorCodeNotJoinRoom";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeParseData"] = -3010] = "ByteRTCKTVErrorCodeParseData";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeDownloading"] = -3012] = "ByteRTCKTVErrorCodeDownloading";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeInternal"] = -3013] = "ByteRTCKTVErrorCodeInternal";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeInsufficientDiskSpace"] = -3014] = "ByteRTCKTVErrorCodeInsufficientDiskSpace";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeMusicDecryptionFailed"] = -3015] = "ByteRTCKTVErrorCodeMusicDecryptionFailed";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeFileRenameFailed"] = -3016] = "ByteRTCKTVErrorCodeFileRenameFailed";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeDownloadTimeOut"] = -3017] = "ByteRTCKTVErrorCodeDownloadTimeOut";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeClearCacheFailed"] = -3018] = "ByteRTCKTVErrorCodeClearCacheFailed";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeDownloadCanceled"] = -3019] = "ByteRTCKTVErrorCodeDownloadCanceled";
    ByteRTCKTVErrorCode[ByteRTCKTVErrorCode["ByteRTCKTVErrorCodeDownload"] = -3011] = "ByteRTCKTVErrorCodeDownload";
})(ByteRTCKTVErrorCode || (ByteRTCKTVErrorCode = {}));
var ByteRTCNetworkDetectionStartReturn;
(function (ByteRTCNetworkDetectionStartReturn) {
    ByteRTCNetworkDetectionStartReturn[ByteRTCNetworkDetectionStartReturn["ByteRTCNetworkDetectionStartReturnSuccess"] = 0] = "ByteRTCNetworkDetectionStartReturnSuccess";
    ByteRTCNetworkDetectionStartReturn[ByteRTCNetworkDetectionStartReturn["ByteRTCNetworkDetectionStartReturnParamErr"] = 1] = "ByteRTCNetworkDetectionStartReturnParamErr";
    ByteRTCNetworkDetectionStartReturn[ByteRTCNetworkDetectionStartReturn["ByteRTCNetworkDetectionStartReturnStreaming"] = 2] = "ByteRTCNetworkDetectionStartReturnStreaming";
    ByteRTCNetworkDetectionStartReturn[ByteRTCNetworkDetectionStartReturn["ByteRTCNetworkDetectionStartReturnStarted"] = 3] = "ByteRTCNetworkDetectionStartReturnStarted";
    ByteRTCNetworkDetectionStartReturn[ByteRTCNetworkDetectionStartReturn["ByteRTCNNetworkDetectionStartReturnNotSupport"] = 4] = "ByteRTCNNetworkDetectionStartReturnNotSupport";
})(ByteRTCNetworkDetectionStartReturn || (ByteRTCNetworkDetectionStartReturn = {}));
var ByteRTCPublicStreamErrorCode;
(function (ByteRTCPublicStreamErrorCode) {
    ByteRTCPublicStreamErrorCode[ByteRTCPublicStreamErrorCode["ByteRTCPublicStreamErrorCodeSuccess"] = 0] = "ByteRTCPublicStreamErrorCodeSuccess";
    ByteRTCPublicStreamErrorCode[ByteRTCPublicStreamErrorCode["ByteRTCPublicStreamErrorCodePushParamError"] = 1191] = "ByteRTCPublicStreamErrorCodePushParamError";
    ByteRTCPublicStreamErrorCode[ByteRTCPublicStreamErrorCode["ByteRTCPublicStreamErrorCodePushStatusError"] = 1192] = "ByteRTCPublicStreamErrorCodePushStatusError";
    ByteRTCPublicStreamErrorCode[ByteRTCPublicStreamErrorCode["ByteRTCPublicStreamErrorCodePushInternalError"] = 1193] = "ByteRTCPublicStreamErrorCodePushInternalError";
    ByteRTCPublicStreamErrorCode[ByteRTCPublicStreamErrorCode["ByteRTCPublicStreamErrorCodePushError"] = 1195] = "ByteRTCPublicStreamErrorCodePushError";
    ByteRTCPublicStreamErrorCode[ByteRTCPublicStreamErrorCode["ByteRTCPublicStreamErrorCodePushTimeOut"] = 1196] = "ByteRTCPublicStreamErrorCodePushTimeOut";
    ByteRTCPublicStreamErrorCode[ByteRTCPublicStreamErrorCode["ByteRTCPublicStreamErrorCodePullNoPushStream"] = 1300] = "ByteRTCPublicStreamErrorCodePullNoPushStream";
})(ByteRTCPublicStreamErrorCode || (ByteRTCPublicStreamErrorCode = {}));
var ByteRTCAudioRecordingErrorCode;
(function (ByteRTCAudioRecordingErrorCode) {
    ByteRTCAudioRecordingErrorCode[ByteRTCAudioRecordingErrorCode["ByteRTCAudioRecordingErrorCodeOk"] = 0] = "ByteRTCAudioRecordingErrorCodeOk";
    ByteRTCAudioRecordingErrorCode[ByteRTCAudioRecordingErrorCode["ByteRTCAudioRecordingErrorCodeNoPermission"] = -1] = "ByteRTCAudioRecordingErrorCodeNoPermission";
    ByteRTCAudioRecordingErrorCode[ByteRTCAudioRecordingErrorCode["ByteRTCAudioRecordingErrorNotInRoom"] = -2] = "ByteRTCAudioRecordingErrorNotInRoom";
    ByteRTCAudioRecordingErrorCode[ByteRTCAudioRecordingErrorCode["ByteRTCAudioRecordingAlreadyStarted"] = -3] = "ByteRTCAudioRecordingAlreadyStarted";
    ByteRTCAudioRecordingErrorCode[ByteRTCAudioRecordingErrorCode["ByteRTCAudioRecordingNotStarted"] = -4] = "ByteRTCAudioRecordingNotStarted";
    ByteRTCAudioRecordingErrorCode[ByteRTCAudioRecordingErrorCode["ByteRTCAudioRecordingErrorCodeNotSupport"] = -5] = "ByteRTCAudioRecordingErrorCodeNotSupport";
    ByteRTCAudioRecordingErrorCode[ByteRTCAudioRecordingErrorCode["ByteRTCAudioRecordingErrorCodeOther"] = -6] = "ByteRTCAudioRecordingErrorCodeOther";
})(ByteRTCAudioRecordingErrorCode || (ByteRTCAudioRecordingErrorCode = {}));
var ByteRTCSingleStreamPushEvent;
(function (ByteRTCSingleStreamPushEvent) {
    ByteRTCSingleStreamPushEvent[ByteRTCSingleStreamPushEvent["ByteRTCSingleStreamPushEventBase"] = 0] = "ByteRTCSingleStreamPushEventBase";
    ByteRTCSingleStreamPushEvent[ByteRTCSingleStreamPushEvent["ByteRTCSingleStreamPushEventStart"] = 1] = "ByteRTCSingleStreamPushEventStart";
    ByteRTCSingleStreamPushEvent[ByteRTCSingleStreamPushEvent["ByteRTCSingleStreamPushEventStartSuccess"] = 2] = "ByteRTCSingleStreamPushEventStartSuccess";
    ByteRTCSingleStreamPushEvent[ByteRTCSingleStreamPushEvent["ByteRTCSingleStreamPushEventStartFailed"] = 3] = "ByteRTCSingleStreamPushEventStartFailed";
    ByteRTCSingleStreamPushEvent[ByteRTCSingleStreamPushEvent["ByteRTCSingleStreamPushEventStop"] = 4] = "ByteRTCSingleStreamPushEventStop";
    ByteRTCSingleStreamPushEvent[ByteRTCSingleStreamPushEvent["ByteRTCSingleStreamPushEventTimeout"] = 5] = "ByteRTCSingleStreamPushEventTimeout";
    ByteRTCSingleStreamPushEvent[ByteRTCSingleStreamPushEvent["ByteRTCSingleStreamPushEventParamError"] = 6] = "ByteRTCSingleStreamPushEventParamError";
})(ByteRTCSingleStreamPushEvent || (ByteRTCSingleStreamPushEvent = {}));
var ByteRTCRoomMessageSendResult;
(function (ByteRTCRoomMessageSendResult) {
    ByteRTCRoomMessageSendResult[ByteRTCRoomMessageSendResult["ByteRTCRoomMessageSendResultSuccess"] = 200] = "ByteRTCRoomMessageSendResultSuccess";
    ByteRTCRoomMessageSendResult[ByteRTCRoomMessageSendResult["ByteRTCRoomMessageSendResultTimeout"] = 1] = "ByteRTCRoomMessageSendResultTimeout";
    ByteRTCRoomMessageSendResult[ByteRTCRoomMessageSendResult["ByteRTCRoomMessageSendResultNetworkDisconnected"] = 2] = "ByteRTCRoomMessageSendResultNetworkDisconnected";
    ByteRTCRoomMessageSendResult[ByteRTCRoomMessageSendResult["ByteRTCRoomMessageSendResultExceedQPS"] = 5] = "ByteRTCRoomMessageSendResultExceedQPS";
    ByteRTCRoomMessageSendResult[ByteRTCRoomMessageSendResult["ByteRTCRoomMessageSendResultNotJoin"] = 100] = "ByteRTCRoomMessageSendResultNotJoin";
    ByteRTCRoomMessageSendResult[ByteRTCRoomMessageSendResult["ByteRTCRoomMessageSendResultInit"] = 101] = "ByteRTCRoomMessageSendResultInit";
    ByteRTCRoomMessageSendResult[ByteRTCRoomMessageSendResult["ByteRTCRoomMessageSendResultNoConnection"] = 102] = "ByteRTCRoomMessageSendResultNoConnection";
    ByteRTCRoomMessageSendResult[ByteRTCRoomMessageSendResult["ByteRTCRoomMessageSendResultExceedMaxLength"] = 103] = "ByteRTCRoomMessageSendResultExceedMaxLength";
    ByteRTCRoomMessageSendResult[ByteRTCRoomMessageSendResult["ByteRTCRoomMessageSendResultUnknown"] = 1000] = "ByteRTCRoomMessageSendResultUnknown";
})(ByteRTCRoomMessageSendResult || (ByteRTCRoomMessageSendResult = {}));
var ByteRTCWarningCode;
(function (ByteRTCWarningCode) {
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeJoinRoomFailed"] = -2001] = "ByteRTCWarningCodeJoinRoomFailed";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodePublishStreamFailed"] = -2002] = "ByteRTCWarningCodePublishStreamFailed";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeSubscribeStreamFailed404"] = -2003] = "ByteRTCWarningCodeSubscribeStreamFailed404";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeSubscribeStreamFailed5xx"] = -2004] = "ByteRTCWarningCodeSubscribeStreamFailed5xx";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeInvokeError"] = -2005] = "ByteRTCWarningCodeInvokeError";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeInvalidExpectMediaServerAddress"] = -2007] = "ByteRTCWarningCodeInvalidExpectMediaServerAddress";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodePublishStreamForbiden"] = -2009] = "ByteRTCWarningCodePublishStreamForbiden";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeSendCustomMessage"] = -2011] = "ByteRTCWarningCodeSendCustomMessage";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeCodeUserNotifyStop"] = -2013] = "ByteRTCWarningCodeCodeUserNotifyStop";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeUserInPublish"] = -2014] = "ByteRTCWarningCodeUserInPublish";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeOldRoomBeenReplaced"] = -2016] = "ByteRTCWarningCodeOldRoomBeenReplaced";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeInEchoTestMode"] = -2017] = "ByteRTCWarningCodeInEchoTestMode";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeNoCameraPermission"] = -5001] = "ByteRTCWarningCodeNoCameraPermission";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningSetScreenAudioSourceTypeFailed"] = -5009] = "ByteRTCWarningSetScreenAudioSourceTypeFailed";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningSetScreenAudioStreamIndexFailed"] = -5010] = "ByteRTCWarningSetScreenAudioStreamIndexFailed";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningInvalidVoicePitch"] = -5011] = "ByteRTCWarningInvalidVoicePitch";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningInvalidCallForExtAudio"] = -5013] = "ByteRTCWarningInvalidCallForExtAudio";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeInvalidCanvasHandle"] = -6001] = "ByteRTCWarningCodeInvalidCanvasHandle";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeInvaildSamiAppkeyORToken"] = -7002] = "ByteRTCWarningCodeInvaildSamiAppkeyORToken";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeInvaildSamiResourcePath"] = -7003] = "ByteRTCWarningCodeInvaildSamiResourcePath";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeLoadSamiLibraryFailed"] = -7004] = "ByteRTCWarningCodeLoadSamiLibraryFailed";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeInvaildSamiEffectType"] = -7005] = "ByteRTCWarningCodeInvaildSamiEffectType";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeGetRoomFailed"] = -2000] = "ByteRTCWarningCodeGetRoomFailed";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeSubscribeStreamForbiden"] = -2010] = "ByteRTCWarningCodeSubscribeStreamForbiden";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeRoomAlreadyExist"] = -2015] = "ByteRTCWarningCodeRoomAlreadyExist";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeNoMicrophonePermission"] = -5002] = "ByteRTCWarningCodeNoMicrophonePermission";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeAudioDeviceManagerRecordingStartFail"] = -5003] = "ByteRTCWarningCodeAudioDeviceManagerRecordingStartFail";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeAudioDeviceManagerPlayoutStartFail"] = -5004] = "ByteRTCWarningCodeAudioDeviceManagerPlayoutStartFail";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeNoRecordingDevice"] = -5005] = "ByteRTCWarningCodeNoRecordingDevice";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeNoPlayoutDevice"] = -5006] = "ByteRTCWarningCodeNoPlayoutDevice";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeRecordingSilence"] = -5007] = "ByteRTCWarningCodeRecordingSilence";
    ByteRTCWarningCode[ByteRTCWarningCode["ByteRTCWarningCodeMediaDeviceOperationDennied"] = -5008] = "ByteRTCWarningCodeMediaDeviceOperationDennied";
})(ByteRTCWarningCode || (ByteRTCWarningCode = {}));
var ByteRTCErrorCode;
(function (ByteRTCErrorCode) {
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeInvalidToken"] = -1000] = "ByteRTCErrorCodeInvalidToken";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeJoinRoom"] = -1001] = "ByteRTCErrorCodeJoinRoom";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeNoPublishPermission"] = -1002] = "ByteRTCErrorCodeNoPublishPermission";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeNoSubscribePermission"] = -1003] = "ByteRTCErrorCodeNoSubscribePermission";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeDuplicateLogin"] = -1004] = "ByteRTCErrorCodeDuplicateLogin";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeKickedOut"] = -1006] = "ByteRTCErrorCodeKickedOut";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeRoomIdIllegal"] = -1007] = "ByteRTCErrorCodeRoomIdIllegal";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeTokenExpired"] = -1009] = "ByteRTCErrorCodeTokenExpired";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeUpdateTokenWithInvalidToken"] = -1010] = "ByteRTCErrorCodeUpdateTokenWithInvalidToken";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeRoomDismiss"] = -1011] = "ByteRTCErrorCodeRoomDismiss";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCJoinRoomWithoutLicenseAuthenticateSDK"] = -1012] = "ByteRTCJoinRoomWithoutLicenseAuthenticateSDK";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCRoomAlreadyExist"] = -1013] = "ByteRTCRoomAlreadyExist";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCUserIDDifferent"] = -1014] = "ByteRTCUserIDDifferent";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeJoinRoomServerLicenseExpired"] = -1017] = "ByteRTCErrorCodeJoinRoomServerLicenseExpired";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeJoinRoomExceedsTheUpperLimit"] = -1018] = "ByteRTCErrorCodeJoinRoomExceedsTheUpperLimit";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeJoinRoomLicenseParameterError"] = -1019] = "ByteRTCErrorCodeJoinRoomLicenseParameterError";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeJoinRoomLicenseFilePathError"] = -1020] = "ByteRTCErrorCodeJoinRoomLicenseFilePathError";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeJoinRoomLicenseIllegal"] = -1021] = "ByteRTCErrorCodeJoinRoomLicenseIllegal";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeJoinRoomLicenseExpired"] = -1022] = "ByteRTCErrorCodeJoinRoomLicenseExpired";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeJoinRoomLicenseInformationNotMatch"] = -1023] = "ByteRTCErrorCodeJoinRoomLicenseInformationNotMatch";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeJoinRoomLicenseNotMatchWithCache"] = -1024] = "ByteRTCErrorCodeJoinRoomLicenseNotMatchWithCache";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeJoinRoomRoomForbidden"] = -1025] = "ByteRTCErrorCodeJoinRoomRoomForbidden";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeJoinRoomUserForbidden"] = -1026] = "ByteRTCErrorCodeJoinRoomUserForbidden";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeOverStreamSubscribeLimit"] = -1070] = "ByteRTCErrorCodeOverStreamSubscribeLimit";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeOverStreamPublishLimit"] = -1080] = "ByteRTCErrorCodeOverStreamPublishLimit";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodInvalidAudioSyncUidRepeated"] = -1083] = "ByteRTCErrorCodInvalidAudioSyncUidRepeated";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeAbnormalServerStatus"] = -1084] = "ByteRTCErrorCodeAbnormalServerStatus";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeMultiRoomUnpublishFailed"] = -1085] = "ByteRTCErrorCodeMultiRoomUnpublishFailed";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeWrongAreaCode"] = -1086] = "ByteRTCErrorCodeWrongAreaCode";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeDeadLockNotify"] = -1111] = "ByteRTCErrorCodeDeadLockNotify";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeOverScreenPublishLimit"] = -1081] = "ByteRTCErrorCodeOverScreenPublishLimit";
    ByteRTCErrorCode[ByteRTCErrorCode["ByteRTCErrorCodeOverVideoPublishLimit"] = -1082] = "ByteRTCErrorCodeOverVideoPublishLimit";
})(ByteRTCErrorCode || (ByteRTCErrorCode = {}));
var ByteRTCUserMessageSendResult;
(function (ByteRTCUserMessageSendResult) {
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultSuccess"] = 0] = "ByteRTCUserMessageSendResultSuccess";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultTimeout"] = 1] = "ByteRTCUserMessageSendResultTimeout";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultNetworkDisconnected"] = 2] = "ByteRTCUserMessageSendResultNetworkDisconnected";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultNoReceiver"] = 3] = "ByteRTCUserMessageSendResultNoReceiver";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultNoRelayPath"] = 4] = "ByteRTCUserMessageSendResultNoRelayPath";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultExceedQPS"] = 5] = "ByteRTCUserMessageSendResultExceedQPS";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultE2BSSendFailed"] = 17] = "ByteRTCUserMessageSendResultE2BSSendFailed";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultE2BSReturnFailed"] = 18] = "ByteRTCUserMessageSendResultE2BSReturnFailed";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultNotJoin"] = 100] = "ByteRTCUserMessageSendResultNotJoin";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultInit"] = 101] = "ByteRTCUserMessageSendResultInit";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultNoConnection"] = 102] = "ByteRTCUserMessageSendResultNoConnection";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultExceedMaxLength"] = 103] = "ByteRTCUserMessageSendResultExceedMaxLength";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultEmptyUser"] = 104] = "ByteRTCUserMessageSendResultEmptyUser";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultNotLogin"] = 105] = "ByteRTCUserMessageSendResultNotLogin";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultServerParamsNotSet"] = 106] = "ByteRTCUserMessageSendResultServerParamsNotSet";
    ByteRTCUserMessageSendResult[ByteRTCUserMessageSendResult["ByteRTCUserMessageSendResultUnknown"] = 1000] = "ByteRTCUserMessageSendResultUnknown";
})(ByteRTCUserMessageSendResult || (ByteRTCUserMessageSendResult = {}));
var ByteRTCLoginErrorCode;
(function (ByteRTCLoginErrorCode) {
    ByteRTCLoginErrorCode[ByteRTCLoginErrorCode["ByteRTCLoginErrorCodeSuccess"] = 0] = "ByteRTCLoginErrorCodeSuccess";
    ByteRTCLoginErrorCode[ByteRTCLoginErrorCode["ByteRTCLoginErrorCodeInvalidToken"] = -1000] = "ByteRTCLoginErrorCodeInvalidToken";
    ByteRTCLoginErrorCode[ByteRTCLoginErrorCode["ByteRTCLoginErrorCodeLoginFailed"] = -1001] = "ByteRTCLoginErrorCodeLoginFailed";
    ByteRTCLoginErrorCode[ByteRTCLoginErrorCode["ByteRTCLoginErrorCodeInvalidUserId"] = -1002] = "ByteRTCLoginErrorCodeInvalidUserId";
    ByteRTCLoginErrorCode[ByteRTCLoginErrorCode["ByteRTCLoginErrorCodeServerError"] = -1003] = "ByteRTCLoginErrorCodeServerError";
})(ByteRTCLoginErrorCode || (ByteRTCLoginErrorCode = {}));
var ByteRTCStreamMixingErrorCode;
(function (ByteRTCStreamMixingErrorCode) {
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeOK"] = 0] = "ByteRTCStreamMixingErrorCodeOK";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeBase"] = 1090] = "ByteRTCStreamMixingErrorCodeBase";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeInvalidParam"] = 1091] = "ByteRTCStreamMixingErrorCodeInvalidParam";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeInvalidState"] = 1092] = "ByteRTCStreamMixingErrorCodeInvalidState";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeInvalidOperator"] = 1093] = "ByteRTCStreamMixingErrorCodeInvalidOperator";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeTimeOut"] = 1094] = "ByteRTCStreamMixingErrorCodeTimeOut";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeInvalidParamByServer"] = 1095] = "ByteRTCStreamMixingErrorCodeInvalidParamByServer";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeSubTimeoutByServer"] = 1096] = "ByteRTCStreamMixingErrorCodeSubTimeoutByServer";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeInvalidStateByServer"] = 1097] = "ByteRTCStreamMixingErrorCodeInvalidStateByServer";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeAuthenticationByCDN"] = 1098] = "ByteRTCStreamMixingErrorCodeAuthenticationByCDN";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeTimeoutBySignaling"] = 1099] = "ByteRTCStreamMixingErrorCodeTimeoutBySignaling";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeMixImageFail"] = 1100] = "ByteRTCStreamMixingErrorCodeMixImageFail";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeUnKnownErrorByServer"] = 1101] = "ByteRTCStreamMixingErrorCodeUnKnownErrorByServer";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeCacheSyncWorse"] = 1102] = "ByteRTCStreamMixingErrorCodeCacheSyncWorse";
    ByteRTCStreamMixingErrorCode[ByteRTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeMax"] = 1199] = "ByteRTCStreamMixingErrorCodeMax";
})(ByteRTCStreamMixingErrorCode || (ByteRTCStreamMixingErrorCode = {}));
var ByteRTCSubtitleErrorCode;
(function (ByteRTCSubtitleErrorCode) {
    ByteRTCSubtitleErrorCode[ByteRTCSubtitleErrorCode["ByteRTCSubtitleErrorCodeUnknow"] = -1] = "ByteRTCSubtitleErrorCodeUnknow";
    ByteRTCSubtitleErrorCode[ByteRTCSubtitleErrorCode["ByteRTCSubtitleErrorCodeSuccess"] = 0] = "ByteRTCSubtitleErrorCodeSuccess";
    ByteRTCSubtitleErrorCode[ByteRTCSubtitleErrorCode["ByteRTCSubtitleErrorCodePostProcessError"] = 1] = "ByteRTCSubtitleErrorCodePostProcessError";
    ByteRTCSubtitleErrorCode[ByteRTCSubtitleErrorCode["ByteRTCSubtitleErrorCodeASRConnectionError"] = 2] = "ByteRTCSubtitleErrorCodeASRConnectionError";
    ByteRTCSubtitleErrorCode[ByteRTCSubtitleErrorCode["ByteRTCSubtitleErrorCodeASRServiceError"] = 3] = "ByteRTCSubtitleErrorCodeASRServiceError";
    ByteRTCSubtitleErrorCode[ByteRTCSubtitleErrorCode["ByteRTCSubtitleErrorCodeBeforeJoinRoom"] = 4] = "ByteRTCSubtitleErrorCodeBeforeJoinRoom";
    ByteRTCSubtitleErrorCode[ByteRTCSubtitleErrorCode["ByteRTCSubtitleErrorCodeAlreadyOn"] = 5] = "ByteRTCSubtitleErrorCodeAlreadyOn";
    ByteRTCSubtitleErrorCode[ByteRTCSubtitleErrorCode["ByteRTCSubtitleErrorCodeUnsupportedLanguage"] = 6] = "ByteRTCSubtitleErrorCodeUnsupportedLanguage";
    ByteRTCSubtitleErrorCode[ByteRTCSubtitleErrorCode["ByteRTCSubtitleErrorCodePostProcessTimeout"] = 7] = "ByteRTCSubtitleErrorCodePostProcessTimeout";
})(ByteRTCSubtitleErrorCode || (ByteRTCSubtitleErrorCode = {}));
var ByteRtcTranscoderErrorCode;
(function (ByteRtcTranscoderErrorCode) {
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeOK"] = 0] = "ByteRtcTranscoderErrorCodeOK";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeBase"] = 1090] = "ByteRtcTranscoderErrorCodeBase";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeInvalidParam"] = 1091] = "ByteRtcTranscoderErrorCodeInvalidParam";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeInvalidState"] = 1092] = "ByteRtcTranscoderErrorCodeInvalidState";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeInvalidOperator"] = 1093] = "ByteRtcTranscoderErrorCodeInvalidOperator";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeTimeOut"] = 1094] = "ByteRtcTranscoderErrorCodeTimeOut";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeInvalidParamByServer"] = 1095] = "ByteRtcTranscoderErrorCodeInvalidParamByServer";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeSubTimeoutByServer"] = 1096] = "ByteRtcTranscoderErrorCodeSubTimeoutByServer";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeInvalidStateByServer"] = 1097] = "ByteRtcTranscoderErrorCodeInvalidStateByServer";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeAuthenticationByCDN"] = 1098] = "ByteRtcTranscoderErrorCodeAuthenticationByCDN";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeTimeoutBySignaling"] = 1099] = "ByteRtcTranscoderErrorCodeTimeoutBySignaling";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeMixImageFail"] = 1100] = "ByteRtcTranscoderErrorCodeMixImageFail";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeUnKnownErrorByServer"] = 1101] = "ByteRtcTranscoderErrorCodeUnKnownErrorByServer";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeCacheSyncWorse"] = 1102] = "ByteRtcTranscoderErrorCodeCacheSyncWorse";
    ByteRtcTranscoderErrorCode[ByteRtcTranscoderErrorCode["ByteRtcTranscoderErrorCodeMax"] = 1199] = "ByteRtcTranscoderErrorCodeMax";
})(ByteRtcTranscoderErrorCode || (ByteRtcTranscoderErrorCode = {}));
var ByteRTSWarningCode;
(function (ByteRTSWarningCode) {
    ByteRTSWarningCode[ByteRTSWarningCode["ByteRTSWarningCodeJoinRoomFailed"] = -2001] = "ByteRTSWarningCodeJoinRoomFailed";
    ByteRTSWarningCode[ByteRTSWarningCode["ByteRTSWarningCodePublishStreamFailed"] = -2002] = "ByteRTSWarningCodePublishStreamFailed";
    ByteRTSWarningCode[ByteRTSWarningCode["ByteRTSWarningCodeInvokeError"] = -2005] = "ByteRTSWarningCodeInvokeError";
    ByteRTSWarningCode[ByteRTSWarningCode["ByteRTSWarningCodeInvalidExpectMediaServerAddress"] = -2007] = "ByteRTSWarningCodeInvalidExpectMediaServerAddress";
    ByteRTSWarningCode[ByteRTSWarningCode["ByteRTSWarningCodeSendCustomMessage"] = -2011] = "ByteRTSWarningCodeSendCustomMessage";
    ByteRTSWarningCode[ByteRTSWarningCode["ByteRTSWarningCodeOldRoomBeenReplaced"] = -2016] = "ByteRTSWarningCodeOldRoomBeenReplaced";
    ByteRTSWarningCode[ByteRTSWarningCode["ByteRTSWarningCodeGetRoomFailed"] = -2000] = "ByteRTSWarningCodeGetRoomFailed";
    ByteRTSWarningCode[ByteRTSWarningCode["ByteRTSWarningCodeRoomAlreadyExist"] = -2015] = "ByteRTSWarningCodeRoomAlreadyExist";
})(ByteRTSWarningCode || (ByteRTSWarningCode = {}));
var ByteRTSErrorCode;
(function (ByteRTSErrorCode) {
    ByteRTSErrorCode[ByteRTSErrorCode["ByteRTSErrorCodeInvalidToken"] = -1000] = "ByteRTSErrorCodeInvalidToken";
    ByteRTSErrorCode[ByteRTSErrorCode["ByteRTSErrorCodeJoinRoom"] = -1001] = "ByteRTSErrorCodeJoinRoom";
    ByteRTSErrorCode[ByteRTSErrorCode["ByteRTSErrorCodeDuplicateLogin"] = -1004] = "ByteRTSErrorCodeDuplicateLogin";
    ByteRTSErrorCode[ByteRTSErrorCode["ByteRTSErrorCodeKickedOut"] = -1006] = "ByteRTSErrorCodeKickedOut";
    ByteRTSErrorCode[ByteRTSErrorCode["ByteRTSErrorCodeRoomIdIllegal"] = -1007] = "ByteRTSErrorCodeRoomIdIllegal";
    ByteRTSErrorCode[ByteRTSErrorCode["ByteRTSErrorCodeTokenExpired"] = -1009] = "ByteRTSErrorCodeTokenExpired";
    ByteRTSErrorCode[ByteRTSErrorCode["ByteRTSErrorCodeUpdateTokenWithInvalidToken"] = -1010] = "ByteRTSErrorCodeUpdateTokenWithInvalidToken";
    ByteRTSErrorCode[ByteRTSErrorCode["ByteRTSErrorCodeRoomDismiss"] = -1011] = "ByteRTSErrorCodeRoomDismiss";
    ByteRTSErrorCode[ByteRTSErrorCode["ByteRTSErrorRoomAlreadyExist"] = -1013] = "ByteRTSErrorRoomAlreadyExist";
    ByteRTSErrorCode[ByteRTSErrorCode["ByteRTSErrorUserIDDifferent"] = -1014] = "ByteRTSErrorUserIDDifferent";
    ByteRTSErrorCode[ByteRTSErrorCode["ByteRTSErrorCodeAbnormalServerStatus"] = -1084] = "ByteRTSErrorCodeAbnormalServerStatus";
})(ByteRTSErrorCode || (ByteRTSErrorCode = {}));

var NativeUIView = function () {
    var _a;
    var _classSuper = NativeView;
    var _instanceExtraInitializers = [];
    var _frame_decorators;
    var _frame_initializers = [];
    var _frame_extraInitializers = [];
    var _bounds_decorators;
    var _bounds_initializers = [];
    var _bounds_extraInitializers = [];
    var _insertSubview_decorators;
    return _a = /** @class */ (function (_super) {
            __extends(NativeUIView, _super);
            function NativeUIView() {
                var _this = _super !== null && _super.apply(this, arguments) || this;
                _this.frame = (__runInitializers(_this, _instanceExtraInitializers), __runInitializers(_this, _frame_initializers, void 0));
                _this.bounds = (__runInitializers(_this, _frame_extraInitializers), __runInitializers(_this, _bounds_initializers, void 0));
                __runInitializers(_this, _bounds_extraInitializers);
                return _this;
            }
            NativeUIView.prototype.insertSubview = function (view, atIndex) {
                return __awaiter(this, void 0, void 0, function () { return __generator(this, function (_b) {
                    return [2 /*return*/];
                }); });
            };
            return NativeUIView;
        }(_classSuper)),
        (function () {
            var _b;
            var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create((_b = _classSuper[Symbol.metadata]) !== null && _b !== void 0 ? _b : null) : void 0;
            _frame_decorators = [NativeMember()];
            _bounds_decorators = [NativeMember()];
            _insertSubview_decorators = [NativeMethod('insertSubview:atIndex:')];
            __esDecorate(_a, null, _insertSubview_decorators, { kind: "method", name: "insertSubview", static: false, private: false, access: { has: function (obj) { return "insertSubview" in obj; }, get: function (obj) { return obj.insertSubview; } }, metadata: _metadata }, null, _instanceExtraInitializers);
            __esDecorate(null, null, _frame_decorators, { kind: "field", name: "frame", static: false, private: false, access: { has: function (obj) { return "frame" in obj; }, get: function (obj) { return obj.frame; }, set: function (obj, value) { obj.frame = value; } }, metadata: _metadata }, _frame_initializers, _frame_extraInitializers);
            __esDecorate(null, null, _bounds_decorators, { kind: "field", name: "bounds", static: false, private: false, access: { has: function (obj) { return "bounds" in obj; }, get: function (obj) { return obj.bounds; }, set: function (obj, value) { obj.bounds = value; } }, metadata: _metadata }, _bounds_initializers, _bounds_extraInitializers);
            if (_metadata) Object.defineProperty(_a, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        })(),
        _a;
}();
var UIView = /** @class */ (function (_super) {
    __extends(UIView, _super);
    function UIView() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return UIView;
}(NativeUIView));
var ByteRTCImage = /** @class */ (function () {
    function ByteRTCImage() {
    }
    return ByteRTCImage;
}());
var ByteRTCView = /** @class */ (function () {
    function ByteRTCView() {
    }
    return ByteRTCView;
}());
var RPSampleBufferType = /** @class */ (function () {
    function RPSampleBufferType() {
    }
    return RPSampleBufferType;
}());

exports.RTCNetworkType = void 0;
(function (RTCNetworkType) {
    RTCNetworkType[RTCNetworkType["UNKNOWN"] = 0] = "UNKNOWN";
    RTCNetworkType[RTCNetworkType["LAN"] = 1] = "LAN";
    RTCNetworkType[RTCNetworkType["MOBILE_2G"] = 2] = "MOBILE_2G";
    RTCNetworkType[RTCNetworkType["MOBILE_3G"] = 3] = "MOBILE_3G";
    RTCNetworkType[RTCNetworkType["WIFI"] = 4] = "WIFI";
    RTCNetworkType[RTCNetworkType["MOBILE_4G"] = 5] = "MOBILE_4G";
    RTCNetworkType[RTCNetworkType["MOBILE_5G"] = 6] = "MOBILE_5G";
    /**
     * @platform android
     */
    RTCNetworkType[RTCNetworkType["NONE"] = 7] = "NONE";
    RTCNetworkType[RTCNetworkType["ByteRTCNetworkTypeDisconnected"] = 8] = "ByteRTCNetworkTypeDisconnected";
})(exports.RTCNetworkType || (exports.RTCNetworkType = {}));
exports.RTCUserOfflineReason = void 0;
(function (RTCUserOfflineReason) {
    RTCUserOfflineReason[RTCUserOfflineReason["ByteRTCUserOfflineReasonQuit"] = 0] = "ByteRTCUserOfflineReasonQuit";
    RTCUserOfflineReason[RTCUserOfflineReason["ByteRTCUserOfflineReasonDropped"] = 1] = "ByteRTCUserOfflineReasonDropped";
    RTCUserOfflineReason[RTCUserOfflineReason["ByteRTCUserOfflineReasonSwitchToInvisible"] = 2] = "ByteRTCUserOfflineReasonSwitchToInvisible";
    RTCUserOfflineReason[RTCUserOfflineReason["ByteRTCUserOfflineReasonKickedByAdmin"] = 3] = "ByteRTCUserOfflineReasonKickedByAdmin";
})(exports.RTCUserOfflineReason || (exports.RTCUserOfflineReason = {}));
exports.RTCStreamSinglePushEvent = void 0;
(function (RTCStreamSinglePushEvent) {
    RTCStreamSinglePushEvent[RTCStreamSinglePushEvent["SINGLE_STREAM_PUSH_START"] = 0] = "SINGLE_STREAM_PUSH_START";
    RTCStreamSinglePushEvent[RTCStreamSinglePushEvent["SINGLE_STREAM_PUSH_SUCCESS"] = 1] = "SINGLE_STREAM_PUSH_SUCCESS";
    RTCStreamSinglePushEvent[RTCStreamSinglePushEvent["SINGLE_STREAM_PUSH_FAILED"] = 2] = "SINGLE_STREAM_PUSH_FAILED";
    RTCStreamSinglePushEvent[RTCStreamSinglePushEvent["SINGLE_STREAM_PUSH_STOP"] = 3] = "SINGLE_STREAM_PUSH_STOP";
    RTCStreamSinglePushEvent[RTCStreamSinglePushEvent["SINGLE_STREAM_PUSH_TIMEOUT"] = 4] = "SINGLE_STREAM_PUSH_TIMEOUT";
    RTCStreamSinglePushEvent[RTCStreamSinglePushEvent["SINGLE_STREAM_PUSH_PARAM_ERROR"] = 5] = "SINGLE_STREAM_PUSH_PARAM_ERROR";
    RTCStreamSinglePushEvent[RTCStreamSinglePushEvent["ByteRTCSingleStreamPushEventStart"] = 7] = "ByteRTCSingleStreamPushEventStart";
    RTCStreamSinglePushEvent[RTCStreamSinglePushEvent["ByteRTCSingleStreamPushEventStartSuccess"] = 8] = "ByteRTCSingleStreamPushEventStartSuccess";
    RTCStreamSinglePushEvent[RTCStreamSinglePushEvent["ByteRTCSingleStreamPushEventStartFailed"] = 9] = "ByteRTCSingleStreamPushEventStartFailed";
    RTCStreamSinglePushEvent[RTCStreamSinglePushEvent["ByteRTCSingleStreamPushEventStop"] = 10] = "ByteRTCSingleStreamPushEventStop";
    RTCStreamSinglePushEvent[RTCStreamSinglePushEvent["ByteRTCSingleStreamPushEventTimeout"] = 11] = "ByteRTCSingleStreamPushEventTimeout";
    RTCStreamSinglePushEvent[RTCStreamSinglePushEvent["ByteRTCSingleStreamPushEventParamError"] = 12] = "ByteRTCSingleStreamPushEventParamError";
})(exports.RTCStreamSinglePushEvent || (exports.RTCStreamSinglePushEvent = {}));
exports.RTCStreamMixingErrorCode = void 0;
(function (RTCStreamMixingErrorCode) {
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["TRANSCODER_ERROR_OK"] = 0] = "TRANSCODER_ERROR_OK";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["TRANSCODER_ERROR_BASE"] = 1] = "TRANSCODER_ERROR_BASE";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["TRANSCODER_ERROR_INVALID_PARAM"] = 2] = "TRANSCODER_ERROR_INVALID_PARAM";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["TRANSCODER_ERROR_INVALID_STATE"] = 3] = "TRANSCODER_ERROR_INVALID_STATE";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["TRANSCODER_ERROR_INVALID_OPERATOR"] = 4] = "TRANSCODER_ERROR_INVALID_OPERATOR";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["TRANSCODER_ERROR_TIMEOUT"] = 5] = "TRANSCODER_ERROR_TIMEOUT";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["TRANSCODER_ERROR_INVALID_PARAM_BY_SERVER"] = 6] = "TRANSCODER_ERROR_INVALID_PARAM_BY_SERVER";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["TRANSCODER_ERROR_SUB_TIMEOUT_BY_SERVER"] = 7] = "TRANSCODER_ERROR_SUB_TIMEOUT_BY_SERVER";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["TRANSCODER_ERROR_INVALID_STATE_BY_SERVER"] = 8] = "TRANSCODER_ERROR_INVALID_STATE_BY_SERVER";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["TRANSCODER_ERROR_AUTHENTICATION_BY_CDN"] = 9] = "TRANSCODER_ERROR_AUTHENTICATION_BY_CDN";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["TRANSCODER_ERROR_TIMEOUT_BY_SIGNALING"] = 10] = "TRANSCODER_ERROR_TIMEOUT_BY_SIGNALING";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["TRANSCODER_ERROR_MIX_IMAGE_FAIL"] = 11] = "TRANSCODER_ERROR_MIX_IMAGE_FAIL";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["TRANSCODER_ERROR_UNKNOW_ERROR_BY_SERVER"] = 12] = "TRANSCODER_ERROR_UNKNOW_ERROR_BY_SERVER";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeOK"] = 13] = "ByteRTCStreamMixingErrorCodeOK";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeBase"] = 14] = "ByteRTCStreamMixingErrorCodeBase";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeInvalidParam"] = 15] = "ByteRTCStreamMixingErrorCodeInvalidParam";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeInvalidState"] = 16] = "ByteRTCStreamMixingErrorCodeInvalidState";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeInvalidOperator"] = 17] = "ByteRTCStreamMixingErrorCodeInvalidOperator";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeTimeOut"] = 18] = "ByteRTCStreamMixingErrorCodeTimeOut";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeInvalidParamByServer"] = 19] = "ByteRTCStreamMixingErrorCodeInvalidParamByServer";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeSubTimeoutByServer"] = 20] = "ByteRTCStreamMixingErrorCodeSubTimeoutByServer";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeInvalidStateByServer"] = 21] = "ByteRTCStreamMixingErrorCodeInvalidStateByServer";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeAuthenticationByCDN"] = 22] = "ByteRTCStreamMixingErrorCodeAuthenticationByCDN";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeTimeoutBySignaling"] = 23] = "ByteRTCStreamMixingErrorCodeTimeoutBySignaling";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeMixImageFail"] = 24] = "ByteRTCStreamMixingErrorCodeMixImageFail";
    RTCStreamMixingErrorCode[RTCStreamMixingErrorCode["ByteRTCStreamMixingErrorCodeUnKnownErrorByServer"] = 25] = "ByteRTCStreamMixingErrorCodeUnKnownErrorByServer";
})(exports.RTCStreamMixingErrorCode || (exports.RTCStreamMixingErrorCode = {}));
exports.RTCScreenVideoEncoderPreference = void 0;
(function (RTCScreenVideoEncoderPreference) {
    RTCScreenVideoEncoderPreference[RTCScreenVideoEncoderPreference["MAINTAIN_FRAMERATE"] = 0] = "MAINTAIN_FRAMERATE";
    RTCScreenVideoEncoderPreference[RTCScreenVideoEncoderPreference["MAINTAIN_QUALITY"] = 1] = "MAINTAIN_QUALITY";
    RTCScreenVideoEncoderPreference[RTCScreenVideoEncoderPreference["DISABLED"] = 2] = "DISABLED";
    RTCScreenVideoEncoderPreference[RTCScreenVideoEncoderPreference["BALANCE"] = 3] = "BALANCE";
})(exports.RTCScreenVideoEncoderPreference || (exports.RTCScreenVideoEncoderPreference = {}));
exports.RTCVideoEncoderPreference = void 0;
(function (RTCVideoEncoderPreference) {
    RTCVideoEncoderPreference[RTCVideoEncoderPreference["DISABLED"] = 0] = "DISABLED";
    RTCVideoEncoderPreference[RTCVideoEncoderPreference["MAINTAIN_FRAMERATE"] = 1] = "MAINTAIN_FRAMERATE";
    RTCVideoEncoderPreference[RTCVideoEncoderPreference["MAINTAIN_QUALITY"] = 2] = "MAINTAIN_QUALITY";
    RTCVideoEncoderPreference[RTCVideoEncoderPreference["BALANCE"] = 3] = "BALANCE";
})(exports.RTCVideoEncoderPreference || (exports.RTCVideoEncoderPreference = {}));
exports.MixedStreamAlternateImageFillMode = void 0;
(function (MixedStreamAlternateImageFillMode) {
    MixedStreamAlternateImageFillMode[MixedStreamAlternateImageFillMode["FIT"] = 0] = "FIT";
    MixedStreamAlternateImageFillMode[MixedStreamAlternateImageFillMode["FILL"] = 1] = "FILL";
})(exports.MixedStreamAlternateImageFillMode || (exports.MixedStreamAlternateImageFillMode = {}));
exports.PauseResumeControlMediaType = void 0;
(function (PauseResumeControlMediaType) {
    PauseResumeControlMediaType[PauseResumeControlMediaType["AUDIO"] = 0] = "AUDIO";
    PauseResumeControlMediaType[PauseResumeControlMediaType["VIDEO"] = 1] = "VIDEO";
    PauseResumeControlMediaType[PauseResumeControlMediaType["AUDIO_AND_VIDEO"] = 2] = "AUDIO_AND_VIDEO";
})(exports.PauseResumeControlMediaType || (exports.PauseResumeControlMediaType = {}));
exports.VideoSourceType = void 0;
(function (VideoSourceType) {
    VideoSourceType[VideoSourceType["VIDEO_SOURCE_TYPE_EXTERNAL"] = 0] = "VIDEO_SOURCE_TYPE_EXTERNAL";
    VideoSourceType[VideoSourceType["VIDEO_SOURCE_TYPE_INTERNAL"] = 1] = "VIDEO_SOURCE_TYPE_INTERNAL";
    VideoSourceType[VideoSourceType["VIDEO_SOURCE_TYPE_ENCODED_WITH_SIMULCAST"] = 2] = "VIDEO_SOURCE_TYPE_ENCODED_WITH_SIMULCAST";
    VideoSourceType[VideoSourceType["VIDEO_SOURCE_TYPE_ENCODED_WITHOUT_SIMULCAST"] = 3] = "VIDEO_SOURCE_TYPE_ENCODED_WITHOUT_SIMULCAST";
})(exports.VideoSourceType || (exports.VideoSourceType = {}));
exports.MessageConfig = void 0;
(function (MessageConfig) {
    MessageConfig[MessageConfig["RELIABLE_ORDERED"] = 0] = "RELIABLE_ORDERED";
    MessageConfig[MessageConfig["UNRELIABLE_ORDERED"] = 1] = "UNRELIABLE_ORDERED";
    MessageConfig[MessageConfig["UNRELIABLE_UNORDERED"] = 2] = "UNRELIABLE_UNORDERED";
})(exports.MessageConfig || (exports.MessageConfig = {}));
var ProblemFeedbackInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ProblemFeedbackInfo_1() {
        }
        Object.defineProperty(ProblemFeedbackInfo_1.prototype, "problemDesc", {
            /** {en}
             * @brief Text description
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.problemDesc);
                }
                else if ($os === 'ios') {
                    return String(this._instance.problemDesc);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.problemDesc = value;
                }
                else if ($os === 'ios') {
                    this._instance.problemDesc = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(ProblemFeedbackInfo_1.prototype, "roomInfo", {
            /** {en}
             * @brief Room info. See {@link ProblemFeedbackRoomInfo ProblemFeedbackRoomInfo}.
             *
             */
            get: function () {
                // TODO: implement
                throw new Error("not implement 'roomInfo'");
            },
            set: function (value) {
                // TODO: implement
                throw new Error("not implement 'roomInfo'");
            },
            enumerable: false,
            configurable: true
        });
        ProblemFeedbackInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        ProblemFeedbackInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCProblemFeedbackInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = ProblemFeedbackInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return ProblemFeedbackInfo_1;
    }());
    __setFunctionName(_classThis, "ProblemFeedbackInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.MediaDeviceType = void 0;
(function (MediaDeviceType) {
    /** {en}
     * @platform android
     * @brief Unknown device
     *
     */
    MediaDeviceType[MediaDeviceType["MEDIA_DEVICE_TYPE_AUDIO_UNKNOWN"] = 0] = "MEDIA_DEVICE_TYPE_AUDIO_UNKNOWN";
    /** {en}
     * @platform android
     * @brief Audio render device
     *
     */
    MediaDeviceType[MediaDeviceType["MEDIA_DEVICE_TYPE_AUDIO_RENDER_DEVICE"] = 1] = "MEDIA_DEVICE_TYPE_AUDIO_RENDER_DEVICE";
    /** {en}
     * @platform android
     * @brief Audio capture device
     *
     */
    MediaDeviceType[MediaDeviceType["MEDIA_DEVICE_TYPE_AUDIO_CAPTURE_DEVICE"] = 2] = "MEDIA_DEVICE_TYPE_AUDIO_CAPTURE_DEVICE";
    /** {en}
     * @platform android
     * @brief Video capture device
     *
     */
    MediaDeviceType[MediaDeviceType["MEDIA_DEVICE_TYPE_VIDEO_CAPTURE_DEVICE"] = 4] = "MEDIA_DEVICE_TYPE_VIDEO_CAPTURE_DEVICE";
    /** {en}
     * @platform android
     * @brief Screen video device
     *
     */
    MediaDeviceType[MediaDeviceType["MEDIA_DEVICE_TYPE_SCREEN_VIDEO_CAPTURE_DEVICE"] = 5] = "MEDIA_DEVICE_TYPE_SCREEN_VIDEO_CAPTURE_DEVICE";
    /** {en}
     * @platform android
     * @brief Screen audio device
     *
     */
    MediaDeviceType[MediaDeviceType["MEDIA_DEVICE_TYPE_SCREEN_AUDIO_CAPTURE_DEVICE"] = 6] = "MEDIA_DEVICE_TYPE_SCREEN_AUDIO_CAPTURE_DEVICE";
    MediaDeviceType[MediaDeviceType["ByteRTCMediaDeviceTypeAudioUnknown"] = 7] = "ByteRTCMediaDeviceTypeAudioUnknown";
    MediaDeviceType[MediaDeviceType["ByteRTCMediaDeviceTypeAudioRenderDevice"] = 8] = "ByteRTCMediaDeviceTypeAudioRenderDevice";
    MediaDeviceType[MediaDeviceType["ByteRTCMediaDeviceTypeAudioCaptureDevice"] = 9] = "ByteRTCMediaDeviceTypeAudioCaptureDevice";
    MediaDeviceType[MediaDeviceType["ByteRTCMediaDeviceTypeVideoCaptureDevice"] = 11] = "ByteRTCMediaDeviceTypeVideoCaptureDevice";
    MediaDeviceType[MediaDeviceType["ByteRTCMediaDeviceTypeScreenVideoCaptureDevice"] = 12] = "ByteRTCMediaDeviceTypeScreenVideoCaptureDevice";
    MediaDeviceType[MediaDeviceType["ByteRTCMediaDeviceTypeScreenAudioCaptureDevice"] = 13] = "ByteRTCMediaDeviceTypeScreenAudioCaptureDevice";
})(exports.MediaDeviceType || (exports.MediaDeviceType = {}));
var UserInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function UserInfo_1() {
        }
        Object.defineProperty(UserInfo_1.prototype, "userId", {
            /** {en}
             * @brief User ID. The string matches the regular expression: `[a-zA-Z0-9_\@\\-\\.]{1,128}`. <br>
             *        You must set or manage the uid yourself and ensure that each uid within the same room is unique.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.uid);
                }
                else if ($os === 'ios') {
                    return String(this._instance.userId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.uid = value;
                }
                else if ($os === 'ios') {
                    this._instance.userId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(UserInfo_1.prototype, "extraInfo", {
            /** {en}
             * @brief Additional information of the user. The maximum length is 200 bytes. The remote user will receive the info in `onUserJoined`.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.extraInfo);
                }
                else if ($os === 'ios') {
                    return String(this._instance.extraInfo);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.extraInfo = value;
                }
                else if ($os === 'ios') {
                    this._instance.extraInfo = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        UserInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        UserInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCUserInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = UserInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return UserInfo_1;
    }());
    __setFunctionName(_classThis, "UserInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.ForwardStreamEvent = void 0;
(function (ForwardStreamEvent) {
    ForwardStreamEvent[ForwardStreamEvent["FORWARD_STREAM_EVENT_DISCONNECTED"] = 0] = "FORWARD_STREAM_EVENT_DISCONNECTED";
    ForwardStreamEvent[ForwardStreamEvent["FORWARD_STREAM_EVENT_CONNECTED"] = 1] = "FORWARD_STREAM_EVENT_CONNECTED";
    ForwardStreamEvent[ForwardStreamEvent["FORWARD_STREAM_EVENT_DST_ROOM_UPDATED"] = 2] = "FORWARD_STREAM_EVENT_DST_ROOM_UPDATED";
    ForwardStreamEvent[ForwardStreamEvent["FORWARD_STREAM_EVENT_UN_EXPECT_API_CALL"] = 3] = "FORWARD_STREAM_EVENT_UN_EXPECT_API_CALL";
    ForwardStreamEvent[ForwardStreamEvent["FORWARD_STREAM_EVENT_INTERRUPT"] = 4] = "FORWARD_STREAM_EVENT_INTERRUPT";
    ForwardStreamEvent[ForwardStreamEvent["ByteRTCForwardStreamEventInterrupt"] = 5] = "ByteRTCForwardStreamEventInterrupt";
})(exports.ForwardStreamEvent || (exports.ForwardStreamEvent = {}));
exports.SubscribeMediaType = void 0;
(function (SubscribeMediaType) {
    SubscribeMediaType[SubscribeMediaType["NONE"] = 0] = "NONE";
    SubscribeMediaType[SubscribeMediaType["AUDIO_ONLY"] = 1] = "AUDIO_ONLY";
    SubscribeMediaType[SubscribeMediaType["VIDEO_ONLY"] = 2] = "VIDEO_ONLY";
    SubscribeMediaType[SubscribeMediaType["AUDIO_AND_VIDEO"] = 3] = "AUDIO_AND_VIDEO";
})(exports.SubscribeMediaType || (exports.SubscribeMediaType = {}));
exports.ConnectionState = void 0;
(function (ConnectionState) {
    ConnectionState[ConnectionState["CONNECTION_STATE_DISCONNECTED"] = 0] = "CONNECTION_STATE_DISCONNECTED";
    ConnectionState[ConnectionState["CONNECTION_STATE_CONNECTING"] = 1] = "CONNECTION_STATE_CONNECTING";
    ConnectionState[ConnectionState["CONNECTION_STATE_CONNECTED"] = 2] = "CONNECTION_STATE_CONNECTED";
    ConnectionState[ConnectionState["CONNECTION_STATE_RECONNECTING"] = 3] = "CONNECTION_STATE_RECONNECTING";
    ConnectionState[ConnectionState["CONNECTION_STATE_RECONNECTED"] = 4] = "CONNECTION_STATE_RECONNECTED";
    ConnectionState[ConnectionState["CONNECTION_STATE_LOST"] = 5] = "CONNECTION_STATE_LOST";
    ConnectionState[ConnectionState["CONNECTION_STATE_FAILED"] = 6] = "CONNECTION_STATE_FAILED";
})(exports.ConnectionState || (exports.ConnectionState = {}));
exports.RecordingType = void 0;
(function (RecordingType) {
    RecordingType[RecordingType["RECORD_AUDIO_ONLY"] = 0] = "RECORD_AUDIO_ONLY";
    RecordingType[RecordingType["RECORD_VIDEO_ONLY"] = 1] = "RECORD_VIDEO_ONLY";
    RecordingType[RecordingType["RECORD_VIDEO_AND_AUDIO"] = 2] = "RECORD_VIDEO_AND_AUDIO";
    RecordingType[RecordingType["ByteRTCRecordingTypeAudioOnly"] = 3] = "ByteRTCRecordingTypeAudioOnly";
    RecordingType[RecordingType["ByteRTCRecordingTypeVideoOnly"] = 4] = "ByteRTCRecordingTypeVideoOnly";
    RecordingType[RecordingType["ByteRTCRecordingTypeVideoAndAudio"] = 5] = "ByteRTCRecordingTypeVideoAndAudio";
})(exports.RecordingType || (exports.RecordingType = {}));
exports.BandFrequency = void 0;
(function (BandFrequency) {
    BandFrequency[BandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_31"] = 0] = "VOICE_EQUALIZATION_BAND_FREQUENCY_31";
    BandFrequency[BandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_62"] = 1] = "VOICE_EQUALIZATION_BAND_FREQUENCY_62";
    BandFrequency[BandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_125"] = 2] = "VOICE_EQUALIZATION_BAND_FREQUENCY_125";
    BandFrequency[BandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_250"] = 3] = "VOICE_EQUALIZATION_BAND_FREQUENCY_250";
    BandFrequency[BandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_500"] = 4] = "VOICE_EQUALIZATION_BAND_FREQUENCY_500";
    BandFrequency[BandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_1K"] = 5] = "VOICE_EQUALIZATION_BAND_FREQUENCY_1K";
    BandFrequency[BandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_2K"] = 6] = "VOICE_EQUALIZATION_BAND_FREQUENCY_2K";
    BandFrequency[BandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_4K"] = 7] = "VOICE_EQUALIZATION_BAND_FREQUENCY_4K";
    BandFrequency[BandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_8K"] = 8] = "VOICE_EQUALIZATION_BAND_FREQUENCY_8K";
    BandFrequency[BandFrequency["VOICE_EQUALIZATION_BAND_FREQUENCY_16K"] = 9] = "VOICE_EQUALIZATION_BAND_FREQUENCY_16K";
    BandFrequency[BandFrequency["ByteRTCBandFrequency31"] = 10] = "ByteRTCBandFrequency31";
    BandFrequency[BandFrequency["ByteRTCBandFrequency62"] = 11] = "ByteRTCBandFrequency62";
    BandFrequency[BandFrequency["ByteRTCBandFrequency125"] = 12] = "ByteRTCBandFrequency125";
    BandFrequency[BandFrequency["ByteRTCBandFrequency250"] = 13] = "ByteRTCBandFrequency250";
    BandFrequency[BandFrequency["ByteRTCBandFrequency500"] = 14] = "ByteRTCBandFrequency500";
    BandFrequency[BandFrequency["ByteRTCBandFrequency1k"] = 15] = "ByteRTCBandFrequency1k";
    BandFrequency[BandFrequency["ByteRTCBandFrequency2k"] = 16] = "ByteRTCBandFrequency2k";
    BandFrequency[BandFrequency["ByteRTCBandFrequency4k"] = 17] = "ByteRTCBandFrequency4k";
    BandFrequency[BandFrequency["ByteRTCBandFrequency8k"] = 18] = "ByteRTCBandFrequency8k";
    BandFrequency[BandFrequency["ByteRTCBandFrequency16k"] = 19] = "ByteRTCBandFrequency16k";
})(exports.BandFrequency || (exports.BandFrequency = {}));
exports.MixedStreamPushMode = void 0;
(function (MixedStreamPushMode) {
    MixedStreamPushMode[MixedStreamPushMode["ON_STREAM"] = 0] = "ON_STREAM";
    MixedStreamPushMode[MixedStreamPushMode["ON_START_REQUEST"] = 1] = "ON_START_REQUEST";
})(exports.MixedStreamPushMode || (exports.MixedStreamPushMode = {}));
exports.EarMonitorMode = void 0;
(function (EarMonitorMode) {
    EarMonitorMode[EarMonitorMode["EAR_MONITOR_MODE_OFF"] = 0] = "EAR_MONITOR_MODE_OFF";
    EarMonitorMode[EarMonitorMode["EAR_MONITOR_MODE_ON"] = 1] = "EAR_MONITOR_MODE_ON";
})(exports.EarMonitorMode || (exports.EarMonitorMode = {}));
exports.FirstFrameSendState = void 0;
(function (FirstFrameSendState) {
    FirstFrameSendState[FirstFrameSendState["FIRST_FRAME_SEND_STATE_SENDING"] = 0] = "FIRST_FRAME_SEND_STATE_SENDING";
    FirstFrameSendState[FirstFrameSendState["FIRST_FRAME_SEND_STATE_SENT"] = 1] = "FIRST_FRAME_SEND_STATE_SENT";
    FirstFrameSendState[FirstFrameSendState["FIRST_FRAME_SEND_STAT_END"] = 2] = "FIRST_FRAME_SEND_STAT_END";
})(exports.FirstFrameSendState || (exports.FirstFrameSendState = {}));
exports.MixedStreamMediaType = void 0;
(function (MixedStreamMediaType) {
    MixedStreamMediaType[MixedStreamMediaType["MIXED_STREAM_MEDIA_TYPE_AUDIO_AND_VIDEO"] = 0] = "MIXED_STREAM_MEDIA_TYPE_AUDIO_AND_VIDEO";
    MixedStreamMediaType[MixedStreamMediaType["MIXED_STREAM_MEDIA_TYPE_AUDIO_ONLY"] = 1] = "MIXED_STREAM_MEDIA_TYPE_AUDIO_ONLY";
    MixedStreamMediaType[MixedStreamMediaType["MIXED_STREAM_MEDIA_TYPE_VIDEO_ONLY"] = 2] = "MIXED_STREAM_MEDIA_TYPE_VIDEO_ONLY";
})(exports.MixedStreamMediaType || (exports.MixedStreamMediaType = {}));
exports.SubtitleMode = void 0;
(function (SubtitleMode) {
    SubtitleMode[SubtitleMode["SUBTITLE_MODE_TRANSLATION"] = 0] = "SUBTITLE_MODE_TRANSLATION";
    SubtitleMode[SubtitleMode["SUBTITLE_MODE_RECOGINTE"] = 1] = "SUBTITLE_MODE_RECOGINTE";
    SubtitleMode[SubtitleMode["ByteRTCSubtitleModeRecognition"] = 2] = "ByteRTCSubtitleModeRecognition";
})(exports.SubtitleMode || (exports.SubtitleMode = {}));
var SourceWantedData = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function SourceWantedData_1() {
        }
        Object.defineProperty(SourceWantedData_1.prototype, "width", {
            /** {en}
             * @brief If send performance fallback is not turned on, this value represents the recommended video input width; <br>
             *         If send performance fallback is turned on, this value represents the maximum width of the current push stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.width);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.width);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.width = value;
                }
                else if ($os === 'ios') {
                    this._instance.width = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SourceWantedData_1.prototype, "height", {
            /** {en}
             * @brief If send performance fallback is not turned on, this value represents the recommended video input height; <br>
             *         If send performance fallback is turned on, this value represents the maximum height of the current push stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.height);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.height);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.height = value;
                }
                else if ($os === 'ios') {
                    this._instance.height = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SourceWantedData_1.prototype, "frameRate", {
            /** {en}
             * @brief If send performance fallback is not turned on, this value represents the recommended video input frame rate in fps; <br>
             *         If send performance fallback is turned on, this value represents the maximum frame rate of the current push stream in fps.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.frameRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.frameRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.frameRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.frameRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        SourceWantedData_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        SourceWantedData_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCSourceWantedData).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = SourceWantedData$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return SourceWantedData_1;
    }());
    __setFunctionName(_classThis, "SourceWantedData");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.VoiceChangerType = void 0;
(function (VoiceChangerType) {
    VoiceChangerType[VoiceChangerType["VOICE_CHANGER_ORIGINAL"] = 0] = "VOICE_CHANGER_ORIGINAL";
    VoiceChangerType[VoiceChangerType["VOICE_CHANGER_GIANT"] = 1] = "VOICE_CHANGER_GIANT";
    VoiceChangerType[VoiceChangerType["VOICE_CHANGER_CHIPMUNK"] = 2] = "VOICE_CHANGER_CHIPMUNK";
    VoiceChangerType[VoiceChangerType["VOICE_CHANGER_MINIONST"] = 3] = "VOICE_CHANGER_MINIONST";
    VoiceChangerType[VoiceChangerType["VOICE_CHANGER_VIBRATO"] = 4] = "VOICE_CHANGER_VIBRATO";
    VoiceChangerType[VoiceChangerType["VOICE_CHANGER_ROBOT"] = 5] = "VOICE_CHANGER_ROBOT";
})(exports.VoiceChangerType || (exports.VoiceChangerType = {}));
exports.EffectBeautyMode = void 0;
(function (EffectBeautyMode) {
    EffectBeautyMode[EffectBeautyMode["WHITE"] = 0] = "WHITE";
    EffectBeautyMode[EffectBeautyMode["SMOOTH"] = 1] = "SMOOTH";
    EffectBeautyMode[EffectBeautyMode["SHARPEN"] = 2] = "SHARPEN";
    EffectBeautyMode[EffectBeautyMode["CLEAR"] = 3] = "CLEAR";
})(exports.EffectBeautyMode || (exports.EffectBeautyMode = {}));
var Orientation = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function Orientation_1() {
        }
        Object.defineProperty(Orientation_1.prototype, "x", {
            /** {en}
             * @brief X-coordinate
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.x);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.x);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.x = value;
                }
                else if ($os === 'ios') {
                    this._instance.x = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Orientation_1.prototype, "y", {
            /** {en}
             * @brief Y-coordinate
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.y);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.y);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.y = value;
                }
                else if ($os === 'ios') {
                    this._instance.y = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Orientation_1.prototype, "z", {
            /** {en}
             * @brief Z-coordinate
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.z);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.z);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.z = value;
                }
                else if ($os === 'ios') {
                    this._instance.z = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Orientation_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        Orientation_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCOrientation).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = Orientation$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return Orientation_1;
    }());
    __setFunctionName(_classThis, "Orientation");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.MusicHotType = void 0;
(function (MusicHotType) {
    MusicHotType[MusicHotType["CONTENT_CENTER"] = 0] = "CONTENT_CENTER";
    MusicHotType[MusicHotType["PROJECT"] = 1] = "PROJECT";
})(exports.MusicHotType || (exports.MusicHotType = {}));
exports.MixedStreamAudioCodecType = void 0;
(function (MixedStreamAudioCodecType) {
    MixedStreamAudioCodecType[MixedStreamAudioCodecType["MIXED_STREAM_AUDIO_CODEC_TYPE_AAC"] = 0] = "MIXED_STREAM_AUDIO_CODEC_TYPE_AAC";
})(exports.MixedStreamAudioCodecType || (exports.MixedStreamAudioCodecType = {}));
exports.LocalLogLevel = void 0;
(function (LocalLogLevel) {
    LocalLogLevel[LocalLogLevel["INFO"] = 0] = "INFO";
    LocalLogLevel[LocalLogLevel["WARNING"] = 1] = "WARNING";
    LocalLogLevel[LocalLogLevel["ERROR"] = 2] = "ERROR";
    LocalLogLevel[LocalLogLevel["NONE"] = 3] = "NONE";
})(exports.LocalLogLevel || (exports.LocalLogLevel = {}));
exports.ForwardStreamState = void 0;
(function (ForwardStreamState) {
    ForwardStreamState[ForwardStreamState["FORWARD_STREAM_STATE_SUCCESS"] = 0] = "FORWARD_STREAM_STATE_SUCCESS";
    ForwardStreamState[ForwardStreamState["FORWARD_STREAM_STATE_FAILURE"] = 1] = "FORWARD_STREAM_STATE_FAILURE";
    ForwardStreamState[ForwardStreamState["FORWARD_STREAM_STATE_IDLE"] = 2] = "FORWARD_STREAM_STATE_IDLE";
    ForwardStreamState[ForwardStreamState["ByteRTCForwardStreamStateIdle"] = 3] = "ByteRTCForwardStreamStateIdle";
})(exports.ForwardStreamState || (exports.ForwardStreamState = {}));
exports.TorchState = void 0;
(function (TorchState) {
    TorchState[TorchState["TORCH_STATE_OFF"] = 0] = "TORCH_STATE_OFF";
    TorchState[TorchState["TORCH_STATE_ON"] = 1] = "TORCH_STATE_ON";
})(exports.TorchState || (exports.TorchState = {}));
exports.VideoCodecType = void 0;
(function (VideoCodecType) {
    VideoCodecType[VideoCodecType["VIDEO_CODEC_TYPE_H264"] = 0] = "VIDEO_CODEC_TYPE_H264";
    VideoCodecType[VideoCodecType["VIDEO_CODEC_TYPE_BYTEVC1"] = 1] = "VIDEO_CODEC_TYPE_BYTEVC1";
    VideoCodecType[VideoCodecType["ByteRTCVideoCodecTypeUnknown"] = 2] = "ByteRTCVideoCodecTypeUnknown";
})(exports.VideoCodecType || (exports.VideoCodecType = {}));
var RTCASRConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RTCASRConfig_1() {
        }
        Object.defineProperty(RTCASRConfig_1.prototype, "userId", {
            /** {en}
             * @brief User ID
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.userId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.userId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.userId = value;
                }
                else if ($os === 'ios') {
                    this._instance.userId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCASRConfig_1.prototype, "accessToken", {
            /** {en}
             * @brief Access token
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.accessToken);
                }
                else if ($os === 'ios') {
                    return String(this._instance.accessToken);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.accessToken = value;
                }
                else if ($os === 'ios') {
                    this._instance.accessToken = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCASRConfig_1.prototype, "secretKey", {
            /** {en}
             * @brief Private key. Signature  cannot be empty in authentication mode, and it is empty in token authentication mode. See [Authentication Method](https://docs.byteplus.com/speech/docs/authentication-method).
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.secretKey);
                }
                else if ($os === 'ios') {
                    return String(this._instance.secretKey);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.secretKey = value;
                }
                else if ($os === 'ios') {
                    this._instance.secretKey = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCASRConfig_1.prototype, "authorizationType", {
            /** {en}
             * @brief Authentication method
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_ASRAuthorizationType.android_to_ts(this._instance.authorizationType);
                }
                else if ($os === 'ios') {
                    return t_ASRAuthorizationType.ios_to_ts(this._instance.authorizationType);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.authorizationType = t_ASRAuthorizationType.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.authorizationType = t_ASRAuthorizationType.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCASRConfig_1.prototype, "cluster", {
            /** {en}
             * @brief Scene information. See [business cluster](https://docs.byteplus.com/en/speech/docs/real-time-speech-recog)
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.cluster);
                }
                else if ($os === 'ios') {
                    return String(this._instance.cluster);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.cluster = value;
                }
                else if ($os === 'ios') {
                    this._instance.cluster = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCASRConfig_1.prototype, "appId", {
            /** {en}
             * @brief Application ID
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.appId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.appId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.appId = value;
                }
                else if ($os === 'ios') {
                    this._instance.appId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        RTCASRConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RTCASRConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCASRConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RTCASRConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RTCASRConfig_1;
    }());
    __setFunctionName(_classThis, "RTCASRConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.RTCASRErrorCode = void 0;
(function (RTCASRErrorCode) {
    RTCASRErrorCode[RTCASRErrorCode["NETWORK_INTERRUPTED"] = 0] = "NETWORK_INTERRUPTED";
    RTCASRErrorCode[RTCASRErrorCode["ALREADY_STARTED"] = 1] = "ALREADY_STARTED";
    RTCASRErrorCode[RTCASRErrorCode["TOKEN_EMPTY"] = 2] = "TOKEN_EMPTY";
    RTCASRErrorCode[RTCASRErrorCode["SIGNATURE_KEY_EMPTY"] = 3] = "SIGNATURE_KEY_EMPTY";
    RTCASRErrorCode[RTCASRErrorCode["USERID_NULL"] = 4] = "USERID_NULL";
    RTCASRErrorCode[RTCASRErrorCode["APPID_NULL"] = 5] = "APPID_NULL";
    RTCASRErrorCode[RTCASRErrorCode["CLUSTER_NULL"] = 6] = "CLUSTER_NULL";
    RTCASRErrorCode[RTCASRErrorCode["OPERATION_DENIED"] = 7] = "OPERATION_DENIED";
    RTCASRErrorCode[RTCASRErrorCode["ByteRTCASRErrorNetworkInterrupted"] = 8] = "ByteRTCASRErrorNetworkInterrupted";
    RTCASRErrorCode[RTCASRErrorCode["ByteRTCASRErrorAlreadyStarted"] = 9] = "ByteRTCASRErrorAlreadyStarted";
    RTCASRErrorCode[RTCASRErrorCode["ByteRTCASRErrorTokenEmpty"] = 10] = "ByteRTCASRErrorTokenEmpty";
    RTCASRErrorCode[RTCASRErrorCode["ByteRTCErrorSignatureKeyEmpty"] = 11] = "ByteRTCErrorSignatureKeyEmpty";
    RTCASRErrorCode[RTCASRErrorCode["ByteRTCASRErrorUserIdNull"] = 12] = "ByteRTCASRErrorUserIdNull";
    RTCASRErrorCode[RTCASRErrorCode["ByteRTCASRErrorAPPIDNull"] = 13] = "ByteRTCASRErrorAPPIDNull";
    RTCASRErrorCode[RTCASRErrorCode["ByteRTCASRErrorClusterNull"] = 14] = "ByteRTCASRErrorClusterNull";
    RTCASRErrorCode[RTCASRErrorCode["ByteRTCASRErrorOperationDenied"] = 15] = "ByteRTCASRErrorOperationDenied";
})(exports.RTCASRErrorCode || (exports.RTCASRErrorCode = {}));
var ForwardStreamEventInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ForwardStreamEventInfo_1() {
        }
        Object.defineProperty(ForwardStreamEventInfo_1.prototype, "roomId", {
            /** {en}
             * @brief ID of the room where the media stream aims to relay to <br>
             *        An Empty string is for all rooms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.roomId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.roomId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.roomId = value;
                }
                else if ($os === 'ios') {
                    this._instance.roomId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(ForwardStreamEventInfo_1.prototype, "event", {
            /** {en}
             * @brief Event from the room during relaying.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_ForwardStreamEvent.android_to_ts(this._instance.event);
                }
                else if ($os === 'ios') {
                    return t_ForwardStreamEvent.ios_to_ts(this._instance.event);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.event = t_ForwardStreamEvent.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.event = t_ForwardStreamEvent.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        ForwardStreamEventInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        ForwardStreamEventInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCForwardStreamEventInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = ForwardStreamEventInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return ForwardStreamEventInfo_1;
    }());
    __setFunctionName(_classThis, "ForwardStreamEventInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RecordingConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RecordingConfig_1() {
        }
        Object.defineProperty(RecordingConfig_1.prototype, "dirPath", {
            /** {en}
             * @brief The absolute folder path to save the recording file.The filename will be generated by RTC. You need to ensure that you have read and write permissions to this path.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.dirPath);
                }
                else if ($os === 'ios') {
                    return String(this._instance.dirPath);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.dirPath = value;
                }
                else if ($os === 'ios') {
                    this._instance.dirPath = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RecordingConfig_1.prototype, "recordingFileType", {
            /** {en}
             * @brief Recording stored file format. See {@link RecordingFileType RecordingFileType}
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_RecordingFileType.android_to_ts(this._instance.recordingFileType);
                }
                else if ($os === 'ios') {
                    return t_RecordingFileType.ios_to_ts(this._instance.recordingFileType);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.recordingFileType = t_RecordingFileType.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.recordingFileType = t_RecordingFileType.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        RecordingConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RecordingConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRecordingConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RecordingConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RecordingConfig_1;
    }());
    __setFunctionName(_classThis, "RecordingConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoCaptureConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function VideoCaptureConfig_1() {
        }
        Object.defineProperty(VideoCaptureConfig_1.prototype, "android_capturePreference", {
            /** {en}
             * @platform android
             * @brief Video capture preference. See {@link CapturePreference CapturePreference}.
             *
             */
            get: function () {
                return this._instance.capturePreference;
            },
            set: function (value) {
                this._instance.capturePreference = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoCaptureConfig_1.prototype, "android_width", {
            /** {en}
             * @platform android
             * @brief The width of video capture resolution in px.
             *
             */
            get: function () {
                return this._instance.width;
            },
            set: function (value) {
                this._instance.width = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoCaptureConfig_1.prototype, "android_height", {
            /** {en}
             * @platform android
             * @brief The height of video capture resolution in px.
             *
             */
            get: function () {
                return this._instance.height;
            },
            set: function (value) {
                this._instance.height = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoCaptureConfig_1.prototype, "frameRate", {
            /** {en}
             * @brief Video capture frame rate in fps.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.frameRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.frameRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.frameRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.frameRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoCaptureConfig_1.prototype, "ios_preference", {
            /** {en}
             * @platform ios
             * @brief Video capture preference. See {@link ByteRTCVideoCapturePreference ByteRTCVideoCapturePreference}
             */
            get: function () {
                return this._instance.preference;
            },
            set: function (value) {
                this._instance.preference = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoCaptureConfig_1.prototype, "ios_videoSize", {
            /** {en}
             * @platform ios
             * @brief Video capture resolution
             */
            get: function () {
                return this._instance.videoSize;
            },
            set: function (value) {
                this._instance.videoSize = value;
            },
            enumerable: false,
            configurable: true
        });
        VideoCaptureConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        VideoCaptureConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCVideoCaptureConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = VideoCaptureConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return VideoCaptureConfig_1;
    }());
    __setFunctionName(_classThis, "VideoCaptureConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var HumanOrientation = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function HumanOrientation_1() {
        }
        Object.defineProperty(HumanOrientation_1.prototype, "forward", {
            /** {en}
             * @brief Forward orientation, the default value is `{1,0,0}`, i.e., the forward orientation is in the positive direction of x-axis.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return packObject(this._instance.forward, Orientation);
                }
                else if ($os === 'ios') {
                    return packObject(this._instance.forward, Orientation);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.forward = unpackObject(value);
                }
                else if ($os === 'ios') {
                    this._instance.forward = unpackObject(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(HumanOrientation_1.prototype, "right", {
            /** {en}
             * @brief Rightward orientation, the default value is `{0,1,0}`, i.e., the rightward orientation is in the positive direction of y-axis.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return packObject(this._instance.right, Orientation);
                }
                else if ($os === 'ios') {
                    return packObject(this._instance.right, Orientation);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.right = unpackObject(value);
                }
                else if ($os === 'ios') {
                    this._instance.right = unpackObject(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(HumanOrientation_1.prototype, "up", {
            /** {en}
             * @brief Upward orientation, the default value is `{0,0,1}`, i.e., the upward orientation is in the positive direction of z-axis.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return packObject(this._instance.up, Orientation);
                }
                else if ($os === 'ios') {
                    return packObject(this._instance.up, Orientation);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.up = unpackObject(value);
                }
                else if ($os === 'ios') {
                    this._instance.up = unpackObject(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        HumanOrientation_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        HumanOrientation_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCHumanOrientation).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = HumanOrientation$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return HumanOrientation_1;
    }());
    __setFunctionName(_classThis, "HumanOrientation");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var LocalAudioPropertiesInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function LocalAudioPropertiesInfo_1() {
        }
        Object.defineProperty(LocalAudioPropertiesInfo_1.prototype, "streamIndex", {
            /** {en}
             * @brief Refer to [StreamIndex](#streamindex-2) for details.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_StreamIndex.android_to_ts(this._instance.streamIndex);
                }
                else if ($os === 'ios') {
                    return t_StreamIndex.ios_to_ts(this._instance.streamIndex);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.streamIndex = t_StreamIndex.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.streamIndex = t_StreamIndex.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalAudioPropertiesInfo_1.prototype, "audioPropertiesInfo", {
            /** {en}
             * @detail keytype
             * @brief See {@link AudioPropertiesInfo AudioPropertiesInfo}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return packObject(this._instance.audioPropertiesInfo, AudioPropertiesInfo);
                }
                else if ($os === 'ios') {
                    return packObject(this._instance.audioPropertiesInfo, AudioPropertiesInfo);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.audioPropertiesInfo = unpackObject(value);
                }
                else if ($os === 'ios') {
                    this._instance.audioPropertiesInfo = unpackObject(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        LocalAudioPropertiesInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        LocalAudioPropertiesInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCLocalAudioPropertiesInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = LocalAudioPropertiesInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return LocalAudioPropertiesInfo_1;
    }());
    __setFunctionName(_classThis, "LocalAudioPropertiesInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.ByteRTCStreamMixingEvent = void 0;
(function (ByteRTCStreamMixingEvent) {
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_START"] = 0] = "STREAM_MIXING_START";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_START_SUCCESS"] = 1] = "STREAM_MIXING_START_SUCCESS";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_START_FAILED"] = 2] = "STREAM_MIXING_START_FAILED";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_UPDATE"] = 3] = "STREAM_MIXING_UPDATE";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_UPDATE_SUCCESS"] = 4] = "STREAM_MIXING_UPDATE_SUCCESS";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_UPDATE_FAILED"] = 5] = "STREAM_MIXING_UPDATE_FAILED";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_STOP"] = 6] = "STREAM_MIXING_STOP";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_STOP_SUCCESS"] = 7] = "STREAM_MIXING_STOP_SUCCESS";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_STOP_FAILED"] = 8] = "STREAM_MIXING_STOP_FAILED";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_CHANGE_MIX_TYPE"] = 9] = "STREAM_MIXING_CHANGE_MIX_TYPE";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_FIRST_AUDIO_FRAME_BY_CLIENT_MIX"] = 10] = "STREAM_MIXING_FIRST_AUDIO_FRAME_BY_CLIENT_MIX";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_FIRST_VIDEO_FRAME_BY_CLIENT_MIX"] = 11] = "STREAM_MIXING_FIRST_VIDEO_FRAME_BY_CLIENT_MIX";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_UPDATE_TIMEOUT"] = 12] = "STREAM_MIXING_UPDATE_TIMEOUT";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_START_TIMEOUT"] = 13] = "STREAM_MIXING_START_TIMEOUT";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_REQUEST_PARAM_ERROR"] = 14] = "STREAM_MIXING_REQUEST_PARAM_ERROR";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["STREAM_MIXING_MIX_IMAGE_EVENT"] = 15] = "STREAM_MIXING_MIX_IMAGE_EVENT";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStart"] = 17] = "ByteRTCStreamMixingEventStart";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStartSuccess"] = 18] = "ByteRTCStreamMixingEventStartSuccess";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStartFailed"] = 19] = "ByteRTCStreamMixingEventStartFailed";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventUpdate"] = 20] = "ByteRTCStreamMixingEventUpdate";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventUpdateSuccess"] = 21] = "ByteRTCStreamMixingEventUpdateSuccess";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventUpdateFailed"] = 22] = "ByteRTCStreamMixingEventUpdateFailed";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStop"] = 23] = "ByteRTCStreamMixingEventStop";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStopSuccess"] = 24] = "ByteRTCStreamMixingEventStopSuccess";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStopFailed"] = 25] = "ByteRTCStreamMixingEventStopFailed";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventChangeMixType"] = 26] = "ByteRTCStreamMixingEventChangeMixType";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventFirstAudioFrameByClientMixer"] = 27] = "ByteRTCStreamMixingEventFirstAudioFrameByClientMixer";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventFirstVideoFrameByClientMixer"] = 28] = "ByteRTCStreamMixingEventFirstVideoFrameByClientMixer";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventUpdateTimeout"] = 29] = "ByteRTCStreamMixingEventUpdateTimeout";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventStartTimeout"] = 30] = "ByteRTCStreamMixingEventStartTimeout";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventRequestParamError"] = 31] = "ByteRTCStreamMixingEventRequestParamError";
    ByteRTCStreamMixingEvent[ByteRTCStreamMixingEvent["ByteRTCStreamMixingEventMixImage"] = 32] = "ByteRTCStreamMixingEventMixImage";
})(exports.ByteRTCStreamMixingEvent || (exports.ByteRTCStreamMixingEvent = {}));
exports.AudioAlignmentMode = void 0;
(function (AudioAlignmentMode) {
    AudioAlignmentMode[AudioAlignmentMode["AUDIO_ALIGNMENT_MODE_OFF"] = 0] = "AUDIO_ALIGNMENT_MODE_OFF";
    AudioAlignmentMode[AudioAlignmentMode["AUDIO_ALIGNMENT_MODE_AUDIOMIXING"] = 1] = "AUDIO_ALIGNMENT_MODE_AUDIOMIXING";
})(exports.AudioAlignmentMode || (exports.AudioAlignmentMode = {}));
exports.FallbackOrRecoverReason = void 0;
(function (FallbackOrRecoverReason) {
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_UNKNOWN"] = 0] = "FALLBACK_OR_RECOVER_REASON_UNKNOWN";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_BANDWIDTH"] = 1] = "FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_BANDWIDTH";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_PERFORMANCE"] = 2] = "FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_PERFORMANCE";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_BANDWIDTH"] = 3] = "FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_BANDWIDTH";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_PERFORMANCE"] = 4] = "FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_PERFORMANCE";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_BANDWIDTH"] = 5] = "FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_BANDWIDTH";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_PERFORMANCE"] = 6] = "FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_PERFORMANCE";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_BANDWIDTH"] = 7] = "FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_BANDWIDTH";
    FallbackOrRecoverReason[FallbackOrRecoverReason["FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_PERFORMANCE"] = 8] = "FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_PERFORMANCE";
})(exports.FallbackOrRecoverReason || (exports.FallbackOrRecoverReason = {}));
var RemoteStreamStats = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RemoteStreamStats_1() {
        }
        Object.defineProperty(RemoteStreamStats_1.prototype, "uid", {
            /** {en}
             * @brief User ID. The remote user ID of the audio/video source.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.uid);
                }
                else if ($os === 'ios') {
                    return String(this._instance.uid);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.uid = value;
                }
                else if ($os === 'ios') {
                    this._instance.uid = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamStats_1.prototype, "audioStats", {
            /** {en}
             * @brief For statistics on remote audio streams. See {@link RemoteAudioStats RemoteAudioStats}
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return packObject(this._instance.audioStats, RemoteAudioStats);
                }
                else if ($os === 'ios') {
                    return packObject(this._instance.audioStats, RemoteAudioStats);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.audioStats = unpackObject(value);
                }
                else if ($os === 'ios') {
                    this._instance.audioStats = unpackObject(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamStats_1.prototype, "videoStats", {
            /** {en}
             * @brief For statistics on remote video streams. See {@link RemoteVideoStats RemoteVideoStats}
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return packObject(this._instance.videoStats, RemoteVideoStats);
                }
                else if ($os === 'ios') {
                    return packObject(this._instance.videoStats, RemoteVideoStats);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.videoStats = unpackObject(value);
                }
                else if ($os === 'ios') {
                    this._instance.videoStats = unpackObject(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamStats_1.prototype, "isScreen", {
            /** {en}
             * @brief Whether the media stream belongs to the user is a screen stream. You can know whether the current statistics come from mainstream or screen stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.isScreen;
                }
                else if ($os === 'ios') {
                    return this._instance.isScreen;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.isScreen = value;
                }
                else if ($os === 'ios') {
                    this._instance.isScreen = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamStats_1.prototype, "txQuality", {
            /** {en}
             * @brief For the uplink network quality of the media stream owned by the user. See {@link NetworkQuality NetworkQuality}.
             * @deprecated since 3.45 and will be deleted in 3.51, use {@link onNetworkQuality onNetworkQuality} instead.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_NetworkQuality.android_to_ts(this._instance.txQuality);
                }
                else if ($os === 'ios') {
                    return t_NetworkQuality.ios_to_ts(this._instance.txQuality);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.txQuality = t_NetworkQuality.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.txQuality = t_NetworkQuality.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamStats_1.prototype, "rxQuality", {
            /** {en}
             * @brief The downlink network quality of the media stream belongs to the user. See {@link NetworkQuality NetworkQuality}.
             * @deprecated since 3.45 and will be deleted in 3.51, use {@link onNetworkQuality onNetworkQuality} instead.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_NetworkQuality.android_to_ts(this._instance.rxQuality);
                }
                else if ($os === 'ios') {
                    return t_NetworkQuality.ios_to_ts(this._instance.rxQuality);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rxQuality = t_NetworkQuality.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.rxQuality = t_NetworkQuality.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        RemoteStreamStats_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RemoteStreamStats_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRemoteStreamStats).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RemoteStreamStats$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RemoteStreamStats_1;
    }());
    __setFunctionName(_classThis, "RemoteStreamStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.MediaDeviceWarning = void 0;
(function (MediaDeviceWarning) {
    /** {en}
     * @platform android
     * @brief No warning
     *
     */
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_OK"] = 0] = "MEDIA_DEVICE_WARNING_OK";
    /** {en}
     * @platform android
     * @brief Illegal device operation. Calls the API for internal device when using the external device.
     *
     */
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_OPERATION_DENIED"] = 1] = "MEDIA_DEVICE_WARNING_OPERATION_DENIED";
    /** {en}
     * @platform android
     * @brief The media device is capturing silent frames.
     *
     */
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_CAPTURE_SILENCE"] = 2] = "MEDIA_DEVICE_WARNING_CAPTURE_SILENCE";
    /** {en}
     * @platform android
     * @brief Silence warning by Android system.
     *
     */
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE"] = 3] = "MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE";
    /** {en}
     * @platform android
     * @brief Silence disappearing warning by Android system.
     *
     */
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE_DISAPPEAR"] = 4] = "MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE_DISAPPEAR";
    /** {en}
     * @platform android
     * @brief Echos between mics and speakers are detected during a call. <br>
     *        `onAudioDeviceWarning` notifies you with this enum of echo issue. During a call, SDK will detect echo issue only when {@link ChannelProfile ChannelProfile} is set to `CHANNEL_PROFIEL_MEETING` or `CHANNEL_PROFILE_MEETING_ROOM` and AEC is disabled.
     *
     */
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_DETECT_LEAK_ECHO"] = 6] = "MEDIA_DEVICE_WARNING_DETECT_LEAK_ECHO";
    /** {en}
     * @platform android
     * @brief Howling detected. <br>
     *        You will receive this callback in the following scenarios: 1) Howling is detected under the room profiles that do not support howling suppression; 2) Detect howling that is not suppressed under the room profiles that support howling suppression. <br>
     *        You can only enable howling suppression when the room profile is CHANNEL_PROFILE_COMMUNICATION(0), CHANNEL_PROFIEL_MEETING(16), or CHANNEL_PROFILE_MEETING_ROOM(17). <br>
     *        We recommend that you remind your users to adjust the physical distance between two devices or disable all unused devices except the connecting one.
     *
     */
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_CAPTURE_DETECT_HOWLING"] = 11] = "MEDIA_DEVICE_WARNING_CAPTURE_DETECT_HOWLING";
    /** {en}
     * @platform android
     * @brief Setting audio route failed because the audio route can not be changed in the current Audio Scenario.
     *
     */
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_INVALID_SCENARIO"] = 12] = "MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_INVALID_SCENARIO";
    /** {en}
     * @platform android
     * @brief Setting audio route failed because the routing device did not exist.
     *
     */
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_EXISTS"] = 13] = "MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_EXISTS";
    /** {en}
     * @platform android
     * @brief Setting audio route failed because the audio route was occupied by the system or the other Apps.
     *
     */
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_FAILED_BY_PRIORITY"] = 14] = "MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_FAILED_BY_PRIORITY";
    /** {en}
     * @platform android
     * @brief Setting audio route failed because the audio route can only be changed in AUDIO_SCENARIO_COMMUNICATION(2) mode.
     *
     */
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_VOIP_MODE"] = 15] = "MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_VOIP_MODE";
    /** {en}
     * @platform android
     * @brief Setting audio route failed because the audio route did not initiate.
     *
     */
    MediaDeviceWarning[MediaDeviceWarning["MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_DEVICE_NOT_START"] = 16] = "MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_DEVICE_NOT_START";
    MediaDeviceWarning[MediaDeviceWarning["ByteRTCMediaDeviceWarningOK"] = 17] = "ByteRTCMediaDeviceWarningOK";
    MediaDeviceWarning[MediaDeviceWarning["ByteRTCMediaDeviceWarningOperationDenied"] = 18] = "ByteRTCMediaDeviceWarningOperationDenied";
    MediaDeviceWarning[MediaDeviceWarning["ByteRTCMediaDeviceWarningCaptureSilence"] = 19] = "ByteRTCMediaDeviceWarningCaptureSilence";
    MediaDeviceWarning[MediaDeviceWarning["ByteRTCMediaDeviceWarningDetectLeakEcho"] = 21] = "ByteRTCMediaDeviceWarningDetectLeakEcho";
    MediaDeviceWarning[MediaDeviceWarning["ByteRTCMediaDeviceWarningCaptureDetectHowling"] = 26] = "ByteRTCMediaDeviceWarningCaptureDetectHowling";
    MediaDeviceWarning[MediaDeviceWarning["ByteRTCMediaDeviceWarningSetAudioRouteInvalidScenario"] = 27] = "ByteRTCMediaDeviceWarningSetAudioRouteInvalidScenario";
    MediaDeviceWarning[MediaDeviceWarning["ByteRTCMediaDeviceWarningSetAudioRouteNotExists"] = 28] = "ByteRTCMediaDeviceWarningSetAudioRouteNotExists";
    MediaDeviceWarning[MediaDeviceWarning["ByteRTCMediaDeviceWarningSetAudioRouteFailedByPriority"] = 29] = "ByteRTCMediaDeviceWarningSetAudioRouteFailedByPriority";
    MediaDeviceWarning[MediaDeviceWarning["ByteRTCMediaDeviceWarningSetAudioRouteNotVoipMode"] = 30] = "ByteRTCMediaDeviceWarningSetAudioRouteNotVoipMode";
    MediaDeviceWarning[MediaDeviceWarning["ByteRTCMediaDeviceWarningSetAudioRouteDeviceNotStart"] = 31] = "ByteRTCMediaDeviceWarningSetAudioRouteDeviceNotStart";
    MediaDeviceWarning[MediaDeviceWarning["ByteRTCMediaDeviceWarningSetBluetoothModeScenarioUnsupport"] = 32] = "ByteRTCMediaDeviceWarningSetBluetoothModeScenarioUnsupport";
    MediaDeviceWarning[MediaDeviceWarning["ByteRTCMediaDeviceWarningSetBluetoothModeUnsupport"] = 33] = "ByteRTCMediaDeviceWarningSetBluetoothModeUnsupport";
})(exports.MediaDeviceWarning || (exports.MediaDeviceWarning = {}));
var RemoteVideoRenderConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RemoteVideoRenderConfig_1() {
        }
        Object.defineProperty(RemoteVideoRenderConfig_1.prototype, "renderMode", {
            /** {en}
             * @brief Rendering mode. <br>
             *        - 1(`RENDER_MODE_HIDDEN`): Fill and Crop. Default setting. The video frame is scaled with a fixed aspect ratio and completely fills the canvas. The region of the video exceeding the canvas will be cropped.
             *        - 2(`RENDER_MODE_FIT`): Fit. The video frame is scaled with a fixed aspect ratio and is shown completely on the canvas. The region of the canvas not filled with the video frame will be filled with `backgroundColor`.
             *        - 3(`RENDER_MODE_FILL`): Fill the canvas. The video frame is scaled to fill the canvas. During the process, the aspect ratio may change.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_RenderMode.android_to_ts(this._instance.renderMode);
                }
                else if ($os === 'ios') {
                    return t_RenderMode.ios_to_ts(this._instance.renderMode);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.renderMode = t_RenderMode.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.renderMode = t_RenderMode.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoRenderConfig_1.prototype, "backgroundColor", {
            /** {en}
             * @brief Set the background color of the canvas which is not filled with video frame. The range is `[0x00000000, 0xFFFFFFFF]`. The default is `0x00000000`. The Alpha index is ignored.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.backgroundColor);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.backgroundColor);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.backgroundColor = value;
                }
                else if ($os === 'ios') {
                    this._instance.backgroundColor = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoRenderConfig_1.prototype, "renderRotation", {
            /** {en}
             * @brief Video frame rotation angle. See {@link VideoRotation VideoRotation}. The default value is 0, which means no rotation is applied.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_VideoRotation.android_to_ts(this._instance.renderRotation);
                }
                else if ($os === 'ios') {
                    return t_VideoRotation.ios_to_ts(this._instance.renderRotation);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.renderRotation = t_VideoRotation.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.renderRotation = t_VideoRotation.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        RemoteVideoRenderConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RemoteVideoRenderConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRemoteVideoRenderConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RemoteVideoRenderConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RemoteVideoRenderConfig_1;
    }());
    __setFunctionName(_classThis, "RemoteVideoRenderConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.AudioProfileType = void 0;
(function (AudioProfileType) {
    AudioProfileType[AudioProfileType["AUDIO_PROFILE_DEFAULT"] = 0] = "AUDIO_PROFILE_DEFAULT";
    AudioProfileType[AudioProfileType["AUDIO_PROFILE_FLUENT"] = 1] = "AUDIO_PROFILE_FLUENT";
    AudioProfileType[AudioProfileType["AUDIO_PROFILE_STANDARD"] = 2] = "AUDIO_PROFILE_STANDARD";
    AudioProfileType[AudioProfileType["AUDIO_PROFILE_HD"] = 3] = "AUDIO_PROFILE_HD";
    AudioProfileType[AudioProfileType["AUDIO_PROFILE_STANDARD_STEREO"] = 4] = "AUDIO_PROFILE_STANDARD_STEREO";
    AudioProfileType[AudioProfileType["AUDIO_PROFILE_HD_MONO"] = 5] = "AUDIO_PROFILE_HD_MONO";
})(exports.AudioProfileType || (exports.AudioProfileType = {}));
exports.CameraId = void 0;
(function (CameraId) {
    CameraId[CameraId["CAMERA_ID_FRONT"] = 0] = "CAMERA_ID_FRONT";
    CameraId[CameraId["CAMERA_ID_BACK"] = 1] = "CAMERA_ID_BACK";
    CameraId[CameraId["CAMERA_ID_INVALID"] = 2] = "CAMERA_ID_INVALID";
})(exports.CameraId || (exports.CameraId = {}));
var SingScoringRealtimeInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function SingScoringRealtimeInfo_1() {
        }
        /**
         * @platform android
         */
        SingScoringRealtimeInfo_1.android_create = function (currentPosition, userPitch, standardPitch, sentenceIndex, sentenceScore, totalScore, averageScore) {
            var $ = function () {
                return SingScoringRealtimeInfo$1.create(currentPosition, userPitch, standardPitch, sentenceIndex, sentenceScore, totalScore, averageScore);
            };
            return $();
        };
        Object.defineProperty(SingScoringRealtimeInfo_1.prototype, "currentPosition", {
            /** {en}
             * @brief Current playback position.
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.currentPosition);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.currentPosition);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.currentPosition = value;
                }
                else if ($os === 'ios') {
                    this._instance.currentPosition = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SingScoringRealtimeInfo_1.prototype, "userPitch", {
            /** {en}
             * @brief The user's pitch.
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.userPitch);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.userPitch);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.userPitch = value;
                }
                else if ($os === 'ios') {
                    this._instance.userPitch = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SingScoringRealtimeInfo_1.prototype, "standardPitch", {
            /** {en}
             * @brief Standard pitch.
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.standardPitch);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.standardPitch);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.standardPitch = value;
                }
                else if ($os === 'ios') {
                    this._instance.standardPitch = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SingScoringRealtimeInfo_1.prototype, "sentenceIndex", {
            /** {en}
             * @brief Lyric index.
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.sentenceIndex);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.sentenceIndex);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.sentenceIndex = value;
                }
                else if ($os === 'ios') {
                    this._instance.sentenceIndex = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SingScoringRealtimeInfo_1.prototype, "sentenceScore", {
            /** {en}
             * @brief The score for the previous lyric.
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.sentenceScore);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.sentenceScore);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.sentenceScore = value;
                }
                else if ($os === 'ios') {
                    this._instance.sentenceScore = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SingScoringRealtimeInfo_1.prototype, "totalScore", {
            /** {en}
             * @brief The total score for the user's current performance.
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.totalScore);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.totalScore);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.totalScore = value;
                }
                else if ($os === 'ios') {
                    this._instance.totalScore = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SingScoringRealtimeInfo_1.prototype, "averageScore", {
            /** {en}
             * @brief The average score for the user's current performance.
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.averageScore);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.averageScore);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.averageScore = value;
                }
                else if ($os === 'ios') {
                    this._instance.averageScore = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        SingScoringRealtimeInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        SingScoringRealtimeInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCSingScoringRealtimeInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = SingScoringRealtimeInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return SingScoringRealtimeInfo_1;
    }());
    __setFunctionName(_classThis, "SingScoringRealtimeInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.RemoteVideoRenderPosition = void 0;
(function (RemoteVideoRenderPosition) {
    RemoteVideoRenderPosition[RemoteVideoRenderPosition["AFTER_DECODER"] = 0] = "AFTER_DECODER";
    RemoteVideoRenderPosition[RemoteVideoRenderPosition["AFTER_POST_PROCESS"] = 1] = "AFTER_POST_PROCESS";
})(exports.RemoteVideoRenderPosition || (exports.RemoteVideoRenderPosition = {}));
exports.TranscoderLayoutRegionType = void 0;
(function (TranscoderLayoutRegionType) {
    TranscoderLayoutRegionType[TranscoderLayoutRegionType["LAYOUT_REGION_TYPE_VIDEO_STREAM"] = 0] = "LAYOUT_REGION_TYPE_VIDEO_STREAM";
    TranscoderLayoutRegionType[TranscoderLayoutRegionType["LAYOUT_REGION_TYPE_IMAGE"] = 1] = "LAYOUT_REGION_TYPE_IMAGE";
    TranscoderLayoutRegionType[TranscoderLayoutRegionType["ByteRTCTranscoderLayoutRegionTypeVideoStream"] = 2] = "ByteRTCTranscoderLayoutRegionTypeVideoStream";
    TranscoderLayoutRegionType[TranscoderLayoutRegionType["ByteRTCTranscoderLayoutRegionTypeImage"] = 3] = "ByteRTCTranscoderLayoutRegionTypeImage";
})(exports.TranscoderLayoutRegionType || (exports.TranscoderLayoutRegionType = {}));
var AudioEffectPlayerConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function AudioEffectPlayerConfig_1() {
        }
        Object.defineProperty(AudioEffectPlayerConfig_1.prototype, "type", {
            /** {en}
             * @brief Mixing playback types. See {@link AudioMixingType AudioMixingType}
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioMixingType.android_to_ts(this._instance.type);
                }
                else if ($os === 'ios') {
                    return t_AudioMixingType.ios_to_ts(this._instance.type);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.type = t_AudioMixingType.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.type = t_AudioMixingType.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioEffectPlayerConfig_1.prototype, "playCount", {
            /** {en}
             * @brief Mix playback times <br>
             *        - Play_count < = 0: Infinite loop
             *        - Play_count == 1: Play once (default)
             *        - Play_count > 1: Play play_count times
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.playCount);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.playCount);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.playCount = value;
                }
                else if ($os === 'ios') {
                    this._instance.playCount = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioEffectPlayerConfig_1.prototype, "startPos", {
            /** {en}
             * @brief The starting position in ms. 0 by default.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.startPos);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.startPos);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.startPos = value;
                }
                else if ($os === 'ios') {
                    this._instance.startPos = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioEffectPlayerConfig_1.prototype, "pitch", {
            /** {en}
             * @brief The increase or decrease value compared with the original pitch of the music file. The range is `[-12, 12]`. The default value is 0. The pitch distance between two adjacent values is half a step. A positive value indicates a rising pitch, and a negative value indicates a falling pitch.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.pitch);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.pitch);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.pitch = value;
                }
                else if ($os === 'ios') {
                    this._instance.pitch = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        AudioEffectPlayerConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        AudioEffectPlayerConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCAudioEffectPlayerConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = AudioEffectPlayerConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return AudioEffectPlayerConfig_1;
    }());
    __setFunctionName(_classThis, "AudioEffectPlayerConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MixedStreamLayoutRegionImageWaterMarkConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function MixedStreamLayoutRegionImageWaterMarkConfig_1() {
        }
        Object.defineProperty(MixedStreamLayoutRegionImageWaterMarkConfig_1.prototype, "ios_imageWidth", {
            /** {en}
             * @platform ios
             * @brief Width of the original image in px.
             */
            get: function () {
                return this._instance.imageWidth;
            },
            set: function (value) {
                this._instance.imageWidth = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionImageWaterMarkConfig_1.prototype, "ios_imageHeight", {
            /** {en}
             * @platform ios
             * @brief Height of the original image in px.
             */
            get: function () {
                return this._instance.imageHeight;
            },
            set: function (value) {
                this._instance.imageHeight = value;
            },
            enumerable: false,
            configurable: true
        });
        MixedStreamLayoutRegionImageWaterMarkConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        MixedStreamLayoutRegionImageWaterMarkConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCMixedStreamLayoutRegionImageWaterMarkConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = MixedStreamLayoutRegionImageWaterMarkConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @brief Sets the height of the original image.
         * @param imageHeight The original image height in px.
         *
         */
        MixedStreamLayoutRegionImageWaterMarkConfig_1.prototype.android_setImageHeight = function (imageHeight) {
            var _this = this;
            var $ = function () { return (_this._instance.setImageHeight(imageHeight), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @brief Gets the height of the original image.
         *
         */
        MixedStreamLayoutRegionImageWaterMarkConfig_1.prototype.android_getImageHeight = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getImageHeight()); };
            return $();
        };
        /** {en}
         * @platform android
         * @brief Sets the height of the original image.
         * @param imageWidth The original image width in px.
         *
         */
        MixedStreamLayoutRegionImageWaterMarkConfig_1.prototype.android_setImageWidth = function (imageWidth) {
            var _this = this;
            var $ = function () { return (_this._instance.setImageWidth(imageWidth), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @brief Gets the width of the original image.
         *
         */
        MixedStreamLayoutRegionImageWaterMarkConfig_1.prototype.android_getImageWidth = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getImageWidth()); };
            return $();
        };
        return MixedStreamLayoutRegionImageWaterMarkConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamLayoutRegionImageWaterMarkConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.LocalVideoStreamError = void 0;
(function (LocalVideoStreamError) {
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_OK"] = 0] = "LOCAL_VIDEO_STREAM_ERROR_OK";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_FAILURE"] = 1] = "LOCAL_VIDEO_STREAM_ERROR_FAILURE";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_DEVICE_NO_PERMISSION"] = 2] = "LOCAL_VIDEO_STREAM_ERROR_DEVICE_NO_PERMISSION";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_DEVICE_BUSY"] = 3] = "LOCAL_VIDEO_STREAM_ERROR_DEVICE_BUSY";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_DEVICE_NOT_FOUND"] = 4] = "LOCAL_VIDEO_STREAM_ERROR_DEVICE_NOT_FOUND";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_CAPTURE_FAILURE"] = 5] = "LOCAL_VIDEO_STREAM_ERROR_CAPTURE_FAILURE";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_ENCODE_FAILURE"] = 6] = "LOCAL_VIDEO_STREAM_ERROR_ENCODE_FAILURE";
    LocalVideoStreamError[LocalVideoStreamError["LOCAL_VIDEO_STREAM_ERROR_DEVICE_DISCONNECTED"] = 7] = "LOCAL_VIDEO_STREAM_ERROR_DEVICE_DISCONNECTED";
})(exports.LocalVideoStreamError || (exports.LocalVideoStreamError = {}));
var NetworkQualityStats = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function NetworkQualityStats_1() {
        }
        Object.defineProperty(NetworkQualityStats_1.prototype, "uid", {
            /** {en}
             * @brief User ID
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.uid);
                }
                else if ($os === 'ios') {
                    return String(this._instance.uid);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.uid = value;
                }
                else if ($os === 'ios') {
                    this._instance.uid = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(NetworkQualityStats_1.prototype, "android_fractionLost", {
            /** {en}
             * @platform android
             * @brief Packet loss ratio of the local client, ranging [0.0,1.0] <br>
             *        For a local user, it is the sent-packet loss ratio. <br>
             *        For a remote user, it is the loss ratio of all the packets received.
             *
             */
            get: function () {
                return this._instance.fractionLost;
            },
            set: function (value) {
                this._instance.fractionLost = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(NetworkQualityStats_1.prototype, "rtt", {
            /** {en}
             * @brief Round-trip time (RTT) from client to server. Effective for the local user. Unit: ms
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rtt);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rtt);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rtt = value;
                }
                else if ($os === 'ios') {
                    this._instance.rtt = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(NetworkQualityStats_1.prototype, "totalBandwidth", {
            /** {en}
             * @brief Average transmission rate of the media RTP packages in 2s. unit: bps <br>
             *        For a local user, it is the packet-transmitting speed. <br>
             *        For a more user, it is the speed of receiving all the subscribed medias.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.totalBandwidth);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.totalBandwidth);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.totalBandwidth = value;
                }
                else if ($os === 'ios') {
                    this._instance.totalBandwidth = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(NetworkQualityStats_1.prototype, "txQuality", {
            /** {en}
             * @brief Tx network quality grade. The higher grade the worst network quality. Refer to {@link NetworkQuality NetworkQuality} for details.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_NetworkQuality.android_to_ts(this._instance.txQuality);
                }
                else if ($os === 'ios') {
                    return t_NetworkQuality.ios_to_ts(this._instance.txQuality);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.txQuality = t_NetworkQuality.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.txQuality = t_NetworkQuality.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(NetworkQualityStats_1.prototype, "rxQuality", {
            /** {en}
             * @brief Rx network quality grade. The higher grade the worst network quality. Refer to {@link NetworkQuality NetworkQuality} for details.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_NetworkQuality.android_to_ts(this._instance.rxQuality);
                }
                else if ($os === 'ios') {
                    return t_NetworkQuality.ios_to_ts(this._instance.rxQuality);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rxQuality = t_NetworkQuality.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.rxQuality = t_NetworkQuality.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(NetworkQualityStats_1.prototype, "ios_lossRatio", {
            /** {en}
             * @platform ios
             * @brief Packet loss ratio of the local client, ranging [0.0,1.0] <br>
             *        For a local user, it is the sent-packet loss ratio. <br>
             *        For a remote user, it is the loss ratio of all the packets received.
             */
            get: function () {
                return this._instance.lossRatio;
            },
            set: function (value) {
                this._instance.lossRatio = value;
            },
            enumerable: false,
            configurable: true
        });
        NetworkQualityStats_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        NetworkQualityStats_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCNetworkQualityStats).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = NetworkQualityStats$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return NetworkQualityStats_1;
    }());
    __setFunctionName(_classThis, "NetworkQualityStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.UserVisibilityChangeError = void 0;
(function (UserVisibilityChangeError) {
    UserVisibilityChangeError[UserVisibilityChangeError["OK"] = 0] = "OK";
    UserVisibilityChangeError[UserVisibilityChangeError["UNKNOWN"] = 1] = "UNKNOWN";
    UserVisibilityChangeError[UserVisibilityChangeError["TOO_MANY_VISIBLE_USER"] = 2] = "TOO_MANY_VISIBLE_USER";
})(exports.UserVisibilityChangeError || (exports.UserVisibilityChangeError = {}));
exports.PublishFallbackOption = void 0;
(function (PublishFallbackOption) {
    PublishFallbackOption[PublishFallbackOption["DISABLE"] = 0] = "DISABLE";
    PublishFallbackOption[PublishFallbackOption["SIMULCAST_SMALL_VIDEO_ONLY"] = 1] = "SIMULCAST_SMALL_VIDEO_ONLY";
    PublishFallbackOption[PublishFallbackOption["ByteRTCPublishFallbackOptionDisabled"] = 2] = "ByteRTCPublishFallbackOptionDisabled";
    PublishFallbackOption[PublishFallbackOption["ByteRTCPublishFallbackOptionSimulcast"] = 3] = "ByteRTCPublishFallbackOptionSimulcast";
})(exports.PublishFallbackOption || (exports.PublishFallbackOption = {}));
exports.LocalAudioStreamError = void 0;
(function (LocalAudioStreamError) {
    LocalAudioStreamError[LocalAudioStreamError["LOCAL_AUDIO_STREAM_ERROR_OK"] = 0] = "LOCAL_AUDIO_STREAM_ERROR_OK";
    LocalAudioStreamError[LocalAudioStreamError["LOCAL_AUDIO_STREAM_ERROR_FAILURE"] = 1] = "LOCAL_AUDIO_STREAM_ERROR_FAILURE";
    LocalAudioStreamError[LocalAudioStreamError["LOCAL_AUDIO_STREAM_ERROR_DEVICE_NO_PERMISSION"] = 2] = "LOCAL_AUDIO_STREAM_ERROR_DEVICE_NO_PERMISSION";
    LocalAudioStreamError[LocalAudioStreamError["LOCAL_AUDIO_STREAM_ERROR_RECORD_FAILURE"] = 3] = "LOCAL_AUDIO_STREAM_ERROR_RECORD_FAILURE";
    LocalAudioStreamError[LocalAudioStreamError["LOCAL_AUDIO_STREAM_ERROR_ENCODE_FAILURE"] = 4] = "LOCAL_AUDIO_STREAM_ERROR_ENCODE_FAILURE";
    LocalAudioStreamError[LocalAudioStreamError["LOCAL_AUDIO_STREAM_ERROR_NO_RECORDING_DEVICE"] = 5] = "LOCAL_AUDIO_STREAM_ERROR_NO_RECORDING_DEVICE";
})(exports.LocalAudioStreamError || (exports.LocalAudioStreamError = {}));
var SubtitleMessage = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function SubtitleMessage_1() {
        }
        /**
         * @platform android
         */
        /**
         * @platform android
         */
        SubtitleMessage_1.android_create = function (userId, text, language, mode, sequence, definite) {
            var $ = function () { return SubtitleMessage$1.create(userId, text, language, mode, sequence, definite); };
            return $();
        };
        Object.defineProperty(SubtitleMessage_1.prototype, "userId", {
            /** {en}
             * @brief The speaker's ID.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.userId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.userId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.userId = value;
                }
                else if ($os === 'ios') {
                    this._instance.userId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubtitleMessage_1.prototype, "text", {
            /** {en}
             * @brief Subtitles encoded in UTF-8 format.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.text);
                }
                else if ($os === 'ios') {
                    return String(this._instance.text);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.text = value;
                }
                else if ($os === 'ios') {
                    this._instance.text = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubtitleMessage_1.prototype, "language", {
            /** {en}
             * @brief The language of the transcribed or translated text according to the subtitle mode.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.language);
                }
                else if ($os === 'ios') {
                    return String(this._instance.language);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.language = value;
                }
                else if ($os === 'ios') {
                    this._instance.language = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubtitleMessage_1.prototype, "mode", {
            /** {en}
             * @brief Subtitle mode. Refer to {@link SubtitleMode SubtitleMode} for more details.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_SubtitleMode.android_to_ts(this._instance.mode);
                }
                else if ($os === 'ios') {
                    return t_SubtitleMode.ios_to_ts(this._instance.mode);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.mode = t_SubtitleMode.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.mode = t_SubtitleMode.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubtitleMessage_1.prototype, "sequence", {
            /** {en}
             * @brief Incremental sequence numbers of the piece of the subtitle. Complete and incomplete sentences are numbered individually.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.sequence);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.sequence);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.sequence = value;
                }
                else if ($os === 'ios') {
                    this._instance.sequence = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubtitleMessage_1.prototype, "definite", {
            /** {en}
             * @brief Whether transcribed texts are complete sentences. True means yes and False means no.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.definite;
                }
                else if ($os === 'ios') {
                    return this._instance.definite;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.definite = value;
                }
                else if ($os === 'ios') {
                    this._instance.definite = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        SubtitleMessage_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        SubtitleMessage_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCSubtitleMessage).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = SubtitleMessage$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return SubtitleMessage_1;
    }());
    __setFunctionName(_classThis, "SubtitleMessage");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RecordingInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RecordingInfo_1() {
        }
        Object.defineProperty(RecordingInfo_1.prototype, "filePath", {
            /** {en}
             * @brief The absolute path of the recorded file, including the file name and file suffix
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.filePath);
                }
                else if ($os === 'ios') {
                    return String(this._instance.filePath);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.filePath = value;
                }
                else if ($os === 'ios') {
                    this._instance.filePath = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RecordingInfo_1.prototype, "android_videoCodecType", {
            /** {en}
             * @platform android
             * @brief The video encoding type of the recorded file. See  see {@link VideoCodecType VideoCodecType}
             *
             */
            get: function () {
                return this._instance.videoCodecType;
            },
            set: function (value) {
                this._instance.videoCodecType = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RecordingInfo_1.prototype, "width", {
            /** {en}
             * @brief The width of the recorded video, in pixels. Please ignore this field for audio-only recording
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.width);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.width);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.width = value;
                }
                else if ($os === 'ios') {
                    this._instance.width = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RecordingInfo_1.prototype, "height", {
            /** {en}
             * @brief The height of the recorded video, the unit: pixels. Please ignore this field for audio-only recording
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.height);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.height);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.height = value;
                }
                else if ($os === 'ios') {
                    this._instance.height = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RecordingInfo_1.prototype, "ios_codecType", {
            /** {en}
             * @platform ios
             * @brief For the video encoding type of the recorded file. See {@link ByteRTCVideoCodecType ByteRTCVideoCodecType}
             */
            get: function () {
                return this._instance.codecType;
            },
            set: function (value) {
                this._instance.codecType = value;
            },
            enumerable: false,
            configurable: true
        });
        RecordingInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RecordingInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRecordingInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RecordingInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RecordingInfo_1;
    }());
    __setFunctionName(_classThis, "RecordingInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioMixingConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function AudioMixingConfig_1() {
        }
        Object.defineProperty(AudioMixingConfig_1.prototype, "type", {
            /** {en}
             * @brief For mixing playback types. See {@link AudioMixingType AudioMixingType}
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioMixingType.android_to_ts(this._instance.type);
                }
                else if ($os === 'ios') {
                    return t_AudioMixingType.ios_to_ts(this._instance.type);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.type = t_AudioMixingType.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.type = t_AudioMixingType.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioMixingConfig_1.prototype, "playCount", {
            /** {en}
             * @brief Mix playback times <br>
             *        - Play_count < = 0: Infinite loop
             *        - Play_count == 1: Play once (default)
             *        - Play_count > 1: Play play_count times
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.playCount);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.playCount);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.playCount = value;
                }
                else if ($os === 'ios') {
                    this._instance.playCount = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioMixingConfig_1.prototype, "position", {
            /** {en}
             * @brief The position of the audio file playback progress bar during audio mixing, the parameter should be an integer, in milliseconds.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.position);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.position);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.position = value;
                }
                else if ($os === 'ios') {
                    this._instance.position = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioMixingConfig_1.prototype, "callbackOnProgressInterval", {
            /** {en}
             * @brief Set the time interval (ms) for the audio file playing progress callback. The `onAudioMixingPlayingProgress` callback then will be triggered according to the set value, no callback by default. <br>
             *       - The value of interval is a multiple of 10 greater than 0. When the value set is not divisible by 10, the default is rounded up by 10. For example, if the value is set to 52ms, it will be automatically adjusted to 60ms, then the SDK will trigger `onAudioMixingPlayingProgress` callback at the set interval.
             *       - If the value is less than or equals to 0, the callback will not be triggered.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.callbackOnProgressInterval);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.callbackOnProgressInterval);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.callbackOnProgressInterval = value;
                }
                else if ($os === 'ios') {
                    this._instance.callbackOnProgressInterval = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioMixingConfig_1.prototype, "syncProgressToRecordFrame", {
            /** {en}
             * @brief Attach the process information of local audio file mixing to the captured audio data. Enable the function to enhance the synchronicity of the remote audio mixing. <br>
             *        - The function is effective when mixing a single audio file.
             *        - Use `true` for enabling the function and `false` for disable the function. The default is `false`.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.syncProgressToRecordFrame;
                }
                else if ($os === 'ios') {
                    return this._instance.syncProgressToRecordFrame;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.syncProgressToRecordFrame = value;
                }
                else if ($os === 'ios') {
                    this._instance.syncProgressToRecordFrame = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        AudioMixingConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        AudioMixingConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCAudioMixingConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = AudioMixingConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return AudioMixingConfig_1;
    }());
    __setFunctionName(_classThis, "AudioMixingConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.SyncInfoStreamType = void 0;
(function (SyncInfoStreamType) {
    SyncInfoStreamType[SyncInfoStreamType["SYNC_INFO_STREAM_TYPE_AUDIO"] = 0] = "SYNC_INFO_STREAM_TYPE_AUDIO";
})(exports.SyncInfoStreamType || (exports.SyncInfoStreamType = {}));
exports.MixedStreamAudioProfile = void 0;
(function (MixedStreamAudioProfile) {
    MixedStreamAudioProfile[MixedStreamAudioProfile["MIXED_STREAM_AUDIO_PROFILE_LC"] = 0] = "MIXED_STREAM_AUDIO_PROFILE_LC";
    MixedStreamAudioProfile[MixedStreamAudioProfile["MIXED_STREAM_AUDIO_PROFILE_HEV1"] = 1] = "MIXED_STREAM_AUDIO_PROFILE_HEV1";
    MixedStreamAudioProfile[MixedStreamAudioProfile["MIXED_STREAM_AUDIO_PROFILE_HEV2"] = 2] = "MIXED_STREAM_AUDIO_PROFILE_HEV2";
})(exports.MixedStreamAudioProfile || (exports.MixedStreamAudioProfile = {}));
var RTCRoomStats = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RTCRoomStats_1() {
        }
        Object.defineProperty(RTCRoomStats_1.prototype, "txKBitRate", {
            /** {en}
             * @brief The instantaneous value of Tx bitrate in kbps
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.txKBitRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.txKbitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.txKBitRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.txKbitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "rxKBitRate", {
            /** {en}
             * @brief The instantaneous value of Rx bitrate in kbps
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rxKBitRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rxKbitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rxKBitRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.rxKbitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "txAudioKBitRate", {
            /** {en}
             * @brief The instantaneous value of audio Tx bitrate in kbps
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.txAudioKBitRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.txAudioKBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.txAudioKBitRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.txAudioKBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "rxAudioKBitRate", {
            /** {en}
             * @brief The instantaneous value of audio Rx bitrate in kbps
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rxAudioKBitRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rxAudioKBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rxAudioKBitRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.rxAudioKBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "txVideoKBitRate", {
            /** {en}
             * @brief The instantaneous value of video Tx bitrate in kbps
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.txVideoKBitRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.txVideoKBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.txVideoKBitRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.txVideoKBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "rxVideoKBitRate", {
            /** {en}
             * @brief The instantaneous value of video Rx bitrate in kbps
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rxVideoKBitRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rxVideoKBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rxVideoKBitRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.rxVideoKBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "txScreenKBitRate", {
            /** {en}
             * @brief The instantaneous RX bitrate of screen-sharing video in Kbps
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.txScreenKBitRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.txScreenKBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.txScreenKBitRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.txScreenKBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "rxScreenKBitRate", {
            /** {en}
             * @brief The instantaneous TX bitrate of screen-sharing video in Kbps
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rxScreenKBitRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rxScreenKBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rxScreenKBitRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.rxScreenKBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "android_totalDuration", {
            /** {en}
             * @platform android
             * @brief Cumulative time between the user joining the room and leaving the room in seconds.
             *
             */
            get: function () {
                return this._instance.totalDuration;
            },
            set: function (value) {
                this._instance.totalDuration = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "txBytes", {
            /** {en}
             * @brief Cumulative data sent by the user in bytes.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.txBytes);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.txBytes);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.txBytes = value;
                }
                else if ($os === 'ios') {
                    this._instance.txBytes = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "rxBytes", {
            /** {en}
             * @brief Cumulative data received by the user in bytes.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rxBytes);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rxBytes);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rxBytes = value;
                }
                else if ($os === 'ios') {
                    this._instance.rxBytes = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "android_users", {
            /** {en}
             * @platform android
             * @brief Number of visible users in the current room
             *
             */
            get: function () {
                return this._instance.users;
            },
            set: function (value) {
                this._instance.users = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "android_cpuTotalUsage", {
            /** {en}
             * @platform android
             * @brief Current CPU usage (\%)
             *
             */
            get: function () {
                return this._instance.cpuTotalUsage;
            },
            set: function (value) {
                this._instance.cpuTotalUsage = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "android_cpuAppUsage", {
            /** {en}
             * @platform android
             * @brief CPU usage (\%) of the application
             *
             */
            get: function () {
                return this._instance.cpuAppUsage;
            },
            set: function (value) {
                this._instance.cpuAppUsage = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "txLostrate", {
            /** {en}
             * @brief Current Tx packet loss rate. The range is [0,1].
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.txLostrate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.txLostrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.txLostrate = value;
                }
                else if ($os === 'ios') {
                    this._instance.txLostrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "rxLostrate", {
            /** {en}
             * @brief Current Rx packet loss rate. The range is [0,1].
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rxLostrate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rxLostrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rxLostrate = value;
                }
                else if ($os === 'ios') {
                    this._instance.rxLostrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "rtt", {
            /** {en}
             * @brief Round-trip time (in ms) from client side to server side
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rtt);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rtt);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rtt = value;
                }
                else if ($os === 'ios') {
                    this._instance.rtt = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "txCellularKBitrate", {
            /** {en}
             * @brief Tx cellular bandwidth consumption
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.txCellularKBitrate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.txCellularKBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.txCellularKBitrate = value;
                }
                else if ($os === 'ios') {
                    this._instance.txCellularKBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "rxCellularKBitrate", {
            /** {en}
             * @brief Rx cellular bandwidth consumption
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rxCellularKBitrate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rxCellularKBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rxCellularKBitrate = value;
                }
                else if ($os === 'ios') {
                    this._instance.rxCellularKBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "ios_duration", {
            /** {en}
             * @platform ios
             * @brief The total time after the user enters the room and starts the call, in s, the cumulative value
             */
            get: function () {
                return this._instance.duration;
            },
            set: function (value) {
                this._instance.duration = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "ios_userCount", {
            /** {en}
             * @platform ios
             * @brief Number of visible users in the current room, including local users themselves
             */
            get: function () {
                return this._instance.userCount;
            },
            set: function (value) {
                this._instance.userCount = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomStats_1.prototype, "ios_txJitter", {
            /** {en}
             * @platform ios
             * @hidden currently not available
             * @brief The system downlink network jitter(ms)
             */
            get: function () {
                return this._instance.txJitter;
            },
            set: function (value) {
                this._instance.txJitter = value;
            },
            enumerable: false,
            configurable: true
        });
        RTCRoomStats_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RTCRoomStats_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRoomStats).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RTCRoomStats$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @region Video Management
         * @brief Reset {@link RTCRoomStats RTCRoomStats}
         *
         */
        RTCRoomStats_1.prototype.android_reset = function () {
            var _this = this;
            var $ = function () { return (_this._instance.reset(), void 0); };
            return $();
        };
        return RTCRoomStats_1;
    }());
    __setFunctionName(_classThis, "RTCRoomStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.AudioTrackType = void 0;
(function (AudioTrackType) {
    AudioTrackType[AudioTrackType["ORIGINAL"] = 0] = "ORIGINAL";
    AudioTrackType[AudioTrackType["ACCOMPANY"] = 1] = "ACCOMPANY";
    AudioTrackType[AudioTrackType["ByteRTCAudioTrackTypeAccompy"] = 2] = "ByteRTCAudioTrackTypeAccompy";
})(exports.AudioTrackType || (exports.AudioTrackType = {}));
var ProblemFeedbackRoomInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ProblemFeedbackRoomInfo_1() {
        }
        Object.defineProperty(ProblemFeedbackRoomInfo_1.prototype, "roomId", {
            /** {en}
             * @brief Room ID.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.roomId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.roomId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.roomId = value;
                }
                else if ($os === 'ios') {
                    this._instance.roomId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(ProblemFeedbackRoomInfo_1.prototype, "userId", {
            /** {en}
             * @brief User ID.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.userId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.userId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.userId = value;
                }
                else if ($os === 'ios') {
                    this._instance.userId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        ProblemFeedbackRoomInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        ProblemFeedbackRoomInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCProblemFeedbackRoomInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = ProblemFeedbackRoomInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return ProblemFeedbackRoomInfo_1;
    }());
    __setFunctionName(_classThis, "ProblemFeedbackRoomInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.AudioSourceType = void 0;
(function (AudioSourceType) {
    AudioSourceType[AudioSourceType["AUDIO_SOURCE_TYPE_EXTERNAL"] = 0] = "AUDIO_SOURCE_TYPE_EXTERNAL";
    AudioSourceType[AudioSourceType["AUDIO_SOURCE_TYPE_INTERNAL"] = 1] = "AUDIO_SOURCE_TYPE_INTERNAL";
})(exports.AudioSourceType || (exports.AudioSourceType = {}));
exports.PerformanceAlarmMode = void 0;
(function (PerformanceAlarmMode) {
    PerformanceAlarmMode[PerformanceAlarmMode["NORMAL"] = 0] = "NORMAL";
    PerformanceAlarmMode[PerformanceAlarmMode["SIMULCAST"] = 1] = "SIMULCAST";
})(exports.PerformanceAlarmMode || (exports.PerformanceAlarmMode = {}));
exports.RecordingErrorCode = void 0;
(function (RecordingErrorCode) {
    RecordingErrorCode[RecordingErrorCode["RECORDING_ERROR_CODE_OK"] = 0] = "RECORDING_ERROR_CODE_OK";
    RecordingErrorCode[RecordingErrorCode["RECORDING_ERROR_CODE_NO_PERMISSION"] = 1] = "RECORDING_ERROR_CODE_NO_PERMISSION";
    RecordingErrorCode[RecordingErrorCode["RECORDING_ERROR_CODE_NOT_SUPPORT"] = 2] = "RECORDING_ERROR_CODE_NOT_SUPPORT";
    RecordingErrorCode[RecordingErrorCode["RECORDING_ERROR_CODE_NO_OTHER"] = 3] = "RECORDING_ERROR_CODE_NO_OTHER";
    RecordingErrorCode[RecordingErrorCode["ByteRTCRecordingErrorCodeOk"] = 4] = "ByteRTCRecordingErrorCodeOk";
    RecordingErrorCode[RecordingErrorCode["ByteRTCRecordingErrorCodeNoPermission"] = 5] = "ByteRTCRecordingErrorCodeNoPermission";
    RecordingErrorCode[RecordingErrorCode["ByteRTCRecordingErrorCodeNotSupport"] = 6] = "ByteRTCRecordingErrorCodeNotSupport";
    RecordingErrorCode[RecordingErrorCode["ByteRTCRecordingErrorCodeOther"] = 7] = "ByteRTCRecordingErrorCodeOther";
})(exports.RecordingErrorCode || (exports.RecordingErrorCode = {}));
exports.EchoTestResult = void 0;
(function (EchoTestResult) {
    EchoTestResult[EchoTestResult["ECHO_TEST_SUCCESS"] = 0] = "ECHO_TEST_SUCCESS";
    EchoTestResult[EchoTestResult["ECHO_TEST_TIMEOUT"] = 1] = "ECHO_TEST_TIMEOUT";
    EchoTestResult[EchoTestResult["ECHO_TEST_INTERVAL_SHORT"] = 2] = "ECHO_TEST_INTERVAL_SHORT";
    EchoTestResult[EchoTestResult["ECHO_TEST_AUDIO_DEVICE_ERROR"] = 3] = "ECHO_TEST_AUDIO_DEVICE_ERROR";
    EchoTestResult[EchoTestResult["ECHO_TEST_VIDEO_DEVICE_ERROR"] = 4] = "ECHO_TEST_VIDEO_DEVICE_ERROR";
    EchoTestResult[EchoTestResult["ECHO_TEST_AUDIO_RECEIVE_ERROR"] = 5] = "ECHO_TEST_AUDIO_RECEIVE_ERROR";
    EchoTestResult[EchoTestResult["ECHO_TEST_VIDEO_RECEIVE_ERROR"] = 6] = "ECHO_TEST_VIDEO_RECEIVE_ERROR";
    EchoTestResult[EchoTestResult["ECHO_TEST_INTERNAL_ERROR"] = 7] = "ECHO_TEST_INTERNAL_ERROR";
    EchoTestResult[EchoTestResult["ByteRTCEchoTestResultSuccess"] = 8] = "ByteRTCEchoTestResultSuccess";
    EchoTestResult[EchoTestResult["ByteRTCEchoTestResultTimeout"] = 9] = "ByteRTCEchoTestResultTimeout";
    EchoTestResult[EchoTestResult["ByteRTCEchoTestResultIntervalShort"] = 10] = "ByteRTCEchoTestResultIntervalShort";
    EchoTestResult[EchoTestResult["ByteRTCEchoTestResultAudioDeviceError"] = 11] = "ByteRTCEchoTestResultAudioDeviceError";
    EchoTestResult[EchoTestResult["ByteRTCEchoTestResultVideoDeviceError"] = 12] = "ByteRTCEchoTestResultVideoDeviceError";
    EchoTestResult[EchoTestResult["ByteRTCEchoTestResultAudioReceiveError"] = 13] = "ByteRTCEchoTestResultAudioReceiveError";
    EchoTestResult[EchoTestResult["ByteRTCEchoTestResultVideoReceiveError"] = 14] = "ByteRTCEchoTestResultVideoReceiveError";
    EchoTestResult[EchoTestResult["ByteRTCEchoTestResultInternalError"] = 15] = "ByteRTCEchoTestResultInternalError";
})(exports.EchoTestResult || (exports.EchoTestResult = {}));
var NetworkTimeInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function NetworkTimeInfo_1() {
        }
        Object.defineProperty(NetworkTimeInfo_1.prototype, "timestamp", {
            /** {en}
             * @brief Network time. Unit: ms
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.timestamp);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.timestamp);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.timestamp = value;
                }
                else if ($os === 'ios') {
                    this._instance.timestamp = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        NetworkTimeInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        NetworkTimeInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCNetworkTimeInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = NetworkTimeInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return NetworkTimeInfo_1;
    }());
    __setFunctionName(_classThis, "NetworkTimeInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.RemoteMirrorType = void 0;
(function (RemoteMirrorType) {
    RemoteMirrorType[RemoteMirrorType["NONE"] = 0] = "NONE";
    RemoteMirrorType[RemoteMirrorType["RENDER"] = 1] = "RENDER";
})(exports.RemoteMirrorType || (exports.RemoteMirrorType = {}));
exports.SubscribeState = void 0;
(function (SubscribeState) {
    SubscribeState[SubscribeState["SUBSCRIBE_STATE_SUCCESS"] = 0] = "SUBSCRIBE_STATE_SUCCESS";
    SubscribeState[SubscribeState["SUBSCRIBE_STATE_FAILED_NOT_IN_ROOM"] = 1] = "SUBSCRIBE_STATE_FAILED_NOT_IN_ROOM";
    SubscribeState[SubscribeState["SUBSCRIBE_STATE_FAILED_STREAM_NOT_FOUND"] = 2] = "SUBSCRIBE_STATE_FAILED_STREAM_NOT_FOUND";
    SubscribeState[SubscribeState["SUBSCRIBE_STATE_FAILED_SIGNAL"] = 3] = "SUBSCRIBE_STATE_FAILED_SIGNAL";
    SubscribeState[SubscribeState["ByteRTCSubscribeStateFailedOverLimit"] = 4] = "ByteRTCSubscribeStateFailedOverLimit";
})(exports.SubscribeState || (exports.SubscribeState = {}));
var VirtualBackgroundSource = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function VirtualBackgroundSource_1() {
        }
        Object.defineProperty(VirtualBackgroundSource_1.prototype, "sourceType", {
            /** {en}
             * @brief See {@link VirtualBackgroundSourceType VirtualBackgroundSourceType}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_VirtualBackgroundSourceType.android_to_ts(this._instance.sourceType);
                }
                else if ($os === 'ios') {
                    return t_VirtualBackgroundSourceType.ios_to_ts(this._instance.sourceType);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.sourceType = t_VirtualBackgroundSourceType.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.sourceType =
                        t_VirtualBackgroundSourceType.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VirtualBackgroundSource_1.prototype, "sourceColor", {
            /** {en}
             * @brief The solid color of the background. <br>
             *        The format is 0xAARRGGBB.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.sourceColor);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.sourceColor);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.sourceColor = value;
                }
                else if ($os === 'ios') {
                    this._instance.sourceColor = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VirtualBackgroundSource_1.prototype, "sourcePath", {
            /** {en}
             * @brief The absolute path of the specified image. <br>
             *        - You can use the absolute path of the local file (file://xxx) and the Asset path (asset://xxx).
             *        - You can upload a .JPG, .PNG, or .JPEG file.
             *        - The image with a resolution higher than 1080p(Full HD) will be rescaled proportionally to fit in the video.
             *        - If the image's aspect ratio matches the video's, the image will be rescaled proportionally to fit in the video.
             *        - If the image’s aspect ratio doesn't match the video's, the shortest side (either height or width) of the image will be stretched proportionally to match the video. Then the image will be cropped to fill in the video.
             *        - The transparent area in the image will be filled with black.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.sourcePath);
                }
                else if ($os === 'ios') {
                    return String(this._instance.sourcePath);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.sourcePath = value;
                }
                else if ($os === 'ios') {
                    this._instance.sourcePath = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        VirtualBackgroundSource_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        VirtualBackgroundSource_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCVirtualBackgroundSource).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = VirtualBackgroundSource$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return VirtualBackgroundSource_1;
    }());
    __setFunctionName(_classThis, "VirtualBackgroundSource");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MixedStreamClientMixConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function MixedStreamClientMixConfig_1() {
        }
        Object.defineProperty(MixedStreamClientMixConfig_1.prototype, "ios_useAudioMixer", {
            /** {en}
             * @platform ios
             * @brief Whether to use audio mixing. Default is true.
             */
            get: function () {
                return this._instance.useAudioMixer;
            },
            set: function (value) {
                this._instance.useAudioMixer = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamClientMixConfig_1.prototype, "ios_videoFormat", {
            /** {en}
             * @platform ios
             * @brief The video format to be set. See {@link ByteRTCMixedStreamClientMixVideoFormat ByteRTCMixedStreamClientMixVideoFormat}.
             */
            get: function () {
                return this._instance.videoFormat;
            },
            set: function (value) {
                this._instance.videoFormat = value;
            },
            enumerable: false,
            configurable: true
        });
        MixedStreamClientMixConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        MixedStreamClientMixConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCMixedStreamClientMixConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = MixedStreamClientMixConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the video format for client stream mixing callback. If the format you set is not valid, the format will be set to the default value.
         * @param videoFormat The video format to be set. See {@link MixedStreamClientMixVideoFormat MixedStreamClientMixVideoFormat}.
         *
         */
        MixedStreamClientMixConfig_1.prototype.android_setVideoFormat = function (videoFormat) {
            var _this = this;
            var $ = function () { return (_this._instance.setVideoFormat(videoFormat), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the video format for client stream mixing callback.
         *
         */
        MixedStreamClientMixConfig_1.prototype.android_getVideoFormat = function () {
            var _this = this;
            var $ = function () { return _this._instance.getVideoFormat(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Set whether the client mixing uses audio mixing.
         * @param useAudioMixer Whether to use audio mixing. True by default.
         * @return See {@link MixedStreamClientMixConfig MixedStreamClientMixConfig}.
         *
         */
        MixedStreamClientMixConfig_1.prototype.android_setUseAudioMixer = function (useAudioMixer) {
            var _this = this;
            var $ = function () { return (_this._instance.setUseAudioMixer(useAudioMixer), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Get the setting of whether the client mixing uses audio mixing.
         *
         */
        MixedStreamClientMixConfig_1.prototype.android_getUseAudioMixer = function () {
            var _this = this;
            var $ = function () { return _this._instance.getUseAudioMixer(); };
            return $();
        };
        return MixedStreamClientMixConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamClientMixConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var PublicStreaming = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var PublicStreaming = _classThis = /** @class */ (function () {
        function PublicStreaming_1() {
        }
        /** {en}
         * @platform android
         *  @type api
         *  @brief Get the default setting of a public stream.
         *  @return The default setting of a public stream. Refer to {@link PublicStreaming PublicStreaming} for more details.
         *
         */
        PublicStreaming_1.android_getDefualtPublicStreaming = function () {
            var $ = function () { return PublicStreaming$1.getDefualtPublicStreaming(); };
            return $();
        };
        /** {en}
         * @platform ios
         * @brief Get the default setting of a public stream.
         * @return {@link ByteRTCPublicStreaming ByteRTCPublicStreaming} struct with default values.
         */
        PublicStreaming_1.ios_defaultPublicStreaming = function () {
            var $ = function () { return packObject(ByteRTCPublicStreaming.defaultPublicStreaming(), PublicStreaming); };
            return $();
        };
        Object.defineProperty(PublicStreaming_1.prototype, "ios_layout", {
            /** {en}
             * @platform ios
             * @brief Required. Layout configuration of the public stream. Refer to {@link ByteRTCPublicStreamLayout ByteRTCPublicStreamLayout} for details.
             */
            get: function () {
                return this._instance.layout;
            },
            set: function (value) {
                this._instance.layout = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(PublicStreaming_1.prototype, "ios_video", {
            /** {en}
             * @platform ios
             * @brief Encoding properties of the public video stream. Refer to {@link ByteRTCPublicStreamVideoConfig ByteRTCPublicStreamVideoConfig} for details.
             */
            get: function () {
                return this._instance.video;
            },
            set: function (value) {
                this._instance.video = value;
            },
            enumerable: false,
            configurable: true
        });
        PublicStreaming_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        PublicStreaming_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCPublicStreaming).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = PublicStreaming$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Set the ID of the room.
         * @param roomId roomID
         *
         */
        PublicStreaming_1.prototype.android_setRoomId = function (roomId) {
            var _this = this;
            var $ = function () { return (_this._instance.setRoomId(roomId), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Set the action taken to the public stream.
         * @param action The action taken to the public stream. <br>
         *               - ACTION_START: Starts
         *               - ACTION_CHANGED: Updates
         *               - ACTION_STOPPED: Stops
         *
         */
        PublicStreaming_1.prototype.android_setAction = function (action) {
            var _this = this;
            var $ = function () { return (_this._instance.setAction(action), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Set the layout of the public stream
         * @param layout Required. Layout configuration of the public stream. Refer to [Layout](#layout-2) for details.
         *
         */
        PublicStreaming_1.prototype.android_setLayout = function (layout) {
            var _this = this;
            var $ = function () { return (_this._instance.setLayout(layout), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Get the layout of the public stream
         * @return Layout configuration of the public stream. Refer to [Layout](#layout-2) for details.
         *
         */
        PublicStreaming_1.prototype.android_getLayout = function () {
            var _this = this;
            var $ = function () { return _this._instance.getLayout(); };
            return $();
        };
        return PublicStreaming_1;
    }());
    __setFunctionName(_classThis, "PublicStreaming");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        PublicStreaming = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return PublicStreaming = _classThis;
}();
exports.StreamIndex = void 0;
(function (StreamIndex) {
    StreamIndex[StreamIndex["STREAM_INDEX_MAIN"] = 0] = "STREAM_INDEX_MAIN";
    StreamIndex[StreamIndex["STREAM_INDEX_SCREEN"] = 1] = "STREAM_INDEX_SCREEN";
})(exports.StreamIndex || (exports.StreamIndex = {}));
exports.RemoteAudioStateChangeReason = void 0;
(function (RemoteAudioStateChangeReason) {
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_CONGESTION"] = 0] = "REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_CONGESTION";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_RECOVERY"] = 1] = "REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_RECOVERY";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_MUTED"] = 2] = "REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_MUTED";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_UNMUTED"] = 3] = "REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_UNMUTED";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_MUTED"] = 4] = "REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_MUTED";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_UNMUTED"] = 5] = "REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_UNMUTED";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_OFFLINE"] = 6] = "REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_OFFLINE";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["REMOTE_AUDIO_STATE_CHANGE_REASON_INTERNAL"] = 7] = "REMOTE_AUDIO_STATE_CHANGE_REASON_INTERNAL";
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["ByteRTCRemoteAudioStateChangeReasonInternal"] = 8] = "ByteRTCRemoteAudioStateChangeReasonInternal";
})(exports.RemoteAudioStateChangeReason || (exports.RemoteAudioStateChangeReason = {}));
exports.PlayerError = void 0;
(function (PlayerError) {
    PlayerError[PlayerError["OK"] = 0] = "OK";
    PlayerError[PlayerError["FORMAT_NOT_SUPPORT"] = 1] = "FORMAT_NOT_SUPPORT";
    PlayerError[PlayerError["INVALID_PATH"] = 2] = "INVALID_PATH";
    PlayerError[PlayerError["INVALID_STATE"] = 3] = "INVALID_STATE";
    PlayerError[PlayerError["INVALID_POSITION"] = 4] = "INVALID_POSITION";
    PlayerError[PlayerError["INVALID_VOLUME"] = 5] = "INVALID_VOLUME";
    PlayerError[PlayerError["INVALID_PITCH"] = 6] = "INVALID_PITCH";
    PlayerError[PlayerError["INVALID_AUDIO_TRACK_INDEX"] = 7] = "INVALID_AUDIO_TRACK_INDEX";
    PlayerError[PlayerError["INVALID_PLAYBACK_SPEED"] = 8] = "INVALID_PLAYBACK_SPEED";
    PlayerError[PlayerError["INVALID_EFFECT_ID"] = 9] = "INVALID_EFFECT_ID";
    PlayerError[PlayerError["ByteRTCPlayerErrorInvalidPath"] = 10] = "ByteRTCPlayerErrorInvalidPath";
    PlayerError[PlayerError["ByteRTCPlayerErrorInvalidState"] = 11] = "ByteRTCPlayerErrorInvalidState";
    PlayerError[PlayerError["ByteRTCPlayerErrorInvalidPosition"] = 12] = "ByteRTCPlayerErrorInvalidPosition";
    PlayerError[PlayerError["ByteRTCPlayerErrorInvalidVolume"] = 13] = "ByteRTCPlayerErrorInvalidVolume";
    PlayerError[PlayerError["ByteRTCPlayerErrorInvalidPitch"] = 14] = "ByteRTCPlayerErrorInvalidPitch";
    PlayerError[PlayerError["ByteRTCPlayerErrorInvalidAudioTrackIndex"] = 15] = "ByteRTCPlayerErrorInvalidAudioTrackIndex";
    PlayerError[PlayerError["ByteRTCPlayerErrorInvalidPlaybackSpeed"] = 16] = "ByteRTCPlayerErrorInvalidPlaybackSpeed";
    PlayerError[PlayerError["ByteRTCPlayerErrorInvalidEffectId"] = 17] = "ByteRTCPlayerErrorInvalidEffectId";
})(exports.PlayerError || (exports.PlayerError = {}));
exports.ReturnStatus = void 0;
(function (ReturnStatus) {
    ReturnStatus[ReturnStatus["RETURN_STATUS_SUCCESS"] = 0] = "RETURN_STATUS_SUCCESS";
    ReturnStatus[ReturnStatus["RETURN_STATUS_FAILURE"] = 1] = "RETURN_STATUS_FAILURE";
    ReturnStatus[ReturnStatus["RETURN_STATUS_PARAMETER_ERR"] = 2] = "RETURN_STATUS_PARAMETER_ERR";
    ReturnStatus[ReturnStatus["RETURN_STATUS_WRONG_STATE"] = 3] = "RETURN_STATUS_WRONG_STATE";
    ReturnStatus[ReturnStatus["RETURN_STATUS_HAS_IN_ROOM"] = 4] = "RETURN_STATUS_HAS_IN_ROOM";
    ReturnStatus[ReturnStatus["RETURN_STATUS_HAS_IN_LOGIN"] = 5] = "RETURN_STATUS_HAS_IN_LOGIN";
    ReturnStatus[ReturnStatus["RETURN_STATUS_HAS_IN_ECHO_TEST"] = 6] = "RETURN_STATUS_HAS_IN_ECHO_TEST";
    ReturnStatus[ReturnStatus["RETURN_STATUS_NEITHER_VIDEO_NOR_AUDIO"] = 7] = "RETURN_STATUS_NEITHER_VIDEO_NOR_AUDIO";
    ReturnStatus[ReturnStatus["RETURN_STATUS_ROOMID_IN_USE"] = 8] = "RETURN_STATUS_ROOMID_IN_USE";
    ReturnStatus[ReturnStatus["RETURN_STATUS_SCREEN_NOT_SUPPORT"] = 9] = "RETURN_STATUS_SCREEN_NOT_SUPPORT";
    ReturnStatus[ReturnStatus["RETURN_STATUS_NOT_SUPPORT"] = 10] = "RETURN_STATUS_NOT_SUPPORT";
    ReturnStatus[ReturnStatus["RETURN_STATUS_RESOURCE_OVERFLOW"] = 11] = "RETURN_STATUS_RESOURCE_OVERFLOW";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_NO_FRAME"] = 12] = "RETURN_STATUS_AUDIO_NO_FRAME";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_NOT_IMPLEMENTED"] = 13] = "RETURN_STATUS_AUDIO_NOT_IMPLEMENTED";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_NO_PERMISSION"] = 14] = "RETURN_STATUS_AUDIO_NO_PERMISSION";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_DEVICE_NOT_EXISTS"] = 15] = "RETURN_STATUS_AUDIO_DEVICE_NOT_EXISTS";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_DEVICE_FORMAT_NOT_SUPPORT"] = 16] = "RETURN_STATUS_AUDIO_DEVICE_FORMAT_NOT_SUPPORT";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_DEVICE_NO_DEVICE"] = 17] = "RETURN_STATUS_AUDIO_DEVICE_NO_DEVICE";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_DEVICE_CAN_NOT_USE"] = 18] = "RETURN_STATUS_AUDIO_DEVICE_CAN_NOT_USE";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_DEVICE_INIT_FAILED"] = 19] = "RETURN_STATUS_AUDIO_DEVICE_INIT_FAILED";
    ReturnStatus[ReturnStatus["RETURN_STATUS_AUDIO_DEVICE_START_FAILED"] = 20] = "RETURN_STATUS_AUDIO_DEVICE_START_FAILED";
    ReturnStatus[ReturnStatus["RETURN_STATUS_NATIVE_IN_VALID"] = 21] = "RETURN_STATUS_NATIVE_IN_VALID";
    ReturnStatus[ReturnStatus["RETURN_STATUS_VIDEO_NOT_SUPPORT"] = 22] = "RETURN_STATUS_VIDEO_NOT_SUPPORT";
    ReturnStatus[ReturnStatus["RETURN_STATUS_VIDEO_TIMESTAMP_WARNING"] = 23] = "RETURN_STATUS_VIDEO_TIMESTAMP_WARNING";
})(exports.ReturnStatus || (exports.ReturnStatus = {}));
var ScreenVideoEncoderConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ScreenVideoEncoderConfig_1() {
        }
        Object.defineProperty(ScreenVideoEncoderConfig_1.prototype, "encodePreference", {
            /** {en}
             * @brief The preference for encoding screen-sharing streams. It defaults to the high-frame-rate mode. <br>
             * See {@link EncoderPreference EncoderPreference}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_RTCScreenVideoEncoderPreference.android_to_ts(this._instance.encodePreference);
                }
                else if ($os === 'ios') {
                    return t_RTCScreenVideoEncoderPreference.ios_to_ts(this._instance.encoderPreference);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.encodePreference =
                        t_RTCScreenVideoEncoderPreference.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.encoderPreference =
                        t_RTCScreenVideoEncoderPreference.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(ScreenVideoEncoderConfig_1.prototype, "width", {
            /** {en}
             * @brief The maximum width of the captured screen, measured in pixel.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.width);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.width);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.width = value;
                }
                else if ($os === 'ios') {
                    this._instance.width = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(ScreenVideoEncoderConfig_1.prototype, "height", {
            /** {en}
             * @brief The maximum height of the captured screen, measured in pixel.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.height);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.height);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.height = value;
                }
                else if ($os === 'ios') {
                    this._instance.height = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(ScreenVideoEncoderConfig_1.prototype, "frameRate", {
            /** {en}
             * @brief The frame rate of the screen capture and encoding, measured in fps.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.frameRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.frameRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.frameRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.frameRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(ScreenVideoEncoderConfig_1.prototype, "maxBitrate", {
            /** {en}
             * @brief The maximum bitrate(in kbps). Optional for internal capture while mandatory for custom capture. <br>
             *        If you set this value to -1, RTC will automatically recommend the bitrate based on the input resolution and frame rate. <br>
             *        If you set this value to 0, the streams will not be encoded and published. <br>
             *        On Version 3.44 or later, the default value for internal capture is -1. On versions earlier than 3.44, you must set the maximum bit rate because there is no default value.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.maxBitrate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.maxBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.maxBitrate = value;
                }
                else if ($os === 'ios') {
                    this._instance.maxBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(ScreenVideoEncoderConfig_1.prototype, "minBitrate", {
            /** {en}
             * @brief The minimum bitrate(in kbps).Optional for internal capture while mandatory for custom capture. <br>
             *        The minimum bitrate must be set lower than the maximum bitrate. Otherwise, the streams will not be encoded and published.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.minBitrate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.minBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.minBitrate = value;
                }
                else if ($os === 'ios') {
                    this._instance.minBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        ScreenVideoEncoderConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        ScreenVideoEncoderConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCScreenVideoEncoderConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = ScreenVideoEncoderConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return ScreenVideoEncoderConfig_1;
    }());
    __setFunctionName(_classThis, "ScreenVideoEncoderConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MediaPlayerConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function MediaPlayerConfig_1() {
        }
        Object.defineProperty(MediaPlayerConfig_1.prototype, "type", {
            /** {en}
             * @brief For mixing playback types. See {@link AudioMixingType AudioMixingType}
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioMixingType.android_to_ts(this._instance.type);
                }
                else if ($os === 'ios') {
                    return t_AudioMixingType.ios_to_ts(this._instance.type);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.type = t_AudioMixingType.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.type = t_AudioMixingType.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MediaPlayerConfig_1.prototype, "playCount", {
            /** {en}
             * @brief Mix playback times <br>
             *        - Play_count < = 0: Infinite loop
             *        - Play_count == 1: Play once (default)
             *        - Play_count > 1: Play play_count times
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.playCount);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.playCount);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.playCount = value;
                }
                else if ($os === 'ios') {
                    this._instance.playCount = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MediaPlayerConfig_1.prototype, "startPos", {
            /** {en}
             * @brief The starting position in ms. 0 by default.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.startPos);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.startPos);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.startPos = value;
                }
                else if ($os === 'ios') {
                    this._instance.startPos = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MediaPlayerConfig_1.prototype, "callbackOnProgressInterval", {
            /** {en}
             * @brief Set the interval of the periodic callback {@link onMediaPlayerPlayingProgress onMediaPlayerPlayingProgress} during audio mixing in ms. <br>
             *       - interval > 0: The callback is enabled. The actual interval is `10*(mod(10)+1)`.
             *       - interval <= 0: The callback is disabled.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.callbackOnProgressInterval);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.callbackOnProgressInterval);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.callbackOnProgressInterval = value;
                }
                else if ($os === 'ios') {
                    this._instance.callbackOnProgressInterval = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MediaPlayerConfig_1.prototype, "syncProgressToRecordFrame", {
            /** {en}
             * @brief Attach the process information of local audio file mixing to the captured audio data. Enable the function to enhance the synchronicity of the remote audio mixing. <br>
             *        - The function is effective when mixing a single audio file.
             *        - Use `true` for enabling the function and `false` for disable the function. The default is `false`.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.syncProgressToRecordFrame;
                }
                else if ($os === 'ios') {
                    return this._instance.syncProgressToRecordFrame;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.syncProgressToRecordFrame = value;
                }
                else if ($os === 'ios') {
                    this._instance.syncProgressToRecordFrame = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MediaPlayerConfig_1.prototype, "autoPlay", {
            /** {en}
             * @brief Play the audio automatically. If not, call {@link start start} to play the audio.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.autoPlay;
                }
                else if ($os === 'ios') {
                    return this._instance.autoPlay;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.autoPlay = value;
                }
                else if ($os === 'ios') {
                    this._instance.autoPlay = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        MediaPlayerConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        MediaPlayerConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCMediaPlayerConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = MediaPlayerConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return MediaPlayerConfig_1;
    }());
    __setFunctionName(_classThis, "MediaPlayerConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.VideoPictureType = void 0;
(function (VideoPictureType) {
    VideoPictureType[VideoPictureType["VIDEO_PICTURE_TYPE_UNKNOWN"] = 0] = "VIDEO_PICTURE_TYPE_UNKNOWN";
    VideoPictureType[VideoPictureType["VIDEO_PICTURE_TYPE_I"] = 1] = "VIDEO_PICTURE_TYPE_I";
    VideoPictureType[VideoPictureType["VIDEO_PICTURE_TYPE_P"] = 2] = "VIDEO_PICTURE_TYPE_P";
    VideoPictureType[VideoPictureType["VIDEO_PICTURE_TYPE_B"] = 3] = "VIDEO_PICTURE_TYPE_B";
})(exports.VideoPictureType || (exports.VideoPictureType = {}));
exports.ColorSpace = void 0;
(function (ColorSpace) {
    ColorSpace[ColorSpace["UNKNOWN"] = 0] = "UNKNOWN";
    ColorSpace[ColorSpace["BT601_LIMITED_RANGE"] = 1] = "BT601_LIMITED_RANGE";
    ColorSpace[ColorSpace["BT601_FULL_RANGE"] = 2] = "BT601_FULL_RANGE";
    ColorSpace[ColorSpace["BT709_LIMITED_RANGE"] = 3] = "BT709_LIMITED_RANGE";
    ColorSpace[ColorSpace["BT709_FULL_RANGE"] = 4] = "BT709_FULL_RANGE";
    ColorSpace[ColorSpace["ByteRTCColorSpaceYCbCrBT601LimitedRange"] = 5] = "ByteRTCColorSpaceYCbCrBT601LimitedRange";
    ColorSpace[ColorSpace["ByteRTCColorSpaceYCbCrBT601FullRange"] = 6] = "ByteRTCColorSpaceYCbCrBT601FullRange";
    ColorSpace[ColorSpace["ByteRTCColorSpaceYCbCrBT709LimitedRange"] = 7] = "ByteRTCColorSpaceYCbCrBT709LimitedRange";
    ColorSpace[ColorSpace["ByteRTCColorSpaceYCbCrBT709FullRange"] = 8] = "ByteRTCColorSpaceYCbCrBT709FullRange";
})(exports.ColorSpace || (exports.ColorSpace = {}));
var AudioPropertiesInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function AudioPropertiesInfo_1() {
        }
        Object.defineProperty(AudioPropertiesInfo_1.prototype, "linearVolume", {
            /** {en}
             * @brief linear volume. The value is in linear relation to the original volume. The higher the value, the higher the volume. The range is [0,255]. <br>
             *        - [0, 25]: Silence
             *        - [26, 75]: Low volume
             *        - [76, 204]: Medium volume
             *        - [205, 255]: High volume
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.linearVolume);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.linearVolume);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.linearVolume = value;
                }
                else if ($os === 'ios') {
                    this._instance.linearVolume = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioPropertiesInfo_1.prototype, "nonlinearVolume", {
            /** {en}
             * @brief non-linear volume in dB. The value is in proportion to the log value of the original volume. You can use the value to recognize the Active Speaker in the room. The range is [-127, 0]. <br>
             *        - [-127, -60]: Silence
             *        - [-59, -40]: Low volume
             *        - [-39, -20]: Medium volume
             *        - [-19, 0]: High volume
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.nonlinearVolume);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.nonlinearVolume);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.nonlinearVolume = value;
                }
                else if ($os === 'ios') {
                    this._instance.nonlinearVolume = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioPropertiesInfo_1.prototype, "spectrum", {
            /** {en}
             * @brief Spectrum array
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.spectrum.map(function ($item) { return Number($item); });
                }
                else if ($os === 'ios') {
                    return this._instance.spectrum.map(function ($item) { return Number($item); });
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.spectrum = value;
                }
                else if ($os === 'ios') {
                    this._instance.spectrum = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioPropertiesInfo_1.prototype, "vad", {
            /** {en}
             * @brief Voice Activity Detection (VAD) result <br>
             *        - 1: Voice activity detected.
             *        - 0: No voice activity detected.
             *        - -1: VAD not activated.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.vad);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.vad);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.vad = value;
                }
                else if ($os === 'ios') {
                    this._instance.vad = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioPropertiesInfo_1.prototype, "voicePitch", {
            /** {en}
             * @brief The vocal pitch of the local user, in Hertz. <br>
             *        When the following two conditions are met at the same time, the vocal pitch of the local user will be returned: <br>
             *      - Calls {@link enableAudioPropertiesReport enableAudioPropertiesReport}, and sets the value of enableVoicePitch to `true`.
             *      - The local user's voice is included in the locally captured audio data.
             *        In other situations, `0` will be returned.
             *
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.voicePitch);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.voicePitch);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.voicePitch = value;
                }
                else if ($os === 'ios') {
                    this._instance.voicePitch = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        AudioPropertiesInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        AudioPropertiesInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCAudioPropertiesInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = AudioPropertiesInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return AudioPropertiesInfo_1;
    }());
    __setFunctionName(_classThis, "AudioPropertiesInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.RemoteVideoState = void 0;
(function (RemoteVideoState) {
    RemoteVideoState[RemoteVideoState["REMOTE_VIDEO_STATE_STOPPED"] = 0] = "REMOTE_VIDEO_STATE_STOPPED";
    RemoteVideoState[RemoteVideoState["REMOTE_VIDEO_STATE_STARTING"] = 1] = "REMOTE_VIDEO_STATE_STARTING";
    RemoteVideoState[RemoteVideoState["REMOTE_VIDEO_STATE_DECODING"] = 2] = "REMOTE_VIDEO_STATE_DECODING";
    RemoteVideoState[RemoteVideoState["REMOTE_VIDEO_STATE_FROZEN"] = 3] = "REMOTE_VIDEO_STATE_FROZEN";
    RemoteVideoState[RemoteVideoState["ByteRTCRemoteVideoStateFailed"] = 4] = "ByteRTCRemoteVideoStateFailed";
})(exports.RemoteVideoState || (exports.RemoteVideoState = {}));
exports.HardwareEchoDetectionResult = void 0;
(function (HardwareEchoDetectionResult) {
    HardwareEchoDetectionResult[HardwareEchoDetectionResult["HARDWARE_ECHO_RESULT_CANCELED"] = 0] = "HARDWARE_ECHO_RESULT_CANCELED";
    HardwareEchoDetectionResult[HardwareEchoDetectionResult["HARDWARE_ECHO_RESULT_UNKNOWN"] = 1] = "HARDWARE_ECHO_RESULT_UNKNOWN";
    HardwareEchoDetectionResult[HardwareEchoDetectionResult["HARDWARE_ECHO_RESULT_NORMAL"] = 2] = "HARDWARE_ECHO_RESULT_NORMAL";
    HardwareEchoDetectionResult[HardwareEchoDetectionResult["HARDWARE_ECHO_RESULT_POOR"] = 3] = "HARDWARE_ECHO_RESULT_POOR";
    HardwareEchoDetectionResult[HardwareEchoDetectionResult["ByteRTCHardwareEchoDetectionCanceled"] = 4] = "ByteRTCHardwareEchoDetectionCanceled";
    HardwareEchoDetectionResult[HardwareEchoDetectionResult["ByteRTCHardwareEchoDetectionUnknown"] = 5] = "ByteRTCHardwareEchoDetectionUnknown";
    HardwareEchoDetectionResult[HardwareEchoDetectionResult["ByteRTCHardwareEchoDetectionNormal"] = 6] = "ByteRTCHardwareEchoDetectionNormal";
    HardwareEchoDetectionResult[HardwareEchoDetectionResult["ByteRTCHardwareEchoDetectionPoor"] = 7] = "ByteRTCHardwareEchoDetectionPoor";
})(exports.HardwareEchoDetectionResult || (exports.HardwareEchoDetectionResult = {}));
var SubscribeVideoConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function SubscribeVideoConfig_1() {
        }
        Object.defineProperty(SubscribeVideoConfig_1.prototype, "ios_videoIndex", {
            /** {en}
             * @platform ios
             * @brief Subscribed video stream resolution subscript. <br>
             *        Quality level of the video stream subscribed to. <br>
             *        In Simulcast mode, use a number to specify the expected quality of the video stream to be subscribed to.  In Simulcast mode, a video has a diversity of encoded qualities that ranking from 0 to 3. Call {@link enableSimulcastMode enableSimulcastMode:} to enable Simulcast mode on the publisher's clients. <br>
             *         Ranging from -1 to 3 <br>
             *         0 (Default): The best quality <br>
             *         -1: Use the previous settings.
             */
            get: function () {
                return this._instance.videoIndex;
            },
            set: function (value) {
                this._instance.videoIndex = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubscribeVideoConfig_1.prototype, "ios_priority", {
            /** {en}
             * @platform ios
             * @brief Remote user priority. See {@link ByteRTCRemoteUserPriority ByteRTCRemoteUserPriority}, the default value is 0.
             */
            get: function () {
                return this._instance.priority;
            },
            set: function (value) {
                this._instance.priority = value;
            },
            enumerable: false,
            configurable: true
        });
        SubscribeVideoConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        SubscribeVideoConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCSubscribeVideoConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = SubscribeVideoConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return SubscribeVideoConfig_1;
    }());
    __setFunctionName(_classThis, "SubscribeVideoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.RecordingState = void 0;
(function (RecordingState) {
    RecordingState[RecordingState["RECORDING_STATE_PROCESSING"] = 0] = "RECORDING_STATE_PROCESSING";
    RecordingState[RecordingState["RECORDING_STATE_SUCCESS"] = 1] = "RECORDING_STATE_SUCCESS";
    RecordingState[RecordingState["RECORDING_STATE_ERROE"] = 2] = "RECORDING_STATE_ERROE";
    RecordingState[RecordingState["ByteRTCRecordingStateError"] = 3] = "ByteRTCRecordingStateError";
})(exports.RecordingState || (exports.RecordingState = {}));
exports.NetworkDetectionLinkType = void 0;
(function (NetworkDetectionLinkType) {
    NetworkDetectionLinkType[NetworkDetectionLinkType["UP"] = 0] = "UP";
    NetworkDetectionLinkType[NetworkDetectionLinkType["DOWN"] = 1] = "DOWN";
})(exports.NetworkDetectionLinkType || (exports.NetworkDetectionLinkType = {}));
var RTCStream = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RTCStream_1() {
        }
        /**
         * @platform android
         */
        RTCStream_1.android_create = function (userId, streamIndex, isScreen, hasVideo, hasAudio) {
            var $ = function () { return RTCStream$1.create(userId, streamIndex, isScreen, hasVideo, hasAudio); };
            return $();
        };
        /**
         * @platform android
         */
        RTCStream_1.android_createWithStreamDescriptions = function (userId, streamIndex, isScreen, hasVideo, hasAudio, videoStreamDescriptions) {
            var $ = function () {
                return RTCStream$1.createWithStreamDescriptions(userId, streamIndex, isScreen, hasVideo, hasAudio, videoStreamDescriptions);
            };
            return $();
        };
        Object.defineProperty(RTCStream_1.prototype, "userId", {
            /** {en}
             * @brief The user ID that published this stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.userId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.userId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCStream_1.prototype, "isScreen", {
            /** {en}
             * @brief Whether this stream is a shared screen stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.isScreen;
                }
                else if ($os === 'ios') {
                    return this._instance.isScreen;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCStream_1.prototype, "hasVideo", {
            /** {en}
             * @brief Whether this stream includes a video stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.hasVideo;
                }
                else if ($os === 'ios') {
                    return this._instance.hasVideo;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCStream_1.prototype, "hasAudio", {
            /** {en}
             * @brief Whether the stream includes an audio stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.hasAudio;
                }
                else if ($os === 'ios') {
                    return this._instance.hasAudio;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCStream_1.prototype, "videoStreamDescriptions", {
            /** {en}
             * @brief Properties of the video stream. <br>
             *        When a remote user calls the {@link setVideoEncoderConfig setVideoEncoderConfig} method to publish multiple configured video streams, this will contain attribute information for all video streams published by the user. <br>
             *         See {@link VideoStreamDescription VideoStreamDescription}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.videoStreamDescriptions;
                }
                else if ($os === 'ios') {
                    return this._instance.videoStreamDescriptions;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCStream_1.prototype, "ios_maxVideoStreamDescription", {
            /** {en}
             * @platform ios
             * @brief The maximum resolution of the video stream, the maximum publish resolution that can be supported by the callback publisher when multi-resolution publish subscription is enabled.
             */
            get: function () {
                return this._instance.maxVideoStreamDescription;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCStream_1.prototype, "ios_index", {
            /**
             * @platform ios
             */
            /**
             * @platform ios
             */
            get: function () {
                return this._instance.index;
            },
            enumerable: false,
            configurable: true
        });
        return RTCStream_1;
    }());
    __setFunctionName(_classThis, "RTCStream");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.VideoDenoiseModeChangedReason = void 0;
(function (VideoDenoiseModeChangedReason) {
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_NULL"] = 0] = "VIDEO_DENOISE_MODE_CHANGED_REASON_NULL";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_API_OFF"] = 1] = "VIDEO_DENOISE_MODE_CHANGED_REASON_API_OFF";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_API_ON"] = 2] = "VIDEO_DENOISE_MODE_CHANGED_REASON_API_ON";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_DISABLED"] = 3] = "VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_DISABLED";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_ENABLED"] = 4] = "VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_ENABLED";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_CLOSE"] = 5] = "VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_CLOSE";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_OPEN"] = 6] = "VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_OPEN";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_RESOLUTION"] = 7] = "VIDEO_DENOISE_MODE_CHANGED_REASON_RESOLUTION";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["VIDEO_DENOISE_MODE_CHANGED_REASON_INTERNAL_EXCEPTION"] = 8] = "VIDEO_DENOISE_MODE_CHANGED_REASON_INTERNAL_EXCEPTION";
    VideoDenoiseModeChangedReason[VideoDenoiseModeChangedReason["ByteRTCVideoDenoiseModeChangedReasonInternalException"] = 9] = "ByteRTCVideoDenoiseModeChangedReasonInternalException";
})(exports.VideoDenoiseModeChangedReason || (exports.VideoDenoiseModeChangedReason = {}));
exports.AudioDeviceType = void 0;
(function (AudioDeviceType) {
    AudioDeviceType[AudioDeviceType["AUDIO_DEVICE_TYPE_UNKNOWN"] = 0] = "AUDIO_DEVICE_TYPE_UNKNOWN";
    AudioDeviceType[AudioDeviceType["AUDIO_DEVICE_TYPE_RENDER_DEVICE"] = 1] = "AUDIO_DEVICE_TYPE_RENDER_DEVICE";
    AudioDeviceType[AudioDeviceType["AUDIO_DEVICE_TYPE_CAPTURE_DEVICE"] = 2] = "AUDIO_DEVICE_TYPE_CAPTURE_DEVICE";
    AudioDeviceType[AudioDeviceType["AUDIO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE"] = 3] = "AUDIO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE";
})(exports.AudioDeviceType || (exports.AudioDeviceType = {}));
exports.SetRoomExtraInfoResult = void 0;
(function (SetRoomExtraInfoResult) {
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["SUCCESS"] = 0] = "SUCCESS";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["NOT_JOIN_ROOM"] = 1] = "NOT_JOIN_ROOM";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["KEY_IS_NULL"] = 2] = "KEY_IS_NULL";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["VALUE_IS_NULL"] = 3] = "VALUE_IS_NULL";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["UNKNOW"] = 4] = "UNKNOW";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["KEY_IS_EMPTY"] = 5] = "KEY_IS_EMPTY";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["TOO_OFTEN"] = 6] = "TOO_OFTEN";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["SILENT_USER"] = 7] = "SILENT_USER";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["KEY_TOO_LONG"] = 8] = "KEY_TOO_LONG";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["VALUE_TOO_LONG"] = 9] = "VALUE_TOO_LONG";
    SetRoomExtraInfoResult[SetRoomExtraInfoResult["SERVER_ERROR"] = 10] = "SERVER_ERROR";
})(exports.SetRoomExtraInfoResult || (exports.SetRoomExtraInfoResult = {}));
exports.LocalProxyState = void 0;
(function (LocalProxyState) {
    LocalProxyState[LocalProxyState["CONNECTED"] = 0] = "CONNECTED";
    LocalProxyState[LocalProxyState["ERROR"] = 1] = "ERROR";
    LocalProxyState[LocalProxyState["INITED"] = 2] = "INITED";
    LocalProxyState[LocalProxyState["ByteRTCLocalProxyStateInited"] = 3] = "ByteRTCLocalProxyStateInited";
})(exports.LocalProxyState || (exports.LocalProxyState = {}));
exports.AVSyncState = void 0;
(function (AVSyncState) {
    AVSyncState[AVSyncState["AV_SYNC_STATE_AUDIO_STREAM_REMOVE"] = 0] = "AV_SYNC_STATE_AUDIO_STREAM_REMOVE";
    AVSyncState[AVSyncState["AV_SYNC_STATE_VIDEO_STREAM_REMOVE"] = 1] = "AV_SYNC_STATE_VIDEO_STREAM_REMOVE";
    AVSyncState[AVSyncState["AV_SYNC_STATE_STREAM_SYNC_BEGIN"] = 2] = "AV_SYNC_STATE_STREAM_SYNC_BEGIN";
})(exports.AVSyncState || (exports.AVSyncState = {}));
var RTCRoomConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RTCRoomConfig_1() {
        }
        Object.defineProperty(RTCRoomConfig_1.prototype, "profile", {
            /** {en}
             * @brief Room profile. See {@link ChannelProfile ChannelProfile}. The default is `CHANNEL_PROFILE_COMMUNICATION`. The setting cannot be changed after joining the room.
             *
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_ChannelProfile.android_to_ts(this._instance.profile);
                }
                else if ($os === 'ios') {
                    return t_ChannelProfile.ios_to_ts(this._instance.profile);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.profile = t_ChannelProfile.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.profile = t_ChannelProfile.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomConfig_1.prototype, "isAutoPublish", {
            /** {en}
             * @brief Whether to publish media streams automatically. The default is automatic publishing. <br>
             *        Only one of the rooms the user joined can be set to auto-publish. If no settings are made in each room, the stream is automatically published in the first room joined by default. <br>
             *        If you call {@link setUserVisibility setUserVisibility} to set your own visibility to false, you will not publish media streams regardless of the value of `isAutoPublish`.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.isAutoPublish;
                }
                else if ($os === 'ios') {
                    return this._instance.isAutoPublish;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.isAutoPublish = value;
                }
                else if ($os === 'ios') {
                    this._instance.isAutoPublish = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomConfig_1.prototype, "isAutoSubscribeAudio", {
            /** {en}
             * @brief Whether to automatically subscribe to the audio stream. The default is automatic subscription. <br>
             *        This setting affects both the main stream and the screen-sharing stream.
             *
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.isAutoSubscribeAudio;
                }
                else if ($os === 'ios') {
                    return this._instance.isAutoSubscribeAudio;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.isAutoSubscribeAudio = value;
                }
                else if ($os === 'ios') {
                    this._instance.isAutoSubscribeAudio = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomConfig_1.prototype, "isAutoSubscribeVideo", {
            /** {en}
             * @brief Whether to automatically subscribe to the main video stream. The default is automatic subscription. <br>
             *        This setting affects both the main stream and the screen-sharing stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.isAutoSubscribeVideo;
                }
                else if ($os === 'ios') {
                    return this._instance.isAutoSubscribeVideo;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.isAutoSubscribeVideo = value;
                }
                else if ($os === 'ios') {
                    this._instance.isAutoSubscribeVideo = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCRoomConfig_1.prototype, "remoteVideoConfig", {
            /** {en}
             * @brief Expected configuration of remote video stream, see {@link RemoteVideoConfig RemoteVideoConfig}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return packObject(this._instance.remoteVideoConfig, RemoteVideoConfig);
                }
                else if ($os === 'ios') {
                    return packObject(this._instance.remoteVideoConfig, RemoteVideoConfig);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.remoteVideoConfig = unpackObject(value);
                }
                else if ($os === 'ios') {
                    this._instance.remoteVideoConfig = unpackObject(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        RTCRoomConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RTCRoomConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRoomConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RTCRoomConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RTCRoomConfig_1;
    }());
    __setFunctionName(_classThis, "RTCRoomConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var Rectangle = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function Rectangle_1() {
        }
        Object.defineProperty(Rectangle_1.prototype, "x", {
            /** {en}
             * @brief The x coordinate of the upper left corner of the rectangular area
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.x);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.x);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.x = value;
                }
                else if ($os === 'ios') {
                    this._instance.x = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Rectangle_1.prototype, "y", {
            /** {en}
             * @brief The y coordinate of the upper left corner of the rectangular area
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.y);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.y);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.y = value;
                }
                else if ($os === 'ios') {
                    this._instance.y = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Rectangle_1.prototype, "width", {
            /** {en}
             * @brief Rectangle width in px
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.width);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.width);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.width = value;
                }
                else if ($os === 'ios') {
                    this._instance.width = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Rectangle_1.prototype, "height", {
            /** {en}
             * @brief Rectangular height in px
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.height);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.height);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.height = value;
                }
                else if ($os === 'ios') {
                    this._instance.height = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Rectangle_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        Rectangle_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRectangle).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = Rectangle$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return Rectangle_1;
    }());
    __setFunctionName(_classThis, "Rectangle");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.MixedStreamClientMixVideoFormat = void 0;
(function (MixedStreamClientMixVideoFormat) {
    MixedStreamClientMixVideoFormat[MixedStreamClientMixVideoFormat["MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_TEXTURE_2D"] = 0] = "MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_TEXTURE_2D";
    MixedStreamClientMixVideoFormat[MixedStreamClientMixVideoFormat["MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_CVPIXEL_BUFFER_BGRA"] = 1] = "MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_CVPIXEL_BUFFER_BGRA";
    MixedStreamClientMixVideoFormat[MixedStreamClientMixVideoFormat["MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_I420"] = 2] = "MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_I420";
    MixedStreamClientMixVideoFormat[MixedStreamClientMixVideoFormat["MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_NV12"] = 3] = "MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_NV12";
    MixedStreamClientMixVideoFormat[MixedStreamClientMixVideoFormat["ByteRTCMixedStreamClientMixVideoFormatI420"] = 4] = "ByteRTCMixedStreamClientMixVideoFormatI420";
    MixedStreamClientMixVideoFormat[MixedStreamClientMixVideoFormat["ByteRTCMixedStreamClientMixVideoFormatNV12"] = 5] = "ByteRTCMixedStreamClientMixVideoFormatNV12";
})(exports.MixedStreamClientMixVideoFormat || (exports.MixedStreamClientMixVideoFormat = {}));
exports.VideoRotationMode = void 0;
(function (VideoRotationMode) {
    VideoRotationMode[VideoRotationMode["FOLLOW_APP"] = 0] = "FOLLOW_APP";
    VideoRotationMode[VideoRotationMode["FOLLOW_GSENSOR"] = 1] = "FOLLOW_GSENSOR";
})(exports.VideoRotationMode || (exports.VideoRotationMode = {}));
exports.PlayerState = void 0;
(function (PlayerState) {
    PlayerState[PlayerState["PRELOADED"] = 0] = "PRELOADED";
    PlayerState[PlayerState["OPENED"] = 1] = "OPENED";
    PlayerState[PlayerState["PLAYING"] = 2] = "PLAYING";
    PlayerState[PlayerState["PAUSED"] = 3] = "PAUSED";
    PlayerState[PlayerState["STOPPED"] = 4] = "STOPPED";
    PlayerState[PlayerState["FAILED"] = 5] = "FAILED";
    PlayerState[PlayerState["FINISHED"] = 6] = "FINISHED";
    PlayerState[PlayerState["IDLE"] = 7] = "IDLE";
    PlayerState[PlayerState["ByteRTCPlayerStateIdle"] = 8] = "ByteRTCPlayerStateIdle";
})(exports.PlayerState || (exports.PlayerState = {}));
exports.MixedStreamVideoType = void 0;
(function (MixedStreamVideoType) {
    MixedStreamVideoType[MixedStreamVideoType["MIXED_STREAM_VIDEO_TYPE_MAIN"] = 0] = "MIXED_STREAM_VIDEO_TYPE_MAIN";
    MixedStreamVideoType[MixedStreamVideoType["MIXED_STREAM_VIDEO_TYPE_SCREEN"] = 1] = "MIXED_STREAM_VIDEO_TYPE_SCREEN";
})(exports.MixedStreamVideoType || (exports.MixedStreamVideoType = {}));
var MixedStreamLayoutRegionConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function MixedStreamLayoutRegionConfig_1() {
        }
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_userID", {
            /** {en}
             * @platform ios
             * @brief The user ID of the user who publishes the video stream. It's recommended to be set.
             */
            get: function () {
                return this._instance.userID;
            },
            set: function (value) {
                this._instance.userID = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_roomID", {
            /** {en}
             * @platform ios
             * @brief The room ID of the media stream. It's recommended to be set. <br>
             *        If the media stream is the stream forwarded by {@link startForwardStreamToRooms startForwardStreamToRooms:}, you must set the roomID to the room ID of the target room.
             */
            get: function () {
                return this._instance.roomID;
            },
            set: function (value) {
                this._instance.roomID = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_locationX", {
            /** {en}
             * @platform ios
             * @brief The X-coordinate in pixels of the upper-left corner of the user's frame in the entire canvas coordinate system, where the origin is at the upper-left corner of the canvas. It represents the horizontal displacement of the upper-left corner of the user's frame relative to the origin. <br>
             *        The value range is [0, the width of the canvas). The default value is 0.
             */
            get: function () {
                return this._instance.locationX;
            },
            set: function (value) {
                this._instance.locationX = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_locationY", {
            /** {en}
             * @platform ios
             * @brief The Y-coordinate in pixels of the upper-left corner of the user's frame in the entire canvas coordinate system, where the origin is at the upper-left corner of the canvas. It represents the vertical displacement of the upper-left corner of the user's frame relative to the origin. <br>
             *        The value range is [0, the height of the canvas). The default value is 0.
             */
            get: function () {
                return this._instance.locationY;
            },
            set: function (value) {
                this._instance.locationY = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_width", {
            /** {en}
             * @platform ios
             * @brief The width of the user's frame in pixels. The value range is [0, the width of the canvas]. The default value is 360.
             */
            get: function () {
                return this._instance.width;
            },
            set: function (value) {
                this._instance.width = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_height", {
            /** {en}
             * @platform ios
             * @brief The heigh of the user's frame in pixels. The value range is [0, the height of the canvas]. The default value is 640.
             */
            get: function () {
                return this._instance.height;
            },
            set: function (value) {
                this._instance.height = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_zOrder", {
            /** {en}
             * @platform ios
             * @brief The layer on which the video is rendered. The range is [0, 100]. 0 for the bottom layer, and 100 for the top layer. The default value is 0. It's recommended to be set.
             */
            get: function () {
                return this._instance.zOrder;
            },
            set: function (value) {
                this._instance.zOrder = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_isLocalUser", {
            /** {en}
             * @platform ios
             *  @brief Whether the source user of the stream is a local user.
             */
            get: function () {
                return this._instance.isLocalUser;
            },
            set: function (value) {
                this._instance.isLocalUser = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_streamType", {
            /** {en}
             * @platform ios
             *  @brief The mixed stream type, the default value is Main.
             */
            get: function () {
                return this._instance.streamType;
            },
            set: function (value) {
                this._instance.streamType = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_alpha", {
            /** {en}
             * @platform ios
             * @brief The opacity in range of (0.0, 1.0]. The lower value, the more transparent. The default value is 1.0.
             */
            get: function () {
                return this._instance.alpha;
            },
            set: function (value) {
                this._instance.alpha = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_cornerRadius", {
            /** {en}
             * @platform ios
             * @brief The proportion of the radius to the width of the canvas. `0.0` by default. <br>
             *        After you set the value, `width_px`, `height_px`, and `cornerRadius_px` are calculated based on `width`, `height`, `cornerRadius`, and the width of the canvas. If `cornerRadius_px < min(width_px/2, height_px/2)` is met, the value of `cornerRadius` is set valid; if not, `cornerRadius_px` is set to `min(width_px/2, height_px/2)`, and `cornerRadius` is set to the proportion of `cornerRadius_px` to the width of the canvas.
             */
            get: function () {
                return this._instance.cornerRadius;
            },
            set: function (value) {
                this._instance.cornerRadius = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_mediaType", {
            /** {en}
             * @platform ios
             * @brief The stream mixing content type. The default value is `ByteRTCTranscoderContentControlTypeHasAudioAndVideo`. See {@link ByteRTCMixedStreamMediaType ByteRTCMixedStreamMediaType}.
             */
            get: function () {
                return this._instance.mediaType;
            },
            set: function (value) {
                this._instance.mediaType = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_renderMode", {
            /** {en}
             * @platform ios
             * @brief The render mode. See {@link ByteRTCMixedStreamRenderMode ByteRTCMixedStreamRenderMode}. The default value is 1.
             */
            get: function () {
                return this._instance.renderMode;
            },
            set: function (value) {
                this._instance.renderMode = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_regionContentType", {
            /** {en}
             * @platform ios
             * @brief Stream mixing region type. See {@link ByteRTCMixedStreamLayoutRegionType ByteRTCMixedStreamLayoutRegionType}. It's recommended to be set.
             */
            get: function () {
                return this._instance.regionContentType;
            },
            set: function (value) {
                this._instance.regionContentType = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_imageWaterMark", {
            /** {en}
             * @platform ios
             * @brief   The RGBA data of the mixing image. Put in null when mixing video streams.
             */
            get: function () {
                return this._instance.imageWaterMark;
            },
            set: function (value) {
                this._instance.imageWaterMark = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_imageWaterMarkConfig", {
            /** {en}
             * @platform ios
             * @brief  Image parameters for stream mixing. See {@link ByteRTCMixedStreamLayoutRegionImageWaterMarkConfig ByteRTCMixedStreamLayoutRegionImageWaterMarkConfig}. Put in null when mixing video streams.
             */
            get: function () {
                return this._instance.imageWaterMarkConfig;
            },
            set: function (value) {
                this._instance.imageWaterMarkConfig = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_spatialPosition", {
            /** {en}
             * @platform ios
             * @brief spatial position. See {@link ByteRTCPosition ByteRTCPosition}.
             */
            get: function () {
                return this._instance.spatialPosition;
            },
            set: function (value) {
                this._instance.spatialPosition = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_applySpatialAudio", {
            /** {en}
             * @platform ios
             * @brief Sets whether a user applies spatial audio effects: <br>
             *        - Yes: Yes (default setting)
             *        - No: No
             */
            get: function () {
                return this._instance.applySpatialAudio;
            },
            set: function (value) {
                this._instance.applySpatialAudio = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_alternateImageFillMode", {
            /** {en}
             * @platform ios
             * @valid since 3.57
             * @brief Sets the fill mode of the placeholder image. <br>
             *        This parameter is used to control the fill mode of the placeholder image after the user stops publishing video streams and the screen reverts to the placeholder image. See {@link ByteRTCMixedStreamAlternateImageFillMode ByteRTCMixedStreamAlternateImageFillMode}.
             */
            get: function () {
                return this._instance.alternateImageFillMode;
            },
            set: function (value) {
                this._instance.alternateImageFillMode = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutRegionConfig_1.prototype, "ios_alternateImageUrl", {
            /** {en}
             * @platform ios
             * @valid since 3.57
             * @brief Sets the URL of the placeholder image, limited to a maximum of 1024 characters.
             */
            get: function () {
                return this._instance.alternateImageUrl;
            },
            set: function (value) {
                this._instance.alternateImageUrl = value;
            },
            enumerable: false,
            configurable: true
        });
        MixedStreamLayoutRegionConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        MixedStreamLayoutRegionConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCMixedStreamLayoutRegionConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = MixedStreamLayoutRegionConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the room ID of the user who publishes the video stream. You are recommended to set the value.
         * @param roomID The room ID to be set. Required.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setRoomID = function (roomID) {
            var _this = this;
            var $ = function () { return (_this._instance.setRoomID(roomID), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the room ID of the user who publishes the video stream.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getRoomID = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getRoomID()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the user ID of the user who publishes the video stream. You are recommended to set the value.
         * @param userID The user ID to be set.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setUserID = function (userID) {
            var _this = this;
            var $ = function () { return (_this._instance.setUserID(userID), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the user ID of the user who publishes the video stream.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getUserID = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getUserID()); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Sets the X-coordinate in pixels of the upper-left corner of the user's frame in the entire canvas coordinate system, where the origin is at the upper-left corner of the canvas. It represents the horizontal displacement of the upper-left corner of the user's frame relative to the origin.
         * @param locationX The X-coordinate of the upper-left corner of the user's frame. The value range is [0, the width of the canvas). The default value is 0.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setLocationX = function (locationX) {
            var _this = this;
            var $ = function () { return (_this._instance.setLocationX(locationX), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Gets the X-coordinate of the upper-left corner of the user's frame.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getLocationX = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getLocationX()); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Sets the Y-coordinate in pixels of the upper-left corner of the user's frame in the entire canvas coordinate system, where the origin is at the upper-left corner of the canvas. It represents the vertical displacement of the upper-left corner of the user's frame relative to the origin.
         * @param locationY The Y-coordinate of the upper-left corner of the user's frame. The value range is [0, the height of the canvas). The default value is 0.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setLocationY = function (locationY) {
            var _this = this;
            var $ = function () { return (_this._instance.setLocationY(locationY), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Gets the Y-coordinate of the upper-left corner of the user's frame.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getLocationY = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getLocationY()); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Sets the width of the user's frame in pixels.
         * @param width The width of the user's frame. The value range is [0, the width of the canvas]. The default value is 360.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setWidth = function (width) {
            var _this = this;
            var $ = function () { return (_this._instance.setWidth(width), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Gets the width of the user's frame in pixels.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getWidth = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getWidth()); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Sets the height of the user's frame in pixels.
         * @param height The height of the user's frame. The value range is [0, the height of the canvas]. The default value is 640.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setHeight = function (height) {
            var _this = this;
            var $ = function () { return (_this._instance.setHeight(height), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Gets the height of the user's frame in pixels.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getHeight = function () {
            var _this = this;
            var $ = function () { return _this._instance.getHeight(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the layer on which the video is rendered.
         * @param zOrder The layer to be set. The range is [0, 100]. 0 for the bottom layer, and 100 for the top layer. The default value is 0.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setZOrder = function (zOrder) {
            var _this = this;
            var $ = function () { return (_this._instance.setZOrder(zOrder), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the layer on which the video is rendered.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getZOrder = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getZOrder()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the transparency.
         * @param alpha (Only server-side stream mixing can set this parameter.) The opacity in range of (0.0, 1.0]. The lower value, the more transparent. The default value is 1.0.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setAlpha = function (alpha) {
            var _this = this;
            var $ = function () { return (_this._instance.setAlpha(alpha), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the transparency.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getAlpha = function () {
            var _this = this;
            var $ = function () { return _this._instance.getAlpha(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the corner radius.
         * @param cornerRadius (Only server-side stream mixing can set this parameter.) The proportion of the radius to the width of the canvas. The default value is 0.0.
         * @note After you set the value, `width_px`, `height_px`, and `radius_px` are calculated based on `width`, `height`, `radius`, and the width of the canvas. If `radius_px < min(width_px/2, height_px/2)` is met, the value of `radius` is set valid; if not, `radius_px` is set to `min(width_px/2, height_px/2)`, and `radius` is set to the proportion of `radius_px` to the width of the canvas.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setCornerRadius = function (cornerRadius) {
            var _this = this;
            var $ = function () { return (_this._instance.setCornerRadius(cornerRadius), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the corner radius.
         * @param cornerRadius (Only server-side stream mixing can set this parameter.) The proportion of the radius to the width of the canvas. The default value is 0.0.
         * @note After you set the value, `width_px`, `height_px`, and `radius_px` are calculated based on `width`, `height`, `radius`, and the width of the canvas. If `radius_px < min(width_px/2, height_px/2)` is met, the value of `radius` is set valid; if not, `radius_px` is set to `min(width_px/2, height_px/2)`, and `radius` is set to the proportion of `radius_px` to the width of the canvas.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getCornerRadius = function () {
            var _this = this;
            var $ = function () { return _this._instance.getCornerRadius(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief (Only server-side stream mixing can set this parameter.) Sets the stream mixing content type.
         * @param mediaType The stream mixing content type. The default value is `MIXED_STREAM_MEDIA_TYPE_AUDIO_AND_VIDEO(0)`. See {@link MixedStreamMediaType MixedStreamMediaType}.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setMediaType = function (mediaType) {
            var _this = this;
            var $ = function () { return (_this._instance.setMediaType(mediaType), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the stream mixing content type.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getMediaType = function () {
            var _this = this;
            var $ = function () { return _this._instance.getMediaType(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the stream mixing region type.
         * @param regionContentType Stream mixing region type. See {@link MixedStreamLayoutRegionType MixedStreamLayoutRegionType}.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setRegionContentType = function (regionContentType) {
            var _this = this;
            var $ = function () { return (_this._instance.setRegionContentType(regionContentType), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the stream mixing region type.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getRegionContentType = function () {
            var _this = this;
            var $ = function () { return _this._instance.getRegionContentType(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief  Sets the render mode. You are recommended to set the value.
         * @param renderMode The render mode. See {@link MixedStreamRenderMode MixedStreamRenderMode}. The default value is 1.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setRenderMode = function (renderMode) {
            var _this = this;
            var $ = function () { return (_this._instance.setRenderMode(renderMode), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the render mode.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getRenderMode = function () {
            var _this = this;
            var $ = function () { return _this._instance.getRenderMode(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief By calling this API, you can know whether the source user of the stream is the local user.
         * @return
         *         - true: Yes
         *         - false: No
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getIsLocalUser = function () {
            var _this = this;
            var $ = function () { return _this._instance.getIsLocalUser(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets whether the source user of the stream is a local user.
         * @param islocalUser <br>
         *       - true: Yes
         *       - false: No
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setIsLocalUser = function (islocalUser) {
            var _this = this;
            var $ = function () { return (_this._instance.setIsLocalUser(islocalUser), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the stream type in the region.
         * @param streamType Stream type, see {@link MixedStreamVideoType MixedStreamVideoType}. Only server-side stream mixing can set this parameter to "MIXED_STREAM_VIDEO_TYPE_SCREEN".
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setStreamType = function (streamType) {
            var _this = this;
            var $ = function () { return (_this._instance.setStreamType(streamType), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the stream type in the region.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getStreamType = function () {
            var _this = this;
            var $ = function () { return _this._instance.getStreamType(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the data of the mixing image.
         * @param imageWaterMark The RGBA data of the mixing image. Put in null when mixing video streams.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setImageWaterMark = function (imageWaterMark) {
            var _this = this;
            var $ = function () { return (_this._instance.setImageWaterMark(imageWaterMark), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the data of the mixing image.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getImageWaterMark = function () {
            var _this = this;
            var $ = function () { return _this._instance.getImageWaterMark(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the image parameters for stream mixing.
         * @param imageWaterMarkConfig Image parameters for stream mixing. See {@link MixedStreamLayoutRegionImageWaterMarkConfig MixedStreamLayoutRegionImageWaterMarkConfig}. Put in null when mixing video streams.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setImageWaterMarkConfig = function (imageWaterMarkConfig) {
            var _this = this;
            var $ = function () { return (_this._instance.setImageWaterMarkConfig(imageWaterMarkConfig), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the image parameters for stream mixing.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getImageWaterMarkConfig = function () {
            var _this = this;
            var $ = function () { return _this._instance.getImageWaterMarkConfig(); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Sets the fill mode of the placeholder image. <br>
         *        This method is used to control the fill mode of the placeholder image after the user stops publishing video streams and the screen reverts to the placeholder image.
         * @param alternateImageFillMode See {@link MixedStreamAlternateImageFillMode MixedStreamAlternateImageFillMode}.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setAlternateImageFillMode = function (alternateImageFillMode) {
            var _this = this;
            var $ = function () { return (_this._instance.setAlternateImageFillMode(alternateImageFillMode), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Sets the setting on the fill mode of the placeholder image.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getAlternateImageFillMode = function () {
            var _this = this;
            var $ = function () { return _this._instance.getAlternateImageFillMode(); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Sets the URL of the placeholder image, limited to a maximum of 1024 characters.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setAlternateImageURL = function (alternateImageUrl) {
            var _this = this;
            var $ = function () { return (_this._instance.setAlternateImageURL(alternateImageUrl), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Gets the URL of the placeholder image, limited to a maximum of 1024 characters.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getAlternateImageURL = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getAlternateImageURL()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets spatial audio position of the current region.
         * @param spatialPosition Spatial position of current region.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setSpatialPosition = function (spatialPosition) {
            var _this = this;
            var $ = function () { return (_this._instance.setSpatialPosition(spatialPosition), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets spatial audio position of the current region.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getSpatialPosition = function () {
            var _this = this;
            var $ = function () { return _this._instance.getSpatialPosition(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets whether a user applies spatial audio effects.
         * @param applySpatialAudio Whether the user applies spatial audio effects: <br>
         *        - true: Yes (default setting)
         *        - false: No
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_setApplySpatialAudio = function (applySpatialAudio) {
            var _this = this;
            var $ = function () { return (_this._instance.setApplySpatialAudio(applySpatialAudio), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the setting of whether a user applies spatial audio effects.
         *
         */
        MixedStreamLayoutRegionConfig_1.prototype.android_getApplySpatialAudio = function () {
            var _this = this;
            var $ = function () { return _this._instance.getApplySpatialAudio(); };
            return $();
        };
        return MixedStreamLayoutRegionConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamLayoutRegionConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.AudioScenarioType = void 0;
(function (AudioScenarioType) {
    AudioScenarioType[AudioScenarioType["AUDIO_SCENARIO_MUSIC"] = 0] = "AUDIO_SCENARIO_MUSIC";
    AudioScenarioType[AudioScenarioType["AUDIO_SCENARIO_HIGHQUALITY_COMMUNICATION"] = 1] = "AUDIO_SCENARIO_HIGHQUALITY_COMMUNICATION";
    AudioScenarioType[AudioScenarioType["AUDIO_SCENARIO_COMMUNICATION"] = 2] = "AUDIO_SCENARIO_COMMUNICATION";
    AudioScenarioType[AudioScenarioType["AUDIO_SCENARIO_MEDIA"] = 3] = "AUDIO_SCENARIO_MEDIA";
    AudioScenarioType[AudioScenarioType["AUDIO_SCENARIO_GAME_STREAMING"] = 4] = "AUDIO_SCENARIO_GAME_STREAMING";
    AudioScenarioType[AudioScenarioType["AUDIO_SCENARIO_HIGHQUALITY_CHAT"] = 5] = "AUDIO_SCENARIO_HIGHQUALITY_CHAT";
})(exports.AudioScenarioType || (exports.AudioScenarioType = {}));
exports.AudioPropertiesMode = void 0;
(function (AudioPropertiesMode) {
    AudioPropertiesMode[AudioPropertiesMode["AUDIO_PROPERTIES_MODE_MICROPHONE"] = 0] = "AUDIO_PROPERTIES_MODE_MICROPHONE";
    AudioPropertiesMode[AudioPropertiesMode["AUDIO_PROPERTIES_MODE_AUDIOMIXING"] = 1] = "AUDIO_PROPERTIES_MODE_AUDIOMIXING";
})(exports.AudioPropertiesMode || (exports.AudioPropertiesMode = {}));
exports.ASRAuthorizationType = void 0;
(function (ASRAuthorizationType) {
    ASRAuthorizationType[ASRAuthorizationType["ASR_AUTHORIZATION_TYPE_TOKEN"] = 0] = "ASR_AUTHORIZATION_TYPE_TOKEN";
    ASRAuthorizationType[ASRAuthorizationType["ASR_AUTHORIZATION_TYPE_SIGNATURE"] = 1] = "ASR_AUTHORIZATION_TYPE_SIGNATURE";
})(exports.ASRAuthorizationType || (exports.ASRAuthorizationType = {}));
var SysStats = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function SysStats_1() {
        }
        Object.defineProperty(SysStats_1.prototype, "cpuCores", {
            /** {en}
             * @brief Device CPU cores
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.cpuCores);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.cpuCores);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.cpuCores = value;
                }
                else if ($os === 'ios') {
                    this._instance.cpuCores = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SysStats_1.prototype, "cpuAppUsage", {
            /** {en}
             * @brief The CPU usage of the application, the value range is [0,1].
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.cpuAppUsage);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.cpuAppUsage);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.cpuAppUsage = value;
                }
                else if ($os === 'ios') {
                    this._instance.cpuAppUsage = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SysStats_1.prototype, "android_cpuTotalUsage", {
            /** {en}
             * @platform android
             * @brief The CPU usage of the system, the value range is [0,1].
             *
             */
            get: function () {
                return this._instance.cpuTotalUsage;
            },
            set: function (value) {
                this._instance.cpuTotalUsage = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SysStats_1.prototype, "memoryUsage", {
            /** {en}
             * @brief Application's memory occupancy in MB
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.memoryUsage);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.memoryUsage);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.memoryUsage = value;
                }
                else if ($os === 'ios') {
                    this._instance.memoryUsage = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SysStats_1.prototype, "fullMemory", {
            /** {en}
             * @brief Device memory size  unit: MB
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.fullMemory);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.fullMemory);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.fullMemory = value;
                }
                else if ($os === 'ios') {
                    this._instance.fullMemory = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SysStats_1.prototype, "totalMemoryUsage", {
            /** {en}
             * @brief System used memory (in MB)
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.totalMemoryUsage);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.totalMemoryUsage);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.totalMemoryUsage = value;
                }
                else if ($os === 'ios') {
                    this._instance.totalMemoryUsage = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SysStats_1.prototype, "freeMemory", {
            /** {en}
             * @brief System current free memory (in MB)
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.freeMemory);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.freeMemory);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.freeMemory = value;
                }
                else if ($os === 'ios') {
                    this._instance.freeMemory = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SysStats_1.prototype, "memoryRatio", {
            /** {en}
             * @brief Memory usage of the current application (in \%)
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.memoryRatio);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.memoryRatio);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.memoryRatio = value;
                }
                else if ($os === 'ios') {
                    this._instance.memoryRatio = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SysStats_1.prototype, "totalMemoryRatio", {
            /** {en}
             * @brief System memory usage (in \%)
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.totalMemoryRatio);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.totalMemoryRatio);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.totalMemoryRatio = value;
                }
                else if ($os === 'ios') {
                    this._instance.totalMemoryRatio = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        SysStats_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        SysStats_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCSysStats).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = SysStats$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return SysStats_1;
    }());
    __setFunctionName(_classThis, "SysStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.VideoContentType = void 0;
(function (VideoContentType) {
    VideoContentType[VideoContentType["NORMAL_FRAME"] = 0] = "NORMAL_FRAME";
    VideoContentType[VideoContentType["BLACK_FRAME"] = 1] = "BLACK_FRAME";
})(exports.VideoContentType || (exports.VideoContentType = {}));
var SubscribeConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function SubscribeConfig_1() {
        }
        /**
         * @platform android
         */
        SubscribeConfig_1.android_create = function (isScreen, subVideo, subAudio, videoIndex, svcLayer, subWidth, subHeight, subVideoIndex) {
            var $ = function () {
                return SubscribeConfig$1.create(isScreen, subVideo, subAudio, videoIndex, svcLayer, subWidth, subHeight, subVideoIndex);
            };
            return $();
        };
        Object.defineProperty(SubscribeConfig_1.prototype, "isScreen", {
            /** {en}
             * @brief Whether the stream is from screen sharing
             *
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.isScreen;
                }
                else if ($os === 'ios') {
                    return this._instance.isScreen;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.isScreen = value;
                }
                else if ($os === 'ios') {
                    this._instance.isScreen = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubscribeConfig_1.prototype, "android_subVideo", {
            /** {en}
             * @platform android
             * @brief Whether video stream is included
             *
             *
             */
            get: function () {
                return this._instance.subVideo;
            },
            set: function (value) {
                this._instance.subVideo = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubscribeConfig_1.prototype, "android_subAudio", {
            /** {en}
             * @platform android
             * @brief Whether audio stream is included
             *
             *
             */
            get: function () {
                return this._instance.subAudio;
            },
            set: function (value) {
                this._instance.subAudio = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubscribeConfig_1.prototype, "videoIndex", {
            /** {en}
             * @brief Subscribed video stream resolution subscript. <br>
             *        Users can publish multiple videos of different resolutions in a stream. Therefore, when subscribing to a stream, you need to specify the specific resolution of the subscription. This parameter is used to specify the subscript of the resolution to be subscribed to, and the default value is 0.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.videoIndex);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.videoIndex);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.videoIndex = value;
                }
                else if ($os === 'ios') {
                    this._instance.videoIndex = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubscribeConfig_1.prototype, "android_subWidth", {
            /** {en}
             * @platform android
             * @brief Width of the video stream in px
             *
             */
            get: function () {
                return this._instance.subWidth;
            },
            set: function (value) {
                this._instance.subWidth = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubscribeConfig_1.prototype, "android_subHeight", {
            /** {en}
             * @platform android
             * @brief Height of the video stream in px
             *
             */
            get: function () {
                return this._instance.subHeight;
            },
            set: function (value) {
                this._instance.subHeight = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubscribeConfig_1.prototype, "framerate", {
            /** {en}
             * @brief Expected maximum frame rate of the subscribed stream in px. The default value is 0, values greater than 10 are valid. <br>
             *        If the frame rate of the stream published is higher than the value set by the subscriber, the subscriber receives the video of the frame rate set by this API; if the frame rate of the stream published is lower than the value set by the subscriber, the subscriber receives the video of the same frame rate of the video published. <br>
             *        Only valid if the stream is coded with SVC technique.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.framerate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.framerate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.framerate = value;
                }
                else if ($os === 'ios') {
                    this._instance.framerate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubscribeConfig_1.prototype, "ios_subscribeVideo", {
            /** {en}
             * @platform ios
             * @brief Whether to subscribe to videos. <br>
             *         The user selects whether to subscribe to videos in the remote stream by setting this parameter. YES is a subscription video, NO is a non-subscription video, the default value is YES.
             */
            get: function () {
                return this._instance.subscribeVideo;
            },
            set: function (value) {
                this._instance.subscribeVideo = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubscribeConfig_1.prototype, "ios_subscribeAudio", {
            /** {en}
             * @platform ios
             * @brief Whether to subscribe to audio. <br>
             *         The user selects whether to subscribe to audio in the remote stream by setting this parameter. YES is subscribed audio, NO is not subscribed audio, the default value is YES.
             */
            get: function () {
                return this._instance.subscribeAudio;
            },
            set: function (value) {
                this._instance.subscribeAudio = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubscribeConfig_1.prototype, "ios_svcLayer", {
            /** {en}
             * @platform ios
             * @brief Time domain hierarchy of the subscribed video stream, default value is 0.
             */
            get: function () {
                return this._instance.svcLayer;
            },
            set: function (value) {
                this._instance.svcLayer = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubscribeConfig_1.prototype, "ios_width", {
            /** {en}
             * @platform ios
             * @brief The width in px of the subscription, the default value is 0.
             */
            get: function () {
                return this._instance.width;
            },
            set: function (value) {
                this._instance.width = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubscribeConfig_1.prototype, "ios_height", {
            /** {en}
             * @platform ios
             * @brief The height in px of the subscription, the default value is 0.
             */
            get: function () {
                return this._instance.height;
            },
            set: function (value) {
                this._instance.height = value;
            },
            enumerable: false,
            configurable: true
        });
        SubscribeConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        SubscribeConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCSubscribeConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = SubscribeConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return SubscribeConfig_1;
    }());
    __setFunctionName(_classThis, "SubscribeConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var EchoTestConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function EchoTestConfig_1() {
        }
        Object.defineProperty(EchoTestConfig_1.prototype, "userId", {
            /** {en}
             * @brief User ID for testing
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.uid);
                }
                else if ($os === 'ios') {
                    return String(this._instance.userId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.uid = value;
                }
                else if ($os === 'ios') {
                    this._instance.userId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(EchoTestConfig_1.prototype, "roomId", {
            /** {en}
             * @brief ID of the room that the tested user will join.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.roomId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.roomId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.roomId = value;
                }
                else if ($os === 'ios') {
                    this._instance.roomId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(EchoTestConfig_1.prototype, "token", {
            /** {en}
             * @brief Token used for authenticating users when they enter the room.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.token);
                }
                else if ($os === 'ios') {
                    return String(this._instance.token);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.token = value;
                }
                else if ($os === 'ios') {
                    this._instance.token = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(EchoTestConfig_1.prototype, "enableAudio", {
            /** {en}
             * @brief Whether to test audio. The device to be tested is the default audio device. <br>
             *        - true: Yes
             *            - If you use internal capture, the device microphone will automatically turn on and `onLocalAudioPropertiesReport` will be triggered when the value of audioReportInterval is set to greater than 0, from which you can judge the working status of the microphone.
             *            - If you choose custom capture, you also need to call {@link pushExternalAudioFrame pushExternalAudioFrame} to push the captured audio to the SDK.
             *        - false: No
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.enableAudio;
                }
                else if ($os === 'ios') {
                    return this._instance.enableAudio;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.enableAudio = value;
                }
                else if ($os === 'ios') {
                    this._instance.enableAudio = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(EchoTestConfig_1.prototype, "enableVideo", {
            /** {en}
             * @brief Whether to test video. If you are using a desktop PC, the device to be tested is by default the first video device in the list. <br>
             *        - true: Yes
             *            - If you use internal capture, the device camera will automatically turn on.
             *            - If you choose custom capture, you also need to call {@link pushExternalVideoFrame pushExternalVideoFrame} to push the captured video to the SDK.
             *        - false: No
             * @note The video is published with fixed parameters: resolution 640px × 360px, frame rate 15fps.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.enableVideo;
                }
                else if ($os === 'ios') {
                    return this._instance.enableVideo;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.enableVideo = value;
                }
                else if ($os === 'ios') {
                    this._instance.enableVideo = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(EchoTestConfig_1.prototype, "audioReportInterval", {
            /** {en}
             * @brief Volume prompt interval in ms, the default value is 100. <br>
             *        - `<= 0`: Turn off prompt
             *        - `(0,100]` Invalid interval value, and will be automatically reset to 100ms.
             *        - `> 100`: the actual value of interval
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.audioReportInterval);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.audioReportInterval);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.audioReportInterval = value;
                }
                else if ($os === 'ios') {
                    this._instance.audioReportInterval = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        EchoTestConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        EchoTestConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCEchoTestConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = EchoTestConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /**
         * @platform android
         */
        /**
         * @platform android
         */
        EchoTestConfig_1.prototype.android_getEchoRenderView = function () {
            var _this = this;
            var $ = function () { return _this._instance.getEchoRenderView(); };
            return $();
        };
        /**
         * @platform android
         */
        /**
         * @platform android
         */
        EchoTestConfig_1.prototype.android_getEchoUid = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getEchoUid()); };
            return $();
        };
        /**
         * @platform android
         */
        /**
         * @platform android
         */
        EchoTestConfig_1.prototype.android_getEchoRoomId = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getEchoRoomId()); };
            return $();
        };
        /**
         * @platform android
         */
        /**
         * @platform android
         */
        EchoTestConfig_1.prototype.android_getEchoToken = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getEchoToken()); };
            return $();
        };
        /**
         * @platform android
         */
        /**
         * @platform android
         */
        EchoTestConfig_1.prototype.android_getEchoEnabledAudio = function () {
            var _this = this;
            var $ = function () { return _this._instance.getEchoEnabledAudio(); };
            return $();
        };
        /**
         * @platform android
         */
        /**
         * @platform android
         */
        EchoTestConfig_1.prototype.android_getEchoEnabledVideo = function () {
            var _this = this;
            var $ = function () { return _this._instance.getEchoEnabledVideo(); };
            return $();
        };
        /**
         * @platform android
         */
        /**
         * @platform android
         */
        EchoTestConfig_1.prototype.android_getAudioReportInterval = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getAudioReportInterval()); };
            return $();
        };
        return EchoTestConfig_1;
    }());
    __setFunctionName(_classThis, "EchoTestConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.AudioSampleRate = void 0;
(function (AudioSampleRate) {
    AudioSampleRate[AudioSampleRate["AUDIO_SAMPLE_RATE_AUTO"] = 0] = "AUDIO_SAMPLE_RATE_AUTO";
    AudioSampleRate[AudioSampleRate["AUDIO_SAMPLE_RATE_8000"] = 1] = "AUDIO_SAMPLE_RATE_8000";
    AudioSampleRate[AudioSampleRate["AUDIO_SAMPLE_RATE_16000"] = 2] = "AUDIO_SAMPLE_RATE_16000";
    AudioSampleRate[AudioSampleRate["AUDIO_SAMPLE_RATE_32000"] = 3] = "AUDIO_SAMPLE_RATE_32000";
    AudioSampleRate[AudioSampleRate["AUDIO_SAMPLE_RATE_44100"] = 4] = "AUDIO_SAMPLE_RATE_44100";
    AudioSampleRate[AudioSampleRate["AUDIO_SAMPLE_RATE_48000"] = 5] = "AUDIO_SAMPLE_RATE_48000";
})(exports.AudioSampleRate || (exports.AudioSampleRate = {}));
var MusicInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function MusicInfo_1() {
        }
        Object.defineProperty(MusicInfo_1.prototype, "musicId", {
            /** {en}
             * @brief Music ID.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.musicId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.musicId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.musicId = value;
                }
                else if ($os === 'ios') {
                    this._instance.musicId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MusicInfo_1.prototype, "musicName", {
            /** {en}
             * @brief Music name.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.musicName);
                }
                else if ($os === 'ios') {
                    return String(this._instance.musicName);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.musicName = value;
                }
                else if ($os === 'ios') {
                    this._instance.musicName = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MusicInfo_1.prototype, "singer", {
            /** {en}
             * @brief Singer.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.singer);
                }
                else if ($os === 'ios') {
                    return String(this._instance.singer);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.singer = value;
                }
                else if ($os === 'ios') {
                    this._instance.singer = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MusicInfo_1.prototype, "vendorId", {
            /** {en}
             * @brief Vendor ID.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.vendorId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.vendorId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.vendorId = value;
                }
                else if ($os === 'ios') {
                    this._instance.vendorId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MusicInfo_1.prototype, "vendorName", {
            /** {en}
             * @brief Vendor name.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.vendorName);
                }
                else if ($os === 'ios') {
                    return String(this._instance.vendorName);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.vendorName = value;
                }
                else if ($os === 'ios') {
                    this._instance.vendorName = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MusicInfo_1.prototype, "updateTimestamp", {
            /** {en}
             * @brief Latest update timestamp in milliseconds.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.updateTimestamp);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.updateTimestamp);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.updateTimestamp = value;
                }
                else if ($os === 'ios') {
                    this._instance.updateTimestamp = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MusicInfo_1.prototype, "posterUrl", {
            /** {en}
             * @brief The URL of the music cover.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.posterUrl);
                }
                else if ($os === 'ios') {
                    return String(this._instance.posterUrl);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.posterUrl = value;
                }
                else if ($os === 'ios') {
                    this._instance.posterUrl = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MusicInfo_1.prototype, "lyricStatus", {
            /** {en}
             * @brief The lyrics type. See {@link LyricStatus LyricStatus}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_LyricStatus.android_to_ts(this._instance.lyricStatus);
                }
                else if ($os === 'ios') {
                    return t_LyricStatus.ios_to_ts(this._instance.lyricStatus);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.lyricStatus = t_LyricStatus.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.lyricStatus = t_LyricStatus.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MusicInfo_1.prototype, "duration", {
            /** {en}
             * @brief The length of the song in milliseconds.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.duration);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.duration);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.duration = value;
                }
                else if ($os === 'ios') {
                    this._instance.duration = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MusicInfo_1.prototype, "enableScore", {
            /** {en}
             * @brief Whether the song supports scoring.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.enableScore;
                }
                else if ($os === 'ios') {
                    return this._instance.enableScore;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.enableScore = value;
                }
                else if ($os === 'ios') {
                    this._instance.enableScore = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MusicInfo_1.prototype, "climaxStartTime", {
            /** {en}
             * @brief The starting time of the climax part in milliseconds.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.climaxStartTime);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.climaxStartTime);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.climaxStartTime = value;
                }
                else if ($os === 'ios') {
                    this._instance.climaxStartTime = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MusicInfo_1.prototype, "climaxEndTime", {
            /** {en}
             * @brief The ending time of the climax part in milliseconds.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.climaxEndTime);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.climaxEndTime);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.climaxEndTime = value;
                }
                else if ($os === 'ios') {
                    this._instance.climaxEndTime = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        MusicInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        MusicInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCMusicInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = MusicInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return MusicInfo_1;
    }());
    __setFunctionName(_classThis, "MusicInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.MixedStreamVideoCodecType = void 0;
(function (MixedStreamVideoCodecType) {
    MixedStreamVideoCodecType[MixedStreamVideoCodecType["MIXED_STREAM_VIDEO_CODEC_TYPE_H264"] = 0] = "MIXED_STREAM_VIDEO_CODEC_TYPE_H264";
    MixedStreamVideoCodecType[MixedStreamVideoCodecType["MIXED_STREAM_VIDEO_CODEC_TYPE_BYTEVC1"] = 1] = "MIXED_STREAM_VIDEO_CODEC_TYPE_BYTEVC1";
})(exports.MixedStreamVideoCodecType || (exports.MixedStreamVideoCodecType = {}));
exports.MuteState = void 0;
(function (MuteState) {
    MuteState[MuteState["MUTE_STATE_OFF"] = 0] = "MUTE_STATE_OFF";
    MuteState[MuteState["MUTE_STATE_ON"] = 1] = "MUTE_STATE_ON";
})(exports.MuteState || (exports.MuteState = {}));
exports.ByteRTCStreamMixingType = void 0;
(function (ByteRTCStreamMixingType) {
    ByteRTCStreamMixingType[ByteRTCStreamMixingType["STREAM_MIXING_BY_SERVER"] = 0] = "STREAM_MIXING_BY_SERVER";
    ByteRTCStreamMixingType[ByteRTCStreamMixingType["STREAM_MIXING_BY_CLIENT"] = 1] = "STREAM_MIXING_BY_CLIENT";
    ByteRTCStreamMixingType[ByteRTCStreamMixingType["ByteRTCStreamMixingTypeByServer"] = 2] = "ByteRTCStreamMixingTypeByServer";
    ByteRTCStreamMixingType[ByteRTCStreamMixingType["ByteRTCStreamMixingTypeByClient"] = 3] = "ByteRTCStreamMixingTypeByClient";
})(exports.ByteRTCStreamMixingType || (exports.ByteRTCStreamMixingType = {}));
exports.MediaDeviceError = void 0;
(function (MediaDeviceError) {
    /** {en}
     * @platform android
     * brief Normal
     *
     */
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_OK"] = 0] = "MEDIA_DEVICE_ERROR_OK";
    /** {en}
     * @platform android
     * brief No permission
     *
     */
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_NOPERMISSION"] = 1] = "MEDIA_DEVICE_ERROR_NOPERMISSION";
    /** {en}
     * @platform android
     * brief Occupied by the other application
     *
     */
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_DEVICEBUSY"] = 2] = "MEDIA_DEVICE_ERROR_DEVICEBUSY";
    /** {en}
     * @platform android
     * brief Error
     *
     */
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_DEVICEFAILURE"] = 3] = "MEDIA_DEVICE_ERROR_DEVICEFAILURE";
    /** {en}
     * @platform android
     * brief Not found
     *
     */
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_DEVICENOTFOUND"] = 4] = "MEDIA_DEVICE_ERROR_DEVICENOTFOUND";
    /** {en}
     * @platform android
     * brief Disconnected
     *
     */
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_DEVICEDISCONNECTED"] = 5] = "MEDIA_DEVICE_ERROR_DEVICEDISCONNECTED";
    /** {en}
     * @platform android
     * @brief No data callback from the capture devices. <br>
     *        RTC emits this error when the media device is expected to be working but no data is received.
     *
     */
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_DEVICENOCALLBACK"] = 6] = "MEDIA_DEVICE_ERROR_DEVICENOCALLBACK";
    /** {en}
     * @platform android
     * @brief Not supported sample rate
     *
     */
    MediaDeviceError[MediaDeviceError["MEDIA_DEVICE_ERROR_UNSUPPORTFORMAT"] = 7] = "MEDIA_DEVICE_ERROR_UNSUPPORTFORMAT";
    MediaDeviceError[MediaDeviceError["ByteRTCMediaDeviceErrorOK"] = 8] = "ByteRTCMediaDeviceErrorOK";
    MediaDeviceError[MediaDeviceError["ByteRTCMediaDeviceErrorDeviceNoPermission"] = 9] = "ByteRTCMediaDeviceErrorDeviceNoPermission";
    MediaDeviceError[MediaDeviceError["ByteRTCMediaDeviceErrorDeviceBusy"] = 10] = "ByteRTCMediaDeviceErrorDeviceBusy";
    MediaDeviceError[MediaDeviceError["ByteRTCMediaDeviceErrorDeviceFailure"] = 11] = "ByteRTCMediaDeviceErrorDeviceFailure";
    MediaDeviceError[MediaDeviceError["ByteRTCMediaDeviceErrorDeviceNotFound"] = 12] = "ByteRTCMediaDeviceErrorDeviceNotFound";
    MediaDeviceError[MediaDeviceError["ByteRTCMediaDeviceErrorDeviceDisconnected"] = 13] = "ByteRTCMediaDeviceErrorDeviceDisconnected";
    MediaDeviceError[MediaDeviceError["ByteRTCMediaDeviceErrorDeviceNoCallback"] = 14] = "ByteRTCMediaDeviceErrorDeviceNoCallback";
    MediaDeviceError[MediaDeviceError["ByteRTCMediaDeviceErrorUNSupportFormat"] = 15] = "ByteRTCMediaDeviceErrorUNSupportFormat";
    MediaDeviceError[MediaDeviceError["ByteRTCMediaDeviceErrorNotFindGroupId"] = 16] = "ByteRTCMediaDeviceErrorNotFindGroupId";
    MediaDeviceError[MediaDeviceError["ByteRTCMediaDeviceErrorNotAvailableInBackground"] = 17] = "ByteRTCMediaDeviceErrorNotAvailableInBackground";
    MediaDeviceError[MediaDeviceError["ByteRTCMediaDeviceErrorVideoInUseByAnotherClient"] = 18] = "ByteRTCMediaDeviceErrorVideoInUseByAnotherClient";
    MediaDeviceError[MediaDeviceError["ByteRTCMediaDeviceErrorNotAvailableWithMultipleForegroundApps"] = 19] = "ByteRTCMediaDeviceErrorNotAvailableWithMultipleForegroundApps";
    MediaDeviceError[MediaDeviceError["ByteRTCMediaDeviceErrorNotAvailableDueToSystemPressure"] = 20] = "ByteRTCMediaDeviceErrorNotAvailableDueToSystemPressure";
})(exports.MediaDeviceError || (exports.MediaDeviceError = {}));
exports.AudioFrameSource = void 0;
(function (AudioFrameSource) {
    AudioFrameSource[AudioFrameSource["AUDIO_FRAME_SOURCE_MIC"] = 0] = "AUDIO_FRAME_SOURCE_MIC";
    AudioFrameSource[AudioFrameSource["AUDIO_FRAME_SOURCE_PLAYBACK"] = 1] = "AUDIO_FRAME_SOURCE_PLAYBACK";
    AudioFrameSource[AudioFrameSource["AUDIO_FRAME_SOURCE_MIXED"] = 2] = "AUDIO_FRAME_SOURCE_MIXED";
    AudioFrameSource[AudioFrameSource["ByteRTCAudioFrameSourceTypeMic"] = 3] = "ByteRTCAudioFrameSourceTypeMic";
    AudioFrameSource[AudioFrameSource["ByteRTCAudioFrameSourceTypePlayback"] = 4] = "ByteRTCAudioFrameSourceTypePlayback";
    AudioFrameSource[AudioFrameSource["ByteRTCAudioFrameSourceTypeMixed"] = 5] = "ByteRTCAudioFrameSourceTypeMixed";
})(exports.AudioFrameSource || (exports.AudioFrameSource = {}));
exports.StreamRemoveReason = void 0;
(function (StreamRemoveReason) {
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_UNPUBLISH"] = 0] = "STREAM_REMOVE_REASON_UNPUBLISH";
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_PUBLISH_FAILED"] = 1] = "STREAM_REMOVE_REASON_PUBLISH_FAILED";
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_KEEP_LIVE_FAILED"] = 2] = "STREAM_REMOVE_REASON_KEEP_LIVE_FAILED";
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_CLIENT_DISCONNECTED"] = 3] = "STREAM_REMOVE_REASON_CLIENT_DISCONNECTED";
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_REPUBLISH"] = 4] = "STREAM_REMOVE_REASON_REPUBLISH";
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_OTHER"] = 5] = "STREAM_REMOVE_REASON_OTHER";
    StreamRemoveReason[StreamRemoveReason["STREAM_REMOVE_REASON_PUBLISH_PRIVILEGE_TOKEN_EXPIRED"] = 6] = "STREAM_REMOVE_REASON_PUBLISH_PRIVILEGE_TOKEN_EXPIRED";
    StreamRemoveReason[StreamRemoveReason["ByteRTCStreamRemoveReasonPublishPrivilegeExpired"] = 7] = "ByteRTCStreamRemoveReasonPublishPrivilegeExpired";
})(exports.StreamRemoveReason || (exports.StreamRemoveReason = {}));
exports.ForwardStreamError = void 0;
(function (ForwardStreamError) {
    ForwardStreamError[ForwardStreamError["FORWARD_STREAM_ERROR_OK"] = 0] = "FORWARD_STREAM_ERROR_OK";
    ForwardStreamError[ForwardStreamError["FORWARD_STREAM_ERROR_RESPONSE"] = 1] = "FORWARD_STREAM_ERROR_RESPONSE";
    ForwardStreamError[ForwardStreamError["FORWARD_STREAM_ERROR_REMOTE_KICKED"] = 2] = "FORWARD_STREAM_ERROR_REMOTE_KICKED";
    ForwardStreamError[ForwardStreamError["FORWARD_STREAM_ERROR_NOT_SUPPORT"] = 3] = "FORWARD_STREAM_ERROR_NOT_SUPPORT";
    ForwardStreamError[ForwardStreamError["FORWARD_STREAM_ERROR_INVALID_ARGUMENT"] = 4] = "FORWARD_STREAM_ERROR_INVALID_ARGUMENT";
    ForwardStreamError[ForwardStreamError["FORWARD_STREAM_ERROR_INVALID_TOKEN"] = 5] = "FORWARD_STREAM_ERROR_INVALID_TOKEN";
    ForwardStreamError[ForwardStreamError["ByteRTCForwardStreamErrorInvalidArgument"] = 6] = "ByteRTCForwardStreamErrorInvalidArgument";
    ForwardStreamError[ForwardStreamError["ByteRTCForwardStreamErrorInvalidToken"] = 7] = "ByteRTCForwardStreamErrorInvalidToken";
})(exports.ForwardStreamError || (exports.ForwardStreamError = {}));
exports.NetworkDetectionStopReason = void 0;
(function (NetworkDetectionStopReason) {
    NetworkDetectionStopReason[NetworkDetectionStopReason["USER"] = 0] = "USER";
    NetworkDetectionStopReason[NetworkDetectionStopReason["TIMEOUT"] = 1] = "TIMEOUT";
    NetworkDetectionStopReason[NetworkDetectionStopReason["CONNECTION_LOST"] = 2] = "CONNECTION_LOST";
    NetworkDetectionStopReason[NetworkDetectionStopReason["STREAMING"] = 3] = "STREAMING";
    NetworkDetectionStopReason[NetworkDetectionStopReason["INNER_ERR"] = 4] = "INNER_ERR";
    NetworkDetectionStopReason[NetworkDetectionStopReason["ByteRTCNetworkDetectionStopReasonInnerErr"] = 5] = "ByteRTCNetworkDetectionStopReasonInnerErr";
})(exports.NetworkDetectionStopReason || (exports.NetworkDetectionStopReason = {}));
var ReceiveRange = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ReceiveRange_1() {
        }
        Object.defineProperty(ReceiveRange_1.prototype, "min", {
            /** {en}
             * @brief The minimum distance at which the local user can hear the attenuated audio from remote users. <br>
             *        The value must be ≥ 0, but ≤ max. <br>
             *        No attenuation effect for audio from distances less than this value you set.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.min);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.min);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.min = value;
                }
                else if ($os === 'ios') {
                    this._instance.min = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(ReceiveRange_1.prototype, "max", {
            /** {en}
             * @brief The maximum distance at which the local user can hear audio from remote users. <br>
             *        The value must be ≥ min, and > 0. <br>
             *        Audio from distances larger than the value you set cannot be heard.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.max);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.max);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.max = value;
                }
                else if ($os === 'ios') {
                    this._instance.max = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        ReceiveRange_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        ReceiveRange_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCReceiveRange).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = ReceiveRange$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return ReceiveRange_1;
    }());
    __setFunctionName(_classThis, "ReceiveRange");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.NetworkQuality = void 0;
(function (NetworkQuality) {
    /** {en}
     * @detail keytype
     * @brief Media stream network quality unknown.
     *
     */
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_UNKNOWN"] = 0] = "NETWORK_QUALITY_UNKNOWN";
    /** {en}
     * @detail keytype
     * @brief Media Streaming Network quality is excellent.
     *
     */
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_EXCELLENT"] = 1] = "NETWORK_QUALITY_EXCELLENT";
    /** {en}
     * @detail keytype
     * @brief Media streaming network quality is good.
     *
     */
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_GOOD"] = 2] = "NETWORK_QUALITY_GOOD";
    /** {en}
     * @detail keytype
     * @brief Media streaming The network quality is poor but does not affect communication.
     *
     */
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_POOR"] = 3] = "NETWORK_QUALITY_POOR";
    /** {en}
     * @detail keytype
     * @brief Media streaming Poor network quality Poor communication.
     *
     */
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_BAD"] = 4] = "NETWORK_QUALITY_BAD";
    /** {en}
     * @detail keytype
     * @brief Media streaming network quality is very poor.
     *
     */
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_VERY_BAD"] = 5] = "NETWORK_QUALITY_VERY_BAD";
    /** {en}
     * @detail keytype
     * @brief The network is down. It may be down due to no answer within 12s, airplane mode on, disconnected cable, etc. <br>
     *        Refer to [Get connection state](https://docs.byteplus.com/byteplus-rtc/docs/95376) for more details about getting connection state.
     *
     */
    NetworkQuality[NetworkQuality["NETWORK_QUALITY_DOWN"] = 6] = "NETWORK_QUALITY_DOWN";
})(exports.NetworkQuality || (exports.NetworkQuality = {}));
exports.RenderMode = void 0;
(function (RenderMode) {
    RenderMode[RenderMode["ByteRTCRenderModeHidden"] = 0] = "ByteRTCRenderModeHidden";
    RenderMode[RenderMode["ByteRTCRenderModeFit"] = 1] = "ByteRTCRenderModeFit";
    RenderMode[RenderMode["ByteRTCRenderModeFill"] = 2] = "ByteRTCRenderModeFill";
})(exports.RenderMode || (exports.RenderMode = {}));
exports.ZoomConfigType = void 0;
(function (ZoomConfigType) {
    ZoomConfigType[ZoomConfigType["ZOOM_FOCUS_OFFSET"] = 0] = "ZOOM_FOCUS_OFFSET";
    ZoomConfigType[ZoomConfigType["ZOOM_MOVE_OFFSET"] = 1] = "ZOOM_MOVE_OFFSET";
    ZoomConfigType[ZoomConfigType["ByteRTCZoomConfigTypeFocusOffset"] = 2] = "ByteRTCZoomConfigTypeFocusOffset";
    ZoomConfigType[ZoomConfigType["ByteRTCZoomConfigTypeMoveOffset"] = 3] = "ByteRTCZoomConfigTypeMoveOffset";
})(exports.ZoomConfigType || (exports.ZoomConfigType = {}));
var StreamSycnInfoConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function StreamSycnInfoConfig_1() {
        }
        Object.defineProperty(StreamSycnInfoConfig_1.prototype, "streamIndex", {
            /** {en}
             * @brief Stream properties, mainstream or screen streams.  Refer to the enumeration class [StreamIndex](#streamindex-2) <br>
             *        - `STREAM_INDEX_MAIN(0)`: Main stream
             *        - `STREAM_INDEX_SCREEN(1)`: Screen-sharing stream
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_StreamIndex.android_to_ts(this._instance.streamIndex);
                }
                else if ($os === 'ios') {
                    return t_StreamIndex.ios_to_ts(this._instance.streamIndex);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.streamIndex = t_StreamIndex.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.streamIndex = t_StreamIndex.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StreamSycnInfoConfig_1.prototype, "repeatCount", {
            /** {en}
             * @brief Repeated number of messages sent
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.repeatCount);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.repeatCount);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.repeatCount = value;
                }
                else if ($os === 'ios') {
                    this._instance.repeatCount = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StreamSycnInfoConfig_1.prototype, "streamType", {
            /** {en}
             * @brief Stream types for media stream information synchronization. See {@link SyncInfoStreamType SyncInfoStreamType}
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_SyncInfoStreamType.android_to_ts(this._instance.streamType);
                }
                else if ($os === 'ios') {
                    return t_SyncInfoStreamType.ios_to_ts(this._instance.streamType);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.streamType = t_SyncInfoStreamType.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.streamType = t_SyncInfoStreamType.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        StreamSycnInfoConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        StreamSycnInfoConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCStreamSycnInfoConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = StreamSycnInfoConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return StreamSycnInfoConfig_1;
    }());
    __setFunctionName(_classThis, "StreamSycnInfoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var LocalVideoStats = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function LocalVideoStats_1() {
        }
        Object.defineProperty(LocalVideoStats_1.prototype, "sentKBitrate", {
            /** {en}
             * @brief TX bitrate in Kbps of the video stream with the highest resolution within the reference period
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.sentKBitrate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.sentKBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.sentKBitrate = value;
                }
                else if ($os === 'ios') {
                    this._instance.sentKBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "inputFrameRate", {
            /** {en}
             * @brief Sampling frame rate in fps of video capture during this reference period
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.inputFrameRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.inputFrameRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.inputFrameRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.inputFrameRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "sentFrameRate", {
            /** {en}
             * @brief TX frame rate in fps of the video stream with the highest resolution within the reference period
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.sentFrameRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.sentFrameRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.sentFrameRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.sentFrameRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "encoderOutputFrameRate", {
            /** {en}
             * @brief Encoder-output frame rate in fps of the video stream with the highest resolution within the reference period
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.encoderOutputFrameRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.encoderOutputFrameRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.encoderOutputFrameRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.encoderOutputFrameRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "rendererOutputFrameRate", {
            /** {en}
             * @brief Local-rendering frame rate in fps during this reference period
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rendererOutputFrameRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rendererOutputFrameRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rendererOutputFrameRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.rendererOutputFrameRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "statsInterval", {
            /** {en}
             * @brief Reference period in ms. <br>
             *        This field is used to set the reference period for the callback, which is 2 s by default.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.statsInterval);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.statsInterval);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.statsInterval = value;
                }
                else if ($os === 'ios') {
                    this._instance.statsInterval = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "videoLossRate", {
            /** {en}
             * @brief Video packet loss rate. The video uplink packet loss rate in this reference period ranges from  [0,1].
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.videoLossRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.videoLossRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.videoLossRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.videoLossRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "rtt", {
            /** {en}
             * @brief Round-trip time in ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rtt);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rtt);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rtt = value;
                }
                else if ($os === 'ios') {
                    this._instance.rtt = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "encodedBitrate", {
            /** {en}
             * @brief Video encoding bitrate in Kbps of the video stream with the highest resolution within the reference period.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.encodedBitrate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.encodedBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.encodedBitrate = value;
                }
                else if ($os === 'ios') {
                    this._instance.encodedBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "encodedFrameWidth", {
            /** {en}
             * @brief Video encoding width in px of the video stream with the highest resolution within the reference period
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.encodedFrameWidth);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.encodedFrameWidth);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.encodedFrameWidth = value;
                }
                else if ($os === 'ios') {
                    this._instance.encodedFrameWidth = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "encodedFrameHeight", {
            /** {en}
             * @brief Video encoding height in px of the video stream with the highest resolution within the reference period
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.encodedFrameHeight);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.encodedFrameHeight);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.encodedFrameHeight = value;
                }
                else if ($os === 'ios') {
                    this._instance.encodedFrameHeight = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "encodedFrameCount", {
            /** {en}
             * @brief The total number of the video stream with the highest resolution within the reference period sent in the reference period.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.encodedFrameCount);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.encodedFrameCount);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.encodedFrameCount = value;
                }
                else if ($os === 'ios') {
                    this._instance.encodedFrameCount = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "codecType", {
            /** {en}
             * @brief For the encoding type of the video, please refer to {@link VideoCodecType VideoCodecType}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_VideoCodecType.android_to_ts(this._instance.codecType);
                }
                else if ($os === 'ios') {
                    return t_VideoCodecType.ios_to_ts(this._instance.codecType);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.codecType = t_VideoCodecType.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.codecType = t_VideoCodecType.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "isScreen", {
            /** {en}
             * @brief Whether the media stream belongs to the user is a screen stream. You can know whether the current statistics come from mainstream or screen stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.isScreen;
                }
                else if ($os === 'ios') {
                    return this._instance.isScreen;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.isScreen = value;
                }
                else if ($os === 'ios') {
                    this._instance.isScreen = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "jitter", {
            /** {en}
             * @brief Video uplink network jitter in ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.jitter);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.jitter);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.jitter = value;
                }
                else if ($os === 'ios') {
                    this._instance.jitter = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "videoDenoiseMode", {
            /** {en}
             * @brief The current state of the video noise reduction mode of local video (0: off/1: on).
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_VideoDenoiseMode.android_to_ts(this._instance.videoDenoiseMode);
                }
                else if ($os === 'ios') {
                    return t_VideoDenoiseMode.ios_to_ts(this._instance.videoDenoiseMode);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.videoDenoiseMode = t_VideoDenoiseMode.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.videoDenoiseMode = t_VideoDenoiseMode.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoStats_1.prototype, "android_isPSNROn", {
            get: function () {
                return this._instance.isPSNROn;
            },
            set: function (value) {
                this._instance.isPSNROn = value;
            },
            enumerable: false,
            configurable: true
        });
        LocalVideoStats_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        LocalVideoStats_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCLocalVideoStats).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = LocalVideoStats$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return LocalVideoStats_1;
    }());
    __setFunctionName(_classThis, "LocalVideoStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.AudioRecordingState = void 0;
(function (AudioRecordingState) {
    AudioRecordingState[AudioRecordingState["AUDIO_RECORDING_STATE_ERROR"] = 0] = "AUDIO_RECORDING_STATE_ERROR";
    AudioRecordingState[AudioRecordingState["AUDIO_RECORDING_STATE_PROCESSING"] = 1] = "AUDIO_RECORDING_STATE_PROCESSING";
    AudioRecordingState[AudioRecordingState["AUDIO_RECORDING_STATE_SUCCESS"] = 2] = "AUDIO_RECORDING_STATE_SUCCESS";
})(exports.AudioRecordingState || (exports.AudioRecordingState = {}));
exports.MulDimSingScoringMode = void 0;
(function (MulDimSingScoringMode) {
    MulDimSingScoringMode[MulDimSingScoringMode["MUL_DIM_SING_SCORING_MODE_NOTE"] = 0] = "MUL_DIM_SING_SCORING_MODE_NOTE";
})(exports.MulDimSingScoringMode || (exports.MulDimSingScoringMode = {}));
exports.AudioPlaybackDevice = void 0;
(function (AudioPlaybackDevice) {
    AudioPlaybackDevice[AudioPlaybackDevice["AUDIO_PLAYBACK_DEVICE_HEADSET"] = 0] = "AUDIO_PLAYBACK_DEVICE_HEADSET";
    AudioPlaybackDevice[AudioPlaybackDevice["AUDIO_PLAYBACK_DEVICE_EARPIECE"] = 1] = "AUDIO_PLAYBACK_DEVICE_EARPIECE";
    AudioPlaybackDevice[AudioPlaybackDevice["AUDIO_PLAYBACK_DEVICE_SPEAKERPHONE"] = 2] = "AUDIO_PLAYBACK_DEVICE_SPEAKERPHONE";
    AudioPlaybackDevice[AudioPlaybackDevice["AUDIO_PLAYBACK_DEVICE_HEADSET_BLUETOOTH"] = 3] = "AUDIO_PLAYBACK_DEVICE_HEADSET_BLUETOOTH";
    AudioPlaybackDevice[AudioPlaybackDevice["AUDIO_PLAYBACK_DEVICE_HEADSET_USB"] = 4] = "AUDIO_PLAYBACK_DEVICE_HEADSET_USB";
})(exports.AudioPlaybackDevice || (exports.AudioPlaybackDevice = {}));
var VideoPreprocessorConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function VideoPreprocessorConfig_1() {
        }
        Object.defineProperty(VideoPreprocessorConfig_1.prototype, "requiredPixelFormat", {
            /** {en}
             * @brief To set the requested pixel format, see'VideoPixelFormat 'in {@link VideoPixelFormat VideoPixelFormat}. <br>
             *        Only `I420,`TEXTURE_2D` and `UNKNOWN` are supported.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_VideoPixelFormat.android_to_ts(this._instance.requiredPixelFormat);
                }
                else if ($os === 'ios') {
                    return t_VideoPixelFormat.ios_to_ts(this._instance.requiredPixelFormat);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.requiredPixelFormat = t_VideoPixelFormat.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.requiredPixelFormat = t_VideoPixelFormat.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        VideoPreprocessorConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        VideoPreprocessorConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCVideoPreprocessorConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = VideoPreprocessorConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return VideoPreprocessorConfig_1;
    }());
    __setFunctionName(_classThis, "VideoPreprocessorConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var AudioFrame = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function AudioFrame_1() {
        }
        Object.defineProperty(AudioFrame_1.prototype, "buffer", {
            /** {en}
             * @brief PCM data
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.buffer;
                }
                else if ($os === 'ios') {
                    return this._instance.buffer;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.buffer = value;
                }
                else if ($os === 'ios') {
                    this._instance.buffer = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioFrame_1.prototype, "samples", {
            /** {en}
             * @brief Total sampling number
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.samples);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.samples);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.samples = value;
                }
                else if ($os === 'ios') {
                    this._instance.samples = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioFrame_1.prototype, "sampleRate", {
            /** {en}
             * @brief Sample rate, see {@link AudioSampleRate AudioSampleRate}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioSampleRate.android_to_ts(this._instance.sampleRate);
                }
                else if ($os === 'ios') {
                    return t_AudioSampleRate.ios_to_ts(this._instance.sampleRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.sampleRate = t_AudioSampleRate.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.sampleRate = t_AudioSampleRate.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioFrame_1.prototype, "channel", {
            /** {en}
             * @brief Audio channel, see {@link AudioChannel AudioChannel}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioChannel.android_to_ts(this._instance.channel);
                }
                else if ($os === 'ios') {
                    return t_AudioChannel.ios_to_ts(this._instance.channel);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.channel = t_AudioChannel.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.channel = t_AudioChannel.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        AudioFrame_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        AudioFrame_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCAudioFrame).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = AudioFrame$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return AudioFrame_1;
    }());
    __setFunctionName(_classThis, "AudioFrame");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var DownloadResult = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function DownloadResult_1() {
        }
        Object.defineProperty(DownloadResult_1.prototype, "musicId", {
            /** {en}
             * @brief Music ID.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.musicId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.musicId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.musicId = value;
                }
                else if ($os === 'ios') {
                    this._instance.musicId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(DownloadResult_1.prototype, "fileType", {
            /** {en}
             * @brief Download file type. See {@link DownloadFileType DownloadFileType}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_DownloadFileType.android_to_ts(this._instance.fileType);
                }
                else if ($os === 'ios') {
                    return t_DownloadFileType.ios_to_ts(this._instance.fileType);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.fileType = t_DownloadFileType.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.fileType = t_DownloadFileType.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(DownloadResult_1.prototype, "filePath", {
            /** {en}
             * @brief Download file path.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.filePath);
                }
                else if ($os === 'ios') {
                    return String(this._instance.filePath);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.filePath = value;
                }
                else if ($os === 'ios') {
                    this._instance.filePath = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        DownloadResult_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        DownloadResult_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCDownloadResult).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = DownloadResult$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return DownloadResult_1;
    }());
    __setFunctionName(_classThis, "DownloadResult");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.ProblemFeedbackOption = void 0;
(function (ProblemFeedbackOption) {
    ProblemFeedbackOption[ProblemFeedbackOption["NONE"] = 0] = "NONE";
    ProblemFeedbackOption[ProblemFeedbackOption["OTHER_MESSAGE"] = 1] = "OTHER_MESSAGE";
    ProblemFeedbackOption[ProblemFeedbackOption["DISCONNECTED"] = 2] = "DISCONNECTED";
    ProblemFeedbackOption[ProblemFeedbackOption["EAR_BACK_DELAY"] = 3] = "EAR_BACK_DELAY";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_NOISE"] = 4] = "LOCAL_NOISE";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_AUDIO_LAGGING"] = 5] = "LOCAL_AUDIO_LAGGING";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_NO_AUDIO"] = 6] = "LOCAL_NO_AUDIO";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_AUDIO_STRENGTH"] = 7] = "LOCAL_AUDIO_STRENGTH";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_ECHO"] = 8] = "LOCAL_ECHO";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_VIDEO_FUZZY"] = 9] = "LOCAL_VIDEO_FUZZY";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_NOT_SYNC"] = 10] = "LOCAL_NOT_SYNC";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_VIDEO_LAGGING"] = 11] = "LOCAL_VIDEO_LAGGING";
    ProblemFeedbackOption[ProblemFeedbackOption["LOCAL_NO_VIDEO"] = 12] = "LOCAL_NO_VIDEO";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_NOISE"] = 13] = "REMOTE_NOISE";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_AUDIO_LAGGING"] = 14] = "REMOTE_AUDIO_LAGGING";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_NO_AUDIO"] = 15] = "REMOTE_NO_AUDIO";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_AUDIO_STRENGTH"] = 16] = "REMOTE_AUDIO_STRENGTH";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_ECHO"] = 17] = "REMOTE_ECHO";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_VIDEO_FUZZY"] = 18] = "REMOTE_VIDEO_FUZZY";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_NOT_SYNC"] = 19] = "REMOTE_NOT_SYNC";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_VIDEO_LAGGING"] = 20] = "REMOTE_VIDEO_LAGGING";
    ProblemFeedbackOption[ProblemFeedbackOption["REMOTE_NO_VIDEO"] = 21] = "REMOTE_NO_VIDEO";
})(exports.ProblemFeedbackOption || (exports.ProblemFeedbackOption = {}));
exports.UserOnlineStatus = void 0;
(function (UserOnlineStatus) {
    /** {en}
     * @platform android
     * @brief Counterpart user is offline <br>
     *        Counterpart user has called `logout`, or has not called `login` to log in
     *
     */
    UserOnlineStatus[UserOnlineStatus["USER_ONLINE_STATUS_OFFLINE"] = 0] = "USER_ONLINE_STATUS_OFFLINE";
    /** {en}
     * @platform android
     * @brief The peer user is online <br>
     *        The peer user calls `login` to log in, and the connection status is normal.
     *
     */
    UserOnlineStatus[UserOnlineStatus["USER_ONLINE_STATUS_ONLINE"] = 1] = "USER_ONLINE_STATUS_ONLINE";
    /** {en}
     * @platform android
     * @brief Unable to get the online state of the peer user <br>
     *        Returned when a cascade error occurs and the online state of the peer user is abnormal
     *
     */
    UserOnlineStatus[UserOnlineStatus["USER_ONLINE_STATUS_UNREACHABLE"] = 2] = "USER_ONLINE_STATUS_UNREACHABLE";
    UserOnlineStatus[UserOnlineStatus["ByteRTCUserOnlineStatusOffline"] = 3] = "ByteRTCUserOnlineStatusOffline";
    UserOnlineStatus[UserOnlineStatus["ByteRTCUserOnlineStatusOnline"] = 4] = "ByteRTCUserOnlineStatusOnline";
    UserOnlineStatus[UserOnlineStatus["ByteRTCUserOnlineStatusUnreachable"] = 5] = "ByteRTCUserOnlineStatusUnreachable";
})(exports.UserOnlineStatus || (exports.UserOnlineStatus = {}));
exports.VideoDecoderConfig = void 0;
(function (VideoDecoderConfig) {
    VideoDecoderConfig[VideoDecoderConfig["VIDEO_DECODER_CONFIG_RAW"] = 0] = "VIDEO_DECODER_CONFIG_RAW";
    VideoDecoderConfig[VideoDecoderConfig["VIDEO_DECODER_CONFIG_ENCODE"] = 1] = "VIDEO_DECODER_CONFIG_ENCODE";
    VideoDecoderConfig[VideoDecoderConfig["VIDEO_DECODER_CONFIG_BOTH"] = 2] = "VIDEO_DECODER_CONFIG_BOTH";
})(exports.VideoDecoderConfig || (exports.VideoDecoderConfig = {}));
var PositionInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function PositionInfo_1() {
        }
        Object.defineProperty(PositionInfo_1.prototype, "position", {
            /** {en}
             * @brief 3D coordinate values of the user's position in the rectangular coordinate system for the spatial audio. You need to build your own rectangular coordinate system. Refer to {@link Position Position} for details.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return packObject(this._instance.position, Position);
                }
                else if ($os === 'ios') {
                    return packObject(this._instance.position, Position);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.position = unpackObject(value);
                }
                else if ($os === 'ios') {
                    this._instance.position = unpackObject(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(PositionInfo_1.prototype, "orientation", {
            /** {en}
             * @brief Information on the three-dimensional orientation of the user in the rectangular coordinate system for the spatial audio. Any two of the 3D coordinate vectors of the user's position need to be perpendicular to each other. Refer to {@link HumanOrientation HumanOrientation} for details.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return packObject(this._instance.orientation, HumanOrientation);
                }
                else if ($os === 'ios') {
                    return packObject(this._instance.orientation, HumanOrientation);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.orientation = unpackObject(value);
                }
                else if ($os === 'ios') {
                    this._instance.orientation = unpackObject(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        PositionInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        PositionInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCPositionInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = PositionInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return PositionInfo_1;
    }());
    __setFunctionName(_classThis, "PositionInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var LocalStreamStats = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function LocalStreamStats_1() {
        }
        Object.defineProperty(LocalStreamStats_1.prototype, "audioStats", {
            /** {en}
             * @brief For statistics on audio streams sent by local devices. See {@link LocalAudioStats LocalAudioStats}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return packObject(this._instance.audioStats, LocalAudioStats);
                }
                else if ($os === 'ios') {
                    return packObject(this._instance.audioStats, LocalAudioStats);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.audioStats = unpackObject(value);
                }
                else if ($os === 'ios') {
                    this._instance.audioStats = unpackObject(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalStreamStats_1.prototype, "videoStats", {
            /** {en}
             * @brief For statistics on video streams sent by local devices. See {@link LocalVideoStats LocalVideoStats}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return packObject(this._instance.videoStats, LocalVideoStats);
                }
                else if ($os === 'ios') {
                    return packObject(this._instance.videoStats, LocalVideoStats);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.videoStats = unpackObject(value);
                }
                else if ($os === 'ios') {
                    this._instance.videoStats = unpackObject(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalStreamStats_1.prototype, "isScreen", {
            /** {en}
             * @brief Whether the media stream belongs to the user is a screen stream. You can know whether the current statistics come from mainstream or screen stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.isScreen;
                }
                else if ($os === 'ios') {
                    return this._instance.isScreen;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.isScreen = value;
                }
                else if ($os === 'ios') {
                    this._instance.isScreen = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalStreamStats_1.prototype, "txQuality", {
            /** {en}
             * @brief For local media uplink network quality. See {@link NetworkQuality NetworkQuality}.
             * @deprecated since 3.45 and will be deleted in 3.51, use {@link onNetworkQuality onNetworkQuality} instead.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_NetworkQuality.android_to_ts(this._instance.txQuality);
                }
                else if ($os === 'ios') {
                    return t_NetworkQuality.ios_to_ts(this._instance.txQuality);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.txQuality = t_NetworkQuality.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.txQuality = t_NetworkQuality.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalStreamStats_1.prototype, "rxQuality", {
            /** {en}
             * @brief Local media downlink network quality. See {@link NetworkQuality NetworkQuality}.
             * @deprecated since 3.45 and will be deleted in 3.51, use {@link onNetworkQuality onNetworkQuality} instead.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_NetworkQuality.android_to_ts(this._instance.rxQuality);
                }
                else if ($os === 'ios') {
                    return t_NetworkQuality.ios_to_ts(this._instance.rxQuality);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rxQuality = t_NetworkQuality.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.rxQuality = t_NetworkQuality.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        LocalStreamStats_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        LocalStreamStats_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCLocalStreamStats).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = LocalStreamStats$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return LocalStreamStats_1;
    }());
    __setFunctionName(_classThis, "LocalStreamStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VoiceEqualizationConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function VoiceEqualizationConfig_1() {
        }
        Object.defineProperty(VoiceEqualizationConfig_1.prototype, "frequency", {
            /** {en}
             * @brief Frequency band. See {@link VoiceEqualizationBandFrequency VoiceEqualizationBandFrequency}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_BandFrequency.android_to_ts(this._instance.frequency);
                }
                else if ($os === 'ios') {
                    return t_BandFrequency.ios_to_ts(this._instance.frequency);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.frequency = t_BandFrequency.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.frequency = t_BandFrequency.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VoiceEqualizationConfig_1.prototype, "gain", {
            /** {en}
             * @brief Gain of the frequency band in dB. The range is `[-15, 15]`.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.gain);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.gain);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.gain = value;
                }
                else if ($os === 'ios') {
                    this._instance.gain = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        VoiceEqualizationConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        VoiceEqualizationConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCVoiceEqualizationConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = VoiceEqualizationConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return VoiceEqualizationConfig_1;
    }());
    __setFunctionName(_classThis, "VoiceEqualizationConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.VideoFrameType = void 0;
(function (VideoFrameType) {
    VideoFrameType[VideoFrameType["RAW_MEMORY"] = 0] = "RAW_MEMORY";
    VideoFrameType[VideoFrameType["GL_TEXTURE"] = 1] = "GL_TEXTURE";
    VideoFrameType[VideoFrameType["ByteRTCVideoFrameTypePixelBuffer"] = 2] = "ByteRTCVideoFrameTypePixelBuffer";
})(exports.VideoFrameType || (exports.VideoFrameType = {}));
exports.TranscoderContentControlType = void 0;
(function (TranscoderContentControlType) {
    TranscoderContentControlType[TranscoderContentControlType["HAS_AUDIO_AND_VIDEO"] = 0] = "HAS_AUDIO_AND_VIDEO";
    TranscoderContentControlType[TranscoderContentControlType["HAS_AUDIO_ONLY"] = 1] = "HAS_AUDIO_ONLY";
    TranscoderContentControlType[TranscoderContentControlType["HAS_VIDEO_ONLY"] = 2] = "HAS_VIDEO_ONLY";
})(exports.TranscoderContentControlType || (exports.TranscoderContentControlType = {}));
exports.ChannelProfile = void 0;
(function (ChannelProfile) {
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_COMMUNICATION"] = 0] = "CHANNEL_PROFILE_COMMUNICATION";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_GAME"] = 1] = "CHANNEL_PROFILE_GAME";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_CLOUD_GAME"] = 2] = "CHANNEL_PROFILE_CLOUD_GAME";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_LOW_LATENCY"] = 3] = "CHANNEL_PROFILE_LOW_LATENCY";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_CHAT"] = 4] = "CHANNEL_PROFILE_CHAT";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_CHAT_ROOM"] = 5] = "CHANNEL_PROFILE_CHAT_ROOM";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_LW_TOGETHER"] = 6] = "CHANNEL_PROFILE_LW_TOGETHER";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_GAME_HD"] = 7] = "CHANNEL_PROFILE_GAME_HD";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_CO_HOST"] = 8] = "CHANNEL_PROFILE_CO_HOST";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_KTV"] = 9] = "CHANNEL_PROFILE_KTV";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_CHORUS"] = 10] = "CHANNEL_PROFILE_CHORUS";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_GAME_STREAMING"] = 11] = "CHANNEL_PROFILE_GAME_STREAMING";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_LAN_LIVE_STREAMING"] = 12] = "CHANNEL_PROFILE_LAN_LIVE_STREAMING";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_MEETING_ROOM"] = 13] = "CHANNEL_PROFILE_MEETING_ROOM";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_CLASSROOM"] = 14] = "CHANNEL_PROFILE_CLASSROOM";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_INTERACTIVE_PODCAST"] = 15] = "CHANNEL_PROFILE_INTERACTIVE_PODCAST";
    ChannelProfile[ChannelProfile["CHANNEL_PROFIEL_VR_CHAT"] = 16] = "CHANNEL_PROFIEL_VR_CHAT";
    ChannelProfile[ChannelProfile["CHANNEL_PROFIEL_MEETING"] = 17] = "CHANNEL_PROFIEL_MEETING";
    ChannelProfile[ChannelProfile["CHANNEL_PROFILE_LIVE_BROADCASTING"] = 18] = "CHANNEL_PROFILE_LIVE_BROADCASTING";
})(exports.ChannelProfile || (exports.ChannelProfile = {}));
var MixedStreamLayoutConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function MixedStreamLayoutConfig_1() {
        }
        Object.defineProperty(MixedStreamLayoutConfig_1.prototype, "ios_backgroundColor", {
            /** {en}
             * @platform ios
             * @brief Background-color of the mixed stream in hexadecimal values such as #FFFFFF and #000000. The default value is #000000 (black). It's recommended to be set. <br>
             *        With invalid or empty input, the configurations will be set as the default values.
             */
            get: function () {
                return this._instance.backgroundColor;
            },
            set: function (value) {
                this._instance.backgroundColor = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutConfig_1.prototype, "ios_regions", {
            /** {en}
             * @platform ios
             * @brief List of user's video layout information. The specific layout of each stream is detailed in {@link ByteRTCMixedStreamLayoutRegionConfig ByteRTCMixedStreamLayoutRegionConfig}. It's recommended to be set. <br>
             *        With invalid or empty input, the configurations will be set as the default values.
             */
            get: function () {
                return this._instance.regions;
            },
            set: function (value) {
                this._instance.regions = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutConfig_1.prototype, "ios_userConfigExtraInfo", {
            /** {en}
             * @platform ios
             * @brief Info passed through from the user.
             */
            get: function () {
                return this._instance.userConfigExtraInfo;
            },
            set: function (value) {
                this._instance.userConfigExtraInfo = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamLayoutConfig_1.prototype, "ios_backgroundImageUrl", {
            /** {en}
             * @platform ios
             * @valid since 3.57
             * @brief Sets the URL of the background image for the canvas that renders the mixed stream, with a maximum length of 1024 bytes. <br>
             *        You can input images in the following supported formats: JPG, JPEG, PNG. <br>
             *        If the width and height of the background image are different from the screen dimensions, the background image will be scaled to fill the screen.
             */
            get: function () {
                return this._instance.backgroundImageUrl;
            },
            set: function (value) {
                this._instance.backgroundImageUrl = value;
            },
            enumerable: false,
            configurable: true
        });
        MixedStreamLayoutConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        MixedStreamLayoutConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCMixedStreamLayoutConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = MixedStreamLayoutConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the background color of the canvas. With invalid or empty input, the configurations will be set as the default values. You are recommended to set the value.
         * @param backgroundColor Background-color of the mixed stream in hexadecimal values such as #FFFFFF and #000000. The default value is #000000 (black).
         *
         */
        MixedStreamLayoutConfig_1.prototype.android_setBackgroundColor = function (backgroundColor) {
            var _this = this;
            var $ = function () { return (_this._instance.setBackgroundColor(backgroundColor), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the background color of the canvas.
         *
         */
        MixedStreamLayoutConfig_1.prototype.android_getBackgroundColor = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getBackgroundColor()); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Sets the URL of the background image for the canvas that renders the mixed stream
         * @param backgroundImageURL URL of the background image with a maximum length of 1024 bytes. <br>
         *        You can input images in the following supported formats: JPG, JPEG, PNG. <br>
         *        If the width and height of the background image are different from the screen dimensions, the background image will be scaled to fill the screen.
         *
         */
        MixedStreamLayoutConfig_1.prototype.android_setBackgroundImageURL = function (backgroundImageURL) {
            var _this = this;
            var $ = function () { return (_this._instance.setBackgroundImageURL(backgroundImageURL), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Gets the background image URL.
         *
         */
        MixedStreamLayoutConfig_1.prototype.android_getBackgroundImageURL = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getBackgroundImageURL()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the user layout information list.
         *
         */
        MixedStreamLayoutConfig_1.prototype.android_getRegions = function () {
            var _this = this;
            var $ = function () { return _this._instance.getRegions(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the data that you want to be passed through from the App and carried by the video stream.
         * @param userConfigExtraInfo The data you need， up to 4KB in length.
         *
         */
        MixedStreamLayoutConfig_1.prototype.android_setUserConfigExtraInfo = function (userConfigExtraInfo) {
            var _this = this;
            var $ = function () { return (_this._instance.setUserConfigExtraInfo(userConfigExtraInfo), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the data passed through from the App.
         *
         */
        MixedStreamLayoutConfig_1.prototype.android_getUserConfigExtraInfo = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getUserConfigExtraInfo()); };
            return $();
        };
        return MixedStreamLayoutConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamLayoutConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IAudioFrame = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IAudioFrame_1() {
        }
        Object.defineProperty(IAudioFrame_1.prototype, "ios_buffer", {
            /** {en}
             * @platform ios
             * @brief PCM data
             */
            get: function () {
                return this._instance.buffer;
            },
            set: function (value) {
                this._instance.buffer = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(IAudioFrame_1.prototype, "ios_samples", {
            /** {en}
             * @platform ios
             * @brief Total sampling number
             */
            get: function () {
                return this._instance.samples;
            },
            set: function (value) {
                this._instance.samples = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(IAudioFrame_1.prototype, "ios_sampleRate", {
            /** {en}
             * @platform ios
             * @brief Sample rate. See {@link ByteRTCAudioSampleRate ByteRTCAudioSampleRate}.
             */
            get: function () {
                return this._instance.sampleRate;
            },
            set: function (value) {
                this._instance.sampleRate = value;
            },
            enumerable: false,
            configurable: true
        });
        IAudioFrame_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        IAudioFrame_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCAudioFrame).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = IAudioFrame$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @author majun.lvhiei
         * @brief  Get the audio timestamp.
         * @return  Audio timestamp in microseconds.
         *
         */
        IAudioFrame_1.prototype.android_timestamp_us = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.timestamp_us()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @author majun.lvhiei
         * @brief  Get the audio sample rate. See {@link AudioSampleRate AudioSampleRate}.
         * @return AudioSampleRate
         *
         */
        IAudioFrame_1.prototype.android_sample_rate = function () {
            var _this = this;
            var $ = function () { return _this._instance.sample_rate(); };
            return $();
        };
        /** {en}
         * @detail api
         * @author majun.lvhiei
         * @brief  Get the audio channel. See {@link AudioChannel AudioChannel}.
         * @return  Audio channel
         * @note For dual channels, the audio frames are interleaved.
         *
         */
        IAudioFrame_1.prototype.channel = function () {
            var _this = this;
            var a = function () { return t_AudioChannel.android_to_ts(_this._instance.channel()); };
            var i = function () {
                return t_AudioChannel.ios_to_ts(_this._instance.channel);
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @author majun.lvhiei
         * @brief  Get the audio frame's temporary storage address
         * @return   Audio frame's ByteBuffer
         *
         */
        IAudioFrame_1.prototype.android_getDataBuffer = function () {
            var _this = this;
            var $ = function () { return _this._instance.getDataBuffer(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @author majun.lvhiei
         * @brief  Get audio frame data size.
         * @return   Audio frame data size in bytes.
         *
         */
        IAudioFrame_1.prototype.android_data_size = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.data_size()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief  Get audio frame type, only PCM is supported currently. See {@link AudioFrameType AudioFrameType}.
         * @return Audio frame type.
         *
         */
        IAudioFrame_1.prototype.android_frame_type = function () {
            var _this = this;
            var $ = function () { return _this._instance.frame_type(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief  Release audio frame.
         *
         */
        IAudioFrame_1.prototype.android_release = function () {
            var _this = this;
            var $ = function () { return (_this._instance.release(), void 0); };
            return $();
        };
        return IAudioFrame_1;
    }());
    __setFunctionName(_classThis, "IAudioFrame");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ForwardStreamStateInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ForwardStreamStateInfo_1() {
        }
        Object.defineProperty(ForwardStreamStateInfo_1.prototype, "roomId", {
            /** {en}
             * @brief ID of the room where the media stream aims to relay to <br>
             *        An Empty string is for all rooms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.roomId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.roomId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.roomId = value;
                }
                else if ($os === 'ios') {
                    this._instance.roomId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(ForwardStreamStateInfo_1.prototype, "state", {
            /** {en}
             * @brief State of the room during relaying. Refer to {@link ForwardStreamState ForwardStreamState} for more information.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_ForwardStreamState.android_to_ts(this._instance.state);
                }
                else if ($os === 'ios') {
                    return t_ForwardStreamState.ios_to_ts(this._instance.state);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.state = t_ForwardStreamState.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.state = t_ForwardStreamState.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(ForwardStreamStateInfo_1.prototype, "error", {
            /** {en}
             * @brief Error code from the room during relaying. Refer to {@link ForwardStreamError ForwardStreamError} for more information.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_ForwardStreamError.android_to_ts(this._instance.error);
                }
                else if ($os === 'ios') {
                    return t_ForwardStreamError.ios_to_ts(this._instance.error);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.error = t_ForwardStreamError.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.error = t_ForwardStreamError.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        ForwardStreamStateInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        ForwardStreamStateInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCForwardStreamStateInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = ForwardStreamStateInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return ForwardStreamStateInfo_1;
    }());
    __setFunctionName(_classThis, "ForwardStreamStateInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RemoteVideoConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RemoteVideoConfig_1() {
        }
        Object.defineProperty(RemoteVideoConfig_1.prototype, "width", {
            /** {en}
             * @brief Width of the video frame in px
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.width);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.width);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.width = value;
                }
                else if ($os === 'ios') {
                    this._instance.width = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoConfig_1.prototype, "height", {
            /** {en}
             * @brief Height of the video frame in px
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.height);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.height);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.height = value;
                }
                else if ($os === 'ios') {
                    this._instance.height = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoConfig_1.prototype, "framerate", {
            /** {en}
             * @brief Expected maximum frame rate of the subscribed stream in px. The default value is 0, which represents full-frame-rate, values greater than 0 are valid. <br>
             *        If the frame rate of the stream published is higher than the value set by the subscriber, the subscriber receives the video of the frame rate set by this API; if the frame rate of the stream published is lower than the value set by the subscriber, the subscriber receives the video of the same frame rate of the video published. <br>
             *        Only valid if the stream is coded with SVC technique.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.framerate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.framerate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.framerate = value;
                }
                else if ($os === 'ios') {
                    this._instance.framerate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        RemoteVideoConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RemoteVideoConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRemoteVideoConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RemoteVideoConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RemoteVideoConfig_1;
    }());
    __setFunctionName(_classThis, "RemoteVideoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RTCEncodedVideoFrame = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RTCEncodedVideoFrame_1() {
        }
        Object.defineProperty(RTCEncodedVideoFrame_1.prototype, "android_buffer", {
            /** {en}
             * @platform android
             * @brief The pointer to the video frame <br>
             *        The buffer must be Direct. And the buffer size is its capacity.
             *
             */
            get: function () {
                return this._instance.buffer;
            },
            set: function (value) {
                this._instance.buffer = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCEncodedVideoFrame_1.prototype, "timestampUs", {
            /** {en}
             * @brief Video capture timestamp in microseconds
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.timestampUs);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.timestampUs);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.timestampUs = value;
                }
                else if ($os === 'ios') {
                    this._instance.timestampUs = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCEncodedVideoFrame_1.prototype, "timestampDtsUs", {
            /** {en}
             * @brief Video encoding timestamp in microseconds
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.timestampDtsUs);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.timestampDtsUs);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.timestampDtsUs = value;
                }
                else if ($os === 'ios') {
                    this._instance.timestampDtsUs = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCEncodedVideoFrame_1.prototype, "width", {
            /** {en}
             * @brief Width of the video in px
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.width);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.width);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.width = value;
                }
                else if ($os === 'ios') {
                    this._instance.width = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCEncodedVideoFrame_1.prototype, "height", {
            /** {en}
             * @brief Height of the video in px
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.height);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.height);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.height = value;
                }
                else if ($os === 'ios') {
                    this._instance.height = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCEncodedVideoFrame_1.prototype, "android_videoCodecType", {
            /** {en}
             * @platform android
             * @brief Video encoding type. See {@link VideoCodecType VideoCodecType}
             *
             */
            get: function () {
                return this._instance.videoCodecType;
            },
            set: function (value) {
                this._instance.videoCodecType = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCEncodedVideoFrame_1.prototype, "android_videoPictureType", {
            /** {en}
             * @platform android
             * @brief Video compression picture type. See {@link VideoPictureType VideoPictureType}
             *
             */
            get: function () {
                return this._instance.videoPictureType;
            },
            set: function (value) {
                this._instance.videoPictureType = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCEncodedVideoFrame_1.prototype, "android_videoRotation", {
            /** {en}
             * @platform android
             * @brief Video frame rotation angle, the default value is 0 degrees. See {@link VideoRotation VideoRotation}
             *
             */
            get: function () {
                return this._instance.videoRotation;
            },
            set: function (value) {
                this._instance.videoRotation = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCEncodedVideoFrame_1.prototype, "ios_codecType", {
            /** {en}
             * @platform ios
             * @brief Video encoding type. See {@link ByteRTCVideoCodecType ByteRTCVideoCodecType}
             */
            get: function () {
                return this._instance.codecType;
            },
            set: function (value) {
                this._instance.codecType = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCEncodedVideoFrame_1.prototype, "ios_pictureType", {
            /** {en}
             * @platform ios
             * @brief Video compression picture type. See {@link ByteRTCVideoPictureType ByteRTCVideoPictureType}
             */
            get: function () {
                return this._instance.pictureType;
            },
            set: function (value) {
                this._instance.pictureType = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCEncodedVideoFrame_1.prototype, "ios_rotation", {
            /** {en}
             * @platform ios
             * @brief Video frame rotation angle. See {@link ByteRTCVideoRotation ByteRTCVideoRotation}
             */
            get: function () {
                return this._instance.rotation;
            },
            set: function (value) {
                this._instance.rotation = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCEncodedVideoFrame_1.prototype, "ios_data", {
            /** {en}
             * @platform ios
             * @brief The pointer to the video frame
             */
            get: function () {
                return this._instance.data;
            },
            set: function (value) {
                this._instance.data = value;
            },
            enumerable: false,
            configurable: true
        });
        RTCEncodedVideoFrame_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RTCEncodedVideoFrame_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCEncodedVideoFrame).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RTCEncodedVideoFrame$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RTCEncodedVideoFrame_1;
    }());
    __setFunctionName(_classThis, "RTCEncodedVideoFrame");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.AudioMixingState = void 0;
(function (AudioMixingState) {
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_PRELOADED"] = 0] = "AUDIO_MIXING_STATE_PRELOADED";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_PLAYING"] = 1] = "AUDIO_MIXING_STATE_PLAYING";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_PAUSED"] = 2] = "AUDIO_MIXING_STATE_PAUSED";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_STOPPED"] = 3] = "AUDIO_MIXING_STATE_STOPPED";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_FAILED"] = 4] = "AUDIO_MIXING_STATE_FAILED";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_FINISHED"] = 5] = "AUDIO_MIXING_STATE_FINISHED";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_PCM_ENABLED"] = 6] = "AUDIO_MIXING_STATE_PCM_ENABLED";
    AudioMixingState[AudioMixingState["AUDIO_MIXING_STATE_PCM_DISABLED"] = 7] = "AUDIO_MIXING_STATE_PCM_DISABLED";
})(exports.AudioMixingState || (exports.AudioMixingState = {}));
exports.DownloadLyricType = void 0;
(function (DownloadLyricType) {
    DownloadLyricType[DownloadLyricType["KRC"] = 0] = "KRC";
    DownloadLyricType[DownloadLyricType["LRC"] = 1] = "LRC";
})(exports.DownloadLyricType || (exports.DownloadLyricType = {}));
exports.MixedStreamType = void 0;
(function (MixedStreamType) {
    MixedStreamType[MixedStreamType["MIXED_STREAM_TYPE_BY_SERVER"] = 0] = "MIXED_STREAM_TYPE_BY_SERVER";
    MixedStreamType[MixedStreamType["MIXED_STREAM_TYPE_BY_CLIENT"] = 1] = "MIXED_STREAM_TYPE_BY_CLIENT";
    MixedStreamType[MixedStreamType["ByteRTCMixedStreamByServer"] = 2] = "ByteRTCMixedStreamByServer";
    MixedStreamType[MixedStreamType["ByteRTCMixedStreamByClient"] = 3] = "ByteRTCMixedStreamByClient";
})(exports.MixedStreamType || (exports.MixedStreamType = {}));
var RemoteAudioStats = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RemoteAudioStats_1() {
        }
        Object.defineProperty(RemoteAudioStats_1.prototype, "audioLossRate", {
            /** {en}
             * @brief Audio packet loss rate. The audio downlink packet loss rate in the reference period. The value range is  [0,1].
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.audioLossRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.audioLossRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.audioLossRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.audioLossRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "receivedKBitrate", {
            /** {en}
             * @brief Receiving bit rate. The audio reception rate in the reference period in kbps.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.receivedKBitrate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.receivedKBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.receivedKBitrate = value;
                }
                else if ($os === 'ios') {
                    this._instance.receivedKBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "stallCount", {
            /** {en}
             * @brief Number of audio stalls.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.stallCount);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.stallCount);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.stallCount = value;
                }
                else if ($os === 'ios') {
                    this._instance.stallCount = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "stallDuration", {
            /** {en}
             * @brief Audio stall duration. Stall duration in the reference period in ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.stallDuration);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.stallDuration);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.stallDuration = value;
                }
                else if ($os === 'ios') {
                    this._instance.stallDuration = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "e2eDelay", {
            /** {en}
             * @brief End-to-end latency at the user experience level. The delay from the start of encoding at the sending end to the start of decoding at the receiving end, in units of ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.e2eDelay);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.e2eDelay);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.e2eDelay = value;
                }
                else if ($os === 'ios') {
                    this._instance.e2eDelay = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "playoutSampleRate", {
            /** {en}
             * @brief Play sample rate. Audio playback sample rate information within the reference period in Hz.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.playoutSampleRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.playoutSampleRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.playoutSampleRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.playoutSampleRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "statsInterval", {
            /** {en}
             * @brief Statistical interval. The interval of this reference period is in ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.statsInterval);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.statsInterval);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.statsInterval = value;
                }
                else if ($os === 'ios') {
                    this._instance.statsInterval = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "rtt", {
            /** {en}
             * @brief Round-trip time for client side to server level data transfer in ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rtt);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rtt);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rtt = value;
                }
                else if ($os === 'ios') {
                    this._instance.rtt = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "totalRtt", {
            /** {en}
             * @brief The sender-server level-the receiver-link data transmission round-trip time. The unit is ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.totalRtt);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.totalRtt);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.totalRtt = value;
                }
                else if ($os === 'ios') {
                    this._instance.totalRtt = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "quality", {
            /** {en}
             * @brief The quality of the audio stream sent by the remote user. Value meaning reference {@link NetworkQuality NetworkQuality}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.quality);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.quality);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.quality = value;
                }
                else if ($os === 'ios') {
                    this._instance.quality = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "jitterBufferDelay", {
            /** {en}
             * @brief The delay caused by the introduction of the jitter buffer mechanism. The unit is ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.jitterBufferDelay);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.jitterBufferDelay);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.jitterBufferDelay = value;
                }
                else if ($os === 'ios') {
                    this._instance.jitterBufferDelay = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "numChannels", {
            /** {en}
             * @brief Number of audio channels.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.numChannels);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.numChannels);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.numChannels = value;
                }
                else if ($os === 'ios') {
                    this._instance.numChannels = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "receivedSampleRate", {
            /** {en}
             * @brief Audio reception sampling rate. Remote audio sampling rate information received within the reference period, in Hz.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.receivedSampleRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.receivedSampleRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.receivedSampleRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.receivedSampleRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "frozenRate", {
            /** {en}
             * @brief The accumulated length of the audio card occurs after the remote user joins the room as a percentage of the total effective length of the audio. The effective duration of audio refers to the duration of audio other than stopping sending audio streams and disabling audio modules after remote users enter the room to publish audio streams.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.frozenRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.frozenRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.frozenRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.frozenRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "concealedSamples", {
            /** {en}
             * @brief Audio packet loss compensation (PLC)  total number of sample points.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.concealedSamples);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.concealedSamples);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.concealedSamples = value;
                }
                else if ($os === 'ios') {
                    this._instance.concealedSamples = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "concealmentEvent", {
            /** {en}
             * @brief Audio packet loss compensation (PLC)  cumulative times.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.concealmentEvent);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.concealmentEvent);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.concealmentEvent = value;
                }
                else if ($os === 'ios') {
                    this._instance.concealmentEvent = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "decSampleRate", {
            /** {en}
             * @brief Audio decoding sample rate. Audio decoding sample rate information in the reference period in Hz.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.decSampleRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.decSampleRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.decSampleRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.decSampleRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "decDuration", {
            /** {en}
             * @brief Cumulative decoding time in seconds of the remote audio stream in this subscription.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.decDuration);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.decDuration);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.decDuration = value;
                }
                else if ($os === 'ios') {
                    this._instance.decDuration = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioStats_1.prototype, "jitter", {
            /** {en}
             * @brief Audio downlink network jitter in ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.jitter);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.jitter);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.jitter = value;
                }
                else if ($os === 'ios') {
                    this._instance.jitter = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        RemoteAudioStats_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RemoteAudioStats_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRemoteAudioStats).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RemoteAudioStats$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RemoteAudioStats_1;
    }());
    __setFunctionName(_classThis, "RemoteAudioStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.VideoOrientation = void 0;
(function (VideoOrientation) {
    VideoOrientation[VideoOrientation["ADAPTIVE"] = 0] = "ADAPTIVE";
    VideoOrientation[VideoOrientation["PORTRAIT"] = 1] = "PORTRAIT";
    VideoOrientation[VideoOrientation["LANDSCAPE"] = 2] = "LANDSCAPE";
})(exports.VideoOrientation || (exports.VideoOrientation = {}));
var AudioRecordingConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function AudioRecordingConfig_1() {
        }
        Object.defineProperty(AudioRecordingConfig_1.prototype, "absoluteFileName", {
            /** {en}
             * @brief Absolute path of the recorded file, file name included. The App must have the write and read permission of the path. <br>
             * The files format is restricted to .aac and .wav.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.absoluteFileName);
                }
                else if ($os === 'ios') {
                    return String(this._instance.absoluteFileName);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.absoluteFileName = value;
                }
                else if ($os === 'ios') {
                    this._instance.absoluteFileName = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioRecordingConfig_1.prototype, "sampleRate", {
            /** {en}
             * @brief See {@link AudioSampleRate AudioSampleRate}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioSampleRate.android_to_ts(this._instance.sampleRate);
                }
                else if ($os === 'ios') {
                    return t_AudioSampleRate.ios_to_ts(this._instance.sampleRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.sampleRate = t_AudioSampleRate.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.sampleRate = t_AudioSampleRate.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioRecordingConfig_1.prototype, "channel", {
            /** {en}
             * @brief Number of audio channels. See {@link AudioChannel AudioChannel}. <br>
             *        If number of audio channels of recording is different than that of audio capture, the behavior is: <br>
             *        - If the number of capture is 1, and the number of recording is 2, the recorded audio is two-channel data after copying mono-channel data.
             *        - If the number of capture is 2, and the number of recording is 1, the recorded audio is recorded by mixing the audio of the two channels.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioChannel.android_to_ts(this._instance.channel);
                }
                else if ($os === 'ios') {
                    return t_AudioChannel.ios_to_ts(this._instance.channel);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.channel = t_AudioChannel.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.channel = t_AudioChannel.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioRecordingConfig_1.prototype, "frameSource", {
            /** {en}
             * @brief The source of the recording. See {@link AudioFrameSource AudioFrameSource}. <br>
             * It is AUDIO_FRAME_SOURCE_MIXED(2) by default.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioFrameSource.android_to_ts(this._instance.frameSource);
                }
                else if ($os === 'ios') {
                    return t_AudioFrameSource.ios_to_ts(this._instance.frameSource);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.frameSource = t_AudioFrameSource.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.frameSource = t_AudioFrameSource.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioRecordingConfig_1.prototype, "quality", {
            /** {en}
             * @brief Recording quality. Only valid for .aac file. See {@link AudioQuality AudioQuality}. <br>
             * When the sample rate is 32kHz, the file (10min) size for different qualities are: <br>
             *        - low: 1.2MB;
             *        - [By Default] medium: 2MB;
             *        - high: 3.75MB;
             *        - ultra high: 7.5MB.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioQuality.android_to_ts(this._instance.quality);
                }
                else if ($os === 'ios') {
                    return t_AudioQuality.ios_to_ts(this._instance.quality);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.quality = t_AudioQuality.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.quality = t_AudioQuality.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        AudioRecordingConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        AudioRecordingConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCAudioRecordingConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = AudioRecordingConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return AudioRecordingConfig_1;
    }());
    __setFunctionName(_classThis, "AudioRecordingConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.AudioRoute = void 0;
(function (AudioRoute) {
    AudioRoute[AudioRoute["AUDIO_ROUTE_DEFAULT"] = 0] = "AUDIO_ROUTE_DEFAULT";
    AudioRoute[AudioRoute["AUDIO_ROUTE_HEADSET"] = 1] = "AUDIO_ROUTE_HEADSET";
    AudioRoute[AudioRoute["AUDIO_ROUTE_EARPIECE"] = 2] = "AUDIO_ROUTE_EARPIECE";
    AudioRoute[AudioRoute["AUDIO_ROUTE_SPEAKERPHONE"] = 3] = "AUDIO_ROUTE_SPEAKERPHONE";
    AudioRoute[AudioRoute["AUDIO_ROUTE_HEADSET_BLUETOOTH"] = 4] = "AUDIO_ROUTE_HEADSET_BLUETOOTH";
    AudioRoute[AudioRoute["AUDIO_ROUTE_HEADSET_USB"] = 5] = "AUDIO_ROUTE_HEADSET_USB";
})(exports.AudioRoute || (exports.AudioRoute = {}));
var Position = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function Position_1() {
        }
        Object.defineProperty(Position_1.prototype, "x", {
            /** {en}
             * @brief X-coordinate
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.x);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.x);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.x = value;
                }
                else if ($os === 'ios') {
                    this._instance.x = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Position_1.prototype, "y", {
            /** {en}
             * @brief Y-coordinate
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.y);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.y);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.y = value;
                }
                else if ($os === 'ios') {
                    this._instance.y = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Position_1.prototype, "z", {
            /** {en}
             * @brief Z-coordinate
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.z);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.z);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.z = value;
                }
                else if ($os === 'ios') {
                    this._instance.z = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Position_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        Position_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCPosition).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = Position$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return Position_1;
    }());
    __setFunctionName(_classThis, "Position");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.AudioPlayType = void 0;
(function (AudioPlayType) {
    AudioPlayType[AudioPlayType["LOCAL"] = 0] = "LOCAL";
    AudioPlayType[AudioPlayType["REMOTE"] = 1] = "REMOTE";
    AudioPlayType[AudioPlayType["LOCAL_AND_REMOTE"] = 2] = "LOCAL_AND_REMOTE";
})(exports.AudioPlayType || (exports.AudioPlayType = {}));
exports.DownloadFileType = void 0;
(function (DownloadFileType) {
    DownloadFileType[DownloadFileType["MUSIC"] = 0] = "MUSIC";
    DownloadFileType[DownloadFileType["KRC"] = 1] = "KRC";
    DownloadFileType[DownloadFileType["LRC"] = 2] = "LRC";
    DownloadFileType[DownloadFileType["MIDI"] = 3] = "MIDI";
})(exports.DownloadFileType || (exports.DownloadFileType = {}));
exports.MediaPlayerCustomSourceSeekWhence = void 0;
(function (MediaPlayerCustomSourceSeekWhence) {
    MediaPlayerCustomSourceSeekWhence[MediaPlayerCustomSourceSeekWhence["SET"] = 0] = "SET";
    MediaPlayerCustomSourceSeekWhence[MediaPlayerCustomSourceSeekWhence["CUR"] = 1] = "CUR";
    MediaPlayerCustomSourceSeekWhence[MediaPlayerCustomSourceSeekWhence["END"] = 2] = "END";
    MediaPlayerCustomSourceSeekWhence[MediaPlayerCustomSourceSeekWhence["SIZE"] = 3] = "SIZE";
})(exports.MediaPlayerCustomSourceSeekWhence || (exports.MediaPlayerCustomSourceSeekWhence = {}));
var SingScoringConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function SingScoringConfig_1() {
        }
        Object.defineProperty(SingScoringConfig_1.prototype, "sampleRate", {
            /** {en}
             * @brief Sampling rate. Only 44,100 Hz and 48,000 Hz are supported.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioSampleRate.android_to_ts(this._instance.sampleRate);
                }
                else if ($os === 'ios') {
                    return t_AudioSampleRate.ios_to_ts(this._instance.sampleRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.sampleRate = t_AudioSampleRate.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.sampleRate = t_AudioSampleRate.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SingScoringConfig_1.prototype, "mode", {
            /** {en}
             * @brief Scoring mode, see {@link MulDimSingScoringMode MulDimSingScoringMode}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_MulDimSingScoringMode.android_to_ts(this._instance.mode);
                }
                else if ($os === 'ios') {
                    return t_MulDimSingScoringMode.ios_to_ts(this._instance.mode);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.mode = t_MulDimSingScoringMode.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.mode = t_MulDimSingScoringMode.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SingScoringConfig_1.prototype, "lyricsFilepath", {
            /** {en}
             * @brief The file path of the lyrics. The scoring feature only supports KRC lyrics file.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.lyricsFilepath);
                }
                else if ($os === 'ios') {
                    return String(this._instance.lyricsFilepath);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.lyricsFilepath = value;
                }
                else if ($os === 'ios') {
                    this._instance.lyricsFilepath = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SingScoringConfig_1.prototype, "midiFilepath", {
            /** {en}
             * @brief The path of the midi file.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.midiFilepath);
                }
                else if ($os === 'ios') {
                    return String(this._instance.midiFilepath);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.midiFilepath = value;
                }
                else if ($os === 'ios') {
                    this._instance.midiFilepath = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        SingScoringConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        SingScoringConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCSingScoringConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = SingScoringConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return SingScoringConfig_1;
    }());
    __setFunctionName(_classThis, "SingScoringConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.LyricStatus = void 0;
(function (LyricStatus) {
    LyricStatus[LyricStatus["NONE"] = 0] = "NONE";
    LyricStatus[LyricStatus["KRC"] = 1] = "KRC";
    LyricStatus[LyricStatus["LRC"] = 2] = "LRC";
    LyricStatus[LyricStatus["KRC_AND_LRC"] = 3] = "KRC_AND_LRC";
})(exports.LyricStatus || (exports.LyricStatus = {}));
exports.AudioQuality = void 0;
(function (AudioQuality) {
    AudioQuality[AudioQuality["AUDIO_QUALITY_LOW"] = 0] = "AUDIO_QUALITY_LOW";
    AudioQuality[AudioQuality["AUDIO_QUALITY_MEDIUM"] = 1] = "AUDIO_QUALITY_MEDIUM";
    AudioQuality[AudioQuality["AUDIO_QUALITY_HIGH"] = 2] = "AUDIO_QUALITY_HIGH";
    AudioQuality[AudioQuality["AUDIO_QUALITY_ULTRA_HIGH"] = 3] = "AUDIO_QUALITY_ULTRA_HIGH";
})(exports.AudioQuality || (exports.AudioQuality = {}));
exports.MixedStreamLayoutRegionType = void 0;
(function (MixedStreamLayoutRegionType) {
    MixedStreamLayoutRegionType[MixedStreamLayoutRegionType["MIXED_STREAM_LAYOUT_REGION_TYPE_VIDEO_STREAM"] = 0] = "MIXED_STREAM_LAYOUT_REGION_TYPE_VIDEO_STREAM";
    MixedStreamLayoutRegionType[MixedStreamLayoutRegionType["MIXED_STREAM_LAYOUT_REGION_TYPE_IMAGE"] = 1] = "MIXED_STREAM_LAYOUT_REGION_TYPE_IMAGE";
    MixedStreamLayoutRegionType[MixedStreamLayoutRegionType["ByteRTCMixedStreamLayoutRegionTypeImage"] = 2] = "ByteRTCMixedStreamLayoutRegionTypeImage";
})(exports.MixedStreamLayoutRegionType || (exports.MixedStreamLayoutRegionType = {}));
exports.AudioFrameCallbackMethod = void 0;
(function (AudioFrameCallbackMethod) {
    AudioFrameCallbackMethod[AudioFrameCallbackMethod["AUDIO_FRAME_CALLBACK_RECORD"] = 0] = "AUDIO_FRAME_CALLBACK_RECORD";
    AudioFrameCallbackMethod[AudioFrameCallbackMethod["AUDIO_FRAME_CALLBACK_PLAYBACK"] = 1] = "AUDIO_FRAME_CALLBACK_PLAYBACK";
    AudioFrameCallbackMethod[AudioFrameCallbackMethod["AUDIO_FRAME_CALLBACK_MIXED"] = 2] = "AUDIO_FRAME_CALLBACK_MIXED";
    AudioFrameCallbackMethod[AudioFrameCallbackMethod["AUDIO_FRAME_CALLBACK_REMOTE_USER"] = 3] = "AUDIO_FRAME_CALLBACK_REMOTE_USER";
})(exports.AudioFrameCallbackMethod || (exports.AudioFrameCallbackMethod = {}));
exports.LogoutReason = void 0;
(function (LogoutReason) {
    /** {en}
     * @platform android
     * @brief Users choose to logout by calling the `logout` to log out or terminating the engine to log out.
     *
     */
    LogoutReason[LogoutReason["LOGOUT_REASON_LOGOUT"] = 0] = "LOGOUT_REASON_LOGOUT";
    /** {en}
     * @platform android
     * @brief The current user is kicked out as another user logs in with the same UserId.
     *
     */
    LogoutReason[LogoutReason["LOGOUT_REASON_DUPLICATE_LOGIN"] = 1] = "LOGOUT_REASON_DUPLICATE_LOGIN";
    LogoutReason[LogoutReason["ByteRTCLogoutReasonLogout"] = 2] = "ByteRTCLogoutReasonLogout";
    LogoutReason[LogoutReason["ByteRTCLogoutReasonDuplicateLogin"] = 3] = "ByteRTCLogoutReasonDuplicateLogin";
})(exports.LogoutReason || (exports.LogoutReason = {}));
exports.VideoRenderMirrorType = void 0;
(function (VideoRenderMirrorType) {
    VideoRenderMirrorType[VideoRenderMirrorType["ON"] = 0] = "ON";
    VideoRenderMirrorType[VideoRenderMirrorType["OFF"] = 1] = "OFF";
})(exports.VideoRenderMirrorType || (exports.VideoRenderMirrorType = {}));
var LiveTranscoding = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var LiveTranscoding = _classThis = /** @class */ (function () {
        function LiveTranscoding_1() {
        }
        /** {en}
         * @platform android
         *  @type api
         *  @brief Gets the default configurations for live transcoding.
         *  @return The default configurations for live transcoding. See {@link LiveTranscoding LiveTranscoding}.
         *
         */
        LiveTranscoding_1.android_getDefualtLiveTranscode = function () {
            var $ = function () { return LiveTranscoding$1.getDefualtLiveTranscode(); };
            return $();
        };
        /** {en}
         * @platform ios
         * @brief Gets the default configurations for pushing streams to CDN.
         * @return Configurations for pushing streams to CDN. See {@link ByteRTCLiveTranscoding ByteRTCLiveTranscoding}.
         */
        LiveTranscoding_1.ios_defaultTranscoding = function () {
            var $ = function () { return packObject(ByteRTCLiveTranscoding.defaultTranscoding(), LiveTranscoding); };
            return $();
        };
        Object.defineProperty(LiveTranscoding_1.prototype, "ios_expectedMixingType", {
            /** {en}
             * @platform ios
             * @brief Stream mixing type. See {@link ByteRTCStreamMixingType ByteRTCStreamMixingType}. <br>
             * This parameter cannot be updated while pushing stream to the CDN.
             */
            get: function () {
                return this._instance.expectedMixingType;
            },
            set: function (value) {
                this._instance.expectedMixingType = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LiveTranscoding_1.prototype, "ios_layout", {
            /** {en}
             * @platform ios
             * @brief The overall video layout of the mixed stream. <br>
             *        After starting to push streams to CDN, you can set the layout of each video stream, the background information of the mixed stream, etc. See {@link ByteRTCVideoCompositingLayout ByteRTCVideoCompositingLayout} for details.
             */
            get: function () {
                return this._instance.layout;
            },
            set: function (value) {
                this._instance.layout = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LiveTranscoding_1.prototype, "ios_video", {
            /** {en}
             * @platform ios
             * @brief Video transcoding related configurations. See {@link ByteRTCTranscodingVideoConfig ByteRTCTranscodingVideoConfig}.
             */
            get: function () {
                return this._instance.video;
            },
            set: function (value) {
                this._instance.video = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LiveTranscoding_1.prototype, "ios_audio", {
            /** {en}
             * @platform ios
             * @brief Audio transcoding related configurations. See {@link ByteRTCTranscodingAudioConfig ByteRTCTranscodingAudioConfig} for data types.
             */
            get: function () {
                return this._instance.audio;
            },
            set: function (value) {
                this._instance.audio = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LiveTranscoding_1.prototype, "ios_clientMixParam", {
            /** {en}
             * @platform ios
             * @brief client mix param. See {@link ByteRTCTranscodingClientMixParam ByteRTCTranscodingClientMixParam} for detail.
             */
            get: function () {
                return this._instance.clientMixParam;
            },
            set: function (value) {
                this._instance.clientMixParam = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LiveTranscoding_1.prototype, "ios_spatialConfig", {
            /** {en}
             * @platform ios
             * @hidden(macOS)
             * @brief The spatial audio config when pushing to CDN. See {@link ByteRTCTranscodingSpatialConfig ByteRTCTranscodingSpatialConfig} for detail.
             */
            get: function () {
                return this._instance.spatialConfig;
            },
            set: function (value) {
                this._instance.spatialConfig = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LiveTranscoding_1.prototype, "ios_url", {
            /** {en}
             * @platform ios
             * @brief The URL for live transcoding. Only supports live transcoding via RTMP. The URL should match the regular expression `/^rtmps?:\\/\\//`. <br>
             *        This parameter cannot be updated while pushing stream to the CDN.
             */
            get: function () {
                return this._instance.url;
            },
            set: function (value) {
                this._instance.url = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LiveTranscoding_1.prototype, "ios_roomId", {
            /** {en}
             * @platform ios
             * @brief The room ID for live transcoding. The sum length of `roomId` and `userId` should not exceed 126 bytes. <br>
             *        This parameter cannot be updated while pushing stream to the CDN.
             */
            get: function () {
                return this._instance.roomId;
            },
            set: function (value) {
                this._instance.roomId = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LiveTranscoding_1.prototype, "ios_userId", {
            /** {en}
             * @platform ios
             * @brief The user ID for live transcoding. The sum length of `roomId` and `userId` should not exceed 126 bytes. <br>
             *        This parameter cannot be updated while pushing stream to the CDN.
             */
            get: function () {
                return this._instance.userId;
            },
            set: function (value) {
                this._instance.userId = value;
            },
            enumerable: false,
            configurable: true
        });
        LiveTranscoding_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        LiveTranscoding_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCLiveTranscoding).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = LiveTranscoding$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /**
         * @platform android
         */
        /**
         * @platform android
         */
        LiveTranscoding_1.prototype.android_getFieldVideoConfigBFrame = function () {
            var _this = this;
            var $ = function () { return _this._instance.getFieldVideoConfigBFrame(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the URL for live transcoding. Only supports live transcoding via RTMP. The URL should match the regular expression `/^rtmps?:\\/\\//`. <br>
         *        This parameter cannot be updated while pushing stream to the CDN.
         * @param url the URL for live transcoding.
         *
         */
        LiveTranscoding_1.prototype.android_setUrl = function (url) {
            var _this = this;
            var $ = function () { return (_this._instance.setUrl(url), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the room ID for live transcoding. The sum length of `roomId` and `userId` should not exceed 126 bytes. <br>
         *        This parameter cannot be updated while pushing stream to the CDN.
         * @param roomId room ID。
         *
         */
        LiveTranscoding_1.prototype.android_setRoomId = function (roomId) {
            var _this = this;
            var $ = function () { return (_this._instance.setRoomId(roomId), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the user ID for live transcoding. The sum length of `roomId` and `userId` should not exceed 126 bytes. <br>
         *        This parameter cannot be updated while pushing stream to the CDN.
         * @param userId User ID。
         *
         */
        LiveTranscoding_1.prototype.android_setUserId = function (userId) {
            var _this = this;
            var $ = function () { return (_this._instance.setUserId(userId), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the video transcoding configurations.
         * @param video The configurations to be set. See {@link VideoConfig VideoConfig}.
         *
         */
        LiveTranscoding_1.prototype.android_setVideo = function (video) {
            var _this = this;
            var $ = function () { return (_this._instance.setVideo(video), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets audio transcoding configurations.
         * @param audio The audio configurations to be set. See {@link AudioConfig AudioConfig}.
         *
         */
        LiveTranscoding_1.prototype.android_setAudio = function (audio) {
            var _this = this;
            var $ = function () { return (_this._instance.setAudio(audio), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the spatial audio configuration when pushing streams to CDN.
         * @param spatialConfig The configurations to be set. See {@link SpatialConfig SpatialConfig}.
         *
         */
        LiveTranscoding_1.prototype.android_setSpatialConfig = function (spatialConfig) {
            var _this = this;
            var $ = function () { return (_this._instance.setSpatialConfig(spatialConfig), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets client mix configurations.
         * @param param The configurations to be set. See {@link ClientMixParam ClientMixParam}.
         *
         */
        LiveTranscoding_1.prototype.android_setClientMixParam = function (param) {
            var _this = this;
            var $ = function () { return (_this._instance.setClientMixParam(param), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the overall video layout of the mixed stream.
         * @param layout The layout to be set. See {@link Layout Layout}.
         *
         */
        LiveTranscoding_1.prototype.android_setLayout = function (layout) {
            var _this = this;
            var $ = function () { return (_this._instance.setLayout(layout), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @region  Push to CDN
         * @brief  Gets the stream mixing type.
         * @return  Stream mixing type. See {@link ByteRTCStreamMixingType ByteRTCStreamMixingType}.
         *
         */
        LiveTranscoding_1.prototype.android_getMixType = function () {
            var _this = this;
            var $ = function () { return _this._instance.getMixType(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @region Push to CDN
         * @brief Sets the stream mixing type.
         * @param mixType Stream mixing type. See {@link ByteRTCStreamMixingType ByteRTCStreamMixingType}.
         * @note This parameter cannot be updated while pushing stream to the CDN.
         *
         */
        LiveTranscoding_1.prototype.android_setMixType = function (mixType) {
            var _this = this;
            var $ = function () { return (_this._instance.setMixType(mixType), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the CDN url where the mixed stream is pushed
         * @return The CDN url
         *
         */
        LiveTranscoding_1.prototype.android_getUrl = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getUrl()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the video transcoding configurations.
         * @return Current video transcoding configurations. See {@link VideoConfig VideoConfig}.
         *
         */
        LiveTranscoding_1.prototype.android_getVideo = function () {
            var _this = this;
            var $ = function () { return _this._instance.getVideo(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the audio transcoding configurations.
         * @return Current audio transcoding configurations. See {@link AudioConfig AudioConfig}.
         *
         */
        LiveTranscoding_1.prototype.android_getAudio = function () {
            var _this = this;
            var $ = function () { return _this._instance.getAudio(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the spatial audio  configurations.
         * @return Current spatial audio configurations. See {@link SpatialConfig SpatialConfig}.
         *
         */
        LiveTranscoding_1.prototype.android_getSpatialConfig = function () {
            var _this = this;
            var $ = function () { return _this._instance.getSpatialConfig(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the client mix configurations.
         * @return Current client mix configurations. See {@link ClientMixParam ClientMixParam}.
         *
         */
        LiveTranscoding_1.prototype.android_getClientMixParam = function () {
            var _this = this;
            var $ = function () { return _this._instance.getClientMixParam(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the overall video layout of the mixed stream.
         * @return Current video layout. See {@link Layout Layout}.
         *
         */
        LiveTranscoding_1.prototype.android_getLayout = function () {
            var _this = this;
            var $ = function () { return _this._instance.getLayout(); };
            return $();
        };
        return LiveTranscoding_1;
    }());
    __setFunctionName(_classThis, "LiveTranscoding");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        LiveTranscoding = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return LiveTranscoding = _classThis;
}();
exports.VideoDenoiseMode = void 0;
(function (VideoDenoiseMode) {
    VideoDenoiseMode[VideoDenoiseMode["VIDEO_DENOISE_MODE_OFF"] = 0] = "VIDEO_DENOISE_MODE_OFF";
    VideoDenoiseMode[VideoDenoiseMode["VIDEO_DENOISE_MODE_AUTO"] = 1] = "VIDEO_DENOISE_MODE_AUTO";
})(exports.VideoDenoiseMode || (exports.VideoDenoiseMode = {}));
exports.MixedStreamSEIContentMode = void 0;
(function (MixedStreamSEIContentMode) {
    MixedStreamSEIContentMode[MixedStreamSEIContentMode["MIXED_STREAM_SEI_CONTENT_MODE_DEFAULT"] = 0] = "MIXED_STREAM_SEI_CONTENT_MODE_DEFAULT";
    MixedStreamSEIContentMode[MixedStreamSEIContentMode["MIXED_STREAM_SEI_CONTENT_MODE_ENABLE_VOLUME_INDICATION"] = 1] = "MIXED_STREAM_SEI_CONTENT_MODE_ENABLE_VOLUME_INDICATION";
})(exports.MixedStreamSEIContentMode || (exports.MixedStreamSEIContentMode = {}));
exports.AudioMixingError = void 0;
(function (AudioMixingError) {
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_OK"] = 0] = "AUDIO_MIXING_ERROR_OK";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_PRELOAD_FAILED"] = 1] = "AUDIO_MIXING_ERROR_PRELOAD_FAILED";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_START_FAILED"] = 2] = "AUDIO_MIXING_ERROR_START_FAILED";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_SET_POSITION_FAILED"] = 3] = "AUDIO_MIXING_ERROR_SET_POSITION_FAILED";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_LOAD_CONFLICT"] = 4] = "AUDIO_MIXING_ERROR_LOAD_CONFLICT";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_ID_NOT_FOUND"] = 5] = "AUDIO_MIXING_ERROR_ID_NOT_FOUND";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_INVALID_VOLUME"] = 6] = "AUDIO_MIXING_ERROR_INVALID_VOLUME";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_ID_TYPE_NOT_MATCH"] = 7] = "AUDIO_MIXING_ERROR_ID_TYPE_NOT_MATCH";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_ID_TYPE_INVALID_PITCH"] = 8] = "AUDIO_MIXING_ERROR_ID_TYPE_INVALID_PITCH";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_INVALID_AUDIO_TRACK"] = 9] = "AUDIO_MIXING_ERROR_INVALID_AUDIO_TRACK";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_IS_STARTING"] = 10] = "AUDIO_MIXING_ERROR_IS_STARTING";
    AudioMixingError[AudioMixingError["AUDIO_MIXING_ERROR_INVALID_PLAYBACK_SPEED"] = 11] = "AUDIO_MIXING_ERROR_INVALID_PLAYBACK_SPEED";
    AudioMixingError[AudioMixingError["ByteRTCAudioMixingErrorIdNotFound"] = 12] = "ByteRTCAudioMixingErrorIdNotFound";
    AudioMixingError[AudioMixingError["ByteRTCAudioMixingErrorInValidVolume"] = 13] = "ByteRTCAudioMixingErrorInValidVolume";
    AudioMixingError[AudioMixingError["ByteRTCAudioMixingErrorIdTypeNotMatch"] = 14] = "ByteRTCAudioMixingErrorIdTypeNotMatch";
    AudioMixingError[AudioMixingError["ByteRTCAudioMixingErrorInValidPitch"] = 15] = "ByteRTCAudioMixingErrorInValidPitch";
    AudioMixingError[AudioMixingError["ByteRTCAudioMixingErrorInValidAudioTrack"] = 16] = "ByteRTCAudioMixingErrorInValidAudioTrack";
    AudioMixingError[AudioMixingError["ByteRTCAudioMixingErrorIsStarting"] = 17] = "ByteRTCAudioMixingErrorIsStarting";
    AudioMixingError[AudioMixingError["ByteRTCAudioMixingErrorInValidPlaybackSpeed"] = 18] = "ByteRTCAudioMixingErrorInValidPlaybackSpeed";
})(exports.AudioMixingError || (exports.AudioMixingError = {}));
exports.AACProfile = void 0;
(function (AACProfile) {
    AACProfile[AACProfile["AAC_PROFILE_LC"] = 0] = "AAC_PROFILE_LC";
    AACProfile[AACProfile["AAC_PROFILE_HEV1"] = 1] = "AAC_PROFILE_HEV1";
    AACProfile[AACProfile["AAC_PROFILE_HEV2"] = 2] = "AAC_PROFILE_HEV2";
})(exports.AACProfile || (exports.AACProfile = {}));
exports.AudioSelectionPriority = void 0;
(function (AudioSelectionPriority) {
    AudioSelectionPriority[AudioSelectionPriority["AUDIO_SELECTION_PRIORITY_NORMAL"] = 0] = "AUDIO_SELECTION_PRIORITY_NORMAL";
    AudioSelectionPriority[AudioSelectionPriority["AUDIO_SELECTION_PRIORITY_HIGH"] = 1] = "AUDIO_SELECTION_PRIORITY_HIGH";
})(exports.AudioSelectionPriority || (exports.AudioSelectionPriority = {}));
exports.DataMessageSourceType = void 0;
(function (DataMessageSourceType) {
    DataMessageSourceType[DataMessageSourceType["DATA_MESSAGE_SOURCE_TYPE_DEFAULT"] = 0] = "DATA_MESSAGE_SOURCE_TYPE_DEFAULT";
    DataMessageSourceType[DataMessageSourceType["DATA_MESSAGE_SOURCE_TYPE_SYSTEM"] = 1] = "DATA_MESSAGE_SOURCE_TYPE_SYSTEM";
})(exports.DataMessageSourceType || (exports.DataMessageSourceType = {}));
var FaceDetectionResult = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function FaceDetectionResult_1() {
        }
        Object.defineProperty(FaceDetectionResult_1.prototype, "detectResult", {
            /** {en}
             * @brief Face Detection Result <br>
             *        - 0: Success
             *        - !0: Failure, see [Error Code Table](https://docs.byteplus.com/en/effects/docs/error-code-table)
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.detectResult);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.detectResult);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.detectResult = value;
                }
                else if ($os === 'ios') {
                    this._instance.detectResult = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(FaceDetectionResult_1.prototype, "imageWidth", {
            /** {en}
             * @brief Width of the original image (px)
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.imageWidth);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.imageWidth);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.imageWidth = value;
                }
                else if ($os === 'ios') {
                    this._instance.imageWidth = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(FaceDetectionResult_1.prototype, "imageHeight", {
            /** {en}
             * @brief Height of the original image (px)
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.imageHeight);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.imageHeight);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.imageHeight = value;
                }
                else if ($os === 'ios') {
                    this._instance.imageHeight = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(FaceDetectionResult_1.prototype, "faces", {
            /** {en}
             * @brief The face recognition rectangles. The length of the array is the same as the number of detected faces. See {@link Rectangle Rectangle}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.faces.map(function ($item) { return packObject($item, Rectangle); });
                }
                else if ($os === 'ios') {
                    return this._instance.faces.map(function ($item) { return packObject($item, Rectangle); });
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.faces = value.map(function ($item) { return unpackObject($item); });
                }
                else if ($os === 'ios') {
                    this._instance.faces = value.map(function ($item) {
                        return unpackObject($item);
                    });
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(FaceDetectionResult_1.prototype, "android_frameTimestampUs", {
            /** {en}
             * @platform android
             * @brief The time stamp of the video frame using face detection.
             *
             */
            get: function () {
                return this._instance.frameTimestampUs;
            },
            set: function (value) {
                this._instance.frameTimestampUs = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(FaceDetectionResult_1.prototype, "ios_frameTimestamp", {
            /** {en}
             * @platform ios
             * @brief The time stamp of the video frame using face detection.
             */
            get: function () {
                return this._instance.frameTimestamp;
            },
            set: function (value) {
                this._instance.frameTimestamp = value;
            },
            enumerable: false,
            configurable: true
        });
        FaceDetectionResult_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        FaceDetectionResult_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCFaceDetectionResult).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = FaceDetectionResult$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return FaceDetectionResult_1;
    }());
    __setFunctionName(_classThis, "FaceDetectionResult");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoFrame = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function VideoFrame_1() {
        }
        Object.defineProperty(VideoFrame_1.prototype, "ios_format", {
            /** {en}
             * @platform ios
             * @brief Video frame format, see {@link ByteRTCVideoPixelFormat ByteRTCVideoPixelFormat}
             */
            get: function () {
                return this._instance.format;
            },
            set: function (value) {
                this._instance.format = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_contentType", {
            /** {en}
             * @platform ios
             * @brief Gets video content type, see {@link ByteRTCVideoContentType ByteRTCVideoContentType}.
             */
            get: function () {
                return this._instance.contentType;
            },
            set: function (value) {
                this._instance.contentType = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_time", {
            /** {en}
             * @platform ios
             * @brief The timestamp information of the current frame
             */
            get: function () {
                return this._instance.time;
            },
            set: function (value) {
                this._instance.time = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_strideInPixels", {
            /** {en}
             * @platform ios
             * @brief Number of bytes per pixel line
             */
            get: function () {
                return this._instance.strideInPixels;
            },
            set: function (value) {
                this._instance.strideInPixels = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_width", {
            /** {en}
             * @platform ios
             * @brief Video frame width
             */
            get: function () {
                return this._instance.width;
            },
            set: function (value) {
                this._instance.width = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_height", {
            /** {en}
             * @platform ios
             * @brief Video frame height
             */
            get: function () {
                return this._instance.height;
            },
            set: function (value) {
                this._instance.height = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_textureBuf", {
            /** {en}
             * @platform ios
             * @brief Data of CVPixelBufferRef type, valid when format is kPixelFormatCVPixelBuffer
             */
            get: function () {
                return this._instance.textureBuf;
            },
            set: function (value) {
                this._instance.textureBuf = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_dataBuf", {
            /** {en}
             * @platform ios
             * @brief The first address in video frame memory
             */
            get: function () {
                return this._instance.dataBuf;
            },
            set: function (value) {
                this._instance.dataBuf = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_rotation", {
            /** {en}
             * @platform ios
             * @brief Video frame rotation angle, the value must be 0,  90, 180, or 270
             */
            get: function () {
                return this._instance.rotation;
            },
            set: function (value) {
                this._instance.rotation = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_colorSpace", {
            /** {en}
             * @platform ios
             * @brief Video frame colorspace
             */
            get: function () {
                return this._instance.colorSpace;
            },
            set: function (value) {
                this._instance.colorSpace = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_cameraId", {
            /** {en}
             * @platform ios
             * @brief the cameraId of the video frame, see {@link ByteRTCCameraID ByteRTCCameraID}
             */
            get: function () {
                return this._instance.cameraId;
            },
            set: function (value) {
                this._instance.cameraId = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_extendedData", {
            /** {en}
             * @platform ios
             * @brief Data attached to the video frame
             */
            get: function () {
                return this._instance.extendedData;
            },
            set: function (value) {
                this._instance.extendedData = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_supplementaryInfo", {
            /** {en}
             * @platform ios
             * @brief Video frame roi data
             */
            get: function () {
                return this._instance.supplementaryInfo;
            },
            set: function (value) {
                this._instance.supplementaryInfo = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_numberOfPlanes", {
            /** {en}
             * @platform ios
             * @brief Video frame color plane number. <br>
             *        YUV formats are categorized into planar format and packed format. <br>
             *        In a planar format, the Y, U, and V components are stored separately as three planes, while in a packed format, the Y, U, and V components are stored in a single array. <br>
             *        When textureBuf has a value, the value is meaningless
             */
            get: function () {
                return this._instance.numberOfPlanes;
            },
            set: function (value) {
                this._instance.numberOfPlanes = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_planeDatas", {
            /** {en}
             * @platform ios
             * @brief Gets plane data pointer, the length of array equals numberOfPlanes, and the type of element is NSData*
             * @param plane_index Plane data index; When textureBuf has a value, the value is meaningless
             */
            get: function () {
                return this._instance.planeDatas;
            },
            set: function (value) {
                this._instance.planeDatas = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_planeStrides", {
            /** {en}
             * @platform ios
             * @brief Gets the length of the data line in the plane
             * @param plane_index Plane data index, the length of array equals numberOfPlanes, and the type of element is NSNumber*; When textureBuf has a value, the value is meaningless
             */
            get: function () {
                return this._instance.planeStrides;
            },
            set: function (value) {
                this._instance.planeStrides = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrame_1.prototype, "ios_stride", {
            /** {en}
             * @platform ios
             * @deprecated since 3.45 and will be deleted in 3.51, use strideInPixels instead.
             */
            get: function () {
                return this._instance.stride;
            },
            set: function (value) {
                this._instance.stride = value;
            },
            enumerable: false,
            configurable: true
        });
        VideoFrame_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        VideoFrame_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCVideoFrame).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = VideoFrame$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the callback of the video frame release. The callback will be triggered when the reference count of the video frame turns to 0.
         * @param releaseCallback Callback of the video frame release
         *
         */
        VideoFrame_1.prototype.android_setReleaseCallback = function (releaseCallback) {
            var _this = this;
            var $ = function () { return (_this._instance.setReleaseCallback(releaseCallback), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Checks if the current video frame has a releaseCallback set
         * @return
         *        - true：Yes
         *        - false：No
         *
         */
        VideoFrame_1.prototype.android_hasReleaseCallback = function () {
            var _this = this;
            var $ = function () { return _this._instance.hasReleaseCallback(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets video frame type, see {@link VideoFrameType VideoFrameType}
         *
         */
        VideoFrame_1.prototype.android_getFrameType = function () {
            var _this = this;
            var $ = function () { return _this._instance.getFrameType(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets video frame format, see {@link VideoPixelFormat VideoPixelFormat}
         *
         */
        VideoFrame_1.prototype.android_getPixelFormat = function () {
            var _this = this;
            var $ = function () { return _this._instance.getPixelFormat(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets video content type.
         * @return See {@link VideoContentType VideoContentType}.
         *
         */
        VideoFrame_1.prototype.android_getContentType = function () {
            var _this = this;
            var $ = function () { return _this._instance.getContentType(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets video frame timestamp in microseconds
         *
         */
        VideoFrame_1.prototype.android_getTimeStampUs = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getTimeStampUs()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets video frame width in px
         *
         */
        VideoFrame_1.prototype.android_getWidth = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getWidth()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets video frame height in px
         *
         */
        VideoFrame_1.prototype.android_getHeight = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getHeight()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets video frame rotation angle
         *
         */
        VideoFrame_1.prototype.android_getRotation = function () {
            var _this = this;
            var $ = function () { return _this._instance.getRotation(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the color space of video frame, see {@link ColorSpace ColorSpace}
         *
         */
        VideoFrame_1.prototype.android_getColorSpace = function () {
            var _this = this;
            var $ = function () { return _this._instance.getColorSpace(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Get cameraId of the frame, see {@link CameraId CameraId}
         *
         */
        VideoFrame_1.prototype.android_getCameraId = function () {
            var _this = this;
            var $ = function () { return _this._instance.getCameraId(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets Video frame color plane number
         * @note YUV formats are categorized into planar format and packed format. <br>
         *        In a planar format, the Y, U, and V components are stored separately as three planes, while in a packed format, the Y, U, and V components are stored in a single array.
         *
         */
        VideoFrame_1.prototype.android_getNumberOfPlanes = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getNumberOfPlanes()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets plane data pointer
         * @param planeIndex Plane data index
         *
         */
        VideoFrame_1.prototype.android_getPlaneData = function (planeIndex) {
            var _this = this;
            var $ = function () { return _this._instance.getPlaneData(planeIndex); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the length of the data line in the specified plane
         * @param planeIndex Plane data index
         *
         */
        VideoFrame_1.prototype.android_getPlaneStride = function (planeIndex) {
            var _this = this;
            var $ = function () { return Number(_this._instance.getPlaneStride(planeIndex)); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets SEI data
         *
         */
        VideoFrame_1.prototype.android_getExternalDataInfo = function () {
            var _this = this;
            var $ = function () { return _this._instance.getExternalDataInfo(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets supplementary data
         *
         */
        VideoFrame_1.prototype.android_getSupplementaryInfo = function () {
            var _this = this;
            var $ = function () { return _this._instance.getSupplementaryInfo(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets texture ID
         *
         */
        VideoFrame_1.prototype.android_getTextureID = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getTextureID()); };
            return $();
        };
        VideoFrame_1.prototype.android_getGLSync = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getGLSync()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets texture matrix
         *
         */
        VideoFrame_1.prototype.android_getTextureMatrix = function () {
            var _this = this;
            var $ = function () { return _this._instance.getTextureMatrix(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the EGLContext used by the texture
         *
         */
        VideoFrame_1.prototype.android_getEGLContext = function () {
            var _this = this;
            var $ = function () { return _this._instance.getEGLContext(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Count once for the number of the current video frame reference
         *
         */
        VideoFrame_1.prototype.android_retain = function () {
            var _this = this;
            var $ = function () { return (_this._instance.retain(), void 0); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Decrease one count for the number of the current video frame reference
         *
         */
        VideoFrame_1.prototype.android_release = function () {
            var _this = this;
            var $ = function () { return (_this._instance.release(), void 0); };
            return $();
        };
        return VideoFrame_1;
    }());
    __setFunctionName(_classThis, "VideoFrame");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RemoteStreamKey = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RemoteStreamKey_1() {
        }
        Object.defineProperty(RemoteStreamKey_1.prototype, "roomId", {
            /** {en}
             * @brief The ID of the room from which the stream was published.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.roomId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.roomId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.roomId = value;
                }
                else if ($os === 'ios') {
                    this._instance.roomId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamKey_1.prototype, "userId", {
            /** {en}
             * @brief The ID of the user who published the stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.userId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.userId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.userId = value;
                }
                else if ($os === 'ios') {
                    this._instance.userId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamKey_1.prototype, "streamIndex", {
            /** {en}
             * @brief Stream type, see [StreamIndex](70083#StreamIndex-2).
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_StreamIndex.android_to_ts(this._instance.streamIndex);
                }
                else if ($os === 'ios') {
                    return t_StreamIndex.ios_to_ts(this._instance.streamIndex);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.streamIndex = t_StreamIndex.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.streamIndex = t_StreamIndex.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        RemoteStreamKey_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RemoteStreamKey_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRemoteStreamKey).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RemoteStreamKey$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @brief Gets the room ID
         *
         */
        RemoteStreamKey_1.prototype.android_getRoomId = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getRoomId()); };
            return $();
        };
        /** {en}
         * @platform android
         * @brief Gets the user ID
         *
         */
        RemoteStreamKey_1.prototype.android_getUserId = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getUserId()); };
            return $();
        };
        /** {en}
         * @platform android
         * @brief Gets stream type, see [StreamIndex](#StreamIndex-2)
         *
         */
        RemoteStreamKey_1.prototype.android_getStreamIndex = function () {
            var _this = this;
            var $ = function () { return _this._instance.getStreamIndex(); };
            return $();
        };
        /** {en}
         * @platform android
         * @brief Check the class has null property
         *
         */
        RemoteStreamKey_1.prototype.android_hasNullProperty = function () {
            var _this = this;
            var $ = function () { return _this._instance.hasNullProperty(); };
            return $();
        };
        return RemoteStreamKey_1;
    }());
    __setFunctionName(_classThis, "RemoteStreamKey");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.VoiceReverbType = void 0;
(function (VoiceReverbType) {
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_ORIGINAL"] = 0] = "VOICE_REVERB_ORIGINAL";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_ECHO"] = 1] = "VOICE_REVERB_ECHO";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_CONCERT"] = 2] = "VOICE_REVERB_CONCERT";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_ETHEREAL"] = 3] = "VOICE_REVERB_ETHEREAL";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_KTV"] = 4] = "VOICE_REVERB_KTV";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_STUDIO"] = 5] = "VOICE_REVERB_STUDIO";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_VIRTUAL_STEREO"] = 6] = "VOICE_REVERB_VIRTUAL_STEREO";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_SPACIOUS"] = 7] = "VOICE_REVERB_SPACIOUS";
    VoiceReverbType[VoiceReverbType["VOICE_REVERB_3D"] = 8] = "VOICE_REVERB_3D";
})(exports.VoiceReverbType || (exports.VoiceReverbType = {}));
exports.MediaPlayerCustomSourceMode = void 0;
(function (MediaPlayerCustomSourceMode) {
    MediaPlayerCustomSourceMode[MediaPlayerCustomSourceMode["PUSH"] = 0] = "PUSH";
    MediaPlayerCustomSourceMode[MediaPlayerCustomSourceMode["PULL"] = 1] = "PULL";
})(exports.MediaPlayerCustomSourceMode || (exports.MediaPlayerCustomSourceMode = {}));
exports.KTVPlayerErrorCode = void 0;
(function (KTVPlayerErrorCode) {
    KTVPlayerErrorCode[KTVPlayerErrorCode["OK"] = 0] = "OK";
    KTVPlayerErrorCode[KTVPlayerErrorCode["FILE_NOT_EXIST"] = 1] = "FILE_NOT_EXIST";
    KTVPlayerErrorCode[KTVPlayerErrorCode["FILE_ERROR"] = 2] = "FILE_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["NOT_JOIN_ROOM"] = 3] = "NOT_JOIN_ROOM";
    KTVPlayerErrorCode[KTVPlayerErrorCode["PARAM"] = 4] = "PARAM";
    KTVPlayerErrorCode[KTVPlayerErrorCode["START_ERROR"] = 5] = "START_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["MIX_ID_ERROR"] = 6] = "MIX_ID_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["POSITION_ERROR"] = 7] = "POSITION_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["AUDIO_VOLUME_ERROR"] = 8] = "AUDIO_VOLUME_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["TYPE_ERROR"] = 9] = "TYPE_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["PITCH_ERROR"] = 10] = "PITCH_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["AUDIO_TRACK_ERROR"] = 11] = "AUDIO_TRACK_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["STARTING_ERROR"] = 12] = "STARTING_ERROR";
    KTVPlayerErrorCode[KTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeOK"] = 13] = "ByteRTCKTVPlayerErrorCodeOK";
    KTVPlayerErrorCode[KTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeFileNotExist"] = 14] = "ByteRTCKTVPlayerErrorCodeFileNotExist";
    KTVPlayerErrorCode[KTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeFileError"] = 15] = "ByteRTCKTVPlayerErrorCodeFileError";
    KTVPlayerErrorCode[KTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeNotJoinRoom"] = 16] = "ByteRTCKTVPlayerErrorCodeNotJoinRoom";
    KTVPlayerErrorCode[KTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeParam"] = 17] = "ByteRTCKTVPlayerErrorCodeParam";
    KTVPlayerErrorCode[KTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeStartError"] = 18] = "ByteRTCKTVPlayerErrorCodeStartError";
    KTVPlayerErrorCode[KTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeMixIdError"] = 19] = "ByteRTCKTVPlayerErrorCodeMixIdError";
    KTVPlayerErrorCode[KTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodePositionError"] = 20] = "ByteRTCKTVPlayerErrorCodePositionError";
    KTVPlayerErrorCode[KTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeAudioVolumeError"] = 21] = "ByteRTCKTVPlayerErrorCodeAudioVolumeError";
    KTVPlayerErrorCode[KTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeTypeError"] = 22] = "ByteRTCKTVPlayerErrorCodeTypeError";
    KTVPlayerErrorCode[KTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodePitchError"] = 23] = "ByteRTCKTVPlayerErrorCodePitchError";
    KTVPlayerErrorCode[KTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeAudioTrackError"] = 24] = "ByteRTCKTVPlayerErrorCodeAudioTrackError";
    KTVPlayerErrorCode[KTVPlayerErrorCode["ByteRTCKTVPlayerErrorCodeStartingError"] = 25] = "ByteRTCKTVPlayerErrorCodeStartingError";
})(exports.KTVPlayerErrorCode || (exports.KTVPlayerErrorCode = {}));
exports.AudioChannel = void 0;
(function (AudioChannel) {
    AudioChannel[AudioChannel["AUDIO_CHANNEL_AUTO"] = 0] = "AUDIO_CHANNEL_AUTO";
    AudioChannel[AudioChannel["AUDIO_CHANNEL_MONO"] = 1] = "AUDIO_CHANNEL_MONO";
    AudioChannel[AudioChannel["AUDIO_CHANNEL_STEREO"] = 2] = "AUDIO_CHANNEL_STEREO";
})(exports.AudioChannel || (exports.AudioChannel = {}));
exports.RemoteVideoStateChangeReason = void 0;
(function (RemoteVideoStateChangeReason) {
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_CONGESTION"] = 0] = "REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_CONGESTION";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_RECOVERY"] = 1] = "REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_RECOVERY";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_MUTED"] = 2] = "REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_MUTED";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_UNMUTED"] = 3] = "REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_UNMUTED";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_MUTED"] = 4] = "REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_MUTED";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_UNMUTED"] = 5] = "REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_UNMUTED";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_OFFLINE"] = 6] = "REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_OFFLINE";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["REMOTE_VIDEO_STATE_CHANGE_REASON_INTERNAL"] = 7] = "REMOTE_VIDEO_STATE_CHANGE_REASON_INTERNAL";
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["ByteRTCRemoteVideoStateChangeReasonInternal"] = 8] = "ByteRTCRemoteVideoStateChangeReasonInternal";
})(exports.RemoteVideoStateChangeReason || (exports.RemoteVideoStateChangeReason = {}));
exports.PerformanceAlarmReason = void 0;
(function (PerformanceAlarmReason) {
    PerformanceAlarmReason[PerformanceAlarmReason["BANDWIDTH_RESUMED"] = 0] = "BANDWIDTH_RESUMED";
    PerformanceAlarmReason[PerformanceAlarmReason["BANDWIDTH_FALLBACKED"] = 1] = "BANDWIDTH_FALLBACKED";
    PerformanceAlarmReason[PerformanceAlarmReason["PERFORMANCE_FALLBACKED"] = 2] = "PERFORMANCE_FALLBACKED";
    PerformanceAlarmReason[PerformanceAlarmReason["PERFORMANCE_RESUMED"] = 3] = "PERFORMANCE_RESUMED";
    PerformanceAlarmReason[PerformanceAlarmReason["ByteRTCPerformanceAlarmReasonBandwidthFallback"] = 4] = "ByteRTCPerformanceAlarmReasonBandwidthFallback";
    PerformanceAlarmReason[PerformanceAlarmReason["ByteRTCPerformanceAlarmReasonFallback"] = 5] = "ByteRTCPerformanceAlarmReasonFallback";
    PerformanceAlarmReason[PerformanceAlarmReason["ByteRTCPerformanceAlarmReasonResumed"] = 6] = "ByteRTCPerformanceAlarmReasonResumed";
})(exports.PerformanceAlarmReason || (exports.PerformanceAlarmReason = {}));
exports.VideoDeviceType = void 0;
(function (VideoDeviceType) {
    VideoDeviceType[VideoDeviceType["VIDEO_DEVICE_TYPE_UNKNOWN"] = 0] = "VIDEO_DEVICE_TYPE_UNKNOWN";
    VideoDeviceType[VideoDeviceType["VIDEO_DEVICE_TYPE_RENDER_DEVICE"] = 1] = "VIDEO_DEVICE_TYPE_RENDER_DEVICE";
    VideoDeviceType[VideoDeviceType["VIDEO_DEVICE_TYPE_CAPTURE_DEVICE"] = 2] = "VIDEO_DEVICE_TYPE_CAPTURE_DEVICE";
    VideoDeviceType[VideoDeviceType["VIDEO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE"] = 3] = "VIDEO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE";
})(exports.VideoDeviceType || (exports.VideoDeviceType = {}));
var HotMusicInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function HotMusicInfo_1() {
        }
        Object.defineProperty(HotMusicInfo_1.prototype, "hotType", {
            /** {en}
             * @brief Hot music type. See {@link MusicHotType MusicHotType}. Multiple hot music types can be combined by the bitwise-or operator.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_MusicHotType.android_to_ts(this._instance.hotType);
                }
                else if ($os === 'ios') {
                    return t_MusicHotType.ios_to_ts(this._instance.hotType);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.hotType = t_MusicHotType.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.hotType = t_MusicHotType.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(HotMusicInfo_1.prototype, "hotName", {
            /** {en}
             * @brief Hot list name.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.hotName);
                }
                else if ($os === 'ios') {
                    return String(this._instance.hotName);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.hotName = value;
                }
                else if ($os === 'ios') {
                    this._instance.hotName = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(HotMusicInfo_1.prototype, "android_musicInfos", {
            /** {en}
             * @platform android
             * @brief Music information. See {@link MusicInfo MusicInfo}.
             *
             */
            get: function () {
                return this._instance.musicInfos;
            },
            set: function (value) {
                this._instance.musicInfos = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(HotMusicInfo_1.prototype, "ios_musics", {
            /** {en}
             * @platform ios
             * @brief Music information. See {@link ByteRTCMusicInfo ByteRTCMusicInfo}.
             */
            get: function () {
                return this._instance.musics;
            },
            set: function (value) {
                this._instance.musics = value;
            },
            enumerable: false,
            configurable: true
        });
        HotMusicInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        HotMusicInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCHotMusicInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = HotMusicInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return HotMusicInfo_1;
    }());
    __setFunctionName(_classThis, "HotMusicInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MixedStreamServerControlConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function MixedStreamServerControlConfig_1() {
        }
        Object.defineProperty(MixedStreamServerControlConfig_1.prototype, "ios_enableVolumeIndication", {
            /** {en}
             * @platform ios
             * @valid since 3.56
             * @brief Sets whether to enable the function of separately sending sound indication SEI: <br>
             *        - True: Enable.
             *        - False: Disable. Default setting.
             *        After setting this parameter to "true", you can choose whether to send sound indication SEI only through `ByteRTCMixedStreamServerControlConfig.seiContentMode`.
             */
            get: function () {
                return this._instance.enableVolumeIndication;
            },
            set: function (value) {
                this._instance.enableVolumeIndication = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamServerControlConfig_1.prototype, "ios_volumeIndicationInterval", {
            /** {en}
             * @platform ios
             * @valid since 3.56
             * @brief Sound indication interval in s. The range is [0.3,+∞). The default value is 2. <br>
             *        If a decimal with two or more decimal places is passed in, it will be rounded to the value of the first decimal place. For example, if you pass in 0.36, it will be automatically adjusted to 0.4.
             */
            get: function () {
                return this._instance.volumeIndicationInterval;
            },
            set: function (value) {
                this._instance.volumeIndicationInterval = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamServerControlConfig_1.prototype, "ios_talkVolume", {
            /** {en}
             * @platform ios
             * @valid since 3.56
             * @brief Effective volume within the range of [0, 255]. The default value is 0. <br>
             *        If the value is set beyond the range, it will be automatically adjusted to the default value 0.
             */
            get: function () {
                return this._instance.talkVolume;
            },
            set: function (value) {
                this._instance.talkVolume = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamServerControlConfig_1.prototype, "ios_isAddVolumeValue", {
            /** {en}
             * @platform ios
             * @valid since 3.56
             * @brief Sets whether volume value is contained in the sound indication SEI: <br>
             *        - True: Yes.
             *        - False: No. Default setting.
             */
            get: function () {
                return this._instance.isAddVolumeValue;
            },
            set: function (value) {
                this._instance.isAddVolumeValue = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamServerControlConfig_1.prototype, "ios_seiContentMode", {
            /** {en}
             * @platform ios
             * @valid since 3.56
             * @brief Sets SEI content. See {@link ByteRTCMixedStreamSEIContentMode ByteRTCMixedStreamSEIContentMode}.
             */
            get: function () {
                return this._instance.seiContentMode;
            },
            set: function (value) {
                this._instance.seiContentMode = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamServerControlConfig_1.prototype, "ios_seiPayloadType", {
            /** {en}
             * @platform ios
             * @valid since 3.56
             * @brief SEI payload type. <br>
             *        The default value is `100`, and the value supported is `5` and `100`. <br>
             *        During the process of pushing streams to CDN, you cannot change the parameter.
             */
            get: function () {
                return this._instance.seiPayloadType;
            },
            set: function (value) {
                this._instance.seiPayloadType = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamServerControlConfig_1.prototype, "ios_seiPayloadUUID", {
            /** {en}
             * @platform ios
             * @valid since 3.56
             * @brief SEI payload UUID.
             * @note When PayloadType is `5`, you must set PayloadUUID, or you will receive a callback indicating parameter error. The error code is 1091. <br>
             *         When PayloadType is not `5`, it is not required to set PayloadUUID. If filled, it will be ignored by the backend. <br>
             *         The length of PayloadUUID should be 32 bits, or you will receive an error code of 1091. <br>
             *         Each character of the parameter should be within the range of [0, 9] [a, f] [A, F]. <br>
             *         The PayloadUUID should not contain `-`. If the automatically generated UUID contains `-`, you should delete it. <br>
             *         During the process of pushing streams to CDN, you cannot change the parameter.
             */
            get: function () {
                return this._instance.seiPayloadUUID;
            },
            set: function (value) {
                this._instance.seiPayloadUUID = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamServerControlConfig_1.prototype, "ios_mediaType", {
            /** {en}
             * @platform ios
             * @valid since 3.57
             * @brief Sets the type of media stream pushed to CDN after being mixed. {@link ByteRTCMixedStreamMediaType ByteRTCMixedStreamMediaType}. <br>
             *        The default value is 0，which means pushing both audio and video.
             */
            get: function () {
                return this._instance.mediaType;
            },
            set: function (value) {
                this._instance.mediaType = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamServerControlConfig_1.prototype, "ios_pushStreamMode", {
            /** {en}
             * @platform ios
             * @valid since 3.57
             * @brief Sets whether to initiate a stream mixing task in the absence of any users publishing streams. See {@link ByteRTCMixedStreamPushMode ByteRTCMixedStreamPushMode}. <br>
             *        Once the stream mixing task is initiated, this parameter can not be updated any more.
             */
            get: function () {
                return this._instance.pushStreamMode;
            },
            set: function (value) {
                this._instance.pushStreamMode = value;
            },
            enumerable: false,
            configurable: true
        });
        MixedStreamServerControlConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        MixedStreamServerControlConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCMixedStreamServerControlConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = MixedStreamServerControlConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @author liujingchao
         * @brief Set SEI payload type.
         * @param seiPayloadType The default value is `100`, and the value supported is `5` and `100`.
         * @return MixedStreamServerControlConfig, See MixedStreamServerControlConfig{@link# MixedStreamServerControlConfig}.
         * @note  During the process of pushing streams to CDN, you cannot change the parameter.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_setSeiPayloadType = function (seiPayloadType) {
            var _this = this;
            var $ = function () { return (_this._instance.setSeiPayloadType(seiPayloadType), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @author liujingchao
         * @brief Get SEI payload type.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_getSeiPayloadType = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getSeiPayloadType()); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @author liujingchao
         * @brief Set SEI Payload UUID.
         * @param seiPayloadUuid The length of PayloadUUID should be 32 bits, or you will receive an error code of 1091. Each character of the parameter should be within the range of [0, 9] [a, f] [A, F]. <br>
         *                       The PayloadUUID should not contain `-`. If the automatically generated UUID contains `-`, you should delete it.
         * @return MixedStreamServerControlConfig, See MixedStreamServerControlConfig{@link# MixedStreamServerControlConfig}.
         * @note When PayloadType is `5`, you must set PayloadUUID, or you will receive a callback indicating parameter error. The error code is 1091. <br>
         *        When PayloadType is not `5`, it is not required to set PayloadUUID. If filled, it will be ignored by the backend. <br>
         *        During the process of pushing streams to CDN, you cannot change the parameter.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_setSeiPayloadUuid = function (seiPayloadUuid) {
            var _this = this;
            var $ = function () { return (_this._instance.setSeiPayloadUuid(seiPayloadUuid), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @author liujingchao
         * @brief Get SEI Payload UUID.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_getSeiPayloadUuid = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getSeiPayloadUuid()); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @brief Sets the sound indication interval.
         * @param volumeIndicationInterval Sound indication interval in s. The range is [0.3,+∞). The default value is 2. <br>
         *        If a decimal with two or more decimal places is passed in, it will be rounded to the value of the first decimal place. For example, if you pass in 0.36, it will be automatically adjusted to 0.4.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_setVolumeIndicationInterval = function (volumeIndicationInterval) {
            var _this = this;
            var $ = function () { return (_this._instance.setVolumeIndicationInterval(volumeIndicationInterval),
                _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @brief Gets the sound indication interval.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_getVolumeIndicationInterval = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getVolumeIndicationInterval()); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @brief Sets whether to enable the function of separately sending sound indication SEI.
         * @param enableVolumeIndication Whether to enable the function of separately sending sound indication SEI: <br>
         *        - true: Enable.
         *        - false: Disable. Default setting.
         * @note After setting this method to "true", you can choose whether to send sound indication SEI only through {@link setSeiContentMode setSeiContentMode}.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_setEnableVolumeIndication = function (enableVolumeIndication) {
            var _this = this;
            var $ = function () { return (_this._instance.setEnableVolumeIndication(enableVolumeIndication), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @brief Gets the setting on whether to enable the function of separately sending sound indication SEI.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_getEnableVolumeIndication = function () {
            var _this = this;
            var $ = function () { return _this._instance.getEnableVolumeIndication(); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @brief Sets whether volume value is contained in the sound indication SEI.
         * @param addVolumeValue Whether volume value is contained in the sound indication SEI: <br>
         *        - true: Yes.
         *        - false: No. Default setting.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_setIsAddVolumeValue = function (addVolumeValue) {
            var _this = this;
            var $ = function () { return (_this._instance.setIsAddVolumeValue(addVolumeValue), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @brief Gets the setting on whether volume value is contained in the sound indication SEI.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_getIsAddVolumeValue = function () {
            var _this = this;
            var $ = function () { return _this._instance.getIsAddVolumeValue(); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @brief Sets SEI content.
         * @param seiContentMode SEI content. See {@link MixedStreamSEIContentMode MixedStreamSEIContentMode}.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_setSeiContentMode = function (seiContentMode) {
            var _this = this;
            var $ = function () { return (_this._instance.setSeiContentMode(seiContentMode), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @brief Gets the setting on SEI content.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_getSeiContentMode = function () {
            var _this = this;
            var $ = function () { return _this._instance.getSeiContentMode(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the effective volume.
         * @param talkVolume Effective volume. The range is [0, 255]. The default value is 0. <br>
         *        If the value is set beyond the range, it will be automatically adjusted to the default value 0.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_setTalkVolume = function (talkVolume) {
            var _this = this;
            var $ = function () { return (_this._instance.setTalkVolume(talkVolume), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @brief Gets the value of the effective volume.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_getTalkVolume = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getTalkVolume()); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Sets whether to initiate a stream mixing task in the absence of any users publishing streams.
         * @param pushStreamMode The initiation mode. See {@link MixedStreamPushMode MixedStreamPushMode}. <br>
         *        Once the stream mixing task is initiated, this parameter can not be updated any more.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_setPushStreamMode = function (pushStreamMode) {
            var _this = this;
            var $ = function () { return (_this._instance.setPushStreamMode(pushStreamMode), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Gets the setting on stream mixing initiation mode.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_getPushStreamMode = function () {
            var _this = this;
            var $ = function () { return _this._instance.getPushStreamMode(); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Sets the type of media stream pushed to CDN after being mixed.
         * @param mediaType See {@link MixedStreamMediaType MixedStreamMediaType}. <br>
         *        The default value is 0，which means pushing both audio and video. Pushing video only is not supported currently.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_setMediaType = function (mediaType) {
            var _this = this;
            var $ = function () { return (_this._instance.setMediaType(mediaType), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.57
         * @detail api
         * @brief Gets the setting on the type of media stream pushed to CDN after being mixed.
         *
         */
        MixedStreamServerControlConfig_1.prototype.android_getMediaType = function () {
            var _this = this;
            var $ = function () { return _this._instance.getMediaType(); };
            return $();
        };
        return MixedStreamServerControlConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamServerControlConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.AudioMixingDualMonoMode = void 0;
(function (AudioMixingDualMonoMode) {
    AudioMixingDualMonoMode[AudioMixingDualMonoMode["AUDIO_MIXING_DUAL_MONO_MODE_AUTO"] = 0] = "AUDIO_MIXING_DUAL_MONO_MODE_AUTO";
    AudioMixingDualMonoMode[AudioMixingDualMonoMode["AUDIO_MIXING_DUAL_MONO_MODE_L"] = 1] = "AUDIO_MIXING_DUAL_MONO_MODE_L";
    AudioMixingDualMonoMode[AudioMixingDualMonoMode["AUDIO_MIXING_DUAL_MONO_MODE_R"] = 2] = "AUDIO_MIXING_DUAL_MONO_MODE_R";
    AudioMixingDualMonoMode[AudioMixingDualMonoMode["AUDIO_MIXING_DUAL_MONO_MODE_MIX"] = 3] = "AUDIO_MIXING_DUAL_MONO_MODE_MIX";
})(exports.AudioMixingDualMonoMode || (exports.AudioMixingDualMonoMode = {}));
var LocalAudioStats = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function LocalAudioStats_1() {
        }
        Object.defineProperty(LocalAudioStats_1.prototype, "audioLossRate", {
            /** {en}
             * @brief Audio packet loss rate. The audio uplink packet loss rate in this reference period. The value range is [0,1].
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.audioLossRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.audioLossRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.audioLossRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.audioLossRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalAudioStats_1.prototype, "android_sendKBitrate", {
            /** {en}
             * @platform android
             * @brief Send rate. The audio transmission rate in the reference period is kbps.
             *
             */
            get: function () {
                return this._instance.sendKBitrate;
            },
            set: function (value) {
                this._instance.sendKBitrate = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalAudioStats_1.prototype, "recordSampleRate", {
            /** {en}
             * @brief Acquisition sampling rate. Audio sampling rate information collected in the reference period, in units of Hz.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.recordSampleRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.recordSampleRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.recordSampleRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.recordSampleRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalAudioStats_1.prototype, "statsInterval", {
            /** {en}
             * @brief Statistical interval. The interval of this reference period is in ms. <br>
             *        This field is used to set the reference period for the callback. The default setting is 2s.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.statsInterval);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.statsInterval);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.statsInterval = value;
                }
                else if ($os === 'ios') {
                    this._instance.statsInterval = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalAudioStats_1.prototype, "rtt", {
            /** {en}
             * @brief Round-trip time. The unit is ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rtt);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rtt);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rtt = value;
                }
                else if ($os === 'ios') {
                    this._instance.rtt = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalAudioStats_1.prototype, "numChannels", {
            /** {en}
             * @brief Number of audio channels.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.numChannels);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.numChannels);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.numChannels = value;
                }
                else if ($os === 'ios') {
                    this._instance.numChannels = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalAudioStats_1.prototype, "sentSampleRate", {
            /** {en}
             * @brief Audio transmission sampling rate. Audio transmission sampling rate information in the reference period, in Hz.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.sentSampleRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.sentSampleRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.sentSampleRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.sentSampleRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalAudioStats_1.prototype, "jitter", {
            /** {en}
             * @brief Audio uplink network jitter in ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.jitter);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.jitter);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.jitter = value;
                }
                else if ($os === 'ios') {
                    this._instance.jitter = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalAudioStats_1.prototype, "ios_sentKBitrate", {
            /** {en}
             * @platform ios
             * @brief The bit rate of transmission. The audio transmission rate in the reference period is kbps.
             */
            get: function () {
                return this._instance.sentKBitrate;
            },
            set: function (value) {
                this._instance.sentKBitrate = value;
            },
            enumerable: false,
            configurable: true
        });
        LocalAudioStats_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        LocalAudioStats_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCLocalAudioStats).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = LocalAudioStats$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return LocalAudioStats_1;
    }());
    __setFunctionName(_classThis, "LocalAudioStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MixedStreamVideoConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function MixedStreamVideoConfig_1() {
        }
        Object.defineProperty(MixedStreamVideoConfig_1.prototype, "ios_videoCodec", {
            /** {en}
             * @platform ios
             * @brief The video codec. See {@link ByteRTCMixedStreamVideoCodecType ByteRTCMixedStreamVideoCodecType}. The default value is `0`. It's recommended to be set. <br>
             *        These parameters cannot be updated while pushing stream to the CDN.
             */
            get: function () {
                return this._instance.videoCodec;
            },
            set: function (value) {
                this._instance.videoCodec = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamVideoConfig_1.prototype, "ios_width", {
            /** {en}
             * @platform ios
             * @brief The width (pixels) to be set. The range is [2, 1920], and must be an even number. The default value is 640 pixels. It's recommended to be set. <br>
             *        If an odd number is set, the width will be adjusted to the next larger even number.
             */
            get: function () {
                return this._instance.width;
            },
            set: function (value) {
                this._instance.width = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamVideoConfig_1.prototype, "ios_height", {
            /** {en}
             * @platform ios
             * @brief The height (pixels) to be set. The range is [2, 1920], and must be an even number. The default value is 360 pixels. It's recommended to be set. <br>
             *        If an odd number is set, the height will be adjusted to the next larger even number.
             */
            get: function () {
                return this._instance.height;
            },
            set: function (value) {
                this._instance.height = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamVideoConfig_1.prototype, "ios_fps", {
            /** {en}
             * @platform ios
             * @brief The frame rate (FPS) in range of [1, 60]. The default value is 15 FPS. It's recommended to be set.
             */
            get: function () {
                return this._instance.fps;
            },
            set: function (value) {
                this._instance.fps = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamVideoConfig_1.prototype, "ios_gop", {
            /** {en}
             * @platform ios
             * @brief The time interval between I-frames (second) in range of [1, 5]. The default value is 2 seconds. It's recommended to be set. <br>
             *        These parameters cannot be updated while pushing stream to the CDN.
             */
            get: function () {
                return this._instance.gop;
            },
            set: function (value) {
                this._instance.gop = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamVideoConfig_1.prototype, "ios_bitrate", {
            /** {en}
             * @platform ios
             * @brief The bitrate (Kbps) in range of [1, 10000]. The default value is self-adaptive. It's recommended to be set.
             */
            get: function () {
                return this._instance.bitrate;
            },
            set: function (value) {
                this._instance.bitrate = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamVideoConfig_1.prototype, "ios_enableBFrame", {
            /** {en}
             * @platform ios
             * @brief Whether to push streams with B frame, only support by server mix.
             */
            get: function () {
                return this._instance.enableBFrame;
            },
            set: function (value) {
                this._instance.enableBFrame = value;
            },
            enumerable: false,
            configurable: true
        });
        MixedStreamVideoConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        MixedStreamVideoConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCMixedStreamVideoConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = MixedStreamVideoConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the frame rate of the mixed video stream. You are recommended to set the value.
         * @param fps The frame rate (FPS) in range of [1, 60]. The default value is 15 FPS.
         *
         */
        MixedStreamVideoConfig_1.prototype.android_setFps = function (fps) {
            var _this = this;
            var $ = function () { return (_this._instance.setFps(fps), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the frame rate of the mixed video stream.
         *
         */
        MixedStreamVideoConfig_1.prototype.android_getFps = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getFps()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the time interval between I-frames. You are recommended to set the value. <br>
         *        This parameter cannot be updated while pushing stream to the CDN.
         * @param gop The time interval between I-frames (second) in range of [1, 5]. The default value is 2 seconds.
         *
         */
        MixedStreamVideoConfig_1.prototype.android_setGop = function (gop) {
            var _this = this;
            var $ = function () { return (_this._instance.setGop(gop), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the time interval between I-frames.
         *
         */
        MixedStreamVideoConfig_1.prototype.android_getGop = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getGop()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the bitrate of the mixed video stream. You are recommended to set the value.
         * @param bitrate The bitrate (Kbps) in range of [1, 10000]. The default value is self-adaptive.
         *
         */
        MixedStreamVideoConfig_1.prototype.android_setBitrate = function (bitrate) {
            var _this = this;
            var $ = function () { return (_this._instance.setBitrate(bitrate), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the bitrate of the mixed video stream.
         *
         */
        MixedStreamVideoConfig_1.prototype.android_getBitrate = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getBitrate()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the width of the mixed video stream. You are recommended to set the value.
         * @param width The width (pixels) to be set. The range is [2, 1920], and must be an even number. The default value is 640 pixels. <br>
         *              If an odd number is set, the width will be adjusted to the next larger even number.
         *
         */
        MixedStreamVideoConfig_1.prototype.android_setWidth = function (width) {
            var _this = this;
            var $ = function () { return (_this._instance.setWidth(width), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the width of the mixed video stream.
         *
         */
        MixedStreamVideoConfig_1.prototype.android_getWidth = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getWidth()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the height of the mixed video stream. You are recommended to set the value.
         * @param height The height (pixels) to be set. The range is [2, 1920], and must be an even number. The default value is 360 pixels. <br>
         *               If an odd number is set, the height will be adjusted to the next larger even number.
         *
         */
        MixedStreamVideoConfig_1.prototype.android_setHeight = function (height) {
            var _this = this;
            var $ = function () { return (_this._instance.setHeight(height), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the height of the mixed video stream.
         *
         */
        MixedStreamVideoConfig_1.prototype.android_getHeight = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getHeight()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets whether to push streams with B frame. Only supported when mixing streams on the server side。
         * @param enableBframe Whether to push streams with B frame: <br>
         *                    - true: Yes
         *                    - false: No
         *
         */
        MixedStreamVideoConfig_1.prototype.android_setEnableBframe = function (enableBframe) {
            var _this = this;
            var $ = function () { return (_this._instance.setEnableBframe(enableBframe), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets setting of whether to push streams with B frame.
         *
         */
        MixedStreamVideoConfig_1.prototype.android_getEnableBframe = function () {
            var _this = this;
            var $ = function () { return _this._instance.getEnableBframe(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the video codec type. You are recommended to set the value. <br>
         *        This parameter cannot be updated while pushing stream to the CDN.
         * @param videoCodec The video codec. See {@link MixedStreamVideoCodecType MixedStreamVideoCodecType}. The default value is `MIXED_STREAM_VIDEO_CODEC_TYPE_H264("H264")`.
         *
         */
        MixedStreamVideoConfig_1.prototype.android_setVideoCodec = function (videoCodec) {
            var _this = this;
            var $ = function () { return (_this._instance.setVideoCodec(videoCodec), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the video codec type.
         *
         */
        MixedStreamVideoConfig_1.prototype.android_getVideoCodec = function () {
            var _this = this;
            var $ = function () { return _this._instance.getVideoCodec(); };
            return $();
        };
        return MixedStreamVideoConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamVideoConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MediaPlayerCustomSource = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function MediaPlayerCustomSource_1() {
        }
        Object.defineProperty(MediaPlayerCustomSource_1.prototype, "mode", {
            /** {en}
             * @detail keytype
             * @brief See {@link MediaPlayerCustomSourceMode MediaPlayerCustomSourceMode}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_MediaPlayerCustomSourceMode.android_to_ts(this._instance.mode);
                }
                else if ($os === 'ios') {
                    return t_MediaPlayerCustomSourceMode.ios_to_ts(this._instance.mode);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.mode = t_MediaPlayerCustomSourceMode.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.mode = t_MediaPlayerCustomSourceMode.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MediaPlayerCustomSource_1.prototype, "type", {
            /** {en}
             * @detail keytype
             * @brief See {@link MediaPlayerCustomSourceStreamType MediaPlayerCustomSourceStreamType}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_MediaPlayerCustomSourceStreamType.android_to_ts(this._instance.type);
                }
                else if ($os === 'ios') {
                    return t_MediaPlayerCustomSourceStreamType.ios_to_ts(this._instance.type);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.type = t_MediaPlayerCustomSourceStreamType.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.type =
                        t_MediaPlayerCustomSourceStreamType.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MediaPlayerCustomSource_1.prototype, "ios_provider", {
            /** {en}
             * @platform ios
             * @detail keytype
             * @brief Specify the {@link ByteRTCMediaPlayerCustomSourceProvider ByteRTCMediaPlayerCustomSourceProvider} instance when you want to play the audio data in memory.
             */
            get: function () {
                return this._instance.provider;
            },
            set: function (value) {
                this._instance.provider = value;
            },
            enumerable: false,
            configurable: true
        });
        MediaPlayerCustomSource_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        MediaPlayerCustomSource_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCMediaPlayerCustomSource).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = MediaPlayerCustomSource$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return MediaPlayerCustomSource_1;
    }());
    __setFunctionName(_classThis, "MediaPlayerCustomSource");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.MusicFilterType = void 0;
(function (MusicFilterType) {
    MusicFilterType[MusicFilterType["NONE"] = 0] = "NONE";
    MusicFilterType[MusicFilterType["WITHOUT_LYRIC"] = 1] = "WITHOUT_LYRIC";
    MusicFilterType[MusicFilterType["UNSUPPORTED_SCORE"] = 2] = "UNSUPPORTED_SCORE";
    MusicFilterType[MusicFilterType["UNSUPPORTED_ACCOMPANY"] = 3] = "UNSUPPORTED_ACCOMPANY";
    MusicFilterType[MusicFilterType["UNSUPPORTED_CLIMAX"] = 4] = "UNSUPPORTED_CLIMAX";
    MusicFilterType[MusicFilterType["ByteRTCMusicFilterTypeUnsupportedAccopmay"] = 5] = "ByteRTCMusicFilterTypeUnsupportedAccopmay";
    MusicFilterType[MusicFilterType["ByteRTCMusicFilterTypeUnsupportedClimx"] = 6] = "ByteRTCMusicFilterTypeUnsupportedClimx";
})(exports.MusicFilterType || (exports.MusicFilterType = {}));
var RemoteAudioPropertiesInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RemoteAudioPropertiesInfo_1() {
        }
        Object.defineProperty(RemoteAudioPropertiesInfo_1.prototype, "streamKey", {
            /** {en}
             * @detail keytype
             * @brief Remote stream information. See {@link RemoteStreamKey RemoteStreamKey}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return packObject(this._instance.streamKey, RemoteStreamKey);
                }
                else if ($os === 'ios') {
                    return packObject(this._instance.streamKey, RemoteStreamKey);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.streamKey = unpackObject(value);
                }
                else if ($os === 'ios') {
                    this._instance.streamKey = unpackObject(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteAudioPropertiesInfo_1.prototype, "audioPropertiesInfo", {
            /** {en}
             * @detail keytype
             * @brief Information of audio properties. See {@link AudioPropertiesInfo AudioPropertiesInfo}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return packObject(this._instance.audioPropertiesInfo, AudioPropertiesInfo);
                }
                else if ($os === 'ios') {
                    return packObject(this._instance.audioPropertiesInfo, AudioPropertiesInfo);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.audioPropertiesInfo = unpackObject(value);
                }
                else if ($os === 'ios') {
                    this._instance.audioPropertiesInfo = unpackObject(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        RemoteAudioPropertiesInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RemoteAudioPropertiesInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRemoteAudioPropertiesInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RemoteAudioPropertiesInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RemoteAudioPropertiesInfo_1;
    }());
    __setFunctionName(_classThis, "RemoteAudioPropertiesInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.LocalVideoRenderPosition = void 0;
(function (LocalVideoRenderPosition) {
    LocalVideoRenderPosition[LocalVideoRenderPosition["AFTER_CAPTURE"] = 0] = "AFTER_CAPTURE";
    LocalVideoRenderPosition[LocalVideoRenderPosition["AFTER_PREPROCESS"] = 1] = "AFTER_PREPROCESS";
})(exports.LocalVideoRenderPosition || (exports.LocalVideoRenderPosition = {}));
var RTCLogConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RTCLogConfig_1() {
        }
        Object.defineProperty(RTCLogConfig_1.prototype, "logPath", {
            /** {en}
             * @brief (Required) Local log directory.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.logPath);
                }
                else if ($os === 'ios') {
                    return String(this._instance.logPath);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.logPath = value;
                }
                else if ($os === 'ios') {
                    this._instance.logPath = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCLogConfig_1.prototype, "logFileSize", {
            /** {en}
             * @brief (Optional) The limits for total log file size in MB. The range is 1 to 100 MB, and the default value is 10 MB. <br>
             *        If `logFileSize` < 1, it will be set to 1 MB. If `logFileSize` > 100, it will be set to 100 MB. <br>
             *        The maximum size for a single log file is 2 MB. <br>
             *        If 1 ≤ `logFileSize` ≤ 2, one log file will be generated. If `logFileSize` > 2, the first `⌊logFileSize/2⌋` files will be filled with 2 MB each, the `⌊logFileSize/2⌋+1` fill will be filled with `logFileSize mod 2`. <br>
             *        If the size exceeds the remaining space, the oldest file will be deleted.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.logFileSize);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.logFileSize);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.logFileSize = value;
                }
                else if ($os === 'ios') {
                    this._instance.logFileSize = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCLogConfig_1.prototype, "logLevel", {
            /** {en}
             * @brief (Optional) The logging level. See {@link LocalLogLevel LocalLogLevel}. The default is warning level.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_LocalLogLevel.android_to_ts(this._instance.logLevel);
                }
                else if ($os === 'ios') {
                    return t_LocalLogLevel.ios_to_ts(this._instance.logLevel);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.logLevel = t_LocalLogLevel.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.logLevel = t_LocalLogLevel.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCLogConfig_1.prototype, "logFilenamePrefix", {
            /** {en}
             * @brief (Optional) Local log file name prefix. It should follow the regular expression pattern of `[a-zA-Z0-9_\@-.]{1,128}`. <br>
             *        The final file name will be the prefix followed by "_" and the file creation time, and "_rtclog.log" at the end. For example, `logPrefix_2023-05-25_172324_rtclog.log`.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.logFilenamePrefix);
                }
                else if ($os === 'ios') {
                    return String(this._instance.logFilenamePrefix);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.logFilenamePrefix = value;
                }
                else if ($os === 'ios') {
                    this._instance.logFilenamePrefix = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        RTCLogConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RTCLogConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCLogConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RTCLogConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RTCLogConfig_1;
    }());
    __setFunctionName(_classThis, "RTCLogConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.AudioReportMode = void 0;
(function (AudioReportMode) {
    AudioReportMode[AudioReportMode["AUDIO_REPORT_MODE_NORMAL"] = 0] = "AUDIO_REPORT_MODE_NORMAL";
    AudioReportMode[AudioReportMode["AUDIO_REPORT_MODE_DISCONNECT"] = 1] = "AUDIO_REPORT_MODE_DISCONNECT";
    AudioReportMode[AudioReportMode["AUDIO_REPORT_MODE_RESET"] = 2] = "AUDIO_REPORT_MODE_RESET";
})(exports.AudioReportMode || (exports.AudioReportMode = {}));
var AudioFormat = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function AudioFormat_1() {
        }
        Object.defineProperty(AudioFormat_1.prototype, "sampleRate", {
            /** {en}
             * @brief Audio sample rate. See {@link AudioSampleRate AudioSampleRate}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioSampleRate.android_to_ts(this._instance.sampleRate);
                }
                else if ($os === 'ios') {
                    return t_AudioSampleRate.ios_to_ts(this._instance.sampleRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.sampleRate = t_AudioSampleRate.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.sampleRate = t_AudioSampleRate.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioFormat_1.prototype, "channel", {
            /** {en}
             * @brief Audio channel. See {@link AudioChannel AudioChannel}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioChannel.android_to_ts(this._instance.channel);
                }
                else if ($os === 'ios') {
                    return t_AudioChannel.ios_to_ts(this._instance.channel);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.channel = t_AudioChannel.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.channel = t_AudioChannel.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioFormat_1.prototype, "samplesPerCall", {
            /** {en}
             * @brief Samples per audio frame returned by callback. `0` by default. The default samples per callback is the minimum value. <br>
             *        The minimum value is `sampleRate * channel * 0.01s`, the value when the callback interval is 0.01s. <br>
             *        The maximum value is `2048`. If the value is invalid, the samples per callback uses the default value. <br>
             *        This parameter only takes effect when setting the read-write callback. It does not take effect when calling {@link enableAudioFrameCallback enableAudioFrameCallback} to enable read-only callback.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.samplesPerCall);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.samplesPerCall);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.samplesPerCall = value;
                }
                else if ($os === 'ios') {
                    this._instance.samplesPerCall = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        AudioFormat_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        AudioFormat_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCAudioFormat).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = AudioFormat$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return AudioFormat_1;
    }());
    __setFunctionName(_classThis, "AudioFormat");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var MediaTypeEnhancementConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function MediaTypeEnhancementConfig_1() {
        }
        Object.defineProperty(MediaTypeEnhancementConfig_1.prototype, "enhanceSignaling", {
            /** {en}
             * @brief Apply to signaling or not. Not by default.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.enhanceSignaling;
                }
                else if ($os === 'ios') {
                    return this._instance.enhanceSignaling;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.enhanceSignaling = value;
                }
                else if ($os === 'ios') {
                    this._instance.enhanceSignaling = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MediaTypeEnhancementConfig_1.prototype, "enhanceAudio", {
            /** {en}
             * @brief Apply to audio stream (Screen-sharing audio not included) or not. Not by default.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.enhanceAudio;
                }
                else if ($os === 'ios') {
                    return this._instance.enhanceAudio;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.enhanceAudio = value;
                }
                else if ($os === 'ios') {
                    this._instance.enhanceAudio = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MediaTypeEnhancementConfig_1.prototype, "enhanceVideo", {
            /** {en}
             * @brief Apply to video (Screen-sharing video not included) or not. Not by default.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.enhanceVideo;
                }
                else if ($os === 'ios') {
                    return this._instance.enhanceVideo;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.enhanceVideo = value;
                }
                else if ($os === 'ios') {
                    this._instance.enhanceVideo = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MediaTypeEnhancementConfig_1.prototype, "enhanceScreenAudio", {
            /** {en}
             * @brief Apply to screen sharing audio or not. Not by default.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.enhanceScreenAudio;
                }
                else if ($os === 'ios') {
                    return this._instance.enhanceScreenAudio;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.enhanceScreenAudio = value;
                }
                else if ($os === 'ios') {
                    this._instance.enhanceScreenAudio = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MediaTypeEnhancementConfig_1.prototype, "enhanceScreenVideo", {
            /** {en}
             * @brief Apply to screen sharing video or not. Not by default.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.enhanceScreenVideo;
                }
                else if ($os === 'ios') {
                    return this._instance.enhanceScreenVideo;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.enhanceScreenVideo = value;
                }
                else if ($os === 'ios') {
                    this._instance.enhanceScreenVideo = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        MediaTypeEnhancementConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        MediaTypeEnhancementConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCMediaTypeEnhancementConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = MediaTypeEnhancementConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return MediaTypeEnhancementConfig_1;
    }());
    __setFunctionName(_classThis, "MediaTypeEnhancementConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.MirrorType = void 0;
(function (MirrorType) {
    MirrorType[MirrorType["MIRROR_TYPE_NONE"] = 0] = "MIRROR_TYPE_NONE";
    MirrorType[MirrorType["MIRROR_TYPE_RENDER"] = 1] = "MIRROR_TYPE_RENDER";
    MirrorType[MirrorType["MIRROR_TYPE_RENDER_AND_ENCODER"] = 2] = "MIRROR_TYPE_RENDER_AND_ENCODER";
})(exports.MirrorType || (exports.MirrorType = {}));
var CloudProxyInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function CloudProxyInfo_1() {
        }
        Object.defineProperty(CloudProxyInfo_1.prototype, "cloudProxyIp", {
            /** {en}
             * @detail keytype
             * @brief Cloud proxy IP
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.cloudProxyIp);
                }
                else if ($os === 'ios') {
                    return String(this._instance.cloudProxyIp);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.cloudProxyIp = value;
                }
                else if ($os === 'ios') {
                    this._instance.cloudProxyIp = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(CloudProxyInfo_1.prototype, "cloudProxyPort", {
            /** {en}
             * @detail keytype
             * @brief Cloud proxy Port
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.cloudProxyPort);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.cloudProxyPort);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.cloudProxyPort = value;
                }
                else if ($os === 'ios') {
                    this._instance.cloudProxyPort = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        CloudProxyInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        CloudProxyInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCCloudProxyInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = CloudProxyInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return CloudProxyInfo_1;
    }());
    __setFunctionName(_classThis, "CloudProxyInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoEncoderConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function VideoEncoderConfig_1() {
        }
        Object.defineProperty(VideoEncoderConfig_1.prototype, "width", {
            /** {en}
             * @brief Width of the video frame in px
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.width);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.width);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.width = value;
                }
                else if ($os === 'ios') {
                    this._instance.width = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoEncoderConfig_1.prototype, "height", {
            /** {en}
             * @brief Height of the video frame in px
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.height);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.height);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.height = value;
                }
                else if ($os === 'ios') {
                    this._instance.height = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoEncoderConfig_1.prototype, "frameRate", {
            /** {en}
             * @brief Video frame rate in fps
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.frameRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.frameRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.frameRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.frameRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoEncoderConfig_1.prototype, "maxBitrate", {
            /** {en}
             * @brief Maximum bit rate in kbps. Optional for internal capturing while mandatory for custom capturing. <br>
             *        If you set this value to -1, SDK will automatically calculate the applicable bit rate based on the input resolution and frame rate. <br>
             *        No stream will be encoded and published if you set this value to 0. <br>
             *        In 3.44.1 and later versions, the default value is `-1` for internal capturing, but no default value in versions earlier than 3.44.1.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.maxBitrate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.maxBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.maxBitrate = value;
                }
                else if ($os === 'ios') {
                    this._instance.maxBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoEncoderConfig_1.prototype, "minBitrate", {
            /** {en}
             * @brief Minimum video encoding bitrate in kbps. The encoding bitrate will not be lower than the `minBitrate`. <br>
             *        It defaults to `0`. <br>
             *        It ranges within [0, maxBitrate). When `maxBitrate` < `minBitrate`, the bitrate is self-adpapted. <br>
             *        In the following circumstance, the assignment to this variable has no effect: <br>
             *        - When `maxBitrate` = `0`, the video encoding is disabled.
             *        - When `maxBitrate` < `0`, the bitrate is self-adapted.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.minBitrate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.minBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.minBitrate = value;
                }
                else if ($os === 'ios') {
                    this._instance.minBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoEncoderConfig_1.prototype, "android_encodePreference", {
            /** {en}
             * @platform android
             * @brief Encoding preference. The default value is MaintainFramerate(1). See {@link EncoderPreference EncoderPreference}.
             *
             */
            get: function () {
                return this._instance.encodePreference;
            },
            set: function (value) {
                this._instance.encodePreference = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoEncoderConfig_1.prototype, "android_maxQp", {
            get: function () {
                return this._instance.maxQp;
            },
            set: function (value) {
                this._instance.maxQp = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoEncoderConfig_1.prototype, "android_minQp", {
            get: function () {
                return this._instance.minQp;
            },
            set: function (value) {
                this._instance.minQp = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoEncoderConfig_1.prototype, "ios_encoderPreference", {
            /** {en}
             * @platform ios
             * @brief Encoding preference. The default value is ByteRTCVideoEncoderPreferenceMaintainFramerate(1). See {@link ByteRTCVideoEncoderPreference ByteRTCVideoEncoderPreference}.
             */
            get: function () {
                return this._instance.encoderPreference;
            },
            set: function (value) {
                this._instance.encoderPreference = value;
            },
            enumerable: false,
            configurable: true
        });
        VideoEncoderConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        VideoEncoderConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCVideoEncoderConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = VideoEncoderConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return VideoEncoderConfig_1;
    }());
    __setFunctionName(_classThis, "VideoEncoderConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.FirstFramePlayState = void 0;
(function (FirstFramePlayState) {
    FirstFramePlayState[FirstFramePlayState["FIRST_FRAME_PLAY_STATE_PLAYING"] = 0] = "FIRST_FRAME_PLAY_STATE_PLAYING";
    FirstFramePlayState[FirstFramePlayState["FIRST_FRAME_PLAY_STATE_END"] = 1] = "FIRST_FRAME_PLAY_STATE_END";
    FirstFramePlayState[FirstFramePlayState["FIRST_FRAME_PLAY_STATE_PLAYED"] = 2] = "FIRST_FRAME_PLAY_STATE_PLAYED";
    FirstFramePlayState[FirstFramePlayState["ByteRTCFirstFramePlayStatePlay"] = 3] = "ByteRTCFirstFramePlayStatePlay";
})(exports.FirstFramePlayState || (exports.FirstFramePlayState = {}));
var RemoteVideoSinkConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RemoteVideoSinkConfig_1() {
        }
        Object.defineProperty(RemoteVideoSinkConfig_1.prototype, "position", {
            /** {en}
             * @brief The position of the remote video frame. See {@link RemoteVideoRenderPosition RemoteVideoRenderPosition}. The default position is after processing.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_RemoteVideoRenderPosition.android_to_ts(this._instance.position);
                }
                else if ($os === 'ios') {
                    return t_RemoteVideoRenderPosition.ios_to_ts(this._instance.position);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.position = t_RemoteVideoRenderPosition.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.position = t_RemoteVideoRenderPosition.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoSinkConfig_1.prototype, "android_pixelFormat", {
            /** {en}
             * @platform android
             * @brief The pixel format of the remote video frame. See {@link VideoPixelFormat VideoPixelFormat}. The default value is 0.
             *
             */
            get: function () {
                return this._instance.pixelFormat;
            },
            set: function (value) {
                this._instance.pixelFormat = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoSinkConfig_1.prototype, "applyRotation", {
            /** {en}
             * @brief Whether the video frame needs to be automatically rotate. See {@link VideoApplyRotation VideoApplyRotation}. The default value is no rotate.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_VideoApplyRotation.android_to_ts(this._instance.applyRotation);
                }
                else if ($os === 'ios') {
                    return t_VideoApplyRotation.ios_to_ts(this._instance.applyRotation);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.applyRotation = t_VideoApplyRotation.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.applyRotation = t_VideoApplyRotation.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoSinkConfig_1.prototype, "mirrorType", {
            /** {en}
             * @brief Whether the video frame needs to be mirrored. See {@link VideoRenderMirrorType VideoRenderMirrorType}. The default value is no mirroring effect.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_VideoRenderMirrorType.android_to_ts(this._instance.mirrorType);
                }
                else if ($os === 'ios') {
                    return t_VideoRenderMirrorType.ios_to_ts(this._instance.mirrorType);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.mirrorType = t_VideoRenderMirrorType.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.mirrorType = t_VideoRenderMirrorType.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoSinkConfig_1.prototype, "ios_requiredPixelFormat", {
            /** {en}
             * @platform ios
             * @brief The pixel format of the remote video frame. See {@link ByteRTCVideoSinkPixelFormat ByteRTCVideoSinkPixelFormat}. The default value is 0.
             */
            get: function () {
                return this._instance.requiredPixelFormat;
            },
            set: function (value) {
                this._instance.requiredPixelFormat = value;
            },
            enumerable: false,
            configurable: true
        });
        RemoteVideoSinkConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RemoteVideoSinkConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRemoteVideoSinkConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RemoteVideoSinkConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RemoteVideoSinkConfig_1;
    }());
    __setFunctionName(_classThis, "RemoteVideoSinkConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.VideoSuperResolutionModeChangedReason = void 0;
(function (VideoSuperResolutionModeChangedReason) {
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_OFF"] = 0] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_OFF";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_ON"] = 1] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_ON";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_RESOLUTION_EXCEED"] = 2] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_RESOLUTION_EXCEED";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OVER_USE"] = 3] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OVER_USE";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DEVICE_NOT_SUPPORT"] = 4] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DEVICE_NOT_SUPPORT";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DYNAMIC_CLOSE"] = 5] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DYNAMIC_CLOSE";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_DISABLED"] = 6] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_DISABLED";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_ENABLED"] = 7] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_ENABLED";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_NO_COMPONENT"] = 8] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_NO_COMPONENT";
    VideoSuperResolutionModeChangedReason[VideoSuperResolutionModeChangedReason["VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_STREAM_NOT_EXIST"] = 9] = "VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_STREAM_NOT_EXIST";
})(exports.VideoSuperResolutionModeChangedReason || (exports.VideoSuperResolutionModeChangedReason = {}));
exports.AnsMode = void 0;
(function (AnsMode) {
    AnsMode[AnsMode["ANS_MODE_DISABLE"] = 0] = "ANS_MODE_DISABLE";
    AnsMode[AnsMode["ANS_MODE_LOW"] = 1] = "ANS_MODE_LOW";
    AnsMode[AnsMode["ANS_MODE_MEDIUM"] = 2] = "ANS_MODE_MEDIUM";
    AnsMode[AnsMode["ANS_MODE_HIGH"] = 3] = "ANS_MODE_HIGH";
    AnsMode[AnsMode["ANS_MODE_AUTOMATIC"] = 4] = "ANS_MODE_AUTOMATIC";
})(exports.AnsMode || (exports.AnsMode = {}));
exports.LocalAudioStreamState = void 0;
(function (LocalAudioStreamState) {
    LocalAudioStreamState[LocalAudioStreamState["LOCAL_AUDIO_STREAM_STATE_STOPPED"] = 0] = "LOCAL_AUDIO_STREAM_STATE_STOPPED";
    LocalAudioStreamState[LocalAudioStreamState["LOCAL_AUDIO_STREAM_STATE_RECORDING"] = 1] = "LOCAL_AUDIO_STREAM_STATE_RECORDING";
    LocalAudioStreamState[LocalAudioStreamState["LOCAL_AUDIO_STREAM_STATE_ENCODING"] = 2] = "LOCAL_AUDIO_STREAM_STATE_ENCODING";
    LocalAudioStreamState[LocalAudioStreamState["LOCAL_AUDIO_STREAM_STATE_FAILED"] = 3] = "LOCAL_AUDIO_STREAM_STATE_FAILED";
})(exports.LocalAudioStreamState || (exports.LocalAudioStreamState = {}));
var VideoFrameInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function VideoFrameInfo_1() {
        }
        Object.defineProperty(VideoFrameInfo_1.prototype, "width", {
            /** {en}
             * @brief Width (pixels)
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.width);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.width);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.width = value;
                }
                else if ($os === 'ios') {
                    this._instance.width = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrameInfo_1.prototype, "height", {
            /** {en}
             * @brief High (pixels)
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.height);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.height);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.height = value;
                }
                else if ($os === 'ios') {
                    this._instance.height = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoFrameInfo_1.prototype, "rotation", {
            /** {en}
             * @brief Video frame clockwise rotation angle. See {@link VideoRotation VideoRotation}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_VideoRotation.android_to_ts(this._instance.rotation);
                }
                else if ($os === 'ios') {
                    return t_VideoRotation.ios_to_ts(this._instance.rotation);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rotation = t_VideoRotation.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.rotation = t_VideoRotation.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        VideoFrameInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        VideoFrameInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCVideoFrameInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = VideoFrameInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return VideoFrameInfo_1;
    }());
    __setFunctionName(_classThis, "VideoFrameInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var VideoCanvas = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function VideoCanvas_1() {
        }
        Object.defineProperty(VideoCanvas_1.prototype, "android_renderView", {
            /** {en}
             * @platform android
             * @brief Local view handler. <br>
             *        When you render the `View` object, use the field, and set `renderSurface` to `null`.
             *
             */
            get: function () {
                return this._instance.renderView;
            },
            set: function (value) {
                this._instance.renderView = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoCanvas_1.prototype, "android_renderSurface", {
            /** {en}
             * @platform android
             * @brief Local surface handler. <br>
             *        When you render the Surface object, use the field, and set `renderView` to `null`.
             *
             */
            get: function () {
                return this._instance.renderSurface;
            },
            set: function (value) {
                this._instance.renderSurface = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoCanvas_1.prototype, "renderMode", {
            /** {en}
             * @brief Rendering mode, the value must be `RENDER_MODE_HIDDEN(1)`, `RENDER_MODE_FIT(2)`, or `RENDER_MODE_FILL(3)`. The default value is `RENDER_MODE_HIDDEN(1)`.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_RenderMode.android_to_ts(this._instance.renderMode);
                }
                else if ($os === 'ios') {
                    return t_RenderMode.ios_to_ts(this._instance.renderMode);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.renderMode = t_RenderMode.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.renderMode = t_RenderMode.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoCanvas_1.prototype, "backgroundColor", {
            /** {en}
             * @brief Set the background color of the canvas which is not filled with video frame. The range is `[0x00000000, 0xFFFFFFFF]`. The default is `0x00000000`. The Alpha index is ignored.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.backgroundColor);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.backgroundColor);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.backgroundColor = value;
                }
                else if ($os === 'ios') {
                    this._instance.backgroundColor = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoCanvas_1.prototype, "renderRotation", {
            /** {en}
             * @brief Video frame rotation angle. See {@link VideoRotation VideoRotation}. The default value is 0, which means no rotation is applied. <br>
             *        This parameter only applies to remote video and does not affect local video settings.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_VideoRotation.android_to_ts(this._instance.renderRotation);
                }
                else if ($os === 'ios') {
                    return t_VideoRotation.ios_to_ts(this._instance.renderRotation);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.renderRotation = t_VideoRotation.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.renderRotation = t_VideoRotation.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VideoCanvas_1.prototype, "ios_view", {
            /** {en}
             * @platform ios
             * @brief Local view handle
             */
            get: function () {
                return this._instance.view;
            },
            set: function (value) {
                this._instance.view = value;
            },
            enumerable: false,
            configurable: true
        });
        VideoCanvas_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        VideoCanvas_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCVideoCanvas).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = VideoCanvas$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return VideoCanvas_1;
    }());
    __setFunctionName(_classThis, "VideoCanvas");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RemoteVideoStats = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RemoteVideoStats_1() {
        }
        Object.defineProperty(RemoteVideoStats_1.prototype, "width", {
            /** {en}
             * @brief Remote Video Stream Width
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.width);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.width);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.width = value;
                }
                else if ($os === 'ios') {
                    this._instance.width = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "height", {
            /** {en}
             * @brief Remote Video Stream Height
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.height);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.height);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.height = value;
                }
                else if ($os === 'ios') {
                    this._instance.height = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "videoLossRate", {
            /** {en}
             * @brief Video packet loss rate. The video downlink packet loss rate in the reference period. The value range is [0,1].
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.videoLossRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.videoLossRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.videoLossRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.videoLossRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "receivedKBitrate", {
            /** {en}
             * @brief Receiving bit rate. Video reception rate within the reference period, in kbps.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.receivedKBitrate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.receivedKBitrate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.receivedKBitrate = value;
                }
                else if ($os === 'ios') {
                    this._instance.receivedKBitrate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "decoderOutputFrameRate", {
            /** {en}
             * @brief The decoder outputs the frame rate. Video decoder output frame rate within the reference period, in fps.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.decoderOutputFrameRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.decoderOutputFrameRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.decoderOutputFrameRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.decoderOutputFrameRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "android_rendererOutputFrameRate", {
            /** {en}
             * @platform android
             * @brief Render frame rate. The video rendering frame rate in the reference period, in fps.
             *
             */
            get: function () {
                return this._instance.rendererOutputFrameRate;
            },
            set: function (value) {
                this._instance.rendererOutputFrameRate = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "stallCount", {
            /** {en}
             * @brief Number of cards. Number of cards in the reference period.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.stallCount);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.stallCount);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.stallCount = value;
                }
                else if ($os === 'ios') {
                    this._instance.stallCount = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "stallDuration", {
            /** {en}
             * @brief Catton duration. The total duration of the video card in the reference period. Unit ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.stallDuration);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.stallDuration);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.stallDuration = value;
                }
                else if ($os === 'ios') {
                    this._instance.stallDuration = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "e2eDelay", {
            /** {en}
             * @brief User experience-level end-to-end delay, in milliseconds, from the time when the sender captures the encoding to the time when the receiver decodes the rendering
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.e2eDelay);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.e2eDelay);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.e2eDelay = value;
                }
                else if ($os === 'ios') {
                    this._instance.e2eDelay = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "isScreen", {
            /** {en}
             * @brief Whether the media stream belongs to the user is a screen stream. You can know whether the current statistics come from mainstream or screen stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.isScreen;
                }
                else if ($os === 'ios') {
                    return this._instance.isScreen;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.isScreen = value;
                }
                else if ($os === 'ios') {
                    this._instance.isScreen = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "statsInterval", {
            /** {en}
             * @brief Statistical interval, the interval of this reference period, in ms. <br>
             *        This field is used to set the reference period for the callback, currently set to 2s.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.statsInterval);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.statsInterval);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.statsInterval = value;
                }
                else if ($os === 'ios') {
                    this._instance.statsInterval = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "rtt", {
            /** {en}
             * @brief Round-trip time in ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.rtt);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.rtt);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.rtt = value;
                }
                else if ($os === 'ios') {
                    this._instance.rtt = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "frozenRate", {
            /** {en}
             * @brief The cumulative duration of the video card of the remote user accounts for the percentage (\%) of the total effective duration of the video after entering the room. The effective duration of the video refers to the duration of the video other than stopping sending the video stream and disabling the video module after the remote user enters the room to publish the video stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.frozenRate);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.frozenRate);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.frozenRate = value;
                }
                else if ($os === 'ios') {
                    this._instance.frozenRate = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "codecType", {
            /** {en}
             * @brief For the encoding type of the video, please refer to {@link VideoCodecType VideoCodecType}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_VideoCodecType.android_to_ts(this._instance.codecType);
                }
                else if ($os === 'ios') {
                    return t_VideoCodecType.ios_to_ts(this._instance.codecType);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.codecType = t_VideoCodecType.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.codecType = t_VideoCodecType.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "videoIndex", {
            /** {en}
             * @brief For subscripts for streams with multiple resolutions.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.videoIndex);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.videoIndex);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.videoIndex = value;
                }
                else if ($os === 'ios') {
                    this._instance.videoIndex = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "jitter", {
            /** {en}
             * @brief Video downlink network jitter in ms.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.jitter);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.jitter);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.jitter = value;
                }
                else if ($os === 'ios') {
                    this._instance.jitter = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "superResolutionMode", {
            /** {en}
             * @brief Super-resolution mode. See {@link VideoSuperResolutionMode VideoSuperResolutionMode}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_VideoSuperResolutionMode.android_to_ts(this._instance.superResolutionMode);
                }
                else if ($os === 'ios') {
                    return t_VideoSuperResolutionMode.ios_to_ts(this._instance.superResolutionMode);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.superResolutionMode = t_VideoSuperResolutionMode.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.superResolutionMode =
                        t_VideoSuperResolutionMode.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "ios_receivedFrameRate", {
            /** {en}
             * @platform ios
             * @brief Remote video receiving frame rate.
             */
            get: function () {
                return this._instance.receivedFrameRate;
            },
            set: function (value) {
                this._instance.receivedFrameRate = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteVideoStats_1.prototype, "ios_renderOutputFrameRate", {
            /** {en}
             * @platform ios
             * @brief Remote video rendering output frame rate.
             */
            get: function () {
                return this._instance.renderOutputFrameRate;
            },
            set: function (value) {
                this._instance.renderOutputFrameRate = value;
            },
            enumerable: false,
            configurable: true
        });
        RemoteVideoStats_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RemoteVideoStats_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRemoteVideoStats).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RemoteVideoStats$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RemoteVideoStats_1;
    }());
    __setFunctionName(_classThis, "RemoteVideoStats");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.VideoApplyRotation = void 0;
(function (VideoApplyRotation) {
    VideoApplyRotation[VideoApplyRotation["DEFAULT"] = 0] = "DEFAULT";
    VideoApplyRotation[VideoApplyRotation["DEGREE_0"] = 1] = "DEGREE_0";
    VideoApplyRotation[VideoApplyRotation["ByteRTCVideoApplyRotation0"] = 2] = "ByteRTCVideoApplyRotation0";
})(exports.VideoApplyRotation || (exports.VideoApplyRotation = {}));
exports.VideoRotation = void 0;
(function (VideoRotation) {
    VideoRotation[VideoRotation["VIDEO_ROTATION_0"] = 0] = "VIDEO_ROTATION_0";
    VideoRotation[VideoRotation["VIDEO_ROTATION_90"] = 1] = "VIDEO_ROTATION_90";
    VideoRotation[VideoRotation["VIDEO_ROTATION_180"] = 2] = "VIDEO_ROTATION_180";
    VideoRotation[VideoRotation["VIDEO_ROTATION_270"] = 3] = "VIDEO_ROTATION_270";
})(exports.VideoRotation || (exports.VideoRotation = {}));
var LocalVideoSinkConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function LocalVideoSinkConfig_1() {
        }
        Object.defineProperty(LocalVideoSinkConfig_1.prototype, "position", {
            /** {en}
             * @brief The position of the local video frame. See {@link LocalVideoRenderPosition LocalVideoRenderPosition}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_LocalVideoRenderPosition.android_to_ts(this._instance.position);
                }
                else if ($os === 'ios') {
                    return t_LocalVideoRenderPosition.ios_to_ts(this._instance.position);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.position = t_LocalVideoRenderPosition.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.position = t_LocalVideoRenderPosition.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoSinkConfig_1.prototype, "android_pixelFormat", {
            /** {en}
             * @platform android
             * @brief The pixel format of the local video frame. See {@link VideoPixelFormat VideoPixelFormat}. The default value is 0.
             *
             */
            get: function () {
                return this._instance.pixelFormat;
            },
            set: function (value) {
                this._instance.pixelFormat = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LocalVideoSinkConfig_1.prototype, "ios_requiredPixelFormat", {
            /** {en}
             * @platform ios
             * @brief The pixel format of the local video frame. See {@link ByteRTCVideoSinkPixelFormat ByteRTCVideoSinkPixelFormat}. The default value is 0.
             */
            get: function () {
                return this._instance.requiredPixelFormat;
            },
            set: function (value) {
                this._instance.requiredPixelFormat = value;
            },
            enumerable: false,
            configurable: true
        });
        LocalVideoSinkConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        LocalVideoSinkConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCLocalVideoSinkConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = LocalVideoSinkConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return LocalVideoSinkConfig_1;
    }());
    __setFunctionName(_classThis, "LocalVideoSinkConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RecordingProgress = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RecordingProgress_1() {
        }
        Object.defineProperty(RecordingProgress_1.prototype, "duration", {
            /** {en}
             * @brief The cumulative recording time of the current file, in milliseconds
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.duration);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.duration);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.duration = value;
                }
                else if ($os === 'ios') {
                    this._instance.duration = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RecordingProgress_1.prototype, "fileSize", {
            /** {en}
             * @brief The size of the currently recorded file in bytes
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.fileSize);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.fileSize);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.fileSize = value;
                }
                else if ($os === 'ios') {
                    this._instance.fileSize = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        RecordingProgress_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RecordingProgress_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRecordingProgress).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RecordingProgress$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RecordingProgress_1;
    }());
    __setFunctionName(_classThis, "RecordingProgress");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.RemoteUserPriority = void 0;
(function (RemoteUserPriority) {
    RemoteUserPriority[RemoteUserPriority["REMOTE_USER_PRIORITY_LOW"] = 0] = "REMOTE_USER_PRIORITY_LOW";
    RemoteUserPriority[RemoteUserPriority["REMOTE_USER_PRIORITY_MEDIUM"] = 1] = "REMOTE_USER_PRIORITY_MEDIUM";
    RemoteUserPriority[RemoteUserPriority["REMOTE_USER_PRIORITY_HIGH"] = 2] = "REMOTE_USER_PRIORITY_HIGH";
})(exports.RemoteUserPriority || (exports.RemoteUserPriority = {}));
exports.LocalVideoStreamState = void 0;
(function (LocalVideoStreamState) {
    LocalVideoStreamState[LocalVideoStreamState["LOCAL_VIDEO_STREAM_STATE_STOPPED"] = 0] = "LOCAL_VIDEO_STREAM_STATE_STOPPED";
    LocalVideoStreamState[LocalVideoStreamState["LOCAL_VIDEO_STREAM_STATE_RECORDING"] = 1] = "LOCAL_VIDEO_STREAM_STATE_RECORDING";
    LocalVideoStreamState[LocalVideoStreamState["LOCAL_VIDEO_STREAM_STATE_ENCODING"] = 2] = "LOCAL_VIDEO_STREAM_STATE_ENCODING";
    LocalVideoStreamState[LocalVideoStreamState["LOCAL_VIDEO_STREAM_STATE_FAILED"] = 3] = "LOCAL_VIDEO_STREAM_STATE_FAILED";
})(exports.LocalVideoStreamState || (exports.LocalVideoStreamState = {}));
exports.RemoteAudioState = void 0;
(function (RemoteAudioState) {
    RemoteAudioState[RemoteAudioState["REMOTE_AUDIO_STATE_STOPPED"] = 0] = "REMOTE_AUDIO_STATE_STOPPED";
    RemoteAudioState[RemoteAudioState["REMOTE_AUDIO_STATE_STARTING"] = 1] = "REMOTE_AUDIO_STATE_STARTING";
    RemoteAudioState[RemoteAudioState["REMOTE_AUDIO_STATE_DECODING"] = 2] = "REMOTE_AUDIO_STATE_DECODING";
    RemoteAudioState[RemoteAudioState["REMOTE_AUDIO_STATE_FROZEN"] = 3] = "REMOTE_AUDIO_STATE_FROZEN";
})(exports.RemoteAudioState || (exports.RemoteAudioState = {}));
var AudioPropertiesConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function AudioPropertiesConfig_1() {
        }
        Object.defineProperty(AudioPropertiesConfig_1.prototype, "interval", {
            /** {en}
             * @brief Prompt interval in ms <br>
             *        - `<= 0`: Turn off prompt
             *        - `(0,100]`: Invalid interval value, and will be automatically reset to 100ms.
             *        - `> 100`: the actual value of interval
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.interval);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.interval);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.interval = value;
                }
                else if ($os === 'ios') {
                    this._instance.interval = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioPropertiesConfig_1.prototype, "enableSpectrum", {
            /** {en}
             * @brief Whether to enable audio spectrum detection
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.enableSpectrum;
                }
                else if ($os === 'ios') {
                    return this._instance.enableSpectrum;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.enableSpectrum = value;
                }
                else if ($os === 'ios') {
                    this._instance.enableSpectrum = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioPropertiesConfig_1.prototype, "enableVad", {
            /** {en}
             * @brief Whether to enable Voice Activity Detection
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.enableVad;
                }
                else if ($os === 'ios') {
                    return this._instance.enableVad;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.enableVad = value;
                }
                else if ($os === 'ios') {
                    this._instance.enableVad = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioPropertiesConfig_1.prototype, "localMainReportMode", {
            /** {en}
             * @brief The volume callback modes. See {@link AudioReportMode AudioReportMode}.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioReportMode.android_to_ts(this._instance.localMainReportMode);
                }
                else if ($os === 'ios') {
                    return t_AudioReportMode.ios_to_ts(this._instance.localMainReportMode);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.localMainReportMode = t_AudioReportMode.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.localMainReportMode = t_AudioReportMode.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioPropertiesConfig_1.prototype, "audioReportMode", {
            /** {en}
             * @brief The audio info included in {@link onLocalAudioPropertiesReport onLocalAudioPropertiesReport}. See {@link AudioPropertiesMode AudioPropertiesMode}. <br>
             *        Locally captured microphone audio info and locally captured screen audio info are included by default.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_AudioPropertiesMode.android_to_ts(this._instance.audioReportMode);
                }
                else if ($os === 'ios') {
                    return t_AudioPropertiesMode.ios_to_ts(this._instance.audioReportMode);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.audioReportMode = t_AudioPropertiesMode.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.audioReportMode = t_AudioPropertiesMode.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioPropertiesConfig_1.prototype, "smooth", {
            /** {en}
             * @brief The smoothing coefficient for audio attribute information prompt. The range is `(0.0, 1.0]`. <br>
             *        The default value is `1.0`, which means the smoothing effect is off by default. Smaller the value, smoother the audio volume prompt. If you want to enable the smooth effect, the recommended value is `0.3`.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.smooth);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.smooth);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.smooth = value;
                }
                else if ($os === 'ios') {
                    this._instance.smooth = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(AudioPropertiesConfig_1.prototype, "enableVoicePitch", {
            /** {en}
             * @brief Sets whether to return the vocal pitch of the local user.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.enableVoicePitch;
                }
                else if ($os === 'ios') {
                    return this._instance.enableVoicePitch;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.enableVoicePitch = value;
                }
                else if ($os === 'ios') {
                    this._instance.enableVoicePitch = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        AudioPropertiesConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        AudioPropertiesConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCAudioPropertiesConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = AudioPropertiesConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return AudioPropertiesConfig_1;
    }());
    __setFunctionName(_classThis, "AudioPropertiesConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.VideoPixelFormat = void 0;
(function (VideoPixelFormat) {
    VideoPixelFormat[VideoPixelFormat["UNKNOWN"] = 0] = "UNKNOWN";
    VideoPixelFormat[VideoPixelFormat["I420"] = 1] = "I420";
    VideoPixelFormat[VideoPixelFormat["NV21"] = 2] = "NV21";
    VideoPixelFormat[VideoPixelFormat["RGBA"] = 3] = "RGBA";
    VideoPixelFormat[VideoPixelFormat["NV12"] = 4] = "NV12";
    VideoPixelFormat[VideoPixelFormat["TEXTURE_2D"] = 5] = "TEXTURE_2D";
    VideoPixelFormat[VideoPixelFormat["TEXTURE_OES"] = 6] = "TEXTURE_OES";
    VideoPixelFormat[VideoPixelFormat["ByteRTCVideoPixelFormatBGRA"] = 7] = "ByteRTCVideoPixelFormatBGRA";
    VideoPixelFormat[VideoPixelFormat["ByteRTCVideoPixelFormatIMC2"] = 8] = "ByteRTCVideoPixelFormatIMC2";
    VideoPixelFormat[VideoPixelFormat["ByteRTCVideoPixelFormatARGB"] = 9] = "ByteRTCVideoPixelFormatARGB";
    VideoPixelFormat[VideoPixelFormat["ByteRTCVideoPixelFormatGLTexture2D"] = 10] = "ByteRTCVideoPixelFormatGLTexture2D";
    VideoPixelFormat[VideoPixelFormat["ByteRTCVideoPixelFormatGLTextureOES"] = 11] = "ByteRTCVideoPixelFormatGLTextureOES";
    VideoPixelFormat[VideoPixelFormat["ByteRTCVideoPixelFormatCVPixelBuffer"] = 12] = "ByteRTCVideoPixelFormatCVPixelBuffer";
})(exports.VideoPixelFormat || (exports.VideoPixelFormat = {}));
exports.LocalProxyError = void 0;
(function (LocalProxyError) {
    LocalProxyError[LocalProxyError["OK"] = 0] = "OK";
    LocalProxyError[LocalProxyError["SOCKS5_VERSION_ERROR"] = 1] = "SOCKS5_VERSION_ERROR";
    LocalProxyError[LocalProxyError["SOCKS5_FORMAT_ERROR"] = 2] = "SOCKS5_FORMAT_ERROR";
    LocalProxyError[LocalProxyError["SOCKS5_INVALID_VALUE"] = 3] = "SOCKS5_INVALID_VALUE";
    LocalProxyError[LocalProxyError["SOCKS5_USER_PASS_NOT_GIVEN"] = 4] = "SOCKS5_USER_PASS_NOT_GIVEN";
    LocalProxyError[LocalProxyError["SOCKS5_TCP_CLOSED"] = 5] = "SOCKS5_TCP_CLOSED";
    LocalProxyError[LocalProxyError["HTTP_TUNNEL_FAILED"] = 6] = "HTTP_TUNNEL_FAILED";
})(exports.LocalProxyError || (exports.LocalProxyError = {}));
exports.MediaStreamType = void 0;
(function (MediaStreamType) {
    MediaStreamType[MediaStreamType["RTC_MEDIA_STREAM_TYPE_AUDIO"] = 0] = "RTC_MEDIA_STREAM_TYPE_AUDIO";
    MediaStreamType[MediaStreamType["RTC_MEDIA_STREAM_TYPE_VIDEO"] = 1] = "RTC_MEDIA_STREAM_TYPE_VIDEO";
    MediaStreamType[MediaStreamType["RTC_MEDIA_STREAM_TYPE_BOTH"] = 2] = "RTC_MEDIA_STREAM_TYPE_BOTH";
})(exports.MediaStreamType || (exports.MediaStreamType = {}));
exports.MediaDeviceState = void 0;
(function (MediaDeviceState) {
    /** {en}
     * @platform android
     * @brief Device started capturing
     *
     */
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_STARTED"] = 0] = "MEDIA_DEVICE_STATE_STARTED";
    /** {en}
     * @platform android
     * @brief Device stopped capturing
     *
     */
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_STOPPED"] = 1] = "MEDIA_DEVICE_STATE_STOPPED";
    /** {en}
     * @platform android
     * @brief Runtime error <br>
     *        For example, when the media device is expected to be working but no data is received.
     *
     */
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_RUNTIMEERROR"] = 2] = "MEDIA_DEVICE_STATE_RUNTIMEERROR";
    /** {en}
     * @platform android
     * @brief Device is added.
     *
     */
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_ADDED"] = 3] = "MEDIA_DEVICE_STATE_ADDED";
    /** {en}
     * @platform android
     * @brief Device is removed.
     *
     */
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_REMOVED"] = 4] = "MEDIA_DEVICE_STATE_REMOVED";
    /** {en}
     * @platform android
     * @brief A Phone call interrupted the RTC call. RTC call will resume once the call ends.
     *
     */
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_INTERRUPTION_BEGAN"] = 5] = "MEDIA_DEVICE_STATE_INTERRUPTION_BEGAN";
    /** {en}
     * @platform android
     * @brief RTC call resumed from the interruption caused by a phone call.
     *
     */
    MediaDeviceState[MediaDeviceState["MEDIA_DEVICE_STATE_INTERRUPTION_ENDED"] = 6] = "MEDIA_DEVICE_STATE_INTERRUPTION_ENDED";
    MediaDeviceState[MediaDeviceState["ByteRTCMediaDeviceStateStarted"] = 7] = "ByteRTCMediaDeviceStateStarted";
    MediaDeviceState[MediaDeviceState["ByteRTCMediaDeviceStateStopped"] = 8] = "ByteRTCMediaDeviceStateStopped";
    MediaDeviceState[MediaDeviceState["ByteRTCMediaDeviceStateRuntimeError"] = 9] = "ByteRTCMediaDeviceStateRuntimeError";
    MediaDeviceState[MediaDeviceState["ByteRTCMediaDeviceStateAdded"] = 10] = "ByteRTCMediaDeviceStateAdded";
    MediaDeviceState[MediaDeviceState["ByteRTCMediaDeviceStateRemoved"] = 11] = "ByteRTCMediaDeviceStateRemoved";
    MediaDeviceState[MediaDeviceState["ByteRTCMediaDeviceStateInterruptionBegan"] = 12] = "ByteRTCMediaDeviceStateInterruptionBegan";
    MediaDeviceState[MediaDeviceState["ByteRTCMediaDeviceStateInterruptionEnded"] = 13] = "ByteRTCMediaDeviceStateInterruptionEnded";
})(exports.MediaDeviceState || (exports.MediaDeviceState = {}));
exports.LocalProxyType = void 0;
(function (LocalProxyType) {
    LocalProxyType[LocalProxyType["SOCKS5"] = 0] = "SOCKS5";
    LocalProxyType[LocalProxyType["HTTP_TUNNEL"] = 1] = "HTTP_TUNNEL";
})(exports.LocalProxyType || (exports.LocalProxyType = {}));
exports.PlayState = void 0;
(function (PlayState) {
    PlayState[PlayState["PLAYING"] = 0] = "PLAYING";
    PlayState[PlayState["PAUSED"] = 1] = "PAUSED";
    PlayState[PlayState["FAILED"] = 2] = "FAILED";
    PlayState[PlayState["FINISHED"] = 3] = "FINISHED";
    PlayState[PlayState["STOPPED"] = 4] = "STOPPED";
    PlayState[PlayState["ByteRTCPlayStateStoped"] = 5] = "ByteRTCPlayStateStoped";
})(exports.PlayState || (exports.PlayState = {}));
var VoiceReverbConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function VoiceReverbConfig_1() {
        }
        Object.defineProperty(VoiceReverbConfig_1.prototype, "roomSize", {
            /** {en}
             * @brief The room size for reverb simulation. The range is `[0.0, 100.0]`. The default value is `50.0f`. The larger the room, the stronger the reverberation.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.roomSize);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.roomSize);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.roomSize = value;
                }
                else if ($os === 'ios') {
                    this._instance.roomSize = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VoiceReverbConfig_1.prototype, "decayTime", {
            /** {en}
             * @brief The decay time of the reverb effect. The range is `[0.0, 100.0]`. The default value is `50.0f`.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.decayTime);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.decayTime);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.decayTime = value;
                }
                else if ($os === 'ios') {
                    this._instance.decayTime = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VoiceReverbConfig_1.prototype, "damping", {
            /** {en}
             * @brief The damping index of the reverb effect. The range is `[0.0, 100.0]`. The default value is `50.0f`.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.damping);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.damping);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.damping = value;
                }
                else if ($os === 'ios') {
                    this._instance.damping = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VoiceReverbConfig_1.prototype, "wetGain", {
            /** {en}
             * @brief The Intensity of the wet signal in dB. The range is `[-20.0, 10.0]`. The default value is `0.0f`.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.wetGain);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.wetGain);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.wetGain = value;
                }
                else if ($os === 'ios') {
                    this._instance.wetGain = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VoiceReverbConfig_1.prototype, "dryGain", {
            /** {en}
             * @brief The Intensity of the dry signal in dB. The range is `[-20.0, 10.0]`. The default value is `0.0f`.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.dryGain);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.dryGain);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.dryGain = value;
                }
                else if ($os === 'ios') {
                    this._instance.dryGain = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(VoiceReverbConfig_1.prototype, "preDelay", {
            /** {en}
             * @brief The delay of the wet signal in ms. The range is `[0.0, 200.0]`. The default value is `0.0f`.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.preDelay);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.preDelay);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.preDelay = value;
                }
                else if ($os === 'ios') {
                    this._instance.preDelay = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        VoiceReverbConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        VoiceReverbConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCVoiceReverbConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = VoiceReverbConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return VoiceReverbConfig_1;
    }());
    __setFunctionName(_classThis, "VoiceReverbConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.VideoSuperResolutionMode = void 0;
(function (VideoSuperResolutionMode) {
    VideoSuperResolutionMode[VideoSuperResolutionMode["VIDEO_SUPER_RESOLUTION_MODE_OFF"] = 0] = "VIDEO_SUPER_RESOLUTION_MODE_OFF";
    VideoSuperResolutionMode[VideoSuperResolutionMode["VIDEO_SUPER_RESOLUTION_MODE_ON"] = 1] = "VIDEO_SUPER_RESOLUTION_MODE_ON";
})(exports.VideoSuperResolutionMode || (exports.VideoSuperResolutionMode = {}));
var PushSingleStreamParam = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function PushSingleStreamParam_1() {
        }
        Object.defineProperty(PushSingleStreamParam_1.prototype, "roomId", {
            /** {en}
             * @brief The room ID of the media stream
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.roomId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.roomId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.roomId = value;
                }
                else if ($os === 'ios') {
                    this._instance.roomId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(PushSingleStreamParam_1.prototype, "userId", {
            /** {en}
             * @brief The user ID of the media stream
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.userId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.userId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.userId = value;
                }
                else if ($os === 'ios') {
                    this._instance.userId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(PushSingleStreamParam_1.prototype, "url", {
            /** {en}
             * @brief The URL for live transcoding. Only supports live transcoding via RTMP. The URL should match the regular expression `/^rtmps?:\\/\\//`. <br>
             *        This parameter cannot be updated while pushing stream to the CDN.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.url);
                }
                else if ($os === 'ios') {
                    return String(this._instance.url);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.url = value;
                }
                else if ($os === 'ios') {
                    this._instance.url = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(PushSingleStreamParam_1.prototype, "isScreen", {
            /** {en}
             * @brief Whether the media stream is a screen-sharing stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.isScreen;
                }
                else if ($os === 'ios') {
                    return this._instance.isScreen;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.isScreen = value;
                }
                else if ($os === 'ios') {
                    this._instance.isScreen = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        PushSingleStreamParam_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        PushSingleStreamParam_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCPushSingleStreamParam).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = PushSingleStreamParam$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return PushSingleStreamParam_1;
    }());
    __setFunctionName(_classThis, "PushSingleStreamParam");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.SubtitleState = void 0;
(function (SubtitleState) {
    SubtitleState[SubtitleState["SUBTITLE_STATE_STARTED"] = 0] = "SUBTITLE_STATE_STARTED";
    SubtitleState[SubtitleState["SUBTITLE_STATE_STOPED"] = 1] = "SUBTITLE_STATE_STOPED";
    SubtitleState[SubtitleState["SUBTITLE_STATE_ERROR"] = 2] = "SUBTITLE_STATE_ERROR";
})(exports.SubtitleState || (exports.SubtitleState = {}));
exports.RecordingFileType = void 0;
(function (RecordingFileType) {
    RecordingFileType[RecordingFileType["AAC"] = 0] = "AAC";
    RecordingFileType[RecordingFileType["MP4"] = 1] = "MP4";
})(exports.RecordingFileType || (exports.RecordingFileType = {}));
exports.ScreenMediaType = void 0;
(function (ScreenMediaType) {
    ScreenMediaType[ScreenMediaType["SCREEN_MEDIA_TYPE_VIDEO_ONLY"] = 0] = "SCREEN_MEDIA_TYPE_VIDEO_ONLY";
    ScreenMediaType[ScreenMediaType["SCREEN_MEDIA_TYPE_AUDIO_ONLY"] = 1] = "SCREEN_MEDIA_TYPE_AUDIO_ONLY";
    ScreenMediaType[ScreenMediaType["SCREEN_MEDIA_TYPE_VIDEO_AND_AUDIO"] = 2] = "SCREEN_MEDIA_TYPE_VIDEO_AND_AUDIO";
})(exports.ScreenMediaType || (exports.ScreenMediaType = {}));
exports.MixedStreamRenderMode = void 0;
(function (MixedStreamRenderMode) {
    MixedStreamRenderMode[MixedStreamRenderMode["MIXED_STREAM_RENDER_MODE_HIDDEN"] = 0] = "MIXED_STREAM_RENDER_MODE_HIDDEN";
    MixedStreamRenderMode[MixedStreamRenderMode["MIXED_STREAM_RENDER_MODE_FIT"] = 1] = "MIXED_STREAM_RENDER_MODE_FIT";
    MixedStreamRenderMode[MixedStreamRenderMode["MIXED_STREAM_RENDER_MODE_ADAPTIVE"] = 2] = "MIXED_STREAM_RENDER_MODE_ADAPTIVE";
})(exports.MixedStreamRenderMode || (exports.MixedStreamRenderMode = {}));
var SubtitleConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function SubtitleConfig_1() {
        }
        Object.defineProperty(SubtitleConfig_1.prototype, "mode", {
            /** {en}
             * @brief Subtitle mode. You can choose between the recognition and translation modes based on your needs. In the recognition mode, the speech of the speaker in the room will be recognized and converted into captions. In the translation mode, the transcribed text will be translated. Refer to {@link SubtitleMode SubtitleMode} for more details.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_SubtitleMode.android_to_ts(this._instance.mode);
                }
                else if ($os === 'ios') {
                    return t_SubtitleMode.ios_to_ts(this._instance.mode);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.mode = t_SubtitleMode.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.mode = t_SubtitleMode.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SubtitleConfig_1.prototype, "targetLanguage", {
            /** {en}
             * @brief Target language.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.targetLanguage);
                }
                else if ($os === 'ios') {
                    return String(this._instance.targetLanguage);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.targetLanguage = value;
                }
                else if ($os === 'ios') {
                    this._instance.targetLanguage = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        SubtitleConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        SubtitleConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCSubtitleConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = SubtitleConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return SubtitleConfig_1;
    }());
    __setFunctionName(_classThis, "SubtitleConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.VirtualBackgroundSourceType = void 0;
(function (VirtualBackgroundSourceType) {
    VirtualBackgroundSourceType[VirtualBackgroundSourceType["COLOR"] = 0] = "COLOR";
    VirtualBackgroundSourceType[VirtualBackgroundSourceType["IMAGE"] = 1] = "IMAGE";
    VirtualBackgroundSourceType[VirtualBackgroundSourceType["ByteRTCVirtualBackgroundSourceTypeImage"] = 2] = "ByteRTCVirtualBackgroundSourceTypeImage";
})(exports.VirtualBackgroundSourceType || (exports.VirtualBackgroundSourceType = {}));
exports.AudioRenderType = void 0;
(function (AudioRenderType) {
    AudioRenderType[AudioRenderType["AUDIO_RENDER_TYPE_EXTERNAL"] = 0] = "AUDIO_RENDER_TYPE_EXTERNAL";
    AudioRenderType[AudioRenderType["AUDIO_RENDER_TYPE_INTERNAL"] = 1] = "AUDIO_RENDER_TYPE_INTERNAL";
    AudioRenderType[AudioRenderType["ByteRTCAudioRenderTypeInternal"] = 2] = "ByteRTCAudioRenderTypeInternal";
})(exports.AudioRenderType || (exports.AudioRenderType = {}));
var MixedStreamAudioConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function MixedStreamAudioConfig_1() {
        }
        Object.defineProperty(MixedStreamAudioConfig_1.prototype, "ios_audioCodec", {
            /** {en}
             * @platform ios
             * @brief The audio codec.
             * @param codec The audio codec. See {@link ByteRTCMixedStreamAudioCodecType ByteRTCMixedStreamAudioCodecType}. Defaults to `0`. It's recommended to be set.
             */
            get: function () {
                return this._instance.audioCodec;
            },
            set: function (value) {
                this._instance.audioCodec = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamAudioConfig_1.prototype, "ios_sampleRate", {
            /** {en}
             * @platform ios
             * @brief The sample rate (Hz). Supported sample rates: 32,000 Hz, 44,100 Hz, 48,000 Hz. Defaults to 48,000 Hz. It's recommended to be set.
             */
            get: function () {
                return this._instance.sampleRate;
            },
            set: function (value) {
                this._instance.sampleRate = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamAudioConfig_1.prototype, "ios_channels", {
            /** {en}
             * @platform ios
             * @brief The number of channels. Supported channels: 1 (single channel), 2 (dual channel).  Defaults to 2. It's recommended to be set.
             */
            get: function () {
                return this._instance.channels;
            },
            set: function (value) {
                this._instance.channels = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamAudioConfig_1.prototype, "ios_bitrate", {
            /** {en}
             * @platform ios
             * @brief The bitrate (Kbps) in range of [32, 192]. Defaults to 64 Kbps. It's recommended to be set.
             */
            get: function () {
                return this._instance.bitrate;
            },
            set: function (value) {
                this._instance.bitrate = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamAudioConfig_1.prototype, "ios_audioProfile", {
            /** {en}
             * @platform ios
             * @brief AAC profile. See {@link ByteRTCMixedStreamAudioProfile ByteRTCMixedStreamAudioProfile}. Defaults to `0`. It's recommended to be set.
             */
            get: function () {
                return this._instance.audioProfile;
            },
            set: function (value) {
                this._instance.audioProfile = value;
            },
            enumerable: false,
            configurable: true
        });
        MixedStreamAudioConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        MixedStreamAudioConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCMixedStreamAudioConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = MixedStreamAudioConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the number of channels. You are recommended to set the value.
         * @param channels The number of channels. Supported channels: 1 (single channel), 2 (dual channel).  Defaults to 2.
         *
         */
        MixedStreamAudioConfig_1.prototype.android_setChannels = function (channels) {
            var _this = this;
            var $ = function () { return (_this._instance.setChannels(channels), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the number of channels.
         *
         */
        MixedStreamAudioConfig_1.prototype.android_getChannels = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getChannels()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the sample rate. You are recommended to set the value.
         * @param sampleRate The sample rate (Hz). Supported sample rates: 32,000 Hz, 44,100 Hz, 48,000 Hz. Defaults to 48,000 Hz.
         *
         */
        MixedStreamAudioConfig_1.prototype.android_setSampleRate = function (sampleRate) {
            var _this = this;
            var $ = function () { return (_this._instance.setSampleRate(sampleRate), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the sample rate.
         *
         */
        MixedStreamAudioConfig_1.prototype.android_getSampleRate = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getSampleRate()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the bitrate. You are recommended to set the value.
         * @param bitrate The bitrate (Kbps) in range of [32, 192]. Defaults to 64 Kbps.
         *
         */
        MixedStreamAudioConfig_1.prototype.android_setBitrate = function (bitrate) {
            var _this = this;
            var $ = function () { return (_this._instance.setBitrate(bitrate), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the bitrate.
         *
         */
        MixedStreamAudioConfig_1.prototype.android_getBitrate = function () {
            var _this = this;
            var $ = function () { return Number(_this._instance.getBitrate()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the audio codec. You are recommended to set the value.
         * @param audioCodec The audio codec. See {@link MixedStreamAudioCodecType MixedStreamAudioCodecType}. Defaults to `MIXED_STREAM_AUDIO_CODEC_TYPE_AAC("AAC")`. <br>
         *              This parameter cannot be updated while pushing stream to the CDN.
         *
         */
        MixedStreamAudioConfig_1.prototype.android_setAudioCodec = function (audioCodec) {
            var _this = this;
            var $ = function () { return (_this._instance.setAudioCodec(audioCodec), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the audio codec.
         *
         */
        MixedStreamAudioConfig_1.prototype.android_getAudioCodec = function () {
            var _this = this;
            var $ = function () { return _this._instance.getAudioCodec(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the AAC profile. You are recommended to set the value.
         * @param audioProfile AAC profile. See {@link MixedStreamAudioProfile MixedStreamAudioProfile}. Defaults to `MIXED_STREAM_AUDIO_PROFILE_LC("LC")`.
         *
         */
        MixedStreamAudioConfig_1.prototype.android_setAudioProfile = function (audioProfile) {
            var _this = this;
            var $ = function () { return (_this._instance.setAudioProfile(audioProfile), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the AAC profile.
         *
         */
        MixedStreamAudioConfig_1.prototype.android_getAudioProfile = function () {
            var _this = this;
            var $ = function () { return _this._instance.getAudioProfile(); };
            return $();
        };
        return MixedStreamAudioConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamAudioConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.ZoomDirectionType = void 0;
(function (ZoomDirectionType) {
    ZoomDirectionType[ZoomDirectionType["CAMERA_MOVE_LEFT"] = 0] = "CAMERA_MOVE_LEFT";
    ZoomDirectionType[ZoomDirectionType["CAMERA_MOVE_RIGHT"] = 1] = "CAMERA_MOVE_RIGHT";
    ZoomDirectionType[ZoomDirectionType["CAMERA_MOVE_UP"] = 2] = "CAMERA_MOVE_UP";
    ZoomDirectionType[ZoomDirectionType["CAMERA_MOVE_DOWN"] = 3] = "CAMERA_MOVE_DOWN";
    ZoomDirectionType[ZoomDirectionType["CAMERA_ZOOM_OUT"] = 4] = "CAMERA_ZOOM_OUT";
    ZoomDirectionType[ZoomDirectionType["CAMERA_ZOOM_IN"] = 5] = "CAMERA_ZOOM_IN";
    ZoomDirectionType[ZoomDirectionType["CAMERA_RESET"] = 6] = "CAMERA_RESET";
    ZoomDirectionType[ZoomDirectionType["ByteRTCZoomDirectionTypeMoveLeft"] = 7] = "ByteRTCZoomDirectionTypeMoveLeft";
    ZoomDirectionType[ZoomDirectionType["ByteRTCZoomDirectionTypeMoveRight"] = 8] = "ByteRTCZoomDirectionTypeMoveRight";
    ZoomDirectionType[ZoomDirectionType["ByteRTCZoomDirectionTypeMoveUp"] = 9] = "ByteRTCZoomDirectionTypeMoveUp";
    ZoomDirectionType[ZoomDirectionType["ByteRTCZoomDirectionTypeMoveDown"] = 10] = "ByteRTCZoomDirectionTypeMoveDown";
    ZoomDirectionType[ZoomDirectionType["ByteRTCZoomDirectionTypeZoomOut"] = 11] = "ByteRTCZoomDirectionTypeZoomOut";
    ZoomDirectionType[ZoomDirectionType["ByteRTCZoomDirectionTypeZoomIn"] = 12] = "ByteRTCZoomDirectionTypeZoomIn";
    ZoomDirectionType[ZoomDirectionType["ByteRTCZoomDirectionTypeReset"] = 13] = "ByteRTCZoomDirectionTypeReset";
})(exports.ZoomDirectionType || (exports.ZoomDirectionType = {}));
var StandardPitchInfo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function StandardPitchInfo_1() {
        }
        /**
         * @platform android
         */
        StandardPitchInfo_1.android_create = function (startTime, duration, pitch) {
            var $ = function () { return StandardPitchInfo$1.create(startTime, duration, pitch); };
            return $();
        };
        Object.defineProperty(StandardPitchInfo_1.prototype, "startTime", {
            /** {en}
             * @brief Starting time, unit: ms.
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.startTime);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.startTime);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.startTime = value;
                }
                else if ($os === 'ios') {
                    this._instance.startTime = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StandardPitchInfo_1.prototype, "duration", {
            /** {en}
             * @brief Duration, unit: ms.
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.duration);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.duration);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.duration = value;
                }
                else if ($os === 'ios') {
                    this._instance.duration = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(StandardPitchInfo_1.prototype, "pitch", {
            /** {en}
             * @brief pitch.
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.pitch);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.pitch);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.pitch = value;
                }
                else if ($os === 'ios') {
                    this._instance.pitch = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        StandardPitchInfo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        StandardPitchInfo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCStandardPitchInfo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = StandardPitchInfo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return StandardPitchInfo_1;
    }());
    __setFunctionName(_classThis, "StandardPitchInfo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.AudioMixingType = void 0;
(function (AudioMixingType) {
    AudioMixingType[AudioMixingType["AUDIO_MIXING_TYPE_PLAYOUT"] = 0] = "AUDIO_MIXING_TYPE_PLAYOUT";
    AudioMixingType[AudioMixingType["AUDIO_MIXING_TYPE_PUBLISH"] = 1] = "AUDIO_MIXING_TYPE_PUBLISH";
    AudioMixingType[AudioMixingType["AUDIO_MIXING_TYPE_PLAYOUT_AND_PUBLISH"] = 2] = "AUDIO_MIXING_TYPE_PLAYOUT_AND_PUBLISH";
})(exports.AudioMixingType || (exports.AudioMixingType = {}));
exports.AttenuationType = void 0;
(function (AttenuationType) {
    AttenuationType[AttenuationType["ATTENUATION_TYPE_NONE"] = 0] = "ATTENUATION_TYPE_NONE";
    AttenuationType[AttenuationType["ATTENUATION_TYPE_LINEAR"] = 1] = "ATTENUATION_TYPE_LINEAR";
    AttenuationType[AttenuationType["ATTENUATION_TYPE_EXPONENTIAL"] = 2] = "ATTENUATION_TYPE_EXPONENTIAL";
})(exports.AttenuationType || (exports.AttenuationType = {}));
exports.MediaPlayerCustomSourceStreamType = void 0;
(function (MediaPlayerCustomSourceStreamType) {
    MediaPlayerCustomSourceStreamType[MediaPlayerCustomSourceStreamType["RAW"] = 0] = "RAW";
    MediaPlayerCustomSourceStreamType[MediaPlayerCustomSourceStreamType["ENCODED"] = 1] = "ENCODED";
})(exports.MediaPlayerCustomSourceStreamType || (exports.MediaPlayerCustomSourceStreamType = {}));
exports.AlphaLayout = void 0;
(function (AlphaLayout) {
    AlphaLayout[AlphaLayout["TOP"] = 0] = "TOP";
})(exports.AlphaLayout || (exports.AlphaLayout = {}));
var MixedStreamConfig = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var MixedStreamConfig = _classThis = /** @class */ (function () {
        function MixedStreamConfig_1() {
        }
        /** {en}
         *  @type api
         *  @brief Gets the default configurations for live transcoding.
         *  @return The default configurations for live transcoding. See {@link MixedStreamConfig MixedStreamConfig}.
         *
         */
        MixedStreamConfig_1.defaultMixedStreamConfig = function () {
            var a = function () { return packObject(MixedStreamConfig$1.defaultMixedStreamConfig(), MixedStreamConfig); };
            var i = function () { return packObject(ByteRTCMixedStreamConfig.defaultMixedStreamConfig(), MixedStreamConfig); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        Object.defineProperty(MixedStreamConfig_1.prototype, "ios_expectedMixingType", {
            /** {en}
             * @platform ios
             * @brief Stream mixing type. See {@link ByteRTCMixedStreamType ByteRTCMixedStreamType}. It's recommended to be set.
             */
            get: function () {
                return this._instance.expectedMixingType;
            },
            set: function (value) {
                this._instance.expectedMixingType = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamConfig_1.prototype, "ios_layoutConfig", {
            /** {en}
             * @platform ios
             * @brief The overall video layout of the mixed stream. <br>
             *        After starting to push streams to CDN, you can set the layout of each video stream, the background information of the mixed stream, etc. See {@link ByteRTCMixedStreamLayoutConfig ByteRTCMixedStreamLayoutConfig} for details.
             */
            get: function () {
                return this._instance.layoutConfig;
            },
            set: function (value) {
                this._instance.layoutConfig = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamConfig_1.prototype, "ios_videoConfig", {
            /** {en}
             * @platform ios
             * @brief Video transcoding related configurations. See {@link ByteRTCMixedStreamVideoConfig ByteRTCMixedStreamVideoConfig}. It's recommended to be set.
             */
            get: function () {
                return this._instance.videoConfig;
            },
            set: function (value) {
                this._instance.videoConfig = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamConfig_1.prototype, "ios_audioConfig", {
            /** {en}
             * @platform ios
             * @brief Audio mixed related configurations. See {@link ByteRTCMixedStreamAudioConfig ByteRTCMixedStreamAudioConfig} for data types. It's recommended to be set.
             */
            get: function () {
                return this._instance.audioConfig;
            },
            set: function (value) {
                this._instance.audioConfig = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamConfig_1.prototype, "ios_clientMixConfig", {
            /** {en}
             * @platform ios
             * @brief client mix param. See {@link ByteRTCMixedStreamClientMixConfig ByteRTCMixedStreamClientMixConfig} for detail. It's recommended to be set.
             */
            get: function () {
                return this._instance.clientMixConfig;
            },
            set: function (value) {
                this._instance.clientMixConfig = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamConfig_1.prototype, "ios_spatialAudioConfig", {
            /** {en}
             * @platform ios
             * @hidden(macOS)
             * @brief The spatial audio config when pushing to CDN. See {@link ByteRTCMixedStreamSpatialAudioConfig ByteRTCMixedStreamSpatialAudioConfig} for detail.
             */
            get: function () {
                return this._instance.spatialAudioConfig;
            },
            set: function (value) {
                this._instance.spatialAudioConfig = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamConfig_1.prototype, "ios_serverControlConfig", {
            /** {en}
             * @platform ios
             * @brief Server mix Control config. See {@link ByteRTCMixedStreamServerControlConfig ByteRTCMixedStreamServerControlConfig} for detail.
             */
            get: function () {
                return this._instance.serverControlConfig;
            },
            set: function (value) {
                this._instance.serverControlConfig = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamConfig_1.prototype, "ios_pushURL", {
            /** {en}
             * @platform ios
             * @brief The URL for live transcoding. Only supports live transcoding via RTMP. The URL should match the regular expression `/^rtmps?:\\/\\//`. It's recommended to be set. <br>
             *        This parameter cannot be updated while pushing stream to the CDN.
             */
            get: function () {
                return this._instance.pushURL;
            },
            set: function (value) {
                this._instance.pushURL = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamConfig_1.prototype, "ios_roomID", {
            /** {en}
             * @platform ios
             * @brief The room ID for live transcoding. The sum length of `roomID` and `userID` should not exceed 126 bytes. It's recommended to be set. <br>
             *        This parameter cannot be updated while pushing stream to the CDN.
             */
            get: function () {
                return this._instance.roomID;
            },
            set: function (value) {
                this._instance.roomID = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(MixedStreamConfig_1.prototype, "ios_userID", {
            /** {en}
             * @platform ios
             * @brief The user ID for live transcoding. The sum length of `roomID` and `userID` should not exceed 126 bytes. It's recommended to be set. <br>
             *        This parameter cannot be updated while pushing stream to the CDN.
             */
            get: function () {
                return this._instance.userID;
            },
            set: function (value) {
                this._instance.userID = value;
            },
            enumerable: false,
            configurable: true
        });
        MixedStreamConfig_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        MixedStreamConfig_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCMixedStreamConfig).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = MixedStreamConfig$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the user ID of the mixed stream pusher. This parameter cannot be updated while pushing stream to the CDN. You are recommended to set the value.
         * @param userID User ID of the mixed stream pusher. The sum length of `roomId` and `userId` should not exceed 126 bytes.
         *
         */
        MixedStreamConfig_1.prototype.android_setUserID = function (userID) {
            var _this = this;
            var $ = function () { return (_this._instance.setUserID(userID), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the user ID of the mixed stream pusher.
         *
         */
        MixedStreamConfig_1.prototype.android_getUserID = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getUserID()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the room ID where the mixed stream pusher is in. This parameter cannot be updated while pushing stream to the CDN. You are recommended to set the value.
         * @param roomID The room ID. The sum length of `roomId` and `userId` should not exceed 126 bytes.
         *
         */
        MixedStreamConfig_1.prototype.android_setRoomID = function (roomID) {
            var _this = this;
            var $ = function () { return (_this._instance.setRoomID(roomID), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the room ID where the mixed stream pusher is in.
         *
         */
        MixedStreamConfig_1.prototype.android_getRoomID = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getRoomID()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the URL for the mixed stream to be pushed to. Only supports live transcoding via RTMP. The URL should match the regular expression `/^rtmps?:\\/\\//`. You are recommended to set the value. <br>
         *        This parameter cannot be updated while pushing stream to the CDN.
         * @param pushURL URL for the mixed stream to be pushed to.
         *
         */
        MixedStreamConfig_1.prototype.android_setPushURL = function (pushURL) {
            var _this = this;
            var $ = function () { return (_this._instance.setPushURL(pushURL), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the URL for the mixed stream to be pushed to
         *
         */
        MixedStreamConfig_1.prototype.android_getPushURL = function () {
            var _this = this;
            var $ = function () { return String(_this._instance.getPushURL()); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @region Push to CDN
         * @brief Sets the stream mixing type. You are recommended to set the value.
         * @param expectedMixingType Stream mixing type. See {@link ByteRTCStreamMixingType ByteRTCStreamMixingType}.
         * @note This parameter cannot be updated while pushing stream to the CDN.
         *
         */
        MixedStreamConfig_1.prototype.android_setExpectedMixingType = function (expectedMixingType) {
            var _this = this;
            var $ = function () { return (_this._instance.setExpectedMixingType(expectedMixingType), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @region Push to CDN
         * @brief Gets the stream mixing type.
         *
         */
        MixedStreamConfig_1.prototype.android_getExpectedMixingType = function () {
            var _this = this;
            var $ = function () { return _this._instance.getExpectedMixingType(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets audio transcoding configurations. You are recommended to set the value.
         * @param audioConfig The audio configurations to be set. See {@link MixedStreamAudioConfig MixedStreamAudioConfig}.
         *
         */
        MixedStreamConfig_1.prototype.android_setAudioConfig = function (audioConfig) {
            var _this = this;
            var $ = function () { return (_this._instance.setAudioConfig(audioConfig), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets audio transcoding configurations.
         *
         */
        MixedStreamConfig_1.prototype.android_getAudioConfig = function () {
            var _this = this;
            var $ = function () { return _this._instance.getAudioConfig(); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @brief Sets the configurations during mixing streams on the server side.
         * @param serverControlConfig The configurations to be set. See {@link MixedStreamServerControlConfig MixedStreamServerControlConfig}.
         *
         */
        MixedStreamConfig_1.prototype.android_setServerControlConfig = function (serverControlConfig) {
            var _this = this;
            var $ = function () { return (_this._instance.setServerControlConfig(serverControlConfig), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @brief Gets the configurations during mixing streams on the server side.
         *
         */
        MixedStreamConfig_1.prototype.android_getServerControlConfig = function () {
            var _this = this;
            var $ = function () { return _this._instance.getServerControlConfig(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the video transcoding configurations. You are recommended to set the value.
         * @param videoConfig The configurations to be set. See {@link MixedStreamVideoConfig MixedStreamVideoConfig}.
         *
         */
        MixedStreamConfig_1.prototype.android_setVideoConfig = function (videoConfig) {
            var _this = this;
            var $ = function () { return (_this._instance.setVideoConfig(videoConfig), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the video transcoding configurations.
         *
         */
        MixedStreamConfig_1.prototype.android_getVideoConfig = function () {
            var _this = this;
            var $ = function () { return _this._instance.getVideoConfig(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets client mix configurations. You are recommended to set the value.
         * @param clientMixConfig The configurations to be set. See {@link MixedStreamClientMixConfig MixedStreamClientMixConfig}.
         *
         */
        MixedStreamConfig_1.prototype.android_setClientMixConfig = function (clientMixConfig) {
            var _this = this;
            var $ = function () { return (_this._instance.setClientMixConfig(clientMixConfig), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the spatial audio configuration when pushing streams to CDN.
         * @param spatialConfig The configurations to be set. See {@link MixedStreamSpatialConfig MixedStreamSpatialConfig}.
         *
         */
        MixedStreamConfig_1.prototype.android_setSpatialConfig = function (spatialConfig) {
            var _this = this;
            var $ = function () { return (_this._instance.setSpatialConfig(spatialConfig), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the spatial audio configuration when pushing streams to CDN.
         *
         */
        MixedStreamConfig_1.prototype.android_getSpatialConfig = function () {
            var _this = this;
            var $ = function () { return _this._instance.getSpatialConfig(); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Sets the overall video layout of the mixed stream. You are recommended to set the value.
         * @param layout The layout to be set. See {@link MixedStreamLayoutConfig MixedStreamLayoutConfig}.
         *
         */
        MixedStreamConfig_1.prototype.android_setLayout = function (layout) {
            var _this = this;
            var $ = function () { return (_this._instance.setLayout(layout), _this); };
            return $();
        };
        /** {en}
         * @platform android
         * @detail api
         * @brief Gets the overall video layout of the mixed stream.
         *
         */
        MixedStreamConfig_1.prototype.android_getLayout = function () {
            var _this = this;
            var $ = function () { return _this._instance.getLayout(); };
            return $();
        };
        /**
         * @platform android
         */
        /**
         * @platform android
         */
        MixedStreamConfig_1.prototype.android_getMixedStreamVideoConfigBFrame = function () {
            var _this = this;
            var $ = function () { return _this._instance.getMixedStreamVideoConfigBFrame(); };
            return $();
        };
        return MixedStreamConfig_1;
    }());
    __setFunctionName(_classThis, "MixedStreamConfig");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        MixedStreamConfig = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return MixedStreamConfig = _classThis;
}();
exports.SEICountPerFrame = void 0;
(function (SEICountPerFrame) {
    SEICountPerFrame[SEICountPerFrame["SEI_COUNT_PER_FRAME_SINGLE"] = 0] = "SEI_COUNT_PER_FRAME_SINGLE";
    SEICountPerFrame[SEICountPerFrame["SEI_COUNT_PER_FRAME_MULTI"] = 1] = "SEI_COUNT_PER_FRAME_MULTI";
})(exports.SEICountPerFrame || (exports.SEICountPerFrame = {}));
var RTCUser = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RTCUser_1() {
        }
        Object.defineProperty(RTCUser_1.prototype, "userId", {
            /** {en}
             * @brief User id
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.userId);
                }
                else if ($os === 'ios') {
                    return String(this._instance.userId);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.userId = value;
                }
                else if ($os === 'ios') {
                    this._instance.userId = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RTCUser_1.prototype, "metaData", {
            /** {en}
             * @brief Metadata
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.metaData);
                }
                else if ($os === 'ios') {
                    return String(this._instance.metaData);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.metaData = value;
                }
                else if ($os === 'ios') {
                    this._instance.metaData = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        RTCUser_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RTCUser_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCUser).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RtcUser).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RTCUser_1;
    }());
    __setFunctionName(_classThis, "RTCUser");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
exports.SEIStreamUpdateEventType = void 0;
(function (SEIStreamUpdateEventType) {
    SEIStreamUpdateEventType[SEIStreamUpdateEventType["STREAM_ADD"] = 0] = "STREAM_ADD";
    SEIStreamUpdateEventType[SEIStreamUpdateEventType["STREAM_REMOVE"] = 1] = "STREAM_REMOVE";
    SEIStreamUpdateEventType[SEIStreamUpdateEventType["ByteRTCSEIStreamEventTypeStreamAdd"] = 2] = "ByteRTCSEIStreamEventTypeStreamAdd";
    SEIStreamUpdateEventType[SEIStreamUpdateEventType["ByteRTCSEIStreamEventTypeStreamRemove"] = 3] = "ByteRTCSEIStreamEventTypeStreamRemove";
})(exports.SEIStreamUpdateEventType || (exports.SEIStreamUpdateEventType = {}));
var RemoteStreamSwitchEvent = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RemoteStreamSwitchEvent_1() {
        }
        Object.defineProperty(RemoteStreamSwitchEvent_1.prototype, "uid", {
            /** {en}
             * @brief User ID of the publisher of the subscribed media stream
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return String(this._instance.uid);
                }
                else if ($os === 'ios') {
                    return String(this._instance.uid);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.uid = value;
                }
                else if ($os === 'ios') {
                    this._instance.uid = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamSwitchEvent_1.prototype, "isScreen", {
            /** {en}
             * @brief Whether it is a screen-sharing stream
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return this._instance.isScreen;
                }
                else if ($os === 'ios') {
                    return this._instance.isScreen;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.isScreen = value;
                }
                else if ($os === 'ios') {
                    this._instance.isScreen = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamSwitchEvent_1.prototype, "beforeVideoIndex", {
            /** {en}
             * @brief The quality index of the subscribed stream before the stream switching
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.beforeVideoIndex);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.beforeVideoIndex);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.beforeVideoIndex = value;
                }
                else if ($os === 'ios') {
                    this._instance.beforeVideoIndex = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamSwitchEvent_1.prototype, "afterVideoIndex", {
            /** {en}
             * @brief The quality index of the subscribed stream after the stream switching
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return Number(this._instance.afterVideoIndex);
                }
                else if ($os === 'ios') {
                    return Number(this._instance.afterVideoIndex);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.afterVideoIndex = value;
                }
                else if ($os === 'ios') {
                    this._instance.afterVideoIndex = value;
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamSwitchEvent_1.prototype, "android_beforeEnable", {
            /** {en}
             * @platform android
             * @brief Whether a video stream before the stream switching
             *
             */
            get: function () {
                return this._instance.beforeEnable;
            },
            set: function (value) {
                this._instance.beforeEnable = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamSwitchEvent_1.prototype, "android_afterEnable", {
            /** {en}
             * @platform android
             * @brief Whether a video stream after the stream switching
             *
             */
            get: function () {
                return this._instance.afterEnable;
            },
            set: function (value) {
                this._instance.afterEnable = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamSwitchEvent_1.prototype, "reason", {
            /** {en}
             * @brief Refer to {@link FallbackOrRecoverReason FallbackOrRecoverReason} for the reason of the Fallback or reverting from the Fallback of the subscribed stream.
             *
             */
            get: function () {
                var $os = env.getOS();
                if ($os === 'android') {
                    return t_FallbackOrRecoverReason.android_to_ts(this._instance.reason);
                }
                else if ($os === 'ios') {
                    return t_FallbackOrRecoverReason.ios_to_ts(this._instance.reason);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            set: function (value) {
                var $os = env.getOS();
                if ($os === 'android') {
                    this._instance.reason = t_FallbackOrRecoverReason.ts_to_android(value);
                }
                else if ($os === 'ios') {
                    this._instance.reason = t_FallbackOrRecoverReason.ts_to_ios(value);
                }
                else {
                    throw new Error('Not Support Platform ' + $os);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamSwitchEvent_1.prototype, "ios_beforeVideoEnabled", {
            /** {en}
             * @platform ios
             * @brief Whether a video stream before the stream switching
             */
            get: function () {
                return this._instance.beforeVideoEnabled;
            },
            set: function (value) {
                this._instance.beforeVideoEnabled = value;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(RemoteStreamSwitchEvent_1.prototype, "ios_afterVideoEnabled", {
            /** {en}
             * @platform ios
             * @brief Whether a video stream after the stream switching
             */
            get: function () {
                return this._instance.afterVideoEnabled;
            },
            set: function (value) {
                this._instance.afterVideoEnabled = value;
            },
            enumerable: false,
            configurable: true
        });
        RemoteStreamSwitchEvent_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RemoteStreamSwitchEvent_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRemoteStreamSwitchEvent).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RemoteStreamSwitch).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RemoteStreamSwitchEvent_1;
    }());
    __setFunctionName(_classThis, "RemoteStreamSwitchEvent");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var t_AudioTrackType = /** @class */ (function () {
    function t_AudioTrackType() {
    }
    t_AudioTrackType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioTrackType.ORIGINAL] = AudioTrackType.ORIGINAL,
            _a[exports.AudioTrackType.ACCOMPANY] = AudioTrackType.ACCOMPANY,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioTrackType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioTrackType.ORIGINAL] = exports.AudioTrackType.ORIGINAL,
            _a[AudioTrackType.ACCOMPANY] = exports.AudioTrackType.ACCOMPANY,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioTrackType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioTrackType.ORIGINAL] = ByteRTCAudioTrackType.ByteRTCAudioTrackTypeOriginal,
            _a[exports.AudioTrackType.ByteRTCAudioTrackTypeAccompy] = ByteRTCAudioTrackType.ByteRTCAudioTrackTypeAccompy,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioTrackType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioTrackType.ByteRTCAudioTrackTypeOriginal] = exports.AudioTrackType.ORIGINAL,
            _a[ByteRTCAudioTrackType.ByteRTCAudioTrackTypeAccompy] = exports.AudioTrackType.ByteRTCAudioTrackTypeAccompy,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioTrackType;
}());
var t_AudioPlayType = /** @class */ (function () {
    function t_AudioPlayType() {
    }
    t_AudioPlayType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioPlayType.LOCAL] = AudioPlayType.LOCAL,
            _a[exports.AudioPlayType.REMOTE] = AudioPlayType.REMOTE,
            _a[exports.AudioPlayType.LOCAL_AND_REMOTE] = AudioPlayType.LOCAL_AND_REMOTE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioPlayType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioPlayType.LOCAL] = exports.AudioPlayType.LOCAL,
            _a[AudioPlayType.REMOTE] = exports.AudioPlayType.REMOTE,
            _a[AudioPlayType.LOCAL_AND_REMOTE] = exports.AudioPlayType.LOCAL_AND_REMOTE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioPlayType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioPlayType.LOCAL] = ByteRTCAudioPlayType.ByteRTCAudioPlayTypeLocal,
            _a[exports.AudioPlayType.REMOTE] = ByteRTCAudioPlayType.ByteRTCAudioPlayTypeRemote,
            _a[exports.AudioPlayType.LOCAL_AND_REMOTE] = ByteRTCAudioPlayType.ByteRTCAudioPlayTypeLocalAndRemote,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioPlayType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioPlayType.ByteRTCAudioPlayTypeLocal] = exports.AudioPlayType.LOCAL,
            _a[ByteRTCAudioPlayType.ByteRTCAudioPlayTypeRemote] = exports.AudioPlayType.REMOTE,
            _a[ByteRTCAudioPlayType.ByteRTCAudioPlayTypeLocalAndRemote] = exports.AudioPlayType.LOCAL_AND_REMOTE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioPlayType;
}());
var t_AudioScenarioType = /** @class */ (function () {
    function t_AudioScenarioType() {
    }
    t_AudioScenarioType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioScenarioType.AUDIO_SCENARIO_MUSIC] = AudioScenarioType.AUDIO_SCENARIO_MUSIC,
            _a[exports.AudioScenarioType.AUDIO_SCENARIO_HIGHQUALITY_COMMUNICATION] = AudioScenarioType.AUDIO_SCENARIO_HIGHQUALITY_COMMUNICATION,
            _a[exports.AudioScenarioType.AUDIO_SCENARIO_COMMUNICATION] = AudioScenarioType.AUDIO_SCENARIO_COMMUNICATION,
            _a[exports.AudioScenarioType.AUDIO_SCENARIO_MEDIA] = AudioScenarioType.AUDIO_SCENARIO_MEDIA,
            _a[exports.AudioScenarioType.AUDIO_SCENARIO_GAME_STREAMING] = AudioScenarioType.AUDIO_SCENARIO_GAME_STREAMING,
            _a[exports.AudioScenarioType.AUDIO_SCENARIO_HIGHQUALITY_CHAT] = AudioScenarioType.AUDIO_SCENARIO_HIGHQUALITY_CHAT,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioScenarioType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioScenarioType.AUDIO_SCENARIO_MUSIC] = exports.AudioScenarioType.AUDIO_SCENARIO_MUSIC,
            _a[AudioScenarioType.AUDIO_SCENARIO_HIGHQUALITY_COMMUNICATION] = exports.AudioScenarioType.AUDIO_SCENARIO_HIGHQUALITY_COMMUNICATION,
            _a[AudioScenarioType.AUDIO_SCENARIO_COMMUNICATION] = exports.AudioScenarioType.AUDIO_SCENARIO_COMMUNICATION,
            _a[AudioScenarioType.AUDIO_SCENARIO_MEDIA] = exports.AudioScenarioType.AUDIO_SCENARIO_MEDIA,
            _a[AudioScenarioType.AUDIO_SCENARIO_GAME_STREAMING] = exports.AudioScenarioType.AUDIO_SCENARIO_GAME_STREAMING,
            _a[AudioScenarioType.AUDIO_SCENARIO_HIGHQUALITY_CHAT] = exports.AudioScenarioType.AUDIO_SCENARIO_HIGHQUALITY_CHAT,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioScenarioType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioScenarioType.AUDIO_SCENARIO_MUSIC] = ByteRTCAudioScenarioType.ByteRTCAudioScenarioMusic,
            _a[exports.AudioScenarioType.AUDIO_SCENARIO_HIGHQUALITY_COMMUNICATION] = ByteRTCAudioScenarioType.ByteRTCAudioScenarioHighqualityCommunication,
            _a[exports.AudioScenarioType.AUDIO_SCENARIO_COMMUNICATION] = ByteRTCAudioScenarioType.ByteRTCAudioScenarioCommunication,
            _a[exports.AudioScenarioType.AUDIO_SCENARIO_MEDIA] = ByteRTCAudioScenarioType.ByteRTCAudioScenarioMedia,
            _a[exports.AudioScenarioType.AUDIO_SCENARIO_GAME_STREAMING] = ByteRTCAudioScenarioType.ByteRTCAudioScenarioGameStreaming,
            _a[exports.AudioScenarioType.AUDIO_SCENARIO_HIGHQUALITY_CHAT] = ByteRTCAudioScenarioType.ByteRTCAudioScenarioHighqualityChat,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioScenarioType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioScenarioType.ByteRTCAudioScenarioMusic] = exports.AudioScenarioType.AUDIO_SCENARIO_MUSIC,
            _a[ByteRTCAudioScenarioType.ByteRTCAudioScenarioHighqualityCommunication] = exports.AudioScenarioType.AUDIO_SCENARIO_HIGHQUALITY_COMMUNICATION,
            _a[ByteRTCAudioScenarioType.ByteRTCAudioScenarioCommunication] = exports.AudioScenarioType.AUDIO_SCENARIO_COMMUNICATION,
            _a[ByteRTCAudioScenarioType.ByteRTCAudioScenarioMedia] = exports.AudioScenarioType.AUDIO_SCENARIO_MEDIA,
            _a[ByteRTCAudioScenarioType.ByteRTCAudioScenarioGameStreaming] = exports.AudioScenarioType.AUDIO_SCENARIO_GAME_STREAMING,
            _a[ByteRTCAudioScenarioType.ByteRTCAudioScenarioHighqualityChat] = exports.AudioScenarioType.AUDIO_SCENARIO_HIGHQUALITY_CHAT,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioScenarioType;
}());
var t_AudioProfileType = /** @class */ (function () {
    function t_AudioProfileType() {
    }
    t_AudioProfileType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioProfileType.AUDIO_PROFILE_DEFAULT] = AudioProfileType.AUDIO_PROFILE_DEFAULT,
            _a[exports.AudioProfileType.AUDIO_PROFILE_FLUENT] = AudioProfileType.AUDIO_PROFILE_FLUENT,
            _a[exports.AudioProfileType.AUDIO_PROFILE_STANDARD] = AudioProfileType.AUDIO_PROFILE_STANDARD,
            _a[exports.AudioProfileType.AUDIO_PROFILE_HD] = AudioProfileType.AUDIO_PROFILE_HD,
            _a[exports.AudioProfileType.AUDIO_PROFILE_STANDARD_STEREO] = AudioProfileType.AUDIO_PROFILE_STANDARD_STEREO,
            _a[exports.AudioProfileType.AUDIO_PROFILE_HD_MONO] = AudioProfileType.AUDIO_PROFILE_HD_MONO,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioProfileType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioProfileType.AUDIO_PROFILE_DEFAULT] = exports.AudioProfileType.AUDIO_PROFILE_DEFAULT,
            _a[AudioProfileType.AUDIO_PROFILE_FLUENT] = exports.AudioProfileType.AUDIO_PROFILE_FLUENT,
            _a[AudioProfileType.AUDIO_PROFILE_STANDARD] = exports.AudioProfileType.AUDIO_PROFILE_STANDARD,
            _a[AudioProfileType.AUDIO_PROFILE_HD] = exports.AudioProfileType.AUDIO_PROFILE_HD,
            _a[AudioProfileType.AUDIO_PROFILE_STANDARD_STEREO] = exports.AudioProfileType.AUDIO_PROFILE_STANDARD_STEREO,
            _a[AudioProfileType.AUDIO_PROFILE_HD_MONO] = exports.AudioProfileType.AUDIO_PROFILE_HD_MONO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioProfileType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioProfileType.AUDIO_PROFILE_DEFAULT] = ByteRTCAudioProfileType.ByteRTCAudioProfileDefault,
            _a[exports.AudioProfileType.AUDIO_PROFILE_FLUENT] = ByteRTCAudioProfileType.ByteRTCAudioProfileFluent,
            _a[exports.AudioProfileType.AUDIO_PROFILE_STANDARD] = ByteRTCAudioProfileType.ByteRTCAudioProfileStandard,
            _a[exports.AudioProfileType.AUDIO_PROFILE_HD] = ByteRTCAudioProfileType.ByteRTCAudioProfileHD,
            _a[exports.AudioProfileType.AUDIO_PROFILE_STANDARD_STEREO] = ByteRTCAudioProfileType.ByteRTCAudioProfileStandardStereo,
            _a[exports.AudioProfileType.AUDIO_PROFILE_HD_MONO] = ByteRTCAudioProfileType.ByteRTCAudioProfileHDMono,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioProfileType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioProfileType.ByteRTCAudioProfileDefault] = exports.AudioProfileType.AUDIO_PROFILE_DEFAULT,
            _a[ByteRTCAudioProfileType.ByteRTCAudioProfileFluent] = exports.AudioProfileType.AUDIO_PROFILE_FLUENT,
            _a[ByteRTCAudioProfileType.ByteRTCAudioProfileStandard] = exports.AudioProfileType.AUDIO_PROFILE_STANDARD,
            _a[ByteRTCAudioProfileType.ByteRTCAudioProfileHD] = exports.AudioProfileType.AUDIO_PROFILE_HD,
            _a[ByteRTCAudioProfileType.ByteRTCAudioProfileStandardStereo] = exports.AudioProfileType.AUDIO_PROFILE_STANDARD_STEREO,
            _a[ByteRTCAudioProfileType.ByteRTCAudioProfileHDMono] = exports.AudioProfileType.AUDIO_PROFILE_HD_MONO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioProfileType;
}());
var t_AnsMode = /** @class */ (function () {
    function t_AnsMode() {
    }
    t_AnsMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AnsMode.ANS_MODE_DISABLE] = AnsMode.ANS_MODE_DISABLE,
            _a[exports.AnsMode.ANS_MODE_LOW] = AnsMode.ANS_MODE_LOW,
            _a[exports.AnsMode.ANS_MODE_MEDIUM] = AnsMode.ANS_MODE_MEDIUM,
            _a[exports.AnsMode.ANS_MODE_HIGH] = AnsMode.ANS_MODE_HIGH,
            _a[exports.AnsMode.ANS_MODE_AUTOMATIC] = AnsMode.ANS_MODE_AUTOMATIC,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AnsMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AnsMode.ANS_MODE_DISABLE] = exports.AnsMode.ANS_MODE_DISABLE,
            _a[AnsMode.ANS_MODE_LOW] = exports.AnsMode.ANS_MODE_LOW,
            _a[AnsMode.ANS_MODE_MEDIUM] = exports.AnsMode.ANS_MODE_MEDIUM,
            _a[AnsMode.ANS_MODE_HIGH] = exports.AnsMode.ANS_MODE_HIGH,
            _a[AnsMode.ANS_MODE_AUTOMATIC] = exports.AnsMode.ANS_MODE_AUTOMATIC,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AnsMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AnsMode.ANS_MODE_DISABLE] = ByteRTCAnsMode.ByteRTCAnsModeDisable,
            _a[exports.AnsMode.ANS_MODE_LOW] = ByteRTCAnsMode.ByteRTCAnsModeLow,
            _a[exports.AnsMode.ANS_MODE_MEDIUM] = ByteRTCAnsMode.ByteRTCAnsModeMedium,
            _a[exports.AnsMode.ANS_MODE_HIGH] = ByteRTCAnsMode.ByteRTCAnsModeHigh,
            _a[exports.AnsMode.ANS_MODE_AUTOMATIC] = ByteRTCAnsMode.ByteRTCAnsModeAutomatic,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AnsMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAnsMode.ByteRTCAnsModeDisable] = exports.AnsMode.ANS_MODE_DISABLE,
            _a[ByteRTCAnsMode.ByteRTCAnsModeLow] = exports.AnsMode.ANS_MODE_LOW,
            _a[ByteRTCAnsMode.ByteRTCAnsModeMedium] = exports.AnsMode.ANS_MODE_MEDIUM,
            _a[ByteRTCAnsMode.ByteRTCAnsModeHigh] = exports.AnsMode.ANS_MODE_HIGH,
            _a[ByteRTCAnsMode.ByteRTCAnsModeAutomatic] = exports.AnsMode.ANS_MODE_AUTOMATIC,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AnsMode;
}());
var t_VoiceChangerType = /** @class */ (function () {
    function t_VoiceChangerType() {
    }
    t_VoiceChangerType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VoiceChangerType.VOICE_CHANGER_ORIGINAL] = VoiceChangerType.VOICE_CHANGER_ORIGINAL,
            _a[exports.VoiceChangerType.VOICE_CHANGER_GIANT] = VoiceChangerType.VOICE_CHANGER_GIANT,
            _a[exports.VoiceChangerType.VOICE_CHANGER_CHIPMUNK] = VoiceChangerType.VOICE_CHANGER_CHIPMUNK,
            _a[exports.VoiceChangerType.VOICE_CHANGER_MINIONST] = VoiceChangerType.VOICE_CHANGER_MINIONST,
            _a[exports.VoiceChangerType.VOICE_CHANGER_VIBRATO] = VoiceChangerType.VOICE_CHANGER_VIBRATO,
            _a[exports.VoiceChangerType.VOICE_CHANGER_ROBOT] = VoiceChangerType.VOICE_CHANGER_ROBOT,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VoiceChangerType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VoiceChangerType.VOICE_CHANGER_ORIGINAL] = exports.VoiceChangerType.VOICE_CHANGER_ORIGINAL,
            _a[VoiceChangerType.VOICE_CHANGER_GIANT] = exports.VoiceChangerType.VOICE_CHANGER_GIANT,
            _a[VoiceChangerType.VOICE_CHANGER_CHIPMUNK] = exports.VoiceChangerType.VOICE_CHANGER_CHIPMUNK,
            _a[VoiceChangerType.VOICE_CHANGER_MINIONST] = exports.VoiceChangerType.VOICE_CHANGER_MINIONST,
            _a[VoiceChangerType.VOICE_CHANGER_VIBRATO] = exports.VoiceChangerType.VOICE_CHANGER_VIBRATO,
            _a[VoiceChangerType.VOICE_CHANGER_ROBOT] = exports.VoiceChangerType.VOICE_CHANGER_ROBOT,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VoiceChangerType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VoiceChangerType.VOICE_CHANGER_ORIGINAL] = ByteRTCVoiceChangerType.ByteRTCVoiceChangerOriginal,
            _a[exports.VoiceChangerType.VOICE_CHANGER_GIANT] = ByteRTCVoiceChangerType.ByteRTCVoiceChangerGiant,
            _a[exports.VoiceChangerType.VOICE_CHANGER_CHIPMUNK] = ByteRTCVoiceChangerType.ByteRTCVoiceChangerChipmunk,
            _a[exports.VoiceChangerType.VOICE_CHANGER_MINIONST] = ByteRTCVoiceChangerType.ByteRTCVoiceChangerMinionst,
            _a[exports.VoiceChangerType.VOICE_CHANGER_VIBRATO] = ByteRTCVoiceChangerType.ByteRTCVoiceChangerVibrato,
            _a[exports.VoiceChangerType.VOICE_CHANGER_ROBOT] = ByteRTCVoiceChangerType.ByteRTCVoiceChangerRobot,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VoiceChangerType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVoiceChangerType.ByteRTCVoiceChangerOriginal] = exports.VoiceChangerType.VOICE_CHANGER_ORIGINAL,
            _a[ByteRTCVoiceChangerType.ByteRTCVoiceChangerGiant] = exports.VoiceChangerType.VOICE_CHANGER_GIANT,
            _a[ByteRTCVoiceChangerType.ByteRTCVoiceChangerChipmunk] = exports.VoiceChangerType.VOICE_CHANGER_CHIPMUNK,
            _a[ByteRTCVoiceChangerType.ByteRTCVoiceChangerMinionst] = exports.VoiceChangerType.VOICE_CHANGER_MINIONST,
            _a[ByteRTCVoiceChangerType.ByteRTCVoiceChangerVibrato] = exports.VoiceChangerType.VOICE_CHANGER_VIBRATO,
            _a[ByteRTCVoiceChangerType.ByteRTCVoiceChangerRobot] = exports.VoiceChangerType.VOICE_CHANGER_ROBOT,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VoiceChangerType;
}());
var t_VoiceReverbType = /** @class */ (function () {
    function t_VoiceReverbType() {
    }
    t_VoiceReverbType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VoiceReverbType.VOICE_REVERB_ORIGINAL] = VoiceReverbType.VOICE_REVERB_ORIGINAL,
            _a[exports.VoiceReverbType.VOICE_REVERB_ECHO] = VoiceReverbType.VOICE_REVERB_ECHO,
            _a[exports.VoiceReverbType.VOICE_REVERB_CONCERT] = VoiceReverbType.VOICE_REVERB_CONCERT,
            _a[exports.VoiceReverbType.VOICE_REVERB_ETHEREAL] = VoiceReverbType.VOICE_REVERB_ETHEREAL,
            _a[exports.VoiceReverbType.VOICE_REVERB_KTV] = VoiceReverbType.VOICE_REVERB_KTV,
            _a[exports.VoiceReverbType.VOICE_REVERB_STUDIO] = VoiceReverbType.VOICE_REVERB_STUDIO,
            _a[exports.VoiceReverbType.VOICE_REVERB_VIRTUAL_STEREO] = VoiceReverbType.VOICE_REVERB_VIRTUAL_STEREO,
            _a[exports.VoiceReverbType.VOICE_REVERB_SPACIOUS] = VoiceReverbType.VOICE_REVERB_SPACIOUS,
            _a[exports.VoiceReverbType.VOICE_REVERB_3D] = VoiceReverbType.VOICE_REVERB_3D,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VoiceReverbType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VoiceReverbType.VOICE_REVERB_ORIGINAL] = exports.VoiceReverbType.VOICE_REVERB_ORIGINAL,
            _a[VoiceReverbType.VOICE_REVERB_ECHO] = exports.VoiceReverbType.VOICE_REVERB_ECHO,
            _a[VoiceReverbType.VOICE_REVERB_CONCERT] = exports.VoiceReverbType.VOICE_REVERB_CONCERT,
            _a[VoiceReverbType.VOICE_REVERB_ETHEREAL] = exports.VoiceReverbType.VOICE_REVERB_ETHEREAL,
            _a[VoiceReverbType.VOICE_REVERB_KTV] = exports.VoiceReverbType.VOICE_REVERB_KTV,
            _a[VoiceReverbType.VOICE_REVERB_STUDIO] = exports.VoiceReverbType.VOICE_REVERB_STUDIO,
            _a[VoiceReverbType.VOICE_REVERB_VIRTUAL_STEREO] = exports.VoiceReverbType.VOICE_REVERB_VIRTUAL_STEREO,
            _a[VoiceReverbType.VOICE_REVERB_SPACIOUS] = exports.VoiceReverbType.VOICE_REVERB_SPACIOUS,
            _a[VoiceReverbType.VOICE_REVERB_3D] = exports.VoiceReverbType.VOICE_REVERB_3D,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VoiceReverbType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VoiceReverbType.VOICE_REVERB_ORIGINAL] = ByteRTCVoiceReverbType.ByteRTCVoiceReverbOriginal,
            _a[exports.VoiceReverbType.VOICE_REVERB_ECHO] = ByteRTCVoiceReverbType.ByteRTCVoiceReverbEcho,
            _a[exports.VoiceReverbType.VOICE_REVERB_CONCERT] = ByteRTCVoiceReverbType.ByteRTCVoiceReverbConcert,
            _a[exports.VoiceReverbType.VOICE_REVERB_ETHEREAL] = ByteRTCVoiceReverbType.ByteRTCVoiceReverbEthereal,
            _a[exports.VoiceReverbType.VOICE_REVERB_KTV] = ByteRTCVoiceReverbType.ByteRTCVoiceReverbKTV,
            _a[exports.VoiceReverbType.VOICE_REVERB_STUDIO] = ByteRTCVoiceReverbType.ByteRTCVoiceReverbStudio,
            _a[exports.VoiceReverbType.VOICE_REVERB_VIRTUAL_STEREO] = ByteRTCVoiceReverbType.ByteRTCVoiceReverbVirtualStereo,
            _a[exports.VoiceReverbType.VOICE_REVERB_SPACIOUS] = ByteRTCVoiceReverbType.ByteRTCVoiceReverbSpacious,
            _a[exports.VoiceReverbType.VOICE_REVERB_3D] = ByteRTCVoiceReverbType.ByteRTCVoiceReverb3D,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VoiceReverbType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVoiceReverbType.ByteRTCVoiceReverbOriginal] = exports.VoiceReverbType.VOICE_REVERB_ORIGINAL,
            _a[ByteRTCVoiceReverbType.ByteRTCVoiceReverbEcho] = exports.VoiceReverbType.VOICE_REVERB_ECHO,
            _a[ByteRTCVoiceReverbType.ByteRTCVoiceReverbConcert] = exports.VoiceReverbType.VOICE_REVERB_CONCERT,
            _a[ByteRTCVoiceReverbType.ByteRTCVoiceReverbEthereal] = exports.VoiceReverbType.VOICE_REVERB_ETHEREAL,
            _a[ByteRTCVoiceReverbType.ByteRTCVoiceReverbKTV] = exports.VoiceReverbType.VOICE_REVERB_KTV,
            _a[ByteRTCVoiceReverbType.ByteRTCVoiceReverbStudio] = exports.VoiceReverbType.VOICE_REVERB_STUDIO,
            _a[ByteRTCVoiceReverbType.ByteRTCVoiceReverbVirtualStereo] = exports.VoiceReverbType.VOICE_REVERB_VIRTUAL_STEREO,
            _a[ByteRTCVoiceReverbType.ByteRTCVoiceReverbSpacious] = exports.VoiceReverbType.VOICE_REVERB_SPACIOUS,
            _a[ByteRTCVoiceReverbType.ByteRTCVoiceReverb3D] = exports.VoiceReverbType.VOICE_REVERB_3D,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VoiceReverbType;
}());
var t_StreamIndex = /** @class */ (function () {
    function t_StreamIndex() {
    }
    t_StreamIndex.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.StreamIndex.STREAM_INDEX_MAIN] = StreamIndex.STREAM_INDEX_MAIN,
            _a[exports.StreamIndex.STREAM_INDEX_SCREEN] = StreamIndex.STREAM_INDEX_SCREEN,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_StreamIndex.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[StreamIndex.STREAM_INDEX_MAIN] = exports.StreamIndex.STREAM_INDEX_MAIN,
            _a[StreamIndex.STREAM_INDEX_SCREEN] = exports.StreamIndex.STREAM_INDEX_SCREEN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_StreamIndex.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.StreamIndex.STREAM_INDEX_MAIN] = ByteRTCStreamIndex.ByteRTCStreamIndexMain,
            _a[exports.StreamIndex.STREAM_INDEX_SCREEN] = ByteRTCStreamIndex.ByteRTCStreamIndexScreen,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_StreamIndex.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCStreamIndex.ByteRTCStreamIndexMain] = exports.StreamIndex.STREAM_INDEX_MAIN,
            _a[ByteRTCStreamIndex.ByteRTCStreamIndexScreen] = exports.StreamIndex.STREAM_INDEX_SCREEN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_StreamIndex;
}());
var t_RenderMode = /** @class */ (function () {
    function t_RenderMode() {
    }
    t_RenderMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RenderMode.ByteRTCRenderModeHidden] = RenderMode.ByteRTCRenderModeHidden,
            _a[exports.RenderMode.ByteRTCRenderModeFit] = RenderMode.ByteRTCRenderModeFit,
            _a[exports.RenderMode.ByteRTCRenderModeFill] = RenderMode.ByteRTCRenderModeFill,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RenderMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RenderMode.ByteRTCRenderModeHidden] = exports.RenderMode.ByteRTCRenderModeHidden,
            _a[RenderMode.ByteRTCRenderModeFit] = exports.RenderMode.ByteRTCRenderModeFit,
            _a[RenderMode.ByteRTCRenderModeFill] = exports.RenderMode.ByteRTCRenderModeFill,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RenderMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RenderMode.ByteRTCRenderModeHidden] = ByteRTCRenderMode.ByteRTCRenderModeHidden,
            _a[exports.RenderMode.ByteRTCRenderModeFit] = ByteRTCRenderMode.ByteRTCRenderModeFit,
            _a[exports.RenderMode.ByteRTCRenderModeFill] = ByteRTCRenderMode.ByteRTCRenderModeFill,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RenderMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRenderMode.ByteRTCRenderModeHidden] = exports.RenderMode.ByteRTCRenderModeHidden,
            _a[ByteRTCRenderMode.ByteRTCRenderModeFit] = exports.RenderMode.ByteRTCRenderModeFit,
            _a[ByteRTCRenderMode.ByteRTCRenderModeFill] = exports.RenderMode.ByteRTCRenderModeFill,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RenderMode;
}());
var t_VideoSuperResolutionMode = /** @class */ (function () {
    function t_VideoSuperResolutionMode() {
    }
    t_VideoSuperResolutionMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoSuperResolutionMode.VIDEO_SUPER_RESOLUTION_MODE_OFF] = VideoSuperResolutionMode.VIDEO_SUPER_RESOLUTION_MODE_OFF,
            _a[exports.VideoSuperResolutionMode.VIDEO_SUPER_RESOLUTION_MODE_ON] = VideoSuperResolutionMode.VIDEO_SUPER_RESOLUTION_MODE_ON,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoSuperResolutionMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoSuperResolutionMode.VIDEO_SUPER_RESOLUTION_MODE_OFF] = exports.VideoSuperResolutionMode.VIDEO_SUPER_RESOLUTION_MODE_OFF,
            _a[VideoSuperResolutionMode.VIDEO_SUPER_RESOLUTION_MODE_ON] = exports.VideoSuperResolutionMode.VIDEO_SUPER_RESOLUTION_MODE_ON,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoSuperResolutionMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoSuperResolutionMode.VIDEO_SUPER_RESOLUTION_MODE_OFF] = ByteRTCVideoSuperResolutionMode.ByteRTCVideoSuperResolutionModeOff,
            _a[exports.VideoSuperResolutionMode.VIDEO_SUPER_RESOLUTION_MODE_ON] = ByteRTCVideoSuperResolutionMode.ByteRTCVideoSuperResolutionModeOn,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoSuperResolutionMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoSuperResolutionMode.ByteRTCVideoSuperResolutionModeOff] = exports.VideoSuperResolutionMode.VIDEO_SUPER_RESOLUTION_MODE_OFF,
            _a[ByteRTCVideoSuperResolutionMode.ByteRTCVideoSuperResolutionModeOn] = exports.VideoSuperResolutionMode.VIDEO_SUPER_RESOLUTION_MODE_ON,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoSuperResolutionMode;
}());
var t_MirrorType = /** @class */ (function () {
    function t_MirrorType() {
    }
    t_MirrorType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MirrorType.MIRROR_TYPE_NONE] = MirrorType.MIRROR_TYPE_NONE,
            _a[exports.MirrorType.MIRROR_TYPE_RENDER] = MirrorType.MIRROR_TYPE_RENDER,
            _a[exports.MirrorType.MIRROR_TYPE_RENDER_AND_ENCODER] = MirrorType.MIRROR_TYPE_RENDER_AND_ENCODER,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MirrorType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MirrorType.MIRROR_TYPE_NONE] = exports.MirrorType.MIRROR_TYPE_NONE,
            _a[MirrorType.MIRROR_TYPE_RENDER] = exports.MirrorType.MIRROR_TYPE_RENDER,
            _a[MirrorType.MIRROR_TYPE_RENDER_AND_ENCODER] = exports.MirrorType.MIRROR_TYPE_RENDER_AND_ENCODER,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MirrorType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MirrorType.MIRROR_TYPE_NONE] = ByteRTCMirrorType.ByteRTCMirrorTypeNone,
            _a[exports.MirrorType.MIRROR_TYPE_RENDER] = ByteRTCMirrorType.ByteRTCMirrorTypeRender,
            _a[exports.MirrorType.MIRROR_TYPE_RENDER_AND_ENCODER] = ByteRTCMirrorType.ByteRTCMirrorTypeRenderAndEncoder,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MirrorType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMirrorType.ByteRTCMirrorTypeNone] = exports.MirrorType.MIRROR_TYPE_NONE,
            _a[ByteRTCMirrorType.ByteRTCMirrorTypeRender] = exports.MirrorType.MIRROR_TYPE_RENDER,
            _a[ByteRTCMirrorType.ByteRTCMirrorTypeRenderAndEncoder] = exports.MirrorType.MIRROR_TYPE_RENDER_AND_ENCODER,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MirrorType;
}());
var t_RemoteMirrorType = /** @class */ (function () {
    function t_RemoteMirrorType() {
    }
    t_RemoteMirrorType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteMirrorType.NONE] = RemoteMirrorType.NONE,
            _a[exports.RemoteMirrorType.RENDER] = RemoteMirrorType.RENDER,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteMirrorType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RemoteMirrorType.NONE] = exports.RemoteMirrorType.NONE,
            _a[RemoteMirrorType.RENDER] = exports.RemoteMirrorType.RENDER,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteMirrorType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteMirrorType.NONE] = ByteRTCRemoteMirrorType.ByteRTCRemoteMirrorTypeNone,
            _a[exports.RemoteMirrorType.RENDER] = ByteRTCRemoteMirrorType.ByteRTCRemoteMirrorTypeRender,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteMirrorType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRemoteMirrorType.ByteRTCRemoteMirrorTypeNone] = exports.RemoteMirrorType.NONE,
            _a[ByteRTCRemoteMirrorType.ByteRTCRemoteMirrorTypeRender] = exports.RemoteMirrorType.RENDER,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RemoteMirrorType;
}());
var t_VideoRotationMode = /** @class */ (function () {
    function t_VideoRotationMode() {
    }
    t_VideoRotationMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoRotationMode.FOLLOW_APP] = VideoRotationMode.FOLLOW_APP,
            _a[exports.VideoRotationMode.FOLLOW_GSENSOR] = VideoRotationMode.FOLLOW_GSENSOR,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoRotationMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoRotationMode.FOLLOW_APP] = exports.VideoRotationMode.FOLLOW_APP,
            _a[VideoRotationMode.FOLLOW_GSENSOR] = exports.VideoRotationMode.FOLLOW_GSENSOR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoRotationMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoRotationMode.FOLLOW_APP] = ByteRTCVideoRotationMode.ByteRTCVideoRotationModeFollowApp,
            _a[exports.VideoRotationMode.FOLLOW_GSENSOR] = ByteRTCVideoRotationMode.ByteRTCVideoRotationModeFollowGSensor,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoRotationMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoRotationMode.ByteRTCVideoRotationModeFollowApp] = exports.VideoRotationMode.FOLLOW_APP,
            _a[ByteRTCVideoRotationMode.ByteRTCVideoRotationModeFollowGSensor] = exports.VideoRotationMode.FOLLOW_GSENSOR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoRotationMode;
}());
var t_CameraId = /** @class */ (function () {
    function t_CameraId() {
    }
    t_CameraId.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.CameraId.CAMERA_ID_FRONT] = CameraId.CAMERA_ID_FRONT,
            _a[exports.CameraId.CAMERA_ID_BACK] = CameraId.CAMERA_ID_BACK,
            _a[exports.CameraId.CAMERA_ID_INVALID] = CameraId.CAMERA_ID_INVALID,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_CameraId.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[CameraId.CAMERA_ID_FRONT] = exports.CameraId.CAMERA_ID_FRONT,
            _a[CameraId.CAMERA_ID_BACK] = exports.CameraId.CAMERA_ID_BACK,
            _a[CameraId.CAMERA_ID_INVALID] = exports.CameraId.CAMERA_ID_INVALID,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_CameraId.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.CameraId.CAMERA_ID_FRONT] = ByteRTCCameraID.ByteRTCCameraIDFront,
            _a[exports.CameraId.CAMERA_ID_BACK] = ByteRTCCameraID.ByteRTCCameraIDBack,
            _a[exports.CameraId.CAMERA_ID_INVALID] = ByteRTCCameraID.ByteRTCCameraIDInvalid,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_CameraId.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCCameraID.ByteRTCCameraIDFront] = exports.CameraId.CAMERA_ID_FRONT,
            _a[ByteRTCCameraID.ByteRTCCameraIDBack] = exports.CameraId.CAMERA_ID_BACK,
            _a[ByteRTCCameraID.ByteRTCCameraIDInvalid] = exports.CameraId.CAMERA_ID_INVALID,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_CameraId;
}());
var t_AudioRoute = /** @class */ (function () {
    function t_AudioRoute() {
    }
    t_AudioRoute.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioRoute.AUDIO_ROUTE_DEFAULT] = AudioRoute.AUDIO_ROUTE_DEFAULT,
            _a[exports.AudioRoute.AUDIO_ROUTE_HEADSET] = AudioRoute.AUDIO_ROUTE_HEADSET,
            _a[exports.AudioRoute.AUDIO_ROUTE_EARPIECE] = AudioRoute.AUDIO_ROUTE_EARPIECE,
            _a[exports.AudioRoute.AUDIO_ROUTE_SPEAKERPHONE] = AudioRoute.AUDIO_ROUTE_SPEAKERPHONE,
            _a[exports.AudioRoute.AUDIO_ROUTE_HEADSET_BLUETOOTH] = AudioRoute.AUDIO_ROUTE_HEADSET_BLUETOOTH,
            _a[exports.AudioRoute.AUDIO_ROUTE_HEADSET_USB] = AudioRoute.AUDIO_ROUTE_HEADSET_USB,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioRoute.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioRoute.AUDIO_ROUTE_DEFAULT] = exports.AudioRoute.AUDIO_ROUTE_DEFAULT,
            _a[AudioRoute.AUDIO_ROUTE_HEADSET] = exports.AudioRoute.AUDIO_ROUTE_HEADSET,
            _a[AudioRoute.AUDIO_ROUTE_EARPIECE] = exports.AudioRoute.AUDIO_ROUTE_EARPIECE,
            _a[AudioRoute.AUDIO_ROUTE_SPEAKERPHONE] = exports.AudioRoute.AUDIO_ROUTE_SPEAKERPHONE,
            _a[AudioRoute.AUDIO_ROUTE_HEADSET_BLUETOOTH] = exports.AudioRoute.AUDIO_ROUTE_HEADSET_BLUETOOTH,
            _a[AudioRoute.AUDIO_ROUTE_HEADSET_USB] = exports.AudioRoute.AUDIO_ROUTE_HEADSET_USB,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioRoute.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioRoute.AUDIO_ROUTE_DEFAULT] = ByteRTCAudioRoute.ByteRTCAudioRouteDefault,
            _a[exports.AudioRoute.AUDIO_ROUTE_HEADSET] = ByteRTCAudioRoute.ByteRTCAudioRouteHeadset,
            _a[exports.AudioRoute.AUDIO_ROUTE_EARPIECE] = ByteRTCAudioRoute.ByteRTCAudioRouteEarpiece,
            _a[exports.AudioRoute.AUDIO_ROUTE_SPEAKERPHONE] = ByteRTCAudioRoute.ByteRTCAudioRouteSpeakerphone,
            _a[exports.AudioRoute.AUDIO_ROUTE_HEADSET_BLUETOOTH] = ByteRTCAudioRoute.ByteRTCAudioRouteHeadsetBluetooth,
            _a[exports.AudioRoute.AUDIO_ROUTE_HEADSET_USB] = ByteRTCAudioRoute.ByteRTCAudioRouteHeadsetUSB,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioRoute.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioRoute.ByteRTCAudioRouteDefault] = exports.AudioRoute.AUDIO_ROUTE_DEFAULT,
            _a[ByteRTCAudioRoute.ByteRTCAudioRouteHeadset] = exports.AudioRoute.AUDIO_ROUTE_HEADSET,
            _a[ByteRTCAudioRoute.ByteRTCAudioRouteEarpiece] = exports.AudioRoute.AUDIO_ROUTE_EARPIECE,
            _a[ByteRTCAudioRoute.ByteRTCAudioRouteSpeakerphone] = exports.AudioRoute.AUDIO_ROUTE_SPEAKERPHONE,
            _a[ByteRTCAudioRoute.ByteRTCAudioRouteHeadsetBluetooth] = exports.AudioRoute.AUDIO_ROUTE_HEADSET_BLUETOOTH,
            _a[ByteRTCAudioRoute.ByteRTCAudioRouteHeadsetUSB] = exports.AudioRoute.AUDIO_ROUTE_HEADSET_USB,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioRoute;
}());
var t_MessageConfig = /** @class */ (function () {
    function t_MessageConfig() {
    }
    t_MessageConfig.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MessageConfig.RELIABLE_ORDERED] = MessageConfig.RELIABLE_ORDERED,
            _a[exports.MessageConfig.UNRELIABLE_ORDERED] = MessageConfig.UNRELIABLE_ORDERED,
            _a[exports.MessageConfig.UNRELIABLE_UNORDERED] = MessageConfig.UNRELIABLE_UNORDERED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MessageConfig.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MessageConfig.RELIABLE_ORDERED] = exports.MessageConfig.RELIABLE_ORDERED,
            _a[MessageConfig.UNRELIABLE_ORDERED] = exports.MessageConfig.UNRELIABLE_ORDERED,
            _a[MessageConfig.UNRELIABLE_UNORDERED] = exports.MessageConfig.UNRELIABLE_UNORDERED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MessageConfig.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MessageConfig.RELIABLE_ORDERED] = ByteRTCMessageConfig.ByteRTCMessageConfigReliableOrdered,
            _a[exports.MessageConfig.UNRELIABLE_ORDERED] = ByteRTCMessageConfig.ByteRTCMessageConfigUnreliableOrdered,
            _a[exports.MessageConfig.UNRELIABLE_UNORDERED] = ByteRTCMessageConfig.ByteRTCMessageConfigUnreliableUnordered,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MessageConfig.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMessageConfig.ByteRTCMessageConfigReliableOrdered] = exports.MessageConfig.RELIABLE_ORDERED,
            _a[ByteRTCMessageConfig.ByteRTCMessageConfigUnreliableOrdered] = exports.MessageConfig.UNRELIABLE_ORDERED,
            _a[ByteRTCMessageConfig.ByteRTCMessageConfigUnreliableUnordered] = exports.MessageConfig.UNRELIABLE_UNORDERED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MessageConfig;
}());
var t_AudioFrameCallbackMethod = /** @class */ (function () {
    function t_AudioFrameCallbackMethod() {
    }
    t_AudioFrameCallbackMethod.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_RECORD] = AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_RECORD,
            _a[exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_PLAYBACK] = AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_PLAYBACK,
            _a[exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_MIXED] = AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_MIXED,
            _a[exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_REMOTE_USER] = AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_REMOTE_USER,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioFrameCallbackMethod.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_RECORD] = exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_RECORD,
            _a[AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_PLAYBACK] = exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_PLAYBACK,
            _a[AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_MIXED] = exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_MIXED,
            _a[AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_REMOTE_USER] = exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_REMOTE_USER,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioFrameCallbackMethod.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_RECORD] = ByteRTCAudioFrameCallbackMethod.ByteRTCAudioFrameCallbackRecord,
            _a[exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_PLAYBACK] = ByteRTCAudioFrameCallbackMethod.ByteRTCAudioFrameCallbackPlayback,
            _a[exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_MIXED] = ByteRTCAudioFrameCallbackMethod.ByteRTCAudioFrameCallbackMixed,
            _a[exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_REMOTE_USER] = ByteRTCAudioFrameCallbackMethod.ByteRTCAudioFrameCallbackRemoteUser,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioFrameCallbackMethod.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioFrameCallbackMethod.ByteRTCAudioFrameCallbackRecord] = exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_RECORD,
            _a[ByteRTCAudioFrameCallbackMethod.ByteRTCAudioFrameCallbackPlayback] = exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_PLAYBACK,
            _a[ByteRTCAudioFrameCallbackMethod.ByteRTCAudioFrameCallbackMixed] = exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_MIXED,
            _a[ByteRTCAudioFrameCallbackMethod.ByteRTCAudioFrameCallbackRemoteUser] = exports.AudioFrameCallbackMethod.AUDIO_FRAME_CALLBACK_REMOTE_USER,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioFrameCallbackMethod;
}());
var t_ZoomConfigType = /** @class */ (function () {
    function t_ZoomConfigType() {
    }
    t_ZoomConfigType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ZoomConfigType.ZOOM_FOCUS_OFFSET] = ZoomConfigType.ZOOM_FOCUS_OFFSET,
            _a[exports.ZoomConfigType.ZOOM_MOVE_OFFSET] = ZoomConfigType.ZOOM_MOVE_OFFSET,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ZoomConfigType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ZoomConfigType.ZOOM_FOCUS_OFFSET] = exports.ZoomConfigType.ZOOM_FOCUS_OFFSET,
            _a[ZoomConfigType.ZOOM_MOVE_OFFSET] = exports.ZoomConfigType.ZOOM_MOVE_OFFSET,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ZoomConfigType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ZoomConfigType.ByteRTCZoomConfigTypeFocusOffset] = ByteRTCZoomConfigType.ByteRTCZoomConfigTypeFocusOffset,
            _a[exports.ZoomConfigType.ByteRTCZoomConfigTypeMoveOffset] = ByteRTCZoomConfigType.ByteRTCZoomConfigTypeMoveOffset,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ZoomConfigType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCZoomConfigType.ByteRTCZoomConfigTypeFocusOffset] = exports.ZoomConfigType.ByteRTCZoomConfigTypeFocusOffset,
            _a[ByteRTCZoomConfigType.ByteRTCZoomConfigTypeMoveOffset] = exports.ZoomConfigType.ByteRTCZoomConfigTypeMoveOffset,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ZoomConfigType;
}());
var t_ZoomDirectionType = /** @class */ (function () {
    function t_ZoomDirectionType() {
    }
    t_ZoomDirectionType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ZoomDirectionType.CAMERA_MOVE_LEFT] = ZoomDirectionType.CAMERA_MOVE_LEFT,
            _a[exports.ZoomDirectionType.CAMERA_MOVE_RIGHT] = ZoomDirectionType.CAMERA_MOVE_RIGHT,
            _a[exports.ZoomDirectionType.CAMERA_MOVE_UP] = ZoomDirectionType.CAMERA_MOVE_UP,
            _a[exports.ZoomDirectionType.CAMERA_MOVE_DOWN] = ZoomDirectionType.CAMERA_MOVE_DOWN,
            _a[exports.ZoomDirectionType.CAMERA_ZOOM_OUT] = ZoomDirectionType.CAMERA_ZOOM_OUT,
            _a[exports.ZoomDirectionType.CAMERA_ZOOM_IN] = ZoomDirectionType.CAMERA_ZOOM_IN,
            _a[exports.ZoomDirectionType.CAMERA_RESET] = ZoomDirectionType.CAMERA_RESET,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ZoomDirectionType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ZoomDirectionType.CAMERA_MOVE_LEFT] = exports.ZoomDirectionType.CAMERA_MOVE_LEFT,
            _a[ZoomDirectionType.CAMERA_MOVE_RIGHT] = exports.ZoomDirectionType.CAMERA_MOVE_RIGHT,
            _a[ZoomDirectionType.CAMERA_MOVE_UP] = exports.ZoomDirectionType.CAMERA_MOVE_UP,
            _a[ZoomDirectionType.CAMERA_MOVE_DOWN] = exports.ZoomDirectionType.CAMERA_MOVE_DOWN,
            _a[ZoomDirectionType.CAMERA_ZOOM_OUT] = exports.ZoomDirectionType.CAMERA_ZOOM_OUT,
            _a[ZoomDirectionType.CAMERA_ZOOM_IN] = exports.ZoomDirectionType.CAMERA_ZOOM_IN,
            _a[ZoomDirectionType.CAMERA_RESET] = exports.ZoomDirectionType.CAMERA_RESET,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ZoomDirectionType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ZoomDirectionType.ByteRTCZoomDirectionTypeMoveLeft] = ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeMoveLeft,
            _a[exports.ZoomDirectionType.ByteRTCZoomDirectionTypeMoveRight] = ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeMoveRight,
            _a[exports.ZoomDirectionType.ByteRTCZoomDirectionTypeMoveUp] = ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeMoveUp,
            _a[exports.ZoomDirectionType.ByteRTCZoomDirectionTypeMoveDown] = ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeMoveDown,
            _a[exports.ZoomDirectionType.ByteRTCZoomDirectionTypeZoomOut] = ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeZoomOut,
            _a[exports.ZoomDirectionType.ByteRTCZoomDirectionTypeZoomIn] = ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeZoomIn,
            _a[exports.ZoomDirectionType.ByteRTCZoomDirectionTypeReset] = ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeReset,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ZoomDirectionType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeMoveLeft] = exports.ZoomDirectionType.ByteRTCZoomDirectionTypeMoveLeft,
            _a[ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeMoveRight] = exports.ZoomDirectionType.ByteRTCZoomDirectionTypeMoveRight,
            _a[ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeMoveUp] = exports.ZoomDirectionType.ByteRTCZoomDirectionTypeMoveUp,
            _a[ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeMoveDown] = exports.ZoomDirectionType.ByteRTCZoomDirectionTypeMoveDown,
            _a[ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeZoomOut] = exports.ZoomDirectionType.ByteRTCZoomDirectionTypeZoomOut,
            _a[ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeZoomIn] = exports.ZoomDirectionType.ByteRTCZoomDirectionTypeZoomIn,
            _a[ByteRTCZoomDirectionType.ByteRTCZoomDirectionTypeReset] = exports.ZoomDirectionType.ByteRTCZoomDirectionTypeReset,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ZoomDirectionType;
}());
var t_VideoSourceType = /** @class */ (function () {
    function t_VideoSourceType() {
    }
    t_VideoSourceType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoSourceType.VIDEO_SOURCE_TYPE_EXTERNAL] = VideoSourceType.VIDEO_SOURCE_TYPE_EXTERNAL,
            _a[exports.VideoSourceType.VIDEO_SOURCE_TYPE_INTERNAL] = VideoSourceType.VIDEO_SOURCE_TYPE_INTERNAL,
            _a[exports.VideoSourceType.VIDEO_SOURCE_TYPE_ENCODED_WITH_SIMULCAST] = VideoSourceType.VIDEO_SOURCE_TYPE_ENCODED_WITH_SIMULCAST,
            _a[exports.VideoSourceType.VIDEO_SOURCE_TYPE_ENCODED_WITHOUT_SIMULCAST] = VideoSourceType.VIDEO_SOURCE_TYPE_ENCODED_WITHOUT_SIMULCAST,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoSourceType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoSourceType.VIDEO_SOURCE_TYPE_EXTERNAL] = exports.VideoSourceType.VIDEO_SOURCE_TYPE_EXTERNAL,
            _a[VideoSourceType.VIDEO_SOURCE_TYPE_INTERNAL] = exports.VideoSourceType.VIDEO_SOURCE_TYPE_INTERNAL,
            _a[VideoSourceType.VIDEO_SOURCE_TYPE_ENCODED_WITH_SIMULCAST] = exports.VideoSourceType.VIDEO_SOURCE_TYPE_ENCODED_WITH_SIMULCAST,
            _a[VideoSourceType.VIDEO_SOURCE_TYPE_ENCODED_WITHOUT_SIMULCAST] = exports.VideoSourceType.VIDEO_SOURCE_TYPE_ENCODED_WITHOUT_SIMULCAST,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoSourceType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoSourceType.VIDEO_SOURCE_TYPE_EXTERNAL] = ByteRTCVideoSourceType.ByteRTCVideoSourceTypeExternal,
            _a[exports.VideoSourceType.VIDEO_SOURCE_TYPE_INTERNAL] = ByteRTCVideoSourceType.ByteRTCVideoSourceTypeInternal,
            _a[exports.VideoSourceType.VIDEO_SOURCE_TYPE_ENCODED_WITH_SIMULCAST] = ByteRTCVideoSourceType.ByteRTCVideoSourceTypeEncodedAutoSimulcast,
            _a[exports.VideoSourceType.VIDEO_SOURCE_TYPE_ENCODED_WITHOUT_SIMULCAST] = ByteRTCVideoSourceType.ByteRTCVideoSourceTypeEncodedManualSimulcast,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoSourceType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoSourceType.ByteRTCVideoSourceTypeExternal] = exports.VideoSourceType.VIDEO_SOURCE_TYPE_EXTERNAL,
            _a[ByteRTCVideoSourceType.ByteRTCVideoSourceTypeInternal] = exports.VideoSourceType.VIDEO_SOURCE_TYPE_INTERNAL,
            _a[ByteRTCVideoSourceType.ByteRTCVideoSourceTypeEncodedAutoSimulcast] = exports.VideoSourceType.VIDEO_SOURCE_TYPE_ENCODED_WITH_SIMULCAST,
            _a[ByteRTCVideoSourceType.ByteRTCVideoSourceTypeEncodedManualSimulcast] = exports.VideoSourceType.VIDEO_SOURCE_TYPE_ENCODED_WITHOUT_SIMULCAST,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoSourceType;
}());
var t_AlphaLayout = /** @class */ (function () {
    function t_AlphaLayout() {
    }
    t_AlphaLayout.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AlphaLayout.TOP] = AlphaLayout.TOP,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AlphaLayout.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AlphaLayout.TOP] = exports.AlphaLayout.TOP,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AlphaLayout.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AlphaLayout.TOP] = ByteRTCAlphaLayout.ByteRTCAlphaLayoutTop,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AlphaLayout.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAlphaLayout.ByteRTCAlphaLayoutTop] = exports.AlphaLayout.TOP,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AlphaLayout;
}());
var t_AudioSourceType = /** @class */ (function () {
    function t_AudioSourceType() {
    }
    t_AudioSourceType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioSourceType.AUDIO_SOURCE_TYPE_EXTERNAL] = AudioSourceType.AUDIO_SOURCE_TYPE_EXTERNAL,
            _a[exports.AudioSourceType.AUDIO_SOURCE_TYPE_INTERNAL] = AudioSourceType.AUDIO_SOURCE_TYPE_INTERNAL,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioSourceType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioSourceType.AUDIO_SOURCE_TYPE_EXTERNAL] = exports.AudioSourceType.AUDIO_SOURCE_TYPE_EXTERNAL,
            _a[AudioSourceType.AUDIO_SOURCE_TYPE_INTERNAL] = exports.AudioSourceType.AUDIO_SOURCE_TYPE_INTERNAL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioSourceType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioSourceType.AUDIO_SOURCE_TYPE_EXTERNAL] = ByteRTCAudioSourceType.ByteRTCAudioSourceTypeExternal,
            _a[exports.AudioSourceType.AUDIO_SOURCE_TYPE_INTERNAL] = ByteRTCAudioSourceType.ByteRTCAudioSourceTypeInternal,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioSourceType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioSourceType.ByteRTCAudioSourceTypeExternal] = exports.AudioSourceType.AUDIO_SOURCE_TYPE_EXTERNAL,
            _a[ByteRTCAudioSourceType.ByteRTCAudioSourceTypeInternal] = exports.AudioSourceType.AUDIO_SOURCE_TYPE_INTERNAL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioSourceType;
}());
var t_AudioRenderType = /** @class */ (function () {
    function t_AudioRenderType() {
    }
    t_AudioRenderType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioRenderType.AUDIO_RENDER_TYPE_EXTERNAL] = AudioRenderType.AUDIO_RENDER_TYPE_EXTERNAL,
            _a[exports.AudioRenderType.AUDIO_RENDER_TYPE_INTERNAL] = AudioRenderType.AUDIO_RENDER_TYPE_INTERNAL,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioRenderType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioRenderType.AUDIO_RENDER_TYPE_EXTERNAL] = exports.AudioRenderType.AUDIO_RENDER_TYPE_EXTERNAL,
            _a[AudioRenderType.AUDIO_RENDER_TYPE_INTERNAL] = exports.AudioRenderType.AUDIO_RENDER_TYPE_INTERNAL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioRenderType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioRenderType.AUDIO_RENDER_TYPE_EXTERNAL] = ByteRTCAudioRenderType.ByteRTCAudioRenderTypeExternal,
            _a[exports.AudioRenderType.ByteRTCAudioRenderTypeInternal] = ByteRTCAudioRenderType.ByteRTCAudioRenderTypeInternal,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioRenderType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioRenderType.ByteRTCAudioRenderTypeExternal] = exports.AudioRenderType.AUDIO_RENDER_TYPE_EXTERNAL,
            _a[ByteRTCAudioRenderType.ByteRTCAudioRenderTypeInternal] = exports.AudioRenderType.ByteRTCAudioRenderTypeInternal,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioRenderType;
}());
var t_PublishFallbackOption = /** @class */ (function () {
    function t_PublishFallbackOption() {
    }
    t_PublishFallbackOption.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PublishFallbackOption.DISABLE] = PublishFallbackOption.DISABLE,
            _a[exports.PublishFallbackOption.SIMULCAST_SMALL_VIDEO_ONLY] = PublishFallbackOption.SIMULCAST_SMALL_VIDEO_ONLY,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PublishFallbackOption.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[PublishFallbackOption.DISABLE] = exports.PublishFallbackOption.DISABLE,
            _a[PublishFallbackOption.SIMULCAST_SMALL_VIDEO_ONLY] = exports.PublishFallbackOption.SIMULCAST_SMALL_VIDEO_ONLY,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PublishFallbackOption.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PublishFallbackOption.ByteRTCPublishFallbackOptionDisabled] = ByteRTCPublishFallbackOption.ByteRTCPublishFallbackOptionDisabled,
            _a[exports.PublishFallbackOption.ByteRTCPublishFallbackOptionSimulcast] = ByteRTCPublishFallbackOption.ByteRTCPublishFallbackOptionSimulcast,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PublishFallbackOption.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCPublishFallbackOption.ByteRTCPublishFallbackOptionDisabled] = exports.PublishFallbackOption.ByteRTCPublishFallbackOptionDisabled,
            _a[ByteRTCPublishFallbackOption.ByteRTCPublishFallbackOptionSimulcast] = exports.PublishFallbackOption.ByteRTCPublishFallbackOptionSimulcast,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_PublishFallbackOption;
}());
var t_RemoteUserPriority = /** @class */ (function () {
    function t_RemoteUserPriority() {
    }
    t_RemoteUserPriority.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteUserPriority.REMOTE_USER_PRIORITY_LOW] = RemoteUserPriority.REMOTE_USER_PRIORITY_LOW,
            _a[exports.RemoteUserPriority.REMOTE_USER_PRIORITY_MEDIUM] = RemoteUserPriority.REMOTE_USER_PRIORITY_MEDIUM,
            _a[exports.RemoteUserPriority.REMOTE_USER_PRIORITY_HIGH] = RemoteUserPriority.REMOTE_USER_PRIORITY_HIGH,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteUserPriority.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RemoteUserPriority.REMOTE_USER_PRIORITY_LOW] = exports.RemoteUserPriority.REMOTE_USER_PRIORITY_LOW,
            _a[RemoteUserPriority.REMOTE_USER_PRIORITY_MEDIUM] = exports.RemoteUserPriority.REMOTE_USER_PRIORITY_MEDIUM,
            _a[RemoteUserPriority.REMOTE_USER_PRIORITY_HIGH] = exports.RemoteUserPriority.REMOTE_USER_PRIORITY_HIGH,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteUserPriority.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteUserPriority.REMOTE_USER_PRIORITY_LOW] = ByteRTCRemoteUserPriority.ByteRTCRemoteUserPriorityLow,
            _a[exports.RemoteUserPriority.REMOTE_USER_PRIORITY_MEDIUM] = ByteRTCRemoteUserPriority.ByteRTCRemoteUserPriorityMedium,
            _a[exports.RemoteUserPriority.REMOTE_USER_PRIORITY_HIGH] = ByteRTCRemoteUserPriority.ByteRTCRemoteUserPriorityHigh,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteUserPriority.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRemoteUserPriority.ByteRTCRemoteUserPriorityLow] = exports.RemoteUserPriority.REMOTE_USER_PRIORITY_LOW,
            _a[ByteRTCRemoteUserPriority.ByteRTCRemoteUserPriorityMedium] = exports.RemoteUserPriority.REMOTE_USER_PRIORITY_MEDIUM,
            _a[ByteRTCRemoteUserPriority.ByteRTCRemoteUserPriorityHigh] = exports.RemoteUserPriority.REMOTE_USER_PRIORITY_HIGH,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RemoteUserPriority;
}());
var t_SEICountPerFrame = /** @class */ (function () {
    function t_SEICountPerFrame() {
    }
    t_SEICountPerFrame.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SEICountPerFrame.SEI_COUNT_PER_FRAME_SINGLE] = SEICountPerFrame.SEI_COUNT_PER_FRAME_SINGLE,
            _a[exports.SEICountPerFrame.SEI_COUNT_PER_FRAME_MULTI] = SEICountPerFrame.SEI_COUNT_PER_FRAME_MULTI,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SEICountPerFrame.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[SEICountPerFrame.SEI_COUNT_PER_FRAME_SINGLE] = exports.SEICountPerFrame.SEI_COUNT_PER_FRAME_SINGLE,
            _a[SEICountPerFrame.SEI_COUNT_PER_FRAME_MULTI] = exports.SEICountPerFrame.SEI_COUNT_PER_FRAME_MULTI,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SEICountPerFrame.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SEICountPerFrame.SEI_COUNT_PER_FRAME_SINGLE] = ByteRTCSEICountPerFrame.ByteRTCSEICountPerFrameSingle,
            _a[exports.SEICountPerFrame.SEI_COUNT_PER_FRAME_MULTI] = ByteRTCSEICountPerFrame.ByteRTCSEICountPerFrameMulti,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SEICountPerFrame.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCSEICountPerFrame.ByteRTCSEICountPerFrameSingle] = exports.SEICountPerFrame.SEI_COUNT_PER_FRAME_SINGLE,
            _a[ByteRTCSEICountPerFrame.ByteRTCSEICountPerFrameMulti] = exports.SEICountPerFrame.SEI_COUNT_PER_FRAME_MULTI,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_SEICountPerFrame;
}());
var t_EffectBeautyMode = /** @class */ (function () {
    function t_EffectBeautyMode() {
    }
    t_EffectBeautyMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.EffectBeautyMode.WHITE] = EffectBeautyMode.WHITE,
            _a[exports.EffectBeautyMode.SMOOTH] = EffectBeautyMode.SMOOTH,
            _a[exports.EffectBeautyMode.SHARPEN] = EffectBeautyMode.SHARPEN,
            _a[exports.EffectBeautyMode.CLEAR] = EffectBeautyMode.CLEAR,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_EffectBeautyMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[EffectBeautyMode.WHITE] = exports.EffectBeautyMode.WHITE,
            _a[EffectBeautyMode.SMOOTH] = exports.EffectBeautyMode.SMOOTH,
            _a[EffectBeautyMode.SHARPEN] = exports.EffectBeautyMode.SHARPEN,
            _a[EffectBeautyMode.CLEAR] = exports.EffectBeautyMode.CLEAR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_EffectBeautyMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.EffectBeautyMode.WHITE] = ByteRTCEffectBeautyMode.ByteRTCEffectBeautyModeWhite,
            _a[exports.EffectBeautyMode.SMOOTH] = ByteRTCEffectBeautyMode.ByteRTCEffectBeautyModeSmooth,
            _a[exports.EffectBeautyMode.SHARPEN] = ByteRTCEffectBeautyMode.ByteRTCEffectBeautyModeSharpen,
            _a[exports.EffectBeautyMode.CLEAR] = ByteRTCEffectBeautyMode.ByteRTCEffectBeautyModeClear,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_EffectBeautyMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCEffectBeautyMode.ByteRTCEffectBeautyModeWhite] = exports.EffectBeautyMode.WHITE,
            _a[ByteRTCEffectBeautyMode.ByteRTCEffectBeautyModeSmooth] = exports.EffectBeautyMode.SMOOTH,
            _a[ByteRTCEffectBeautyMode.ByteRTCEffectBeautyModeSharpen] = exports.EffectBeautyMode.SHARPEN,
            _a[ByteRTCEffectBeautyMode.ByteRTCEffectBeautyModeClear] = exports.EffectBeautyMode.CLEAR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_EffectBeautyMode;
}());
var t_VideoOrientation = /** @class */ (function () {
    function t_VideoOrientation() {
    }
    t_VideoOrientation.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoOrientation.ADAPTIVE] = VideoOrientation.ADAPTIVE,
            _a[exports.VideoOrientation.PORTRAIT] = VideoOrientation.PORTRAIT,
            _a[exports.VideoOrientation.LANDSCAPE] = VideoOrientation.LANDSCAPE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoOrientation.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoOrientation.ADAPTIVE] = exports.VideoOrientation.ADAPTIVE,
            _a[VideoOrientation.PORTRAIT] = exports.VideoOrientation.PORTRAIT,
            _a[VideoOrientation.LANDSCAPE] = exports.VideoOrientation.LANDSCAPE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoOrientation.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoOrientation.ADAPTIVE] = ByteRTCVideoOrientation.ByteRTCVideoOrientationAdaptive,
            _a[exports.VideoOrientation.PORTRAIT] = ByteRTCVideoOrientation.ByteRTCVideoOrientationPortrait,
            _a[exports.VideoOrientation.LANDSCAPE] = ByteRTCVideoOrientation.ByteRTCVideoOrientationLandscape,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoOrientation.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoOrientation.ByteRTCVideoOrientationAdaptive] = exports.VideoOrientation.ADAPTIVE,
            _a[ByteRTCVideoOrientation.ByteRTCVideoOrientationPortrait] = exports.VideoOrientation.PORTRAIT,
            _a[ByteRTCVideoOrientation.ByteRTCVideoOrientationLandscape] = exports.VideoOrientation.LANDSCAPE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoOrientation;
}());
var t_RecordingType = /** @class */ (function () {
    function t_RecordingType() {
    }
    t_RecordingType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RecordingType.RECORD_AUDIO_ONLY] = RecordingType.RECORD_AUDIO_ONLY,
            _a[exports.RecordingType.RECORD_VIDEO_ONLY] = RecordingType.RECORD_VIDEO_ONLY,
            _a[exports.RecordingType.RECORD_VIDEO_AND_AUDIO] = RecordingType.RECORD_VIDEO_AND_AUDIO,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RecordingType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RecordingType.RECORD_AUDIO_ONLY] = exports.RecordingType.RECORD_AUDIO_ONLY,
            _a[RecordingType.RECORD_VIDEO_ONLY] = exports.RecordingType.RECORD_VIDEO_ONLY,
            _a[RecordingType.RECORD_VIDEO_AND_AUDIO] = exports.RecordingType.RECORD_VIDEO_AND_AUDIO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RecordingType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RecordingType.ByteRTCRecordingTypeAudioOnly] = ByteRTCRecordingType.ByteRTCRecordingTypeAudioOnly,
            _a[exports.RecordingType.ByteRTCRecordingTypeVideoOnly] = ByteRTCRecordingType.ByteRTCRecordingTypeVideoOnly,
            _a[exports.RecordingType.ByteRTCRecordingTypeVideoAndAudio] = ByteRTCRecordingType.ByteRTCRecordingTypeVideoAndAudio,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RecordingType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRecordingType.ByteRTCRecordingTypeAudioOnly] = exports.RecordingType.ByteRTCRecordingTypeAudioOnly,
            _a[ByteRTCRecordingType.ByteRTCRecordingTypeVideoOnly] = exports.RecordingType.ByteRTCRecordingTypeVideoOnly,
            _a[ByteRTCRecordingType.ByteRTCRecordingTypeVideoAndAudio] = exports.RecordingType.ByteRTCRecordingTypeVideoAndAudio,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RecordingType;
}());
var t_ScreenMediaType = /** @class */ (function () {
    function t_ScreenMediaType() {
    }
    t_ScreenMediaType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ScreenMediaType.SCREEN_MEDIA_TYPE_VIDEO_ONLY] = ScreenMediaType.SCREEN_MEDIA_TYPE_VIDEO_ONLY,
            _a[exports.ScreenMediaType.SCREEN_MEDIA_TYPE_AUDIO_ONLY] = ScreenMediaType.SCREEN_MEDIA_TYPE_AUDIO_ONLY,
            _a[exports.ScreenMediaType.SCREEN_MEDIA_TYPE_VIDEO_AND_AUDIO] = ScreenMediaType.SCREEN_MEDIA_TYPE_VIDEO_AND_AUDIO,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ScreenMediaType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ScreenMediaType.SCREEN_MEDIA_TYPE_VIDEO_ONLY] = exports.ScreenMediaType.SCREEN_MEDIA_TYPE_VIDEO_ONLY,
            _a[ScreenMediaType.SCREEN_MEDIA_TYPE_AUDIO_ONLY] = exports.ScreenMediaType.SCREEN_MEDIA_TYPE_AUDIO_ONLY,
            _a[ScreenMediaType.SCREEN_MEDIA_TYPE_VIDEO_AND_AUDIO] = exports.ScreenMediaType.SCREEN_MEDIA_TYPE_VIDEO_AND_AUDIO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ScreenMediaType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ScreenMediaType.SCREEN_MEDIA_TYPE_VIDEO_ONLY] = ByteRTCScreenMediaType.ByteRTCScreenMediaTypeVideoOnly,
            _a[exports.ScreenMediaType.SCREEN_MEDIA_TYPE_AUDIO_ONLY] = ByteRTCScreenMediaType.ByteRTCScreenMediaTypeAudioOnly,
            _a[exports.ScreenMediaType.SCREEN_MEDIA_TYPE_VIDEO_AND_AUDIO] = ByteRTCScreenMediaType.ByteRTCScreenMediaTypeVideoAndAudio,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ScreenMediaType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCScreenMediaType.ByteRTCScreenMediaTypeVideoOnly] = exports.ScreenMediaType.SCREEN_MEDIA_TYPE_VIDEO_ONLY,
            _a[ByteRTCScreenMediaType.ByteRTCScreenMediaTypeAudioOnly] = exports.ScreenMediaType.SCREEN_MEDIA_TYPE_AUDIO_ONLY,
            _a[ByteRTCScreenMediaType.ByteRTCScreenMediaTypeVideoAndAudio] = exports.ScreenMediaType.SCREEN_MEDIA_TYPE_VIDEO_AND_AUDIO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ScreenMediaType;
}());
var t_VideoDecoderConfig = /** @class */ (function () {
    function t_VideoDecoderConfig() {
    }
    t_VideoDecoderConfig.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoDecoderConfig.VIDEO_DECODER_CONFIG_RAW] = VideoDecoderConfig.VIDEO_DECODER_CONFIG_RAW,
            _a[exports.VideoDecoderConfig.VIDEO_DECODER_CONFIG_ENCODE] = VideoDecoderConfig.VIDEO_DECODER_CONFIG_ENCODE,
            _a[exports.VideoDecoderConfig.VIDEO_DECODER_CONFIG_BOTH] = VideoDecoderConfig.VIDEO_DECODER_CONFIG_BOTH,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoDecoderConfig.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoDecoderConfig.VIDEO_DECODER_CONFIG_RAW] = exports.VideoDecoderConfig.VIDEO_DECODER_CONFIG_RAW,
            _a[VideoDecoderConfig.VIDEO_DECODER_CONFIG_ENCODE] = exports.VideoDecoderConfig.VIDEO_DECODER_CONFIG_ENCODE,
            _a[VideoDecoderConfig.VIDEO_DECODER_CONFIG_BOTH] = exports.VideoDecoderConfig.VIDEO_DECODER_CONFIG_BOTH,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoDecoderConfig.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoDecoderConfig.VIDEO_DECODER_CONFIG_RAW] = ByteRTCVideoDecoderConfig.ByteRTCVideoDecoderConfigRaw,
            _a[exports.VideoDecoderConfig.VIDEO_DECODER_CONFIG_ENCODE] = ByteRTCVideoDecoderConfig.ByteRTCVideoDecoderConfigEncode,
            _a[exports.VideoDecoderConfig.VIDEO_DECODER_CONFIG_BOTH] = ByteRTCVideoDecoderConfig.ByteRTCVideoDecoderConfigBoth,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoDecoderConfig.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoDecoderConfig.ByteRTCVideoDecoderConfigRaw] = exports.VideoDecoderConfig.VIDEO_DECODER_CONFIG_RAW,
            _a[ByteRTCVideoDecoderConfig.ByteRTCVideoDecoderConfigEncode] = exports.VideoDecoderConfig.VIDEO_DECODER_CONFIG_ENCODE,
            _a[ByteRTCVideoDecoderConfig.ByteRTCVideoDecoderConfigBoth] = exports.VideoDecoderConfig.VIDEO_DECODER_CONFIG_BOTH,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoDecoderConfig;
}());
var t_EarMonitorMode = /** @class */ (function () {
    function t_EarMonitorMode() {
    }
    t_EarMonitorMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.EarMonitorMode.EAR_MONITOR_MODE_OFF] = EarMonitorMode.EAR_MONITOR_MODE_OFF,
            _a[exports.EarMonitorMode.EAR_MONITOR_MODE_ON] = EarMonitorMode.EAR_MONITOR_MODE_ON,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_EarMonitorMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[EarMonitorMode.EAR_MONITOR_MODE_OFF] = exports.EarMonitorMode.EAR_MONITOR_MODE_OFF,
            _a[EarMonitorMode.EAR_MONITOR_MODE_ON] = exports.EarMonitorMode.EAR_MONITOR_MODE_ON,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_EarMonitorMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.EarMonitorMode.EAR_MONITOR_MODE_OFF] = ByteRTCEarMonitorMode.ByteRTCEarMonitorModeOff,
            _a[exports.EarMonitorMode.EAR_MONITOR_MODE_ON] = ByteRTCEarMonitorMode.ByteRTCEarMonitorModeOn,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_EarMonitorMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCEarMonitorMode.ByteRTCEarMonitorModeOff] = exports.EarMonitorMode.EAR_MONITOR_MODE_OFF,
            _a[ByteRTCEarMonitorMode.ByteRTCEarMonitorModeOn] = exports.EarMonitorMode.EAR_MONITOR_MODE_ON,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_EarMonitorMode;
}());
var t_TorchState = /** @class */ (function () {
    function t_TorchState() {
    }
    t_TorchState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.TorchState.TORCH_STATE_OFF] = TorchState.TORCH_STATE_OFF,
            _a[exports.TorchState.TORCH_STATE_ON] = TorchState.TORCH_STATE_ON,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_TorchState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[TorchState.TORCH_STATE_OFF] = exports.TorchState.TORCH_STATE_OFF,
            _a[TorchState.TORCH_STATE_ON] = exports.TorchState.TORCH_STATE_ON,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_TorchState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.TorchState.TORCH_STATE_OFF] = ByteRTCTorchState.ByteRTCTorchStateOff,
            _a[exports.TorchState.TORCH_STATE_ON] = ByteRTCTorchState.ByteRTCTorchStateOn,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_TorchState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCTorchState.ByteRTCTorchStateOff] = exports.TorchState.TORCH_STATE_OFF,
            _a[ByteRTCTorchState.ByteRTCTorchStateOn] = exports.TorchState.TORCH_STATE_ON,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_TorchState;
}());
var t_VideoRotation = /** @class */ (function () {
    function t_VideoRotation() {
    }
    t_VideoRotation.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoRotation.VIDEO_ROTATION_0] = VideoRotation.VIDEO_ROTATION_0,
            _a[exports.VideoRotation.VIDEO_ROTATION_90] = VideoRotation.VIDEO_ROTATION_90,
            _a[exports.VideoRotation.VIDEO_ROTATION_180] = VideoRotation.VIDEO_ROTATION_180,
            _a[exports.VideoRotation.VIDEO_ROTATION_270] = VideoRotation.VIDEO_ROTATION_270,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoRotation.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoRotation.VIDEO_ROTATION_0] = exports.VideoRotation.VIDEO_ROTATION_0,
            _a[VideoRotation.VIDEO_ROTATION_90] = exports.VideoRotation.VIDEO_ROTATION_90,
            _a[VideoRotation.VIDEO_ROTATION_180] = exports.VideoRotation.VIDEO_ROTATION_180,
            _a[VideoRotation.VIDEO_ROTATION_270] = exports.VideoRotation.VIDEO_ROTATION_270,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoRotation.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoRotation.VIDEO_ROTATION_0] = ByteRTCVideoRotation.ByteRTCVideoRotation0,
            _a[exports.VideoRotation.VIDEO_ROTATION_90] = ByteRTCVideoRotation.ByteRTCVideoRotation90,
            _a[exports.VideoRotation.VIDEO_ROTATION_180] = ByteRTCVideoRotation.ByteRTCVideoRotation180,
            _a[exports.VideoRotation.VIDEO_ROTATION_270] = ByteRTCVideoRotation.ByteRTCVideoRotation270,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoRotation.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoRotation.ByteRTCVideoRotation0] = exports.VideoRotation.VIDEO_ROTATION_0,
            _a[ByteRTCVideoRotation.ByteRTCVideoRotation90] = exports.VideoRotation.VIDEO_ROTATION_90,
            _a[ByteRTCVideoRotation.ByteRTCVideoRotation180] = exports.VideoRotation.VIDEO_ROTATION_180,
            _a[ByteRTCVideoRotation.ByteRTCVideoRotation270] = exports.VideoRotation.VIDEO_ROTATION_270,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoRotation;
}());
var t_MediaStreamType = /** @class */ (function () {
    function t_MediaStreamType() {
    }
    t_MediaStreamType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaStreamType.RTC_MEDIA_STREAM_TYPE_AUDIO] = MediaStreamType.RTC_MEDIA_STREAM_TYPE_AUDIO,
            _a[exports.MediaStreamType.RTC_MEDIA_STREAM_TYPE_VIDEO] = MediaStreamType.RTC_MEDIA_STREAM_TYPE_VIDEO,
            _a[exports.MediaStreamType.RTC_MEDIA_STREAM_TYPE_BOTH] = MediaStreamType.RTC_MEDIA_STREAM_TYPE_BOTH,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaStreamType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MediaStreamType.RTC_MEDIA_STREAM_TYPE_AUDIO] = exports.MediaStreamType.RTC_MEDIA_STREAM_TYPE_AUDIO,
            _a[MediaStreamType.RTC_MEDIA_STREAM_TYPE_VIDEO] = exports.MediaStreamType.RTC_MEDIA_STREAM_TYPE_VIDEO,
            _a[MediaStreamType.RTC_MEDIA_STREAM_TYPE_BOTH] = exports.MediaStreamType.RTC_MEDIA_STREAM_TYPE_BOTH,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaStreamType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaStreamType.RTC_MEDIA_STREAM_TYPE_AUDIO] = ByteRTCMediaStreamType.ByteRTCMediaStreamTypeAudio,
            _a[exports.MediaStreamType.RTC_MEDIA_STREAM_TYPE_VIDEO] = ByteRTCMediaStreamType.ByteRTCMediaStreamTypeVideo,
            _a[exports.MediaStreamType.RTC_MEDIA_STREAM_TYPE_BOTH] = ByteRTCMediaStreamType.ByteRTCMediaStreamTypeBoth,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaStreamType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMediaStreamType.ByteRTCMediaStreamTypeAudio] = exports.MediaStreamType.RTC_MEDIA_STREAM_TYPE_AUDIO,
            _a[ByteRTCMediaStreamType.ByteRTCMediaStreamTypeVideo] = exports.MediaStreamType.RTC_MEDIA_STREAM_TYPE_VIDEO,
            _a[ByteRTCMediaStreamType.ByteRTCMediaStreamTypeBoth] = exports.MediaStreamType.RTC_MEDIA_STREAM_TYPE_BOTH,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MediaStreamType;
}());
var t_PauseResumeControlMediaType = /** @class */ (function () {
    function t_PauseResumeControlMediaType() {
    }
    t_PauseResumeControlMediaType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PauseResumeControlMediaType.AUDIO] = PauseResumeControlMediaType.AUDIO,
            _a[exports.PauseResumeControlMediaType.VIDEO] = PauseResumeControlMediaType.VIDEO,
            _a[exports.PauseResumeControlMediaType.AUDIO_AND_VIDEO] = PauseResumeControlMediaType.AUDIO_AND_VIDEO,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PauseResumeControlMediaType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[PauseResumeControlMediaType.AUDIO] = exports.PauseResumeControlMediaType.AUDIO,
            _a[PauseResumeControlMediaType.VIDEO] = exports.PauseResumeControlMediaType.VIDEO,
            _a[PauseResumeControlMediaType.AUDIO_AND_VIDEO] = exports.PauseResumeControlMediaType.AUDIO_AND_VIDEO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PauseResumeControlMediaType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PauseResumeControlMediaType.AUDIO] = ByteRTCPauseResumControlMediaType.ByteRTCControlMediaTypeAudio,
            _a[exports.PauseResumeControlMediaType.VIDEO] = ByteRTCPauseResumControlMediaType.ByteRtcControlMediaTypeVideo,
            _a[exports.PauseResumeControlMediaType.AUDIO_AND_VIDEO] = ByteRTCPauseResumControlMediaType.ByteRtcControlMediaTypeAudioAndVideo,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PauseResumeControlMediaType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCPauseResumControlMediaType.ByteRTCControlMediaTypeAudio] = exports.PauseResumeControlMediaType.AUDIO,
            _a[ByteRTCPauseResumControlMediaType.ByteRtcControlMediaTypeVideo] = exports.PauseResumeControlMediaType.VIDEO,
            _a[ByteRTCPauseResumControlMediaType.ByteRtcControlMediaTypeAudioAndVideo] = exports.PauseResumeControlMediaType.AUDIO_AND_VIDEO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_PauseResumeControlMediaType;
}());
var t_AudioSelectionPriority = /** @class */ (function () {
    function t_AudioSelectionPriority() {
    }
    t_AudioSelectionPriority.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioSelectionPriority.AUDIO_SELECTION_PRIORITY_NORMAL] = AudioSelectionPriority.AUDIO_SELECTION_PRIORITY_NORMAL,
            _a[exports.AudioSelectionPriority.AUDIO_SELECTION_PRIORITY_HIGH] = AudioSelectionPriority.AUDIO_SELECTION_PRIORITY_HIGIH,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioSelectionPriority.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioSelectionPriority.AUDIO_SELECTION_PRIORITY_NORMAL] = exports.AudioSelectionPriority.AUDIO_SELECTION_PRIORITY_NORMAL,
            _a[AudioSelectionPriority.AUDIO_SELECTION_PRIORITY_HIGIH] = exports.AudioSelectionPriority.AUDIO_SELECTION_PRIORITY_HIGH,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioSelectionPriority.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioSelectionPriority.AUDIO_SELECTION_PRIORITY_NORMAL] = ByteRTCAudioSelectionPriority.ByteRTCAudioSelectionPriorityNormal,
            _a[exports.AudioSelectionPriority.AUDIO_SELECTION_PRIORITY_HIGH] = ByteRTCAudioSelectionPriority.ByteRTCAudioSelectionPriorityHigh,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioSelectionPriority.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioSelectionPriority.ByteRTCAudioSelectionPriorityNormal] = exports.AudioSelectionPriority.AUDIO_SELECTION_PRIORITY_NORMAL,
            _a[ByteRTCAudioSelectionPriority.ByteRTCAudioSelectionPriorityHigh] = exports.AudioSelectionPriority.AUDIO_SELECTION_PRIORITY_HIGH,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioSelectionPriority;
}());
var t_DownloadLyricType = /** @class */ (function () {
    function t_DownloadLyricType() {
    }
    t_DownloadLyricType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.DownloadLyricType.KRC] = DownloadLyricType.KRC,
            _a[exports.DownloadLyricType.LRC] = DownloadLyricType.LRC,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_DownloadLyricType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[DownloadLyricType.KRC] = exports.DownloadLyricType.KRC,
            _a[DownloadLyricType.LRC] = exports.DownloadLyricType.LRC,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_DownloadLyricType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.DownloadLyricType.KRC] = ByteRTCDownloadLyricType.ByteRTCDownloadLyricTypeKRC,
            _a[exports.DownloadLyricType.LRC] = ByteRTCDownloadLyricType.ByteRTCDownloadLyricTypeLRC,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_DownloadLyricType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCDownloadLyricType.ByteRTCDownloadLyricTypeKRC] = exports.DownloadLyricType.KRC,
            _a[ByteRTCDownloadLyricType.ByteRTCDownloadLyricTypeLRC] = exports.DownloadLyricType.LRC,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_DownloadLyricType;
}());
var t_AttenuationType = /** @class */ (function () {
    function t_AttenuationType() {
    }
    t_AttenuationType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AttenuationType.ATTENUATION_TYPE_NONE] = AttenuationType.ATTENUATION_TYPE_NONE,
            _a[exports.AttenuationType.ATTENUATION_TYPE_LINEAR] = AttenuationType.ATTENUATION_TYPE_LINEAR,
            _a[exports.AttenuationType.ATTENUATION_TYPE_EXPONENTIAL] = AttenuationType.ATTENUATION_TYPE_EXPONENTIAL,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AttenuationType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AttenuationType.ATTENUATION_TYPE_NONE] = exports.AttenuationType.ATTENUATION_TYPE_NONE,
            _a[AttenuationType.ATTENUATION_TYPE_LINEAR] = exports.AttenuationType.ATTENUATION_TYPE_LINEAR,
            _a[AttenuationType.ATTENUATION_TYPE_EXPONENTIAL] = exports.AttenuationType.ATTENUATION_TYPE_EXPONENTIAL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AttenuationType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AttenuationType.ATTENUATION_TYPE_NONE] = ByteRTCAttenuationType.ByteRTCAttenuationTypeNone,
            _a[exports.AttenuationType.ATTENUATION_TYPE_LINEAR] = ByteRTCAttenuationType.ByteRTCAttenuationTypeLinear,
            _a[exports.AttenuationType.ATTENUATION_TYPE_EXPONENTIAL] = ByteRTCAttenuationType.ByteRTCAttenuationTypeExponential,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AttenuationType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAttenuationType.ByteRTCAttenuationTypeNone] = exports.AttenuationType.ATTENUATION_TYPE_NONE,
            _a[ByteRTCAttenuationType.ByteRTCAttenuationTypeLinear] = exports.AttenuationType.ATTENUATION_TYPE_LINEAR,
            _a[ByteRTCAttenuationType.ByteRTCAttenuationTypeExponential] = exports.AttenuationType.ATTENUATION_TYPE_EXPONENTIAL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AttenuationType;
}());
var t_AudioMixingType = /** @class */ (function () {
    function t_AudioMixingType() {
    }
    t_AudioMixingType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT] = AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT,
            _a[exports.AudioMixingType.AUDIO_MIXING_TYPE_PUBLISH] = AudioMixingType.AUDIO_MIXING_TYPE_PUBLISH,
            _a[exports.AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT_AND_PUBLISH] = AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT_AND_PUBLISH,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioMixingType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT] = exports.AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT,
            _a[AudioMixingType.AUDIO_MIXING_TYPE_PUBLISH] = exports.AudioMixingType.AUDIO_MIXING_TYPE_PUBLISH,
            _a[AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT_AND_PUBLISH] = exports.AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT_AND_PUBLISH,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioMixingType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT] = ByteRTCAudioMixingType.ByteRTCAudioMixingTypePlayout,
            _a[exports.AudioMixingType.AUDIO_MIXING_TYPE_PUBLISH] = ByteRTCAudioMixingType.ByteRTCAudioMixingTypePublish,
            _a[exports.AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT_AND_PUBLISH] = ByteRTCAudioMixingType.ByteRTCAudioMixingTypePlayoutAndPublish,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioMixingType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioMixingType.ByteRTCAudioMixingTypePlayout] = exports.AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT,
            _a[ByteRTCAudioMixingType.ByteRTCAudioMixingTypePublish] = exports.AudioMixingType.AUDIO_MIXING_TYPE_PUBLISH,
            _a[ByteRTCAudioMixingType.ByteRTCAudioMixingTypePlayoutAndPublish] = exports.AudioMixingType.AUDIO_MIXING_TYPE_PLAYOUT_AND_PUBLISH,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioMixingType;
}());
var t_AudioMixingDualMonoMode = /** @class */ (function () {
    function t_AudioMixingDualMonoMode() {
    }
    t_AudioMixingDualMonoMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_AUTO] = AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_AUTO,
            _a[exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_L] = AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_L,
            _a[exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_R] = AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_R,
            _a[exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_MIX] = AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_MIX,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioMixingDualMonoMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_AUTO] = exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_AUTO,
            _a[AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_L] = exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_L,
            _a[AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_R] = exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_R,
            _a[AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_MIX] = exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_MIX,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioMixingDualMonoMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_AUTO] = ByteRTCAudioMixingDualMonoMode.ByteRTCAudioMixingDualMonoModeAuto,
            _a[exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_L] = ByteRTCAudioMixingDualMonoMode.ByteRTCAudioMixingDualMonoModeL,
            _a[exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_R] = ByteRTCAudioMixingDualMonoMode.ByteRTCAudioMixingDualMonoModeR,
            _a[exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_MIX] = ByteRTCAudioMixingDualMonoMode.ByteRTCAudioMixingDualMonoModeMix,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioMixingDualMonoMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioMixingDualMonoMode.ByteRTCAudioMixingDualMonoModeAuto] = exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_AUTO,
            _a[ByteRTCAudioMixingDualMonoMode.ByteRTCAudioMixingDualMonoModeL] = exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_L,
            _a[ByteRTCAudioMixingDualMonoMode.ByteRTCAudioMixingDualMonoModeR] = exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_R,
            _a[ByteRTCAudioMixingDualMonoMode.ByteRTCAudioMixingDualMonoModeMix] = exports.AudioMixingDualMonoMode.AUDIO_MIXING_DUAL_MONO_MODE_MIX,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioMixingDualMonoMode;
}());
var t_RTCNetworkType = /** @class */ (function () {
    function t_RTCNetworkType() {
    }
    t_RTCNetworkType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCNetworkType.UNKNOWN] = NetworkType.UNKNOWN,
            _a[exports.RTCNetworkType.LAN] = NetworkType.MOBILE,
            _a[exports.RTCNetworkType.MOBILE_2G] = NetworkType.MOBILE_2G,
            _a[exports.RTCNetworkType.MOBILE_3G] = NetworkType.MOBILE_3G,
            _a[exports.RTCNetworkType.WIFI] = NetworkType.WIFI,
            _a[exports.RTCNetworkType.MOBILE_4G] = NetworkType.MOBILE_4G,
            _a[exports.RTCNetworkType.MOBILE_5G] = NetworkType.MOBILE_5G,
            _a[exports.RTCNetworkType.NONE] = NetworkType.NONE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCNetworkType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[NetworkType.UNKNOWN] = exports.RTCNetworkType.UNKNOWN,
            _a[NetworkType.MOBILE] = exports.RTCNetworkType.LAN,
            _a[NetworkType.MOBILE_2G] = exports.RTCNetworkType.MOBILE_2G,
            _a[NetworkType.MOBILE_3G] = exports.RTCNetworkType.MOBILE_3G,
            _a[NetworkType.WIFI] = exports.RTCNetworkType.WIFI,
            _a[NetworkType.MOBILE_4G] = exports.RTCNetworkType.MOBILE_4G,
            _a[NetworkType.MOBILE_5G] = exports.RTCNetworkType.MOBILE_5G,
            _a[NetworkType.NONE] = exports.RTCNetworkType.NONE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCNetworkType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCNetworkType.UNKNOWN] = ByteRTCNetworkType.ByteRTCNetworkTypeUnknown,
            _a[exports.RTCNetworkType.LAN] = ByteRTCNetworkType.ByteRTCNetworkTypeLAN,
            _a[exports.RTCNetworkType.MOBILE_2G] = ByteRTCNetworkType.ByteRTCNetworkTypeMobile2G,
            _a[exports.RTCNetworkType.MOBILE_3G] = ByteRTCNetworkType.ByteRTCNetworkTypeMobile3G,
            _a[exports.RTCNetworkType.WIFI] = ByteRTCNetworkType.ByteRTCNetworkTypeWIFI,
            _a[exports.RTCNetworkType.MOBILE_4G] = ByteRTCNetworkType.ByteRTCNetworkTypeMobile4G,
            _a[exports.RTCNetworkType.MOBILE_5G] = ByteRTCNetworkType.ByteRTCNetworkTypeMobile5G,
            _a[exports.RTCNetworkType.ByteRTCNetworkTypeDisconnected] = ByteRTCNetworkType.ByteRTCNetworkTypeDisconnected,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCNetworkType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCNetworkType.ByteRTCNetworkTypeUnknown] = exports.RTCNetworkType.UNKNOWN,
            _a[ByteRTCNetworkType.ByteRTCNetworkTypeLAN] = exports.RTCNetworkType.LAN,
            _a[ByteRTCNetworkType.ByteRTCNetworkTypeMobile2G] = exports.RTCNetworkType.MOBILE_2G,
            _a[ByteRTCNetworkType.ByteRTCNetworkTypeMobile3G] = exports.RTCNetworkType.MOBILE_3G,
            _a[ByteRTCNetworkType.ByteRTCNetworkTypeWIFI] = exports.RTCNetworkType.WIFI,
            _a[ByteRTCNetworkType.ByteRTCNetworkTypeMobile4G] = exports.RTCNetworkType.MOBILE_4G,
            _a[ByteRTCNetworkType.ByteRTCNetworkTypeMobile5G] = exports.RTCNetworkType.MOBILE_5G,
            _a[ByteRTCNetworkType.ByteRTCNetworkTypeDisconnected] = exports.RTCNetworkType.ByteRTCNetworkTypeDisconnected,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RTCNetworkType;
}());
var t_RTCUserOfflineReason = /** @class */ (function () {
    function t_RTCUserOfflineReason() {
    }
    t_RTCUserOfflineReason.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonQuit] = UserOfflineReason.ByteRTCUserOfflineReasonQuit,
            _a[exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonDropped] = UserOfflineReason.ByteRTCUserOfflineReasonDropped,
            _a[exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonSwitchToInvisible] = UserOfflineReason.ByteRTCUserOfflineReasonSwitchToInvisible,
            _a[exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonKickedByAdmin] = UserOfflineReason.ByteRTCUserOfflineReasonKickedByAdmin,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCUserOfflineReason.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[UserOfflineReason.ByteRTCUserOfflineReasonQuit] = exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonQuit,
            _a[UserOfflineReason.ByteRTCUserOfflineReasonDropped] = exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonDropped,
            _a[UserOfflineReason.ByteRTCUserOfflineReasonSwitchToInvisible] = exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonSwitchToInvisible,
            _a[UserOfflineReason.ByteRTCUserOfflineReasonKickedByAdmin] = exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonKickedByAdmin,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCUserOfflineReason.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonQuit] = ByteRTCUserOfflineReason.ByteRTCUserOfflineReasonQuit,
            _a[exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonDropped] = ByteRTCUserOfflineReason.ByteRTCUserOfflineReasonDropped,
            _a[exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonSwitchToInvisible] = ByteRTCUserOfflineReason.ByteRTCUserOfflineReasonSwitchToInvisible,
            _a[exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonKickedByAdmin] = ByteRTCUserOfflineReason.ByteRTCUserOfflineReasonKickedByAdmin,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCUserOfflineReason.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCUserOfflineReason.ByteRTCUserOfflineReasonQuit] = exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonQuit,
            _a[ByteRTCUserOfflineReason.ByteRTCUserOfflineReasonDropped] = exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonDropped,
            _a[ByteRTCUserOfflineReason.ByteRTCUserOfflineReasonSwitchToInvisible] = exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonSwitchToInvisible,
            _a[ByteRTCUserOfflineReason.ByteRTCUserOfflineReasonKickedByAdmin] = exports.RTCUserOfflineReason.ByteRTCUserOfflineReasonKickedByAdmin,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RTCUserOfflineReason;
}());
var t_RTCStreamSinglePushEvent = /** @class */ (function () {
    function t_RTCStreamSinglePushEvent() {
    }
    t_RTCStreamSinglePushEvent.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_START] = ByteRTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_START,
            _a[exports.RTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_SUCCESS] = ByteRTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_SUCCESS,
            _a[exports.RTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_FAILED] = ByteRTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_FAILED,
            _a[exports.RTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_STOP] = ByteRTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_STOP,
            _a[exports.RTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_TIMEOUT] = ByteRTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_TIMEOUT,
            _a[exports.RTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_PARAM_ERROR] = ByteRTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_PARAM_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCStreamSinglePushEvent.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_START] = exports.RTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_START,
            _a[ByteRTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_SUCCESS] = exports.RTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_SUCCESS,
            _a[ByteRTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_FAILED] = exports.RTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_FAILED,
            _a[ByteRTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_STOP] = exports.RTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_STOP,
            _a[ByteRTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_TIMEOUT] = exports.RTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_TIMEOUT,
            _a[ByteRTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_PARAM_ERROR] = exports.RTCStreamSinglePushEvent.SINGLE_STREAM_PUSH_PARAM_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCStreamSinglePushEvent.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCStreamSinglePushEvent.ByteRTCSingleStreamPushEventStart] = ByteRTCSingleStreamPushEvent.ByteRTCSingleStreamPushEventStart,
            _a[exports.RTCStreamSinglePushEvent.ByteRTCSingleStreamPushEventStartSuccess] = ByteRTCSingleStreamPushEvent.ByteRTCSingleStreamPushEventStartSuccess,
            _a[exports.RTCStreamSinglePushEvent.ByteRTCSingleStreamPushEventStartFailed] = ByteRTCSingleStreamPushEvent.ByteRTCSingleStreamPushEventStartFailed,
            _a[exports.RTCStreamSinglePushEvent.ByteRTCSingleStreamPushEventStop] = ByteRTCSingleStreamPushEvent.ByteRTCSingleStreamPushEventStop,
            _a[exports.RTCStreamSinglePushEvent.ByteRTCSingleStreamPushEventTimeout] = ByteRTCSingleStreamPushEvent.ByteRTCSingleStreamPushEventTimeout,
            _a[exports.RTCStreamSinglePushEvent.ByteRTCSingleStreamPushEventParamError] = ByteRTCSingleStreamPushEvent.ByteRTCSingleStreamPushEventParamError,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCStreamSinglePushEvent.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCSingleStreamPushEvent.ByteRTCSingleStreamPushEventStart] = exports.RTCStreamSinglePushEvent.ByteRTCSingleStreamPushEventStart,
            _a[ByteRTCSingleStreamPushEvent.ByteRTCSingleStreamPushEventStartSuccess] = exports.RTCStreamSinglePushEvent.ByteRTCSingleStreamPushEventStartSuccess,
            _a[ByteRTCSingleStreamPushEvent.ByteRTCSingleStreamPushEventStartFailed] = exports.RTCStreamSinglePushEvent.ByteRTCSingleStreamPushEventStartFailed,
            _a[ByteRTCSingleStreamPushEvent.ByteRTCSingleStreamPushEventStop] = exports.RTCStreamSinglePushEvent.ByteRTCSingleStreamPushEventStop,
            _a[ByteRTCSingleStreamPushEvent.ByteRTCSingleStreamPushEventTimeout] = exports.RTCStreamSinglePushEvent.ByteRTCSingleStreamPushEventTimeout,
            _a[ByteRTCSingleStreamPushEvent.ByteRTCSingleStreamPushEventParamError] = exports.RTCStreamSinglePushEvent.ByteRTCSingleStreamPushEventParamError,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RTCStreamSinglePushEvent;
}());
var t_RTCStreamMixingErrorCode = /** @class */ (function () {
    function t_RTCStreamMixingErrorCode() {
    }
    t_RTCStreamMixingErrorCode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_OK] = ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_OK,
            _a[exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_BASE] = ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_BASE,
            _a[exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_INVALID_PARAM] = ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_INVALID_PARAM,
            _a[exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_INVALID_STATE] = ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_INVALID_STATE,
            _a[exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_INVALID_OPERATOR] = ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_INVALID_OPERATOR,
            _a[exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_TIMEOUT] = ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_TIMEOUT,
            _a[exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_INVALID_PARAM_BY_SERVER] = ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_INVALID_PARAM_BY_SERVER,
            _a[exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_SUB_TIMEOUT_BY_SERVER] = ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_SUB_TIMEOUT_BY_SERVER,
            _a[exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_INVALID_STATE_BY_SERVER] = ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_INVALID_STATE_BY_SERVER,
            _a[exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_AUTHENTICATION_BY_CDN] = ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_AUTHENTICATION_BY_CDN,
            _a[exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_TIMEOUT_BY_SIGNALING] = ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_TIMEOUT_BY_SIGNALING,
            _a[exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_MIX_IMAGE_FAIL] = ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_MIX_IMAGE_FAIL,
            _a[exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_UNKNOW_ERROR_BY_SERVER] = ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_UNKNOW_ERROR_BY_SERVER,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCStreamMixingErrorCode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_OK] = exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_OK,
            _a[ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_BASE] = exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_BASE,
            _a[ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_INVALID_PARAM] = exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_INVALID_PARAM,
            _a[ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_INVALID_STATE] = exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_INVALID_STATE,
            _a[ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_INVALID_OPERATOR] = exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_INVALID_OPERATOR,
            _a[ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_TIMEOUT] = exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_TIMEOUT,
            _a[ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_INVALID_PARAM_BY_SERVER] = exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_INVALID_PARAM_BY_SERVER,
            _a[ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_SUB_TIMEOUT_BY_SERVER] = exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_SUB_TIMEOUT_BY_SERVER,
            _a[ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_INVALID_STATE_BY_SERVER] = exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_INVALID_STATE_BY_SERVER,
            _a[ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_AUTHENTICATION_BY_CDN] = exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_AUTHENTICATION_BY_CDN,
            _a[ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_TIMEOUT_BY_SIGNALING] = exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_TIMEOUT_BY_SIGNALING,
            _a[ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_MIX_IMAGE_FAIL] = exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_MIX_IMAGE_FAIL,
            _a[ByteRTCTranscoderErrorCode.TRANSCODER_ERROR_UNKNOW_ERROR_BY_SERVER] = exports.RTCStreamMixingErrorCode.TRANSCODER_ERROR_UNKNOW_ERROR_BY_SERVER,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCStreamMixingErrorCode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeOK] = ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeOK,
            _a[exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeBase] = ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeBase,
            _a[exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidParam] = ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidParam,
            _a[exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidState] = ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidState,
            _a[exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidOperator] = ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidOperator,
            _a[exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeTimeOut] = ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeTimeOut,
            _a[exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidParamByServer] = ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidParamByServer,
            _a[exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeSubTimeoutByServer] = ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeSubTimeoutByServer,
            _a[exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidStateByServer] = ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidStateByServer,
            _a[exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeAuthenticationByCDN] = ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeAuthenticationByCDN,
            _a[exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeTimeoutBySignaling] = ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeTimeoutBySignaling,
            _a[exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeMixImageFail] = ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeMixImageFail,
            _a[exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeUnKnownErrorByServer] = ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeUnKnownErrorByServer,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCStreamMixingErrorCode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeOK] = exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeOK,
            _a[ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeBase] = exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeBase,
            _a[ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidParam] = exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidParam,
            _a[ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidState] = exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidState,
            _a[ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidOperator] = exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidOperator,
            _a[ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeTimeOut] = exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeTimeOut,
            _a[ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidParamByServer] = exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidParamByServer,
            _a[ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeSubTimeoutByServer] = exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeSubTimeoutByServer,
            _a[ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidStateByServer] = exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeInvalidStateByServer,
            _a[ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeAuthenticationByCDN] = exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeAuthenticationByCDN,
            _a[ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeTimeoutBySignaling] = exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeTimeoutBySignaling,
            _a[ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeMixImageFail] = exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeMixImageFail,
            _a[ByteRTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeUnKnownErrorByServer] = exports.RTCStreamMixingErrorCode.ByteRTCStreamMixingErrorCodeUnKnownErrorByServer,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RTCStreamMixingErrorCode;
}());
var t_RTCScreenVideoEncoderPreference = /** @class */ (function () {
    function t_RTCScreenVideoEncoderPreference() {
    }
    t_RTCScreenVideoEncoderPreference.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCScreenVideoEncoderPreference.MAINTAIN_FRAMERATE] = EncoderPreference.MAINTAIN_FRAMERATE,
            _a[exports.RTCScreenVideoEncoderPreference.MAINTAIN_QUALITY] = EncoderPreference.MAINTAIN_QUALITY,
            _a[exports.RTCScreenVideoEncoderPreference.DISABLED] = EncoderPreference.DISABLED,
            _a[exports.RTCScreenVideoEncoderPreference.BALANCE] = EncoderPreference.BALANCE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCScreenVideoEncoderPreference.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[EncoderPreference.MAINTAIN_FRAMERATE] = exports.RTCScreenVideoEncoderPreference.MAINTAIN_FRAMERATE,
            _a[EncoderPreference.MAINTAIN_QUALITY] = exports.RTCScreenVideoEncoderPreference.MAINTAIN_QUALITY,
            _a[EncoderPreference.DISABLED] = exports.RTCScreenVideoEncoderPreference.DISABLED,
            _a[EncoderPreference.BALANCE] = exports.RTCScreenVideoEncoderPreference.BALANCE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCScreenVideoEncoderPreference.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCScreenVideoEncoderPreference.MAINTAIN_FRAMERATE] = ByteRTCScreenVideoEncoderPreference.ByteRTCScreenVideoEncodePreferenceFramerate,
            _a[exports.RTCScreenVideoEncoderPreference.MAINTAIN_QUALITY] = ByteRTCScreenVideoEncoderPreference.ByteRTCScreenVideoEncodePreferenceQuality,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCScreenVideoEncoderPreference.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCScreenVideoEncoderPreference.ByteRTCScreenVideoEncodePreferenceFramerate] = exports.RTCScreenVideoEncoderPreference.MAINTAIN_FRAMERATE,
            _a[ByteRTCScreenVideoEncoderPreference.ByteRTCScreenVideoEncodePreferenceQuality] = exports.RTCScreenVideoEncoderPreference.MAINTAIN_QUALITY,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RTCScreenVideoEncoderPreference;
}());
var t_RTCVideoEncoderPreference = /** @class */ (function () {
    function t_RTCVideoEncoderPreference() {
    }
    t_RTCVideoEncoderPreference.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCVideoEncoderPreference.DISABLED] = EncoderPreference.DISABLED,
            _a[exports.RTCVideoEncoderPreference.MAINTAIN_FRAMERATE] = EncoderPreference.MAINTAIN_FRAMERATE,
            _a[exports.RTCVideoEncoderPreference.MAINTAIN_QUALITY] = EncoderPreference.MAINTAIN_QUALITY,
            _a[exports.RTCVideoEncoderPreference.BALANCE] = EncoderPreference.BALANCE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCVideoEncoderPreference.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[EncoderPreference.DISABLED] = exports.RTCVideoEncoderPreference.DISABLED,
            _a[EncoderPreference.MAINTAIN_FRAMERATE] = exports.RTCVideoEncoderPreference.MAINTAIN_FRAMERATE,
            _a[EncoderPreference.MAINTAIN_QUALITY] = exports.RTCVideoEncoderPreference.MAINTAIN_QUALITY,
            _a[EncoderPreference.BALANCE] = exports.RTCVideoEncoderPreference.BALANCE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCVideoEncoderPreference.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCVideoEncoderPreference.DISABLED] = ByteRTCVideoEncoderPreference.ByteRTCVideoEncoderPreferenceDisabled,
            _a[exports.RTCVideoEncoderPreference.MAINTAIN_FRAMERATE] = ByteRTCVideoEncoderPreference.ByteRTCVideoEncoderPreferenceMaintainFramerate,
            _a[exports.RTCVideoEncoderPreference.MAINTAIN_QUALITY] = ByteRTCVideoEncoderPreference.ByteRTCVideoEncoderPreferenceMaintainQuality,
            _a[exports.RTCVideoEncoderPreference.BALANCE] = ByteRTCVideoEncoderPreference.ByteRTCVideoEncoderPreferenceBalance,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCVideoEncoderPreference.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoEncoderPreference.ByteRTCVideoEncoderPreferenceDisabled] = exports.RTCVideoEncoderPreference.DISABLED,
            _a[ByteRTCVideoEncoderPreference.ByteRTCVideoEncoderPreferenceMaintainFramerate] = exports.RTCVideoEncoderPreference.MAINTAIN_FRAMERATE,
            _a[ByteRTCVideoEncoderPreference.ByteRTCVideoEncoderPreferenceMaintainQuality] = exports.RTCVideoEncoderPreference.MAINTAIN_QUALITY,
            _a[ByteRTCVideoEncoderPreference.ByteRTCVideoEncoderPreferenceBalance] = exports.RTCVideoEncoderPreference.BALANCE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RTCVideoEncoderPreference;
}());
var t_MixedStreamAlternateImageFillMode = /** @class */ (function () {
    function t_MixedStreamAlternateImageFillMode() {
    }
    t_MixedStreamAlternateImageFillMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamAlternateImageFillMode.FIT] = MixedStreamAlternateImageFillMode.FIT,
            _a[exports.MixedStreamAlternateImageFillMode.FILL] = MixedStreamAlternateImageFillMode.FILL,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamAlternateImageFillMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MixedStreamAlternateImageFillMode.FIT] = exports.MixedStreamAlternateImageFillMode.FIT,
            _a[MixedStreamAlternateImageFillMode.FILL] = exports.MixedStreamAlternateImageFillMode.FILL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamAlternateImageFillMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamAlternateImageFillMode.FIT] = ByteRTCMixedStreamAlternateImageFillMode.ByteRTCMixedStreamAlternateImageFillModeFit,
            _a[exports.MixedStreamAlternateImageFillMode.FILL] = ByteRTCMixedStreamAlternateImageFillMode.ByteRTCMixedStreamAlternateImageFillModeFill,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamAlternateImageFillMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMixedStreamAlternateImageFillMode.ByteRTCMixedStreamAlternateImageFillModeFit] = exports.MixedStreamAlternateImageFillMode.FIT,
            _a[ByteRTCMixedStreamAlternateImageFillMode.ByteRTCMixedStreamAlternateImageFillModeFill] = exports.MixedStreamAlternateImageFillMode.FILL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MixedStreamAlternateImageFillMode;
}());
var t_MediaDeviceType = /** @class */ (function () {
    function t_MediaDeviceType() {
    }
    t_MediaDeviceType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaDeviceType.MEDIA_DEVICE_TYPE_AUDIO_UNKNOWN] = MediaDeviceType.MEDIA_DEVICE_TYPE_AUDIO_UNKNOWN,
            _a[exports.MediaDeviceType.MEDIA_DEVICE_TYPE_AUDIO_RENDER_DEVICE] = MediaDeviceType.MEDIA_DEVICE_TYPE_AUDIO_RENDER_DEVICE,
            _a[exports.MediaDeviceType.MEDIA_DEVICE_TYPE_AUDIO_CAPTURE_DEVICE] = MediaDeviceType.MEDIA_DEVICE_TYPE_AUDIO_CAPTURE_DEVICE,
            _a[exports.MediaDeviceType.MEDIA_DEVICE_TYPE_VIDEO_CAPTURE_DEVICE] = MediaDeviceType.MEDIA_DEVICE_TYPE_VIDEO_CAPTURE_DEVICE,
            _a[exports.MediaDeviceType.MEDIA_DEVICE_TYPE_SCREEN_VIDEO_CAPTURE_DEVICE] = MediaDeviceType.MEDIA_DEVICE_TYPE_SCREEN_VIDEO_CAPTURE_DEVICE,
            _a[exports.MediaDeviceType.MEDIA_DEVICE_TYPE_SCREEN_AUDIO_CAPTURE_DEVICE] = MediaDeviceType.MEDIA_DEVICE_TYPE_SCREEN_AUDIO_CAPTURE_DEVICE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaDeviceType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MediaDeviceType.MEDIA_DEVICE_TYPE_AUDIO_UNKNOWN] = exports.MediaDeviceType.MEDIA_DEVICE_TYPE_AUDIO_UNKNOWN,
            _a[MediaDeviceType.MEDIA_DEVICE_TYPE_AUDIO_RENDER_DEVICE] = exports.MediaDeviceType.MEDIA_DEVICE_TYPE_AUDIO_RENDER_DEVICE,
            _a[MediaDeviceType.MEDIA_DEVICE_TYPE_AUDIO_CAPTURE_DEVICE] = exports.MediaDeviceType.MEDIA_DEVICE_TYPE_AUDIO_CAPTURE_DEVICE,
            _a[MediaDeviceType.MEDIA_DEVICE_TYPE_VIDEO_CAPTURE_DEVICE] = exports.MediaDeviceType.MEDIA_DEVICE_TYPE_VIDEO_CAPTURE_DEVICE,
            _a[MediaDeviceType.MEDIA_DEVICE_TYPE_SCREEN_VIDEO_CAPTURE_DEVICE] = exports.MediaDeviceType.MEDIA_DEVICE_TYPE_SCREEN_VIDEO_CAPTURE_DEVICE,
            _a[MediaDeviceType.MEDIA_DEVICE_TYPE_SCREEN_AUDIO_CAPTURE_DEVICE] = exports.MediaDeviceType.MEDIA_DEVICE_TYPE_SCREEN_AUDIO_CAPTURE_DEVICE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaDeviceType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaDeviceType.ByteRTCMediaDeviceTypeAudioUnknown] = ByteRTCMediaDeviceType.ByteRTCMediaDeviceTypeAudioUnknown,
            _a[exports.MediaDeviceType.ByteRTCMediaDeviceTypeAudioRenderDevice] = ByteRTCMediaDeviceType.ByteRTCMediaDeviceTypeAudioRenderDevice,
            _a[exports.MediaDeviceType.ByteRTCMediaDeviceTypeAudioCaptureDevice] = ByteRTCMediaDeviceType.ByteRTCMediaDeviceTypeAudioCaptureDevice,
            _a[exports.MediaDeviceType.ByteRTCMediaDeviceTypeVideoCaptureDevice] = ByteRTCMediaDeviceType.ByteRTCMediaDeviceTypeVideoCaptureDevice,
            _a[exports.MediaDeviceType.ByteRTCMediaDeviceTypeScreenVideoCaptureDevice] = ByteRTCMediaDeviceType.ByteRTCMediaDeviceTypeScreenVideoCaptureDevice,
            _a[exports.MediaDeviceType.ByteRTCMediaDeviceTypeScreenAudioCaptureDevice] = ByteRTCMediaDeviceType.ByteRTCMediaDeviceTypeScreenAudioCaptureDevice,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaDeviceType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMediaDeviceType.ByteRTCMediaDeviceTypeAudioUnknown] = exports.MediaDeviceType.ByteRTCMediaDeviceTypeAudioUnknown,
            _a[ByteRTCMediaDeviceType.ByteRTCMediaDeviceTypeAudioRenderDevice] = exports.MediaDeviceType.ByteRTCMediaDeviceTypeAudioRenderDevice,
            _a[ByteRTCMediaDeviceType.ByteRTCMediaDeviceTypeAudioCaptureDevice] = exports.MediaDeviceType.ByteRTCMediaDeviceTypeAudioCaptureDevice,
            _a[ByteRTCMediaDeviceType.ByteRTCMediaDeviceTypeVideoCaptureDevice] = exports.MediaDeviceType.ByteRTCMediaDeviceTypeVideoCaptureDevice,
            _a[ByteRTCMediaDeviceType.ByteRTCMediaDeviceTypeScreenVideoCaptureDevice] = exports.MediaDeviceType.ByteRTCMediaDeviceTypeScreenVideoCaptureDevice,
            _a[ByteRTCMediaDeviceType.ByteRTCMediaDeviceTypeScreenAudioCaptureDevice] = exports.MediaDeviceType.ByteRTCMediaDeviceTypeScreenAudioCaptureDevice,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MediaDeviceType;
}());
var t_ForwardStreamEvent = /** @class */ (function () {
    function t_ForwardStreamEvent() {
    }
    t_ForwardStreamEvent.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_DISCONNECTED] = ForwardStreamEvent.FORWARD_STREAM_EVENT_DISCONNECTED,
            _a[exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_CONNECTED] = ForwardStreamEvent.FORWARD_STREAM_EVENT_CONNECTED,
            _a[exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_DST_ROOM_UPDATED] = ForwardStreamEvent.FORWARD_STREAM_EVENT_DST_ROOM_UPDATED,
            _a[exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_UN_EXPECT_API_CALL] = ForwardStreamEvent.FORWARD_STREAM_EVENT_UN_EXPECT_API_CALL,
            _a[exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_INTERRUPT] = ForwardStreamEvent.FORWARD_STREAM_EVENT_INTERRUPT,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ForwardStreamEvent.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ForwardStreamEvent.FORWARD_STREAM_EVENT_DISCONNECTED] = exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_DISCONNECTED,
            _a[ForwardStreamEvent.FORWARD_STREAM_EVENT_CONNECTED] = exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_CONNECTED,
            _a[ForwardStreamEvent.FORWARD_STREAM_EVENT_DST_ROOM_UPDATED] = exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_DST_ROOM_UPDATED,
            _a[ForwardStreamEvent.FORWARD_STREAM_EVENT_UN_EXPECT_API_CALL] = exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_UN_EXPECT_API_CALL,
            _a[ForwardStreamEvent.FORWARD_STREAM_EVENT_INTERRUPT] = exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_INTERRUPT,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ForwardStreamEvent.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_DISCONNECTED] = ByteRTCForwardStreamEvent.ByteRTCForwardStreamEventDisconnected,
            _a[exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_CONNECTED] = ByteRTCForwardStreamEvent.ByteRTCForwardStreamEventConnected,
            _a[exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_DST_ROOM_UPDATED] = ByteRTCForwardStreamEvent.ByteRTCForwardStreamEventDstRoomUpdated,
            _a[exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_UN_EXPECT_API_CALL] = ByteRTCForwardStreamEvent.ByteRTCForwardStreamEventUnExpectAPICall,
            _a[exports.ForwardStreamEvent.ByteRTCForwardStreamEventInterrupt] = ByteRTCForwardStreamEvent.ByteRTCForwardStreamEventInterrupt,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ForwardStreamEvent.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCForwardStreamEvent.ByteRTCForwardStreamEventDisconnected] = exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_DISCONNECTED,
            _a[ByteRTCForwardStreamEvent.ByteRTCForwardStreamEventConnected] = exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_CONNECTED,
            _a[ByteRTCForwardStreamEvent.ByteRTCForwardStreamEventDstRoomUpdated] = exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_DST_ROOM_UPDATED,
            _a[ByteRTCForwardStreamEvent.ByteRTCForwardStreamEventUnExpectAPICall] = exports.ForwardStreamEvent.FORWARD_STREAM_EVENT_UN_EXPECT_API_CALL,
            _a[ByteRTCForwardStreamEvent.ByteRTCForwardStreamEventInterrupt] = exports.ForwardStreamEvent.ByteRTCForwardStreamEventInterrupt,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ForwardStreamEvent;
}());
var t_SubscribeMediaType = /** @class */ (function () {
    function t_SubscribeMediaType() {
    }
    t_SubscribeMediaType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SubscribeMediaType.NONE] = SubscribeMediaType.NONE,
            _a[exports.SubscribeMediaType.AUDIO_ONLY] = SubscribeMediaType.AUDIO_ONLY,
            _a[exports.SubscribeMediaType.VIDEO_ONLY] = SubscribeMediaType.VIDEO_ONLY,
            _a[exports.SubscribeMediaType.AUDIO_AND_VIDEO] = SubscribeMediaType.AUDIO_AND_VIDEO,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubscribeMediaType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[SubscribeMediaType.NONE] = exports.SubscribeMediaType.NONE,
            _a[SubscribeMediaType.AUDIO_ONLY] = exports.SubscribeMediaType.AUDIO_ONLY,
            _a[SubscribeMediaType.VIDEO_ONLY] = exports.SubscribeMediaType.VIDEO_ONLY,
            _a[SubscribeMediaType.AUDIO_AND_VIDEO] = exports.SubscribeMediaType.AUDIO_AND_VIDEO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubscribeMediaType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SubscribeMediaType.NONE] = ByteRTCSubscribeMediaType.ByteRTCSubscribeMediaTypeNone,
            _a[exports.SubscribeMediaType.AUDIO_ONLY] = ByteRTCSubscribeMediaType.ByteRTCSubscribeMediaTypeAudioOnly,
            _a[exports.SubscribeMediaType.VIDEO_ONLY] = ByteRTCSubscribeMediaType.ByteRTCSubscribeMediaTypeVideoOnly,
            _a[exports.SubscribeMediaType.AUDIO_AND_VIDEO] = ByteRTCSubscribeMediaType.ByteRTCSubscribeMediaTypeAudioAndVideo,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubscribeMediaType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCSubscribeMediaType.ByteRTCSubscribeMediaTypeNone] = exports.SubscribeMediaType.NONE,
            _a[ByteRTCSubscribeMediaType.ByteRTCSubscribeMediaTypeAudioOnly] = exports.SubscribeMediaType.AUDIO_ONLY,
            _a[ByteRTCSubscribeMediaType.ByteRTCSubscribeMediaTypeVideoOnly] = exports.SubscribeMediaType.VIDEO_ONLY,
            _a[ByteRTCSubscribeMediaType.ByteRTCSubscribeMediaTypeAudioAndVideo] = exports.SubscribeMediaType.AUDIO_AND_VIDEO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_SubscribeMediaType;
}());
var t_ConnectionState = /** @class */ (function () {
    function t_ConnectionState() {
    }
    t_ConnectionState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ConnectionState.CONNECTION_STATE_DISCONNECTED] = ConnectionState.CONNECTION_STATE_DISCONNECTED,
            _a[exports.ConnectionState.CONNECTION_STATE_CONNECTING] = ConnectionState.CONNECTION_STATE_CONNECTING,
            _a[exports.ConnectionState.CONNECTION_STATE_CONNECTED] = ConnectionState.CONNECTION_STATE_CONNECTED,
            _a[exports.ConnectionState.CONNECTION_STATE_RECONNECTING] = ConnectionState.CONNECTION_STATE_RECONNECTING,
            _a[exports.ConnectionState.CONNECTION_STATE_RECONNECTED] = ConnectionState.CONNECTION_STATE_RECONNECTED,
            _a[exports.ConnectionState.CONNECTION_STATE_LOST] = ConnectionState.CONNECTION_STATE_LOST,
            _a[exports.ConnectionState.CONNECTION_STATE_FAILED] = ConnectionState.CONNECTION_STATE_FAILED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ConnectionState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ConnectionState.CONNECTION_STATE_DISCONNECTED] = exports.ConnectionState.CONNECTION_STATE_DISCONNECTED,
            _a[ConnectionState.CONNECTION_STATE_CONNECTING] = exports.ConnectionState.CONNECTION_STATE_CONNECTING,
            _a[ConnectionState.CONNECTION_STATE_CONNECTED] = exports.ConnectionState.CONNECTION_STATE_CONNECTED,
            _a[ConnectionState.CONNECTION_STATE_RECONNECTING] = exports.ConnectionState.CONNECTION_STATE_RECONNECTING,
            _a[ConnectionState.CONNECTION_STATE_RECONNECTED] = exports.ConnectionState.CONNECTION_STATE_RECONNECTED,
            _a[ConnectionState.CONNECTION_STATE_LOST] = exports.ConnectionState.CONNECTION_STATE_LOST,
            _a[ConnectionState.CONNECTION_STATE_FAILED] = exports.ConnectionState.CONNECTION_STATE_FAILED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ConnectionState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ConnectionState.CONNECTION_STATE_DISCONNECTED] = ByteRTCConnectionState.ByteRTCConnectionStateDisconnected,
            _a[exports.ConnectionState.CONNECTION_STATE_CONNECTING] = ByteRTCConnectionState.ByteRTCConnectionStateConnecting,
            _a[exports.ConnectionState.CONNECTION_STATE_CONNECTED] = ByteRTCConnectionState.ByteRTCConnectionStateConnected,
            _a[exports.ConnectionState.CONNECTION_STATE_RECONNECTING] = ByteRTCConnectionState.ByteRTCConnectionStateReconnecting,
            _a[exports.ConnectionState.CONNECTION_STATE_RECONNECTED] = ByteRTCConnectionState.ByteRTCConnectionStateReconnected,
            _a[exports.ConnectionState.CONNECTION_STATE_LOST] = ByteRTCConnectionState.ByteRTCConnectionStateLost,
            _a[exports.ConnectionState.CONNECTION_STATE_FAILED] = ByteRTCConnectionState.ByteRTCConnectionStateFailed,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ConnectionState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCConnectionState.ByteRTCConnectionStateDisconnected] = exports.ConnectionState.CONNECTION_STATE_DISCONNECTED,
            _a[ByteRTCConnectionState.ByteRTCConnectionStateConnecting] = exports.ConnectionState.CONNECTION_STATE_CONNECTING,
            _a[ByteRTCConnectionState.ByteRTCConnectionStateConnected] = exports.ConnectionState.CONNECTION_STATE_CONNECTED,
            _a[ByteRTCConnectionState.ByteRTCConnectionStateReconnecting] = exports.ConnectionState.CONNECTION_STATE_RECONNECTING,
            _a[ByteRTCConnectionState.ByteRTCConnectionStateReconnected] = exports.ConnectionState.CONNECTION_STATE_RECONNECTED,
            _a[ByteRTCConnectionState.ByteRTCConnectionStateLost] = exports.ConnectionState.CONNECTION_STATE_LOST,
            _a[ByteRTCConnectionState.ByteRTCConnectionStateFailed] = exports.ConnectionState.CONNECTION_STATE_FAILED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ConnectionState;
}());
var t_BandFrequency = /** @class */ (function () {
    function t_BandFrequency() {
    }
    t_BandFrequency.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_31] = VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_31,
            _a[exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_62] = VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_62,
            _a[exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_125] = VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_125,
            _a[exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_250] = VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_250,
            _a[exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_500] = VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_500,
            _a[exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_1K] = VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_1K,
            _a[exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_2K] = VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_2K,
            _a[exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_4K] = VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_4K,
            _a[exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_8K] = VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_8K,
            _a[exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_16K] = VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_16K,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_BandFrequency.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_31] = exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_31,
            _a[VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_62] = exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_62,
            _a[VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_125] = exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_125,
            _a[VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_250] = exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_250,
            _a[VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_500] = exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_500,
            _a[VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_1K] = exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_1K,
            _a[VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_2K] = exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_2K,
            _a[VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_4K] = exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_4K,
            _a[VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_8K] = exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_8K,
            _a[VoiceEqualizationBandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_16K] = exports.BandFrequency.VOICE_EQUALIZATION_BAND_FREQUENCY_16K,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_BandFrequency.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.BandFrequency.ByteRTCBandFrequency31] = ByteRTCBandFrequency.ByteRTCBandFrequency31,
            _a[exports.BandFrequency.ByteRTCBandFrequency62] = ByteRTCBandFrequency.ByteRTCBandFrequency62,
            _a[exports.BandFrequency.ByteRTCBandFrequency125] = ByteRTCBandFrequency.ByteRTCBandFrequency125,
            _a[exports.BandFrequency.ByteRTCBandFrequency250] = ByteRTCBandFrequency.ByteRTCBandFrequency250,
            _a[exports.BandFrequency.ByteRTCBandFrequency500] = ByteRTCBandFrequency.ByteRTCBandFrequency500,
            _a[exports.BandFrequency.ByteRTCBandFrequency1k] = ByteRTCBandFrequency.ByteRTCBandFrequency1k,
            _a[exports.BandFrequency.ByteRTCBandFrequency2k] = ByteRTCBandFrequency.ByteRTCBandFrequency2k,
            _a[exports.BandFrequency.ByteRTCBandFrequency4k] = ByteRTCBandFrequency.ByteRTCBandFrequency4k,
            _a[exports.BandFrequency.ByteRTCBandFrequency8k] = ByteRTCBandFrequency.ByteRTCBandFrequency8k,
            _a[exports.BandFrequency.ByteRTCBandFrequency16k] = ByteRTCBandFrequency.ByteRTCBandFrequency16k,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_BandFrequency.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCBandFrequency.ByteRTCBandFrequency31] = exports.BandFrequency.ByteRTCBandFrequency31,
            _a[ByteRTCBandFrequency.ByteRTCBandFrequency62] = exports.BandFrequency.ByteRTCBandFrequency62,
            _a[ByteRTCBandFrequency.ByteRTCBandFrequency125] = exports.BandFrequency.ByteRTCBandFrequency125,
            _a[ByteRTCBandFrequency.ByteRTCBandFrequency250] = exports.BandFrequency.ByteRTCBandFrequency250,
            _a[ByteRTCBandFrequency.ByteRTCBandFrequency500] = exports.BandFrequency.ByteRTCBandFrequency500,
            _a[ByteRTCBandFrequency.ByteRTCBandFrequency1k] = exports.BandFrequency.ByteRTCBandFrequency1k,
            _a[ByteRTCBandFrequency.ByteRTCBandFrequency2k] = exports.BandFrequency.ByteRTCBandFrequency2k,
            _a[ByteRTCBandFrequency.ByteRTCBandFrequency4k] = exports.BandFrequency.ByteRTCBandFrequency4k,
            _a[ByteRTCBandFrequency.ByteRTCBandFrequency8k] = exports.BandFrequency.ByteRTCBandFrequency8k,
            _a[ByteRTCBandFrequency.ByteRTCBandFrequency16k] = exports.BandFrequency.ByteRTCBandFrequency16k,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_BandFrequency;
}());
var t_MixedStreamPushMode = /** @class */ (function () {
    function t_MixedStreamPushMode() {
    }
    t_MixedStreamPushMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamPushMode.ON_STREAM] = MixedStreamPushMode.ON_STREAM,
            _a[exports.MixedStreamPushMode.ON_START_REQUEST] = MixedStreamPushMode.ON_START_REQUEST,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamPushMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MixedStreamPushMode.ON_STREAM] = exports.MixedStreamPushMode.ON_STREAM,
            _a[MixedStreamPushMode.ON_START_REQUEST] = exports.MixedStreamPushMode.ON_START_REQUEST,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamPushMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamPushMode.ON_STREAM] = ByteRTCMixedStreamPushMode.ByteRTCMixedStreamPushModeOnStream,
            _a[exports.MixedStreamPushMode.ON_START_REQUEST] = ByteRTCMixedStreamPushMode.ByteRTCMixedStreamPushModeOnStartRequest,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamPushMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMixedStreamPushMode.ByteRTCMixedStreamPushModeOnStream] = exports.MixedStreamPushMode.ON_STREAM,
            _a[ByteRTCMixedStreamPushMode.ByteRTCMixedStreamPushModeOnStartRequest] = exports.MixedStreamPushMode.ON_START_REQUEST,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MixedStreamPushMode;
}());
var t_FirstFrameSendState = /** @class */ (function () {
    function t_FirstFrameSendState() {
    }
    t_FirstFrameSendState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.FirstFrameSendState.FIRST_FRAME_SEND_STATE_SENDING] = FirstFrameSendState.FIRST_FRAME_SEND_STATE_SENDING,
            _a[exports.FirstFrameSendState.FIRST_FRAME_SEND_STATE_SENT] = FirstFrameSendState.FIRST_FRAME_SEND_STATE_SENT,
            _a[exports.FirstFrameSendState.FIRST_FRAME_SEND_STAT_END] = FirstFrameSendState.FIRST_FRAME_SEND_STAT_END,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_FirstFrameSendState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[FirstFrameSendState.FIRST_FRAME_SEND_STATE_SENDING] = exports.FirstFrameSendState.FIRST_FRAME_SEND_STATE_SENDING,
            _a[FirstFrameSendState.FIRST_FRAME_SEND_STATE_SENT] = exports.FirstFrameSendState.FIRST_FRAME_SEND_STATE_SENT,
            _a[FirstFrameSendState.FIRST_FRAME_SEND_STAT_END] = exports.FirstFrameSendState.FIRST_FRAME_SEND_STAT_END,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_FirstFrameSendState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.FirstFrameSendState.FIRST_FRAME_SEND_STATE_SENDING] = ByteRTCFirstFrameSendState.ByteRTCFirstFrameSendStateSending,
            _a[exports.FirstFrameSendState.FIRST_FRAME_SEND_STATE_SENT] = ByteRTCFirstFrameSendState.ByteRTCFirstFrameSendStateSent,
            _a[exports.FirstFrameSendState.FIRST_FRAME_SEND_STAT_END] = ByteRTCFirstFrameSendState.ByteRTCFirstFrameSendStateEnd,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_FirstFrameSendState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCFirstFrameSendState.ByteRTCFirstFrameSendStateSending] = exports.FirstFrameSendState.FIRST_FRAME_SEND_STATE_SENDING,
            _a[ByteRTCFirstFrameSendState.ByteRTCFirstFrameSendStateSent] = exports.FirstFrameSendState.FIRST_FRAME_SEND_STATE_SENT,
            _a[ByteRTCFirstFrameSendState.ByteRTCFirstFrameSendStateEnd] = exports.FirstFrameSendState.FIRST_FRAME_SEND_STAT_END,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_FirstFrameSendState;
}());
var t_MixedStreamMediaType = /** @class */ (function () {
    function t_MixedStreamMediaType() {
    }
    t_MixedStreamMediaType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_AUDIO_AND_VIDEO] = MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_AUDIO_AND_VIDEO,
            _a[exports.MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_AUDIO_ONLY] = MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_AUDIO_ONLY,
            _a[exports.MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_VIDEO_ONLY] = MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_VIDEO_ONLY,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamMediaType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_AUDIO_AND_VIDEO] = exports.MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_AUDIO_AND_VIDEO,
            _a[MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_AUDIO_ONLY] = exports.MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_AUDIO_ONLY,
            _a[MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_VIDEO_ONLY] = exports.MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_VIDEO_ONLY,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamMediaType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_AUDIO_AND_VIDEO] = ByteRTCMixedStreamMediaType.ByteRTCMixedStreamMediaTypeAudioAndVideo,
            _a[exports.MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_AUDIO_ONLY] = ByteRTCMixedStreamMediaType.ByteRTCMixedStreamMediaTypeAudioOnly,
            _a[exports.MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_VIDEO_ONLY] = ByteRTCMixedStreamMediaType.ByteRTCMixedStreamMediaTypeVideoOnly,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamMediaType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMixedStreamMediaType.ByteRTCMixedStreamMediaTypeAudioAndVideo] = exports.MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_AUDIO_AND_VIDEO,
            _a[ByteRTCMixedStreamMediaType.ByteRTCMixedStreamMediaTypeAudioOnly] = exports.MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_AUDIO_ONLY,
            _a[ByteRTCMixedStreamMediaType.ByteRTCMixedStreamMediaTypeVideoOnly] = exports.MixedStreamMediaType.MIXED_STREAM_MEDIA_TYPE_VIDEO_ONLY,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MixedStreamMediaType;
}());
var t_SubtitleMode = /** @class */ (function () {
    function t_SubtitleMode() {
    }
    t_SubtitleMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SubtitleMode.SUBTITLE_MODE_TRANSLATION] = SubtitleMode.SUBTITLE_MODE_TRANSLATION,
            _a[exports.SubtitleMode.SUBTITLE_MODE_RECOGINTE] = SubtitleMode.SUBTITLE_MODE_RECOGINTE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubtitleMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[SubtitleMode.SUBTITLE_MODE_TRANSLATION] = exports.SubtitleMode.SUBTITLE_MODE_TRANSLATION,
            _a[SubtitleMode.SUBTITLE_MODE_RECOGINTE] = exports.SubtitleMode.SUBTITLE_MODE_RECOGINTE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubtitleMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SubtitleMode.SUBTITLE_MODE_TRANSLATION] = ByteRTCSubtitleMode.ByteRTCSubtitleModeTranslation,
            _a[exports.SubtitleMode.ByteRTCSubtitleModeRecognition] = ByteRTCSubtitleMode.ByteRTCSubtitleModeRecognition,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubtitleMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCSubtitleMode.ByteRTCSubtitleModeTranslation] = exports.SubtitleMode.SUBTITLE_MODE_TRANSLATION,
            _a[ByteRTCSubtitleMode.ByteRTCSubtitleModeRecognition] = exports.SubtitleMode.ByteRTCSubtitleModeRecognition,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_SubtitleMode;
}());
var t_MusicHotType = /** @class */ (function () {
    function t_MusicHotType() {
    }
    t_MusicHotType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MusicHotType.CONTENT_CENTER] = MusicHotType.CONTENT_CENTER,
            _a[exports.MusicHotType.PROJECT] = MusicHotType.PROJECT,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MusicHotType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MusicHotType.CONTENT_CENTER] = exports.MusicHotType.CONTENT_CENTER,
            _a[MusicHotType.PROJECT] = exports.MusicHotType.PROJECT,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MusicHotType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MusicHotType.CONTENT_CENTER] = ByteRTCMusicHotType.ByteRTCMusicHotTypeContentCenter,
            _a[exports.MusicHotType.PROJECT] = ByteRTCMusicHotType.ByteRTCMusicHotTypeProject,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MusicHotType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMusicHotType.ByteRTCMusicHotTypeContentCenter] = exports.MusicHotType.CONTENT_CENTER,
            _a[ByteRTCMusicHotType.ByteRTCMusicHotTypeProject] = exports.MusicHotType.PROJECT,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MusicHotType;
}());
var t_MixedStreamAudioCodecType = /** @class */ (function () {
    function t_MixedStreamAudioCodecType() {
    }
    t_MixedStreamAudioCodecType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamAudioCodecType.MIXED_STREAM_AUDIO_CODEC_TYPE_AAC] = MixedStreamAudioCodecType.MIXED_STREAM_AUDIO_CODEC_TYPE_AAC,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamAudioCodecType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MixedStreamAudioCodecType.MIXED_STREAM_AUDIO_CODEC_TYPE_AAC] = exports.MixedStreamAudioCodecType.MIXED_STREAM_AUDIO_CODEC_TYPE_AAC,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamAudioCodecType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamAudioCodecType.MIXED_STREAM_AUDIO_CODEC_TYPE_AAC] = ByteRTCMixedStreamAudioCodecType.ByteRTCMixedStreamAudioCodecTypeAAC,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamAudioCodecType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMixedStreamAudioCodecType.ByteRTCMixedStreamAudioCodecTypeAAC] = exports.MixedStreamAudioCodecType.MIXED_STREAM_AUDIO_CODEC_TYPE_AAC,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MixedStreamAudioCodecType;
}());
var t_LocalLogLevel = /** @class */ (function () {
    function t_LocalLogLevel() {
    }
    t_LocalLogLevel.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalLogLevel.INFO] = LocalLogLevel.INFO,
            _a[exports.LocalLogLevel.WARNING] = LocalLogLevel.WARNING,
            _a[exports.LocalLogLevel.ERROR] = LocalLogLevel.ERROR,
            _a[exports.LocalLogLevel.NONE] = LocalLogLevel.NONE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalLogLevel.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[LocalLogLevel.INFO] = exports.LocalLogLevel.INFO,
            _a[LocalLogLevel.WARNING] = exports.LocalLogLevel.WARNING,
            _a[LocalLogLevel.ERROR] = exports.LocalLogLevel.ERROR,
            _a[LocalLogLevel.NONE] = exports.LocalLogLevel.NONE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalLogLevel.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalLogLevel.INFO] = ByteRTCLocalLogLevel.ByteRTCLocalLogLevelInfo,
            _a[exports.LocalLogLevel.WARNING] = ByteRTCLocalLogLevel.ByteRTCLocalLogLevelWarning,
            _a[exports.LocalLogLevel.ERROR] = ByteRTCLocalLogLevel.ByteRTCLocalLogLevelError,
            _a[exports.LocalLogLevel.NONE] = ByteRTCLocalLogLevel.ByteRTCLocalLogLevelNone,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalLogLevel.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCLocalLogLevel.ByteRTCLocalLogLevelInfo] = exports.LocalLogLevel.INFO,
            _a[ByteRTCLocalLogLevel.ByteRTCLocalLogLevelWarning] = exports.LocalLogLevel.WARNING,
            _a[ByteRTCLocalLogLevel.ByteRTCLocalLogLevelError] = exports.LocalLogLevel.ERROR,
            _a[ByteRTCLocalLogLevel.ByteRTCLocalLogLevelNone] = exports.LocalLogLevel.NONE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_LocalLogLevel;
}());
var t_ForwardStreamState = /** @class */ (function () {
    function t_ForwardStreamState() {
    }
    t_ForwardStreamState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ForwardStreamState.FORWARD_STREAM_STATE_SUCCESS] = ForwardStreamState.FORWARD_STREAM_STATE_SUCCESS,
            _a[exports.ForwardStreamState.FORWARD_STREAM_STATE_FAILURE] = ForwardStreamState.FORWARD_STREAM_STATE_FAILURE,
            _a[exports.ForwardStreamState.FORWARD_STREAM_STATE_IDLE] = ForwardStreamState.FORWARD_STREAM_STATE_IDLE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ForwardStreamState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ForwardStreamState.FORWARD_STREAM_STATE_SUCCESS] = exports.ForwardStreamState.FORWARD_STREAM_STATE_SUCCESS,
            _a[ForwardStreamState.FORWARD_STREAM_STATE_FAILURE] = exports.ForwardStreamState.FORWARD_STREAM_STATE_FAILURE,
            _a[ForwardStreamState.FORWARD_STREAM_STATE_IDLE] = exports.ForwardStreamState.FORWARD_STREAM_STATE_IDLE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ForwardStreamState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ForwardStreamState.FORWARD_STREAM_STATE_SUCCESS] = ByteRTCForwardStreamState.ByteRTCForwardStreamStateSuccess,
            _a[exports.ForwardStreamState.FORWARD_STREAM_STATE_FAILURE] = ByteRTCForwardStreamState.ByteRTCForwardStreamStateFailure,
            _a[exports.ForwardStreamState.ByteRTCForwardStreamStateIdle] = ByteRTCForwardStreamState.ByteRTCForwardStreamStateIdle,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ForwardStreamState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCForwardStreamState.ByteRTCForwardStreamStateSuccess] = exports.ForwardStreamState.FORWARD_STREAM_STATE_SUCCESS,
            _a[ByteRTCForwardStreamState.ByteRTCForwardStreamStateFailure] = exports.ForwardStreamState.FORWARD_STREAM_STATE_FAILURE,
            _a[ByteRTCForwardStreamState.ByteRTCForwardStreamStateIdle] = exports.ForwardStreamState.ByteRTCForwardStreamStateIdle,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ForwardStreamState;
}());
var t_VideoCodecType = /** @class */ (function () {
    function t_VideoCodecType() {
    }
    t_VideoCodecType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoCodecType.VIDEO_CODEC_TYPE_H264] = VideoConfig$VideoCodecType.VIDEO_CODEC_TYPE_H264,
            _a[exports.VideoCodecType.VIDEO_CODEC_TYPE_BYTEVC1] = VideoConfig$VideoCodecType.VIDEO_CODEC_TYPE_BYTEVC1,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoCodecType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoConfig$VideoCodecType.VIDEO_CODEC_TYPE_H264] = exports.VideoCodecType.VIDEO_CODEC_TYPE_H264,
            _a[VideoConfig$VideoCodecType.VIDEO_CODEC_TYPE_BYTEVC1] = exports.VideoCodecType.VIDEO_CODEC_TYPE_BYTEVC1,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoCodecType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoCodecType.VIDEO_CODEC_TYPE_H264] = ByteRTCVideoCodecType.ByteRTCVideoCodecTypeH264,
            _a[exports.VideoCodecType.VIDEO_CODEC_TYPE_BYTEVC1] = ByteRTCVideoCodecType.ByteRTCVideoCodecTypeByteVC1,
            _a[exports.VideoCodecType.ByteRTCVideoCodecTypeUnknown] = ByteRTCVideoCodecType.ByteRTCVideoCodecTypeUnknown,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoCodecType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoCodecType.ByteRTCVideoCodecTypeH264] = exports.VideoCodecType.VIDEO_CODEC_TYPE_H264,
            _a[ByteRTCVideoCodecType.ByteRTCVideoCodecTypeByteVC1] = exports.VideoCodecType.VIDEO_CODEC_TYPE_BYTEVC1,
            _a[ByteRTCVideoCodecType.ByteRTCVideoCodecTypeUnknown] = exports.VideoCodecType.ByteRTCVideoCodecTypeUnknown,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoCodecType;
}());
var t_ASRAuthorizationType = /** @class */ (function () {
    function t_ASRAuthorizationType() {
    }
    t_ASRAuthorizationType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ASRAuthorizationType.ASR_AUTHORIZATION_TYPE_TOKEN] = ASRAuthorizationType.ASR_AUTHORIZATION_TYPE_TOKEN,
            _a[exports.ASRAuthorizationType.ASR_AUTHORIZATION_TYPE_SIGNATURE] = ASRAuthorizationType.ASR_AUTHORIZATION_TYPE_SIGNATURE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ASRAuthorizationType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ASRAuthorizationType.ASR_AUTHORIZATION_TYPE_TOKEN] = exports.ASRAuthorizationType.ASR_AUTHORIZATION_TYPE_TOKEN,
            _a[ASRAuthorizationType.ASR_AUTHORIZATION_TYPE_SIGNATURE] = exports.ASRAuthorizationType.ASR_AUTHORIZATION_TYPE_SIGNATURE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ASRAuthorizationType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ASRAuthorizationType.ASR_AUTHORIZATION_TYPE_TOKEN] = ByteRTCASRAuthorizationType.ByteRTCASRAuthorizationTypeToken,
            _a[exports.ASRAuthorizationType.ASR_AUTHORIZATION_TYPE_SIGNATURE] = ByteRTCASRAuthorizationType.ByteRTCASRAuthorizationTypeSignature,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ASRAuthorizationType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCASRAuthorizationType.ByteRTCASRAuthorizationTypeToken] = exports.ASRAuthorizationType.ASR_AUTHORIZATION_TYPE_TOKEN,
            _a[ByteRTCASRAuthorizationType.ByteRTCASRAuthorizationTypeSignature] = exports.ASRAuthorizationType.ASR_AUTHORIZATION_TYPE_SIGNATURE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ASRAuthorizationType;
}());
var t_RTCASRErrorCode = /** @class */ (function () {
    function t_RTCASRErrorCode() {
    }
    t_RTCASRErrorCode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCASRErrorCode.NETWORK_INTERRUPTED] = RTCASRErrorCode.NETWORK_INTERRUPTED,
            _a[exports.RTCASRErrorCode.ALREADY_STARTED] = RTCASRErrorCode.ALREADY_STARTED,
            _a[exports.RTCASRErrorCode.TOKEN_EMPTY] = RTCASRErrorCode.TOKEN_EMPTY,
            _a[exports.RTCASRErrorCode.SIGNATURE_KEY_EMPTY] = RTCASRErrorCode.SIGNATURE_KEY_EMPTY,
            _a[exports.RTCASRErrorCode.USERID_NULL] = RTCASRErrorCode.USERID_NULL,
            _a[exports.RTCASRErrorCode.APPID_NULL] = RTCASRErrorCode.APPID_NULL,
            _a[exports.RTCASRErrorCode.CLUSTER_NULL] = RTCASRErrorCode.CLUSTER_NULL,
            _a[exports.RTCASRErrorCode.OPERATION_DENIED] = RTCASRErrorCode.OPERATION_DENIED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCASRErrorCode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RTCASRErrorCode.NETWORK_INTERRUPTED] = exports.RTCASRErrorCode.NETWORK_INTERRUPTED,
            _a[RTCASRErrorCode.ALREADY_STARTED] = exports.RTCASRErrorCode.ALREADY_STARTED,
            _a[RTCASRErrorCode.TOKEN_EMPTY] = exports.RTCASRErrorCode.TOKEN_EMPTY,
            _a[RTCASRErrorCode.SIGNATURE_KEY_EMPTY] = exports.RTCASRErrorCode.SIGNATURE_KEY_EMPTY,
            _a[RTCASRErrorCode.USERID_NULL] = exports.RTCASRErrorCode.USERID_NULL,
            _a[RTCASRErrorCode.APPID_NULL] = exports.RTCASRErrorCode.APPID_NULL,
            _a[RTCASRErrorCode.CLUSTER_NULL] = exports.RTCASRErrorCode.CLUSTER_NULL,
            _a[RTCASRErrorCode.OPERATION_DENIED] = exports.RTCASRErrorCode.OPERATION_DENIED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCASRErrorCode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RTCASRErrorCode.ByteRTCASRErrorNetworkInterrupted] = ByteRTCASRErrorCode.ByteRTCASRErrorNetworkInterrupted,
            _a[exports.RTCASRErrorCode.ByteRTCASRErrorAlreadyStarted] = ByteRTCASRErrorCode.ByteRTCASRErrorAlreadyStarted,
            _a[exports.RTCASRErrorCode.ByteRTCASRErrorTokenEmpty] = ByteRTCASRErrorCode.ByteRTCASRErrorTokenEmpty,
            _a[exports.RTCASRErrorCode.ByteRTCErrorSignatureKeyEmpty] = ByteRTCASRErrorCode.ByteRTCErrorSignatureKeyEmpty,
            _a[exports.RTCASRErrorCode.ByteRTCASRErrorUserIdNull] = ByteRTCASRErrorCode.ByteRTCASRErrorUserIdNull,
            _a[exports.RTCASRErrorCode.ByteRTCASRErrorAPPIDNull] = ByteRTCASRErrorCode.ByteRTCASRErrorAPPIDNull,
            _a[exports.RTCASRErrorCode.ByteRTCASRErrorClusterNull] = ByteRTCASRErrorCode.ByteRTCASRErrorClusterNull,
            _a[exports.RTCASRErrorCode.ByteRTCASRErrorOperationDenied] = ByteRTCASRErrorCode.ByteRTCASRErrorOperationDenied,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RTCASRErrorCode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCASRErrorCode.ByteRTCASRErrorNetworkInterrupted] = exports.RTCASRErrorCode.ByteRTCASRErrorNetworkInterrupted,
            _a[ByteRTCASRErrorCode.ByteRTCASRErrorAlreadyStarted] = exports.RTCASRErrorCode.ByteRTCASRErrorAlreadyStarted,
            _a[ByteRTCASRErrorCode.ByteRTCASRErrorTokenEmpty] = exports.RTCASRErrorCode.ByteRTCASRErrorTokenEmpty,
            _a[ByteRTCASRErrorCode.ByteRTCErrorSignatureKeyEmpty] = exports.RTCASRErrorCode.ByteRTCErrorSignatureKeyEmpty,
            _a[ByteRTCASRErrorCode.ByteRTCASRErrorUserIdNull] = exports.RTCASRErrorCode.ByteRTCASRErrorUserIdNull,
            _a[ByteRTCASRErrorCode.ByteRTCASRErrorAPPIDNull] = exports.RTCASRErrorCode.ByteRTCASRErrorAPPIDNull,
            _a[ByteRTCASRErrorCode.ByteRTCASRErrorClusterNull] = exports.RTCASRErrorCode.ByteRTCASRErrorClusterNull,
            _a[ByteRTCASRErrorCode.ByteRTCASRErrorOperationDenied] = exports.RTCASRErrorCode.ByteRTCASRErrorOperationDenied,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RTCASRErrorCode;
}());
var t_RecordingFileType = /** @class */ (function () {
    function t_RecordingFileType() {
    }
    t_RecordingFileType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RecordingFileType.AAC] = RecordingFileType.AAC,
            _a[exports.RecordingFileType.MP4] = RecordingFileType.MP4,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RecordingFileType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RecordingFileType.AAC] = exports.RecordingFileType.AAC,
            _a[RecordingFileType.MP4] = exports.RecordingFileType.MP4,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RecordingFileType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RecordingFileType.AAC] = ByteRTCRecordingFileType.ByteRTCRecordingFileTypeAAC,
            _a[exports.RecordingFileType.MP4] = ByteRTCRecordingFileType.ByteRTCRecordingFileTypeMP4,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RecordingFileType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRecordingFileType.ByteRTCRecordingFileTypeAAC] = exports.RecordingFileType.AAC,
            _a[ByteRTCRecordingFileType.ByteRTCRecordingFileTypeMP4] = exports.RecordingFileType.MP4,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RecordingFileType;
}());
var t_ByteRTCStreamMixingEvent = /** @class */ (function () {
    function t_ByteRTCStreamMixingEvent() {
    }
    t_ByteRTCStreamMixingEvent.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_START] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_START,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_START_SUCCESS] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_START_SUCCESS,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_START_FAILED] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_START_FAILED,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_UPDATE] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_UPDATE,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_UPDATE_SUCCESS] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_UPDATE_SUCCESS,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_UPDATE_FAILED] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_UPDATE_FAILED,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_STOP] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_STOP,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_STOP_SUCCESS] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_STOP_SUCCESS,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_STOP_FAILED] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_STOP_FAILED,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_CHANGE_MIX_TYPE] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_CHANGE_MIX_TYPE,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_FIRST_AUDIO_FRAME_BY_CLIENT_MIX] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_FIRST_AUDIO_FRAME_BY_CLIENT_MIX,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_FIRST_VIDEO_FRAME_BY_CLIENT_MIX] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_FIRST_VIDEO_FRAME_BY_CLIENT_MIX,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_UPDATE_TIMEOUT] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_UPDATE_TIMEOUT,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_START_TIMEOUT] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_START_TIMEOUT,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_REQUEST_PARAM_ERROR] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_REQUEST_PARAM_ERROR,
            _a[exports.ByteRTCStreamMixingEvent.STREAM_MIXING_MIX_IMAGE_EVENT] = ByteRTCStreamMixingEvent$1.STREAM_MIXING_MIX_IMAGE_EVENT,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ByteRTCStreamMixingEvent.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_START] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_START,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_START_SUCCESS] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_START_SUCCESS,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_START_FAILED] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_START_FAILED,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_UPDATE] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_UPDATE,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_UPDATE_SUCCESS] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_UPDATE_SUCCESS,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_UPDATE_FAILED] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_UPDATE_FAILED,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_STOP] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_STOP,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_STOP_SUCCESS] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_STOP_SUCCESS,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_STOP_FAILED] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_STOP_FAILED,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_CHANGE_MIX_TYPE] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_CHANGE_MIX_TYPE,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_FIRST_AUDIO_FRAME_BY_CLIENT_MIX] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_FIRST_AUDIO_FRAME_BY_CLIENT_MIX,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_FIRST_VIDEO_FRAME_BY_CLIENT_MIX] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_FIRST_VIDEO_FRAME_BY_CLIENT_MIX,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_UPDATE_TIMEOUT] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_UPDATE_TIMEOUT,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_START_TIMEOUT] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_START_TIMEOUT,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_REQUEST_PARAM_ERROR] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_REQUEST_PARAM_ERROR,
            _a[ByteRTCStreamMixingEvent$1.STREAM_MIXING_MIX_IMAGE_EVENT] = exports.ByteRTCStreamMixingEvent.STREAM_MIXING_MIX_IMAGE_EVENT,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ByteRTCStreamMixingEvent.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStart] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStart,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStartSuccess] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStartSuccess,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStartFailed] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStartFailed,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdate] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdate,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdateSuccess] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdateSuccess,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdateFailed] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdateFailed,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStop] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStop,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStopSuccess] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStopSuccess,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStopFailed] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStopFailed,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventChangeMixType] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventChangeMixType,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventFirstAudioFrameByClientMixer] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventFirstAudioFrameByClientMixer,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventFirstVideoFrameByClientMixer] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventFirstVideoFrameByClientMixer,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdateTimeout] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdateTimeout,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStartTimeout] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStartTimeout,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventRequestParamError] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventRequestParamError,
            _a[exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventMixImage] = ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventMixImage,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ByteRTCStreamMixingEvent.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStart] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStart,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStartSuccess] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStartSuccess,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStartFailed] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStartFailed,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdate] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdate,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdateSuccess] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdateSuccess,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdateFailed] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdateFailed,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStop] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStop,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStopSuccess] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStopSuccess,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStopFailed] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStopFailed,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventChangeMixType] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventChangeMixType,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventFirstAudioFrameByClientMixer] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventFirstAudioFrameByClientMixer,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventFirstVideoFrameByClientMixer] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventFirstVideoFrameByClientMixer,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdateTimeout] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventUpdateTimeout,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStartTimeout] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventStartTimeout,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventRequestParamError] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventRequestParamError,
            _a[ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventMixImage] = exports.ByteRTCStreamMixingEvent.ByteRTCStreamMixingEventMixImage,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ByteRTCStreamMixingEvent;
}());
var t_AudioAlignmentMode = /** @class */ (function () {
    function t_AudioAlignmentMode() {
    }
    t_AudioAlignmentMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioAlignmentMode.AUDIO_ALIGNMENT_MODE_OFF] = AudioAlignmentMode.AUDIO_ALIGNMENT_MODE_OFF,
            _a[exports.AudioAlignmentMode.AUDIO_ALIGNMENT_MODE_AUDIOMIXING] = AudioAlignmentMode.AUDIO_ALIGNMENT_MODE_AUDIOMIXING,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioAlignmentMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioAlignmentMode.AUDIO_ALIGNMENT_MODE_OFF] = exports.AudioAlignmentMode.AUDIO_ALIGNMENT_MODE_OFF,
            _a[AudioAlignmentMode.AUDIO_ALIGNMENT_MODE_AUDIOMIXING] = exports.AudioAlignmentMode.AUDIO_ALIGNMENT_MODE_AUDIOMIXING,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioAlignmentMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioAlignmentMode.AUDIO_ALIGNMENT_MODE_OFF] = ByteRTCAudioAlignmentMode.ByteRTCAudioAlignmentModeOff,
            _a[exports.AudioAlignmentMode.AUDIO_ALIGNMENT_MODE_AUDIOMIXING] = ByteRTCAudioAlignmentMode.ByteRTCAudioAlignmentModeAudioMixing,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioAlignmentMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioAlignmentMode.ByteRTCAudioAlignmentModeOff] = exports.AudioAlignmentMode.AUDIO_ALIGNMENT_MODE_OFF,
            _a[ByteRTCAudioAlignmentMode.ByteRTCAudioAlignmentModeAudioMixing] = exports.AudioAlignmentMode.AUDIO_ALIGNMENT_MODE_AUDIOMIXING,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioAlignmentMode;
}());
var t_FallbackOrRecoverReason = /** @class */ (function () {
    function t_FallbackOrRecoverReason() {
    }
    t_FallbackOrRecoverReason.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_UNKNOWN] = FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_UNKNOWN,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_BANDWIDTH] = FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_BANDWIDTH,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_PERFORMANCE] = FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_PERFORMANCE,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_BANDWIDTH] = FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_BANDWIDTH,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_PERFORMANCE] = FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_PERFORMANCE,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_BANDWIDTH] = FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_BANDWIDTH,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_PERFORMANCE] = FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_PERFORMANCE,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_BANDWIDTH] = FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_BANDWIDTH,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_PERFORMANCE] = FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_PERFORMANCE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_FallbackOrRecoverReason.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_UNKNOWN] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_UNKNOWN,
            _a[FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_BANDWIDTH] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_BANDWIDTH,
            _a[FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_PERFORMANCE] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_PERFORMANCE,
            _a[FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_BANDWIDTH] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_BANDWIDTH,
            _a[FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_PERFORMANCE] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_PERFORMANCE,
            _a[FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_BANDWIDTH] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_BANDWIDTH,
            _a[FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_PERFORMANCE] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_PERFORMANCE,
            _a[FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_BANDWIDTH] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_BANDWIDTH,
            _a[FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_PERFORMANCE] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_PERFORMANCE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_FallbackOrRecoverReason.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_UNKNOWN] = ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonUnknown,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_BANDWIDTH] = ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonSubscribeFallbackByBandwidth,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_PERFORMANCE] = ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonSubscribeFallbackByPerformance,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_BANDWIDTH] = ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonSubscribeRecoverByBandwidth,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_PERFORMANCE] = ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonSubscribeRecoverByPerformance,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_BANDWIDTH] = ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonPublishFallbackByBandwidth,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_PERFORMANCE] = ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonPublishFallbackByPerformance,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_BANDWIDTH] = ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonPublishRecoverByBandwidth,
            _a[exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_PERFORMANCE] = ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonPublishRecoverByPerformance,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_FallbackOrRecoverReason.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonUnknown] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_UNKNOWN,
            _a[ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonSubscribeFallbackByBandwidth] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_BANDWIDTH,
            _a[ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonSubscribeFallbackByPerformance] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_FALLBACK_BY_PERFORMANCE,
            _a[ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonSubscribeRecoverByBandwidth] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_BANDWIDTH,
            _a[ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonSubscribeRecoverByPerformance] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_SUBSCRIBE_RECOVER_BY_PERFORMANCE,
            _a[ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonPublishFallbackByBandwidth] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_BANDWIDTH,
            _a[ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonPublishFallbackByPerformance] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_FALLBACK_BY_PERFORMANCE,
            _a[ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonPublishRecoverByBandwidth] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_BANDWIDTH,
            _a[ByteRTCFallbackOrRecoverReason.ByteRTCFallbackOrRecoverReasonPublishRecoverByPerformance] = exports.FallbackOrRecoverReason.FALLBACK_OR_RECOVER_REASON_PUBLISH_RECOVER_BY_PERFORMANCE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_FallbackOrRecoverReason;
}());
var t_NetworkQuality = /** @class */ (function () {
    function t_NetworkQuality() {
    }
    t_NetworkQuality.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.NetworkQuality.NETWORK_QUALITY_UNKNOWN] = NetworkQuality.NETWORK_QUALITY_UNKNOWN,
            _a[exports.NetworkQuality.NETWORK_QUALITY_EXCELLENT] = NetworkQuality.NETWORK_QUALITY_EXCELLENT,
            _a[exports.NetworkQuality.NETWORK_QUALITY_GOOD] = NetworkQuality.NETWORK_QUALITY_GOOD,
            _a[exports.NetworkQuality.NETWORK_QUALITY_POOR] = NetworkQuality.NETWORK_QUALITY_POOR,
            _a[exports.NetworkQuality.NETWORK_QUALITY_BAD] = NetworkQuality.NETWORK_QUALITY_BAD,
            _a[exports.NetworkQuality.NETWORK_QUALITY_VERY_BAD] = NetworkQuality.NETWORK_QUALITY_VERY_BAD,
            _a[exports.NetworkQuality.NETWORK_QUALITY_DOWN] = NetworkQuality.NETWORK_QUALITY_DOWN,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_NetworkQuality.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[NetworkQuality.NETWORK_QUALITY_UNKNOWN] = exports.NetworkQuality.NETWORK_QUALITY_UNKNOWN,
            _a[NetworkQuality.NETWORK_QUALITY_EXCELLENT] = exports.NetworkQuality.NETWORK_QUALITY_EXCELLENT,
            _a[NetworkQuality.NETWORK_QUALITY_GOOD] = exports.NetworkQuality.NETWORK_QUALITY_GOOD,
            _a[NetworkQuality.NETWORK_QUALITY_POOR] = exports.NetworkQuality.NETWORK_QUALITY_POOR,
            _a[NetworkQuality.NETWORK_QUALITY_BAD] = exports.NetworkQuality.NETWORK_QUALITY_BAD,
            _a[NetworkQuality.NETWORK_QUALITY_VERY_BAD] = exports.NetworkQuality.NETWORK_QUALITY_VERY_BAD,
            _a[NetworkQuality.NETWORK_QUALITY_DOWN] = exports.NetworkQuality.NETWORK_QUALITY_DOWN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_NetworkQuality.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.NetworkQuality.NETWORK_QUALITY_UNKNOWN] = ByteRTCNetworkQuality.ByteRTCNetworkQualityUnknown,
            _a[exports.NetworkQuality.NETWORK_QUALITY_EXCELLENT] = ByteRTCNetworkQuality.ByteRTCNetworkQualityExcellent,
            _a[exports.NetworkQuality.NETWORK_QUALITY_GOOD] = ByteRTCNetworkQuality.ByteRTCNetworkQualityGood,
            _a[exports.NetworkQuality.NETWORK_QUALITY_POOR] = ByteRTCNetworkQuality.ByteRTCNetworkQualityPoor,
            _a[exports.NetworkQuality.NETWORK_QUALITY_BAD] = ByteRTCNetworkQuality.ByteRTCNetworkQualityBad,
            _a[exports.NetworkQuality.NETWORK_QUALITY_VERY_BAD] = ByteRTCNetworkQuality.ByteRTCNetworkQualityVeryBad,
            _a[exports.NetworkQuality.NETWORK_QUALITY_DOWN] = ByteRTCNetworkQuality.ByteRTCNetworkQualityDown,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_NetworkQuality.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCNetworkQuality.ByteRTCNetworkQualityUnknown] = exports.NetworkQuality.NETWORK_QUALITY_UNKNOWN,
            _a[ByteRTCNetworkQuality.ByteRTCNetworkQualityExcellent] = exports.NetworkQuality.NETWORK_QUALITY_EXCELLENT,
            _a[ByteRTCNetworkQuality.ByteRTCNetworkQualityGood] = exports.NetworkQuality.NETWORK_QUALITY_GOOD,
            _a[ByteRTCNetworkQuality.ByteRTCNetworkQualityPoor] = exports.NetworkQuality.NETWORK_QUALITY_POOR,
            _a[ByteRTCNetworkQuality.ByteRTCNetworkQualityBad] = exports.NetworkQuality.NETWORK_QUALITY_BAD,
            _a[ByteRTCNetworkQuality.ByteRTCNetworkQualityVeryBad] = exports.NetworkQuality.NETWORK_QUALITY_VERY_BAD,
            _a[ByteRTCNetworkQuality.ByteRTCNetworkQualityDown] = exports.NetworkQuality.NETWORK_QUALITY_DOWN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_NetworkQuality;
}());
var t_MediaDeviceWarning = /** @class */ (function () {
    function t_MediaDeviceWarning() {
    }
    t_MediaDeviceWarning.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_OK] = MediaDeviceWarning.MEDIA_DEVICE_WARNING_OK,
            _a[exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_OPERATION_DENIED] = MediaDeviceWarning.MEDIA_DEVICE_WARNING_OPERATION_DENIED,
            _a[exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_CAPTURE_SILENCE] = MediaDeviceWarning.MEDIA_DEVICE_WARNING_CAPTURE_SILENCE,
            _a[exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE] = MediaDeviceWarning.MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE,
            _a[exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE_DISAPPEAR] = MediaDeviceWarning.MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE_DISAPPEAR,
            _a[exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_DETECT_LEAK_ECHO] = MediaDeviceWarning.MEDIA_DEVICE_WARNING_DETECT_LEAK_ECHO,
            _a[exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_CAPTURE_DETECT_HOWLING] = MediaDeviceWarning.MEDIA_DEVICE_WARNING_CAPTURE_DETECT_HOWLING,
            _a[exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_INVALID_SCENARIO] = MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_INVALID_SCENARIO,
            _a[exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_EXISTS] = MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_EXISTS,
            _a[exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_FAILED_BY_PRIORITY] = MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_FAILED_BY_PRIORITY,
            _a[exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_VOIP_MODE] = MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_VOIP_MODE,
            _a[exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_DEVICE_NOT_START] = MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_DEVICE_NOT_START,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaDeviceWarning.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MediaDeviceWarning.MEDIA_DEVICE_WARNING_OK] = exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_OK,
            _a[MediaDeviceWarning.MEDIA_DEVICE_WARNING_OPERATION_DENIED] = exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_OPERATION_DENIED,
            _a[MediaDeviceWarning.MEDIA_DEVICE_WARNING_CAPTURE_SILENCE] = exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_CAPTURE_SILENCE,
            _a[MediaDeviceWarning.MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE] = exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE,
            _a[MediaDeviceWarning.MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE_DISAPPEAR] = exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_ANDROID_SYS_SILENCE_DISAPPEAR,
            _a[MediaDeviceWarning.MEDIA_DEVICE_WARNING_DETECT_LEAK_ECHO] = exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_DETECT_LEAK_ECHO,
            _a[MediaDeviceWarning.MEDIA_DEVICE_WARNING_CAPTURE_DETECT_HOWLING] = exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_CAPTURE_DETECT_HOWLING,
            _a[MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_INVALID_SCENARIO] = exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_INVALID_SCENARIO,
            _a[MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_EXISTS] = exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_EXISTS,
            _a[MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_FAILED_BY_PRIORITY] = exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_FAILED_BY_PRIORITY,
            _a[MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_VOIP_MODE] = exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_NOT_VOIP_MODE,
            _a[MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_DEVICE_NOT_START] = exports.MediaDeviceWarning.MEDIA_DEVICE_WARNING_SET_AUDIO_ROUTE_DEVICE_NOT_START,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaDeviceWarning.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningOK] = ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningOK,
            _a[exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningOperationDenied] = ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningOperationDenied,
            _a[exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningCaptureSilence] = ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningCaptureSilence,
            _a[exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningDetectLeakEcho] = ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningDetectLeakEcho,
            _a[exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningCaptureDetectHowling] = ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningCaptureDetectHowling,
            _a[exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteInvalidScenario] = ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteInvalidScenario,
            _a[exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteNotExists] = ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteNotExists,
            _a[exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteFailedByPriority] = ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteFailedByPriority,
            _a[exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteNotVoipMode] = ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteNotVoipMode,
            _a[exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteDeviceNotStart] = ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteDeviceNotStart,
            _a[exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetBluetoothModeScenarioUnsupport] = ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetBluetoothModeScenarioUnsupport,
            _a[exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetBluetoothModeUnsupport] = ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetBluetoothModeUnsupport,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaDeviceWarning.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningOK] = exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningOK,
            _a[ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningOperationDenied] = exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningOperationDenied,
            _a[ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningCaptureSilence] = exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningCaptureSilence,
            _a[ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningDetectLeakEcho] = exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningDetectLeakEcho,
            _a[ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningCaptureDetectHowling] = exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningCaptureDetectHowling,
            _a[ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteInvalidScenario] = exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteInvalidScenario,
            _a[ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteNotExists] = exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteNotExists,
            _a[ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteFailedByPriority] = exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteFailedByPriority,
            _a[ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteNotVoipMode] = exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteNotVoipMode,
            _a[ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteDeviceNotStart] = exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetAudioRouteDeviceNotStart,
            _a[ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetBluetoothModeScenarioUnsupport] = exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetBluetoothModeScenarioUnsupport,
            _a[ByteRTCMediaDeviceWarning.ByteRTCMediaDeviceWarningSetBluetoothModeUnsupport] = exports.MediaDeviceWarning.ByteRTCMediaDeviceWarningSetBluetoothModeUnsupport,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MediaDeviceWarning;
}());
var t_RemoteVideoRenderPosition = /** @class */ (function () {
    function t_RemoteVideoRenderPosition() {
    }
    t_RemoteVideoRenderPosition.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteVideoRenderPosition.AFTER_DECODER] = RemoteVideoRenderPosition.AFTER_DECODER,
            _a[exports.RemoteVideoRenderPosition.AFTER_POST_PROCESS] = RemoteVideoRenderPosition.AFTER_POST_PROCESS,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteVideoRenderPosition.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RemoteVideoRenderPosition.AFTER_DECODER] = exports.RemoteVideoRenderPosition.AFTER_DECODER,
            _a[RemoteVideoRenderPosition.AFTER_POST_PROCESS] = exports.RemoteVideoRenderPosition.AFTER_POST_PROCESS,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteVideoRenderPosition.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteVideoRenderPosition.AFTER_DECODER] = ByteRTCRemoteVideoRenderPosition.ByteRTCRemoteVideoRenderPositionAfterDecoder,
            _a[exports.RemoteVideoRenderPosition.AFTER_POST_PROCESS] = ByteRTCRemoteVideoRenderPosition.ByteRTCRemoteVideoRenderPositionAfterPostprocess,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteVideoRenderPosition.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRemoteVideoRenderPosition.ByteRTCRemoteVideoRenderPositionAfterDecoder] = exports.RemoteVideoRenderPosition.AFTER_DECODER,
            _a[ByteRTCRemoteVideoRenderPosition.ByteRTCRemoteVideoRenderPositionAfterPostprocess] = exports.RemoteVideoRenderPosition.AFTER_POST_PROCESS,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RemoteVideoRenderPosition;
}());
var t_TranscoderLayoutRegionType = /** @class */ (function () {
    function t_TranscoderLayoutRegionType() {
    }
    t_TranscoderLayoutRegionType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.TranscoderLayoutRegionType.LAYOUT_REGION_TYPE_VIDEO_STREAM] = TranscoderLayoutRegionType.LAYOUT_REGION_TYPE_VIDEO_STREAM,
            _a[exports.TranscoderLayoutRegionType.LAYOUT_REGION_TYPE_IMAGE] = TranscoderLayoutRegionType.LAYOUT_REGION_TYPE_IMAGE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_TranscoderLayoutRegionType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[TranscoderLayoutRegionType.LAYOUT_REGION_TYPE_VIDEO_STREAM] = exports.TranscoderLayoutRegionType.LAYOUT_REGION_TYPE_VIDEO_STREAM,
            _a[TranscoderLayoutRegionType.LAYOUT_REGION_TYPE_IMAGE] = exports.TranscoderLayoutRegionType.LAYOUT_REGION_TYPE_IMAGE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_TranscoderLayoutRegionType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.TranscoderLayoutRegionType.ByteRTCTranscoderLayoutRegionTypeVideoStream] = ByteRTCTranscoderLayoutRegionType.ByteRTCTranscoderLayoutRegionTypeVideoStream,
            _a[exports.TranscoderLayoutRegionType.ByteRTCTranscoderLayoutRegionTypeImage] = ByteRTCTranscoderLayoutRegionType.ByteRTCTranscoderLayoutRegionTypeImage,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_TranscoderLayoutRegionType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCTranscoderLayoutRegionType.ByteRTCTranscoderLayoutRegionTypeVideoStream] = exports.TranscoderLayoutRegionType.ByteRTCTranscoderLayoutRegionTypeVideoStream,
            _a[ByteRTCTranscoderLayoutRegionType.ByteRTCTranscoderLayoutRegionTypeImage] = exports.TranscoderLayoutRegionType.ByteRTCTranscoderLayoutRegionTypeImage,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_TranscoderLayoutRegionType;
}());
var t_LocalVideoStreamError = /** @class */ (function () {
    function t_LocalVideoStreamError() {
    }
    t_LocalVideoStreamError.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_OK] = LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_OK,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_FAILURE] = LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_FAILURE,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_NO_PERMISSION] = LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_NO_PERMISSION,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_BUSY] = LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_BUSY,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_NOT_FOUND] = LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_NOT_FOUND,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_CAPTURE_FAILURE] = LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_CAPTURE_FAILURE,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_ENCODE_FAILURE] = LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_ENCODE_FAILURE,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_DISCONNECTED] = LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_DISCONNECTED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalVideoStreamError.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_OK] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_OK,
            _a[LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_FAILURE] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_FAILURE,
            _a[LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_NO_PERMISSION] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_NO_PERMISSION,
            _a[LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_BUSY] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_BUSY,
            _a[LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_NOT_FOUND] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_NOT_FOUND,
            _a[LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_CAPTURE_FAILURE] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_CAPTURE_FAILURE,
            _a[LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_ENCODE_FAILURE] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_ENCODE_FAILURE,
            _a[LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_DISCONNECTED] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_DISCONNECTED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalVideoStreamError.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_OK] = ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorOk,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_FAILURE] = ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorFailure,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_NO_PERMISSION] = ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorDeviceNoPermission,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_BUSY] = ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorDeviceBusy,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_NOT_FOUND] = ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorDeviceNotFound,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_CAPTURE_FAILURE] = ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorCaptureFailure,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_ENCODE_FAILURE] = ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorEncodeFailure,
            _a[exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_DISCONNECTED] = ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorDeviceDisconnected,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalVideoStreamError.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorOk] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_OK,
            _a[ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorFailure] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_FAILURE,
            _a[ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorDeviceNoPermission] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_NO_PERMISSION,
            _a[ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorDeviceBusy] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_BUSY,
            _a[ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorDeviceNotFound] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_NOT_FOUND,
            _a[ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorCaptureFailure] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_CAPTURE_FAILURE,
            _a[ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorEncodeFailure] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_ENCODE_FAILURE,
            _a[ByteRTCLocalVideoStreamError.ByteRTCLocalVideoStreamErrorDeviceDisconnected] = exports.LocalVideoStreamError.LOCAL_VIDEO_STREAM_ERROR_DEVICE_DISCONNECTED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_LocalVideoStreamError;
}());
var t_UserVisibilityChangeError = /** @class */ (function () {
    function t_UserVisibilityChangeError() {
    }
    t_UserVisibilityChangeError.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.UserVisibilityChangeError.OK] = UserVisibilityChangeError.OK,
            _a[exports.UserVisibilityChangeError.UNKNOWN] = UserVisibilityChangeError.UNKNOWN,
            _a[exports.UserVisibilityChangeError.TOO_MANY_VISIBLE_USER] = UserVisibilityChangeError.TOO_MANY_VISIBLE_USER,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_UserVisibilityChangeError.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[UserVisibilityChangeError.OK] = exports.UserVisibilityChangeError.OK,
            _a[UserVisibilityChangeError.UNKNOWN] = exports.UserVisibilityChangeError.UNKNOWN,
            _a[UserVisibilityChangeError.TOO_MANY_VISIBLE_USER] = exports.UserVisibilityChangeError.TOO_MANY_VISIBLE_USER,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_UserVisibilityChangeError.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.UserVisibilityChangeError.OK] = ByteRTCUserVisibilityChangeError.ByteRTCUserVisibilityChangeErrorOk,
            _a[exports.UserVisibilityChangeError.UNKNOWN] = ByteRTCUserVisibilityChangeError.ByteRTCUserVisibilityChangeErrorUnknown,
            _a[exports.UserVisibilityChangeError.TOO_MANY_VISIBLE_USER] = ByteRTCUserVisibilityChangeError.ByteRTCUserVisibilityChangeErrorTooManyVisibleUser,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_UserVisibilityChangeError.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCUserVisibilityChangeError.ByteRTCUserVisibilityChangeErrorOk] = exports.UserVisibilityChangeError.OK,
            _a[ByteRTCUserVisibilityChangeError.ByteRTCUserVisibilityChangeErrorUnknown] = exports.UserVisibilityChangeError.UNKNOWN,
            _a[ByteRTCUserVisibilityChangeError.ByteRTCUserVisibilityChangeErrorTooManyVisibleUser] = exports.UserVisibilityChangeError.TOO_MANY_VISIBLE_USER,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_UserVisibilityChangeError;
}());
var t_LocalAudioStreamError = /** @class */ (function () {
    function t_LocalAudioStreamError() {
    }
    t_LocalAudioStreamError.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_OK] = LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_OK,
            _a[exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_FAILURE] = LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_FAILURE,
            _a[exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_DEVICE_NO_PERMISSION] = LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_DEVICE_NO_PERMISSION,
            _a[exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_RECORD_FAILURE] = LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_RECORD_FAILURE,
            _a[exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_ENCODE_FAILURE] = LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_ENCODE_FAILURE,
            _a[exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_NO_RECORDING_DEVICE] = LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_NO_RECORDING_DEVICE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalAudioStreamError.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_OK] = exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_OK,
            _a[LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_FAILURE] = exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_FAILURE,
            _a[LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_DEVICE_NO_PERMISSION] = exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_DEVICE_NO_PERMISSION,
            _a[LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_RECORD_FAILURE] = exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_RECORD_FAILURE,
            _a[LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_ENCODE_FAILURE] = exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_ENCODE_FAILURE,
            _a[LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_NO_RECORDING_DEVICE] = exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_NO_RECORDING_DEVICE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalAudioStreamError.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_OK] = ByteRTCLocalAudioStreamError.ByteRTCLocalAudioStreamErrorOk,
            _a[exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_FAILURE] = ByteRTCLocalAudioStreamError.ByteRTCLocalAudioStreamErrorFailure,
            _a[exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_DEVICE_NO_PERMISSION] = ByteRTCLocalAudioStreamError.ByteRTCLocalAudioStreamErrorDeviceNoPermission,
            _a[exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_RECORD_FAILURE] = ByteRTCLocalAudioStreamError.ByteRTCLocalAudioStreamErrorRecordFailure,
            _a[exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_ENCODE_FAILURE] = ByteRTCLocalAudioStreamError.ByteRTCLocalAudioStreamErrorEncodeFailure,
            _a[exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_NO_RECORDING_DEVICE] = ByteRTCLocalAudioStreamError.ByteRTCLocalAudioStreamErrorNoRecordingDevice,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalAudioStreamError.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCLocalAudioStreamError.ByteRTCLocalAudioStreamErrorOk] = exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_OK,
            _a[ByteRTCLocalAudioStreamError.ByteRTCLocalAudioStreamErrorFailure] = exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_FAILURE,
            _a[ByteRTCLocalAudioStreamError.ByteRTCLocalAudioStreamErrorDeviceNoPermission] = exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_DEVICE_NO_PERMISSION,
            _a[ByteRTCLocalAudioStreamError.ByteRTCLocalAudioStreamErrorRecordFailure] = exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_RECORD_FAILURE,
            _a[ByteRTCLocalAudioStreamError.ByteRTCLocalAudioStreamErrorEncodeFailure] = exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_ENCODE_FAILURE,
            _a[ByteRTCLocalAudioStreamError.ByteRTCLocalAudioStreamErrorNoRecordingDevice] = exports.LocalAudioStreamError.LOCAL_AUDIO_STREAM_ERROR_NO_RECORDING_DEVICE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_LocalAudioStreamError;
}());
var t_SyncInfoStreamType = /** @class */ (function () {
    function t_SyncInfoStreamType() {
    }
    t_SyncInfoStreamType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SyncInfoStreamType.SYNC_INFO_STREAM_TYPE_AUDIO] = SyncInfoStreamType.SYNC_INFO_STREAM_TYPE_AUDIO,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SyncInfoStreamType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[SyncInfoStreamType.SYNC_INFO_STREAM_TYPE_AUDIO] = exports.SyncInfoStreamType.SYNC_INFO_STREAM_TYPE_AUDIO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SyncInfoStreamType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SyncInfoStreamType.SYNC_INFO_STREAM_TYPE_AUDIO] = ByteRTCSyncInfoStreamType.ByteRTCSyncInfoStreamTypeAudio,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SyncInfoStreamType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCSyncInfoStreamType.ByteRTCSyncInfoStreamTypeAudio] = exports.SyncInfoStreamType.SYNC_INFO_STREAM_TYPE_AUDIO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_SyncInfoStreamType;
}());
var t_MixedStreamAudioProfile = /** @class */ (function () {
    function t_MixedStreamAudioProfile() {
    }
    t_MixedStreamAudioProfile.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_LC] = MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_LC,
            _a[exports.MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_HEV1] = MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_HEV1,
            _a[exports.MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_HEV2] = MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_HEV2,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamAudioProfile.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_LC] = exports.MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_LC,
            _a[MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_HEV1] = exports.MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_HEV1,
            _a[MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_HEV2] = exports.MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_HEV2,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamAudioProfile.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_LC] = ByteRTCMixedStreamAudioProfile.ByteRTCMixedStreamAudioProfileLC,
            _a[exports.MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_HEV1] = ByteRTCMixedStreamAudioProfile.ByteRTCMixedStreamAudioProfileHEv1,
            _a[exports.MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_HEV2] = ByteRTCMixedStreamAudioProfile.ByteRTCMixedStreamAudioProfileHEv2,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamAudioProfile.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMixedStreamAudioProfile.ByteRTCMixedStreamAudioProfileLC] = exports.MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_LC,
            _a[ByteRTCMixedStreamAudioProfile.ByteRTCMixedStreamAudioProfileHEv1] = exports.MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_HEV1,
            _a[ByteRTCMixedStreamAudioProfile.ByteRTCMixedStreamAudioProfileHEv2] = exports.MixedStreamAudioProfile.MIXED_STREAM_AUDIO_PROFILE_HEV2,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MixedStreamAudioProfile;
}());
var t_PerformanceAlarmMode = /** @class */ (function () {
    function t_PerformanceAlarmMode() {
    }
    t_PerformanceAlarmMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PerformanceAlarmMode.NORMAL] = PerformanceAlarmMode.NORMAL,
            _a[exports.PerformanceAlarmMode.SIMULCAST] = PerformanceAlarmMode.SIMULCAST,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PerformanceAlarmMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[PerformanceAlarmMode.NORMAL] = exports.PerformanceAlarmMode.NORMAL,
            _a[PerformanceAlarmMode.SIMULCAST] = exports.PerformanceAlarmMode.SIMULCAST,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PerformanceAlarmMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PerformanceAlarmMode.NORMAL] = ByteRTCPerformanceAlarmMode.ByteRTCPerformanceAlarmModeNormal,
            _a[exports.PerformanceAlarmMode.SIMULCAST] = ByteRTCPerformanceAlarmMode.ByteRTCPerformanceAlarmModeSimulcast,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PerformanceAlarmMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCPerformanceAlarmMode.ByteRTCPerformanceAlarmModeNormal] = exports.PerformanceAlarmMode.NORMAL,
            _a[ByteRTCPerformanceAlarmMode.ByteRTCPerformanceAlarmModeSimulcast] = exports.PerformanceAlarmMode.SIMULCAST,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_PerformanceAlarmMode;
}());
var t_RecordingErrorCode = /** @class */ (function () {
    function t_RecordingErrorCode() {
    }
    t_RecordingErrorCode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RecordingErrorCode.RECORDING_ERROR_CODE_OK] = RecordingErrorCode.RECORDING_ERROR_CODE_OK,
            _a[exports.RecordingErrorCode.RECORDING_ERROR_CODE_NO_PERMISSION] = RecordingErrorCode.RECORDING_ERROR_CODE_NO_PERMISSION,
            _a[exports.RecordingErrorCode.RECORDING_ERROR_CODE_NOT_SUPPORT] = RecordingErrorCode.RECORDING_ERROR_CODE_NOT_SUPPORT,
            _a[exports.RecordingErrorCode.RECORDING_ERROR_CODE_NO_OTHER] = RecordingErrorCode.RECORDING_ERROR_CODE_NO_OTHER,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RecordingErrorCode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RecordingErrorCode.RECORDING_ERROR_CODE_OK] = exports.RecordingErrorCode.RECORDING_ERROR_CODE_OK,
            _a[RecordingErrorCode.RECORDING_ERROR_CODE_NO_PERMISSION] = exports.RecordingErrorCode.RECORDING_ERROR_CODE_NO_PERMISSION,
            _a[RecordingErrorCode.RECORDING_ERROR_CODE_NOT_SUPPORT] = exports.RecordingErrorCode.RECORDING_ERROR_CODE_NOT_SUPPORT,
            _a[RecordingErrorCode.RECORDING_ERROR_CODE_NO_OTHER] = exports.RecordingErrorCode.RECORDING_ERROR_CODE_NO_OTHER,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RecordingErrorCode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RecordingErrorCode.ByteRTCRecordingErrorCodeOk] = ByteRTCRecordingErrorCode.ByteRTCRecordingErrorCodeOk,
            _a[exports.RecordingErrorCode.ByteRTCRecordingErrorCodeNoPermission] = ByteRTCRecordingErrorCode.ByteRTCRecordingErrorCodeNoPermission,
            _a[exports.RecordingErrorCode.ByteRTCRecordingErrorCodeNotSupport] = ByteRTCRecordingErrorCode.ByteRTCRecordingErrorCodeNotSupport,
            _a[exports.RecordingErrorCode.ByteRTCRecordingErrorCodeOther] = ByteRTCRecordingErrorCode.ByteRTCRecordingErrorCodeOther,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RecordingErrorCode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRecordingErrorCode.ByteRTCRecordingErrorCodeOk] = exports.RecordingErrorCode.ByteRTCRecordingErrorCodeOk,
            _a[ByteRTCRecordingErrorCode.ByteRTCRecordingErrorCodeNoPermission] = exports.RecordingErrorCode.ByteRTCRecordingErrorCodeNoPermission,
            _a[ByteRTCRecordingErrorCode.ByteRTCRecordingErrorCodeNotSupport] = exports.RecordingErrorCode.ByteRTCRecordingErrorCodeNotSupport,
            _a[ByteRTCRecordingErrorCode.ByteRTCRecordingErrorCodeOther] = exports.RecordingErrorCode.ByteRTCRecordingErrorCodeOther,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RecordingErrorCode;
}());
var t_EchoTestResult = /** @class */ (function () {
    function t_EchoTestResult() {
    }
    t_EchoTestResult.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.EchoTestResult.ECHO_TEST_SUCCESS] = EchoTestResult.ECHO_TEST_SUCCESS,
            _a[exports.EchoTestResult.ECHO_TEST_TIMEOUT] = EchoTestResult.ECHO_TEST_TIMEOUT,
            _a[exports.EchoTestResult.ECHO_TEST_INTERVAL_SHORT] = EchoTestResult.ECHO_TEST_INTERVAL_SHORT,
            _a[exports.EchoTestResult.ECHO_TEST_AUDIO_DEVICE_ERROR] = EchoTestResult.ECHO_TEST_AUDIO_DEVICE_ERROR,
            _a[exports.EchoTestResult.ECHO_TEST_VIDEO_DEVICE_ERROR] = EchoTestResult.ECHO_TEST_VIDEO_DEVICE_ERROR,
            _a[exports.EchoTestResult.ECHO_TEST_AUDIO_RECEIVE_ERROR] = EchoTestResult.ECHO_TEST_AUDIO_RECEIVE_ERROR,
            _a[exports.EchoTestResult.ECHO_TEST_VIDEO_RECEIVE_ERROR] = EchoTestResult.ECHO_TEST_VIDEO_RECEIVE_ERROR,
            _a[exports.EchoTestResult.ECHO_TEST_INTERNAL_ERROR] = EchoTestResult.ECHO_TEST_INTERNAL_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_EchoTestResult.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[EchoTestResult.ECHO_TEST_SUCCESS] = exports.EchoTestResult.ECHO_TEST_SUCCESS,
            _a[EchoTestResult.ECHO_TEST_TIMEOUT] = exports.EchoTestResult.ECHO_TEST_TIMEOUT,
            _a[EchoTestResult.ECHO_TEST_INTERVAL_SHORT] = exports.EchoTestResult.ECHO_TEST_INTERVAL_SHORT,
            _a[EchoTestResult.ECHO_TEST_AUDIO_DEVICE_ERROR] = exports.EchoTestResult.ECHO_TEST_AUDIO_DEVICE_ERROR,
            _a[EchoTestResult.ECHO_TEST_VIDEO_DEVICE_ERROR] = exports.EchoTestResult.ECHO_TEST_VIDEO_DEVICE_ERROR,
            _a[EchoTestResult.ECHO_TEST_AUDIO_RECEIVE_ERROR] = exports.EchoTestResult.ECHO_TEST_AUDIO_RECEIVE_ERROR,
            _a[EchoTestResult.ECHO_TEST_VIDEO_RECEIVE_ERROR] = exports.EchoTestResult.ECHO_TEST_VIDEO_RECEIVE_ERROR,
            _a[EchoTestResult.ECHO_TEST_INTERNAL_ERROR] = exports.EchoTestResult.ECHO_TEST_INTERNAL_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_EchoTestResult.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.EchoTestResult.ByteRTCEchoTestResultSuccess] = ByteRTCEchoTestResult.ByteRTCEchoTestResultSuccess,
            _a[exports.EchoTestResult.ByteRTCEchoTestResultTimeout] = ByteRTCEchoTestResult.ByteRTCEchoTestResultTimeout,
            _a[exports.EchoTestResult.ByteRTCEchoTestResultIntervalShort] = ByteRTCEchoTestResult.ByteRTCEchoTestResultIntervalShort,
            _a[exports.EchoTestResult.ByteRTCEchoTestResultAudioDeviceError] = ByteRTCEchoTestResult.ByteRTCEchoTestResultAudioDeviceError,
            _a[exports.EchoTestResult.ByteRTCEchoTestResultVideoDeviceError] = ByteRTCEchoTestResult.ByteRTCEchoTestResultVideoDeviceError,
            _a[exports.EchoTestResult.ByteRTCEchoTestResultAudioReceiveError] = ByteRTCEchoTestResult.ByteRTCEchoTestResultAudioReceiveError,
            _a[exports.EchoTestResult.ByteRTCEchoTestResultVideoReceiveError] = ByteRTCEchoTestResult.ByteRTCEchoTestResultVideoReceiveError,
            _a[exports.EchoTestResult.ByteRTCEchoTestResultInternalError] = ByteRTCEchoTestResult.ByteRTCEchoTestResultInternalError,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_EchoTestResult.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCEchoTestResult.ByteRTCEchoTestResultSuccess] = exports.EchoTestResult.ByteRTCEchoTestResultSuccess,
            _a[ByteRTCEchoTestResult.ByteRTCEchoTestResultTimeout] = exports.EchoTestResult.ByteRTCEchoTestResultTimeout,
            _a[ByteRTCEchoTestResult.ByteRTCEchoTestResultIntervalShort] = exports.EchoTestResult.ByteRTCEchoTestResultIntervalShort,
            _a[ByteRTCEchoTestResult.ByteRTCEchoTestResultAudioDeviceError] = exports.EchoTestResult.ByteRTCEchoTestResultAudioDeviceError,
            _a[ByteRTCEchoTestResult.ByteRTCEchoTestResultVideoDeviceError] = exports.EchoTestResult.ByteRTCEchoTestResultVideoDeviceError,
            _a[ByteRTCEchoTestResult.ByteRTCEchoTestResultAudioReceiveError] = exports.EchoTestResult.ByteRTCEchoTestResultAudioReceiveError,
            _a[ByteRTCEchoTestResult.ByteRTCEchoTestResultVideoReceiveError] = exports.EchoTestResult.ByteRTCEchoTestResultVideoReceiveError,
            _a[ByteRTCEchoTestResult.ByteRTCEchoTestResultInternalError] = exports.EchoTestResult.ByteRTCEchoTestResultInternalError,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_EchoTestResult;
}());
var t_SubscribeState = /** @class */ (function () {
    function t_SubscribeState() {
    }
    t_SubscribeState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SubscribeState.SUBSCRIBE_STATE_SUCCESS] = SubscribeState.SUBSCRIBE_STATE_SUCCESS,
            _a[exports.SubscribeState.SUBSCRIBE_STATE_FAILED_NOT_IN_ROOM] = SubscribeState.SUBSCRIBE_STATE_FAILED_NOT_IN_ROOM,
            _a[exports.SubscribeState.SUBSCRIBE_STATE_FAILED_STREAM_NOT_FOUND] = SubscribeState.SUBSCRIBE_STATE_FAILED_STREAM_NOT_FOUND,
            _a[exports.SubscribeState.SUBSCRIBE_STATE_FAILED_SIGNAL] = SubscribeState.SUBSCRIBE_STATE_FAILED_SIGNAL,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubscribeState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[SubscribeState.SUBSCRIBE_STATE_SUCCESS] = exports.SubscribeState.SUBSCRIBE_STATE_SUCCESS,
            _a[SubscribeState.SUBSCRIBE_STATE_FAILED_NOT_IN_ROOM] = exports.SubscribeState.SUBSCRIBE_STATE_FAILED_NOT_IN_ROOM,
            _a[SubscribeState.SUBSCRIBE_STATE_FAILED_STREAM_NOT_FOUND] = exports.SubscribeState.SUBSCRIBE_STATE_FAILED_STREAM_NOT_FOUND,
            _a[SubscribeState.SUBSCRIBE_STATE_FAILED_SIGNAL] = exports.SubscribeState.SUBSCRIBE_STATE_FAILED_SIGNAL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubscribeState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SubscribeState.SUBSCRIBE_STATE_SUCCESS] = ByteRTCSubscribeState.ByteRTCSubscribeStateSuccess,
            _a[exports.SubscribeState.SUBSCRIBE_STATE_FAILED_NOT_IN_ROOM] = ByteRTCSubscribeState.ByteRTCSubscribeStateFailedNotInRoom,
            _a[exports.SubscribeState.SUBSCRIBE_STATE_FAILED_STREAM_NOT_FOUND] = ByteRTCSubscribeState.ByteRTCSubscribeStateFailedStreamNotFound,
            _a[exports.SubscribeState.ByteRTCSubscribeStateFailedOverLimit] = ByteRTCSubscribeState.ByteRTCSubscribeStateFailedOverLimit,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubscribeState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCSubscribeState.ByteRTCSubscribeStateSuccess] = exports.SubscribeState.SUBSCRIBE_STATE_SUCCESS,
            _a[ByteRTCSubscribeState.ByteRTCSubscribeStateFailedNotInRoom] = exports.SubscribeState.SUBSCRIBE_STATE_FAILED_NOT_IN_ROOM,
            _a[ByteRTCSubscribeState.ByteRTCSubscribeStateFailedStreamNotFound] = exports.SubscribeState.SUBSCRIBE_STATE_FAILED_STREAM_NOT_FOUND,
            _a[ByteRTCSubscribeState.ByteRTCSubscribeStateFailedOverLimit] = exports.SubscribeState.ByteRTCSubscribeStateFailedOverLimit,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_SubscribeState;
}());
var t_VirtualBackgroundSourceType = /** @class */ (function () {
    function t_VirtualBackgroundSourceType() {
    }
    t_VirtualBackgroundSourceType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VirtualBackgroundSourceType.COLOR] = VirtualBackgroundSourceType.COLOR,
            _a[exports.VirtualBackgroundSourceType.IMAGE] = VirtualBackgroundSourceType.IMAGE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VirtualBackgroundSourceType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VirtualBackgroundSourceType.COLOR] = exports.VirtualBackgroundSourceType.COLOR,
            _a[VirtualBackgroundSourceType.IMAGE] = exports.VirtualBackgroundSourceType.IMAGE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VirtualBackgroundSourceType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VirtualBackgroundSourceType.COLOR] = ByteRTCVirtualBackgroundSourceType.ByteRTCVirtualBackgroundSourceTypeColor,
            _a[exports.VirtualBackgroundSourceType.ByteRTCVirtualBackgroundSourceTypeImage] = ByteRTCVirtualBackgroundSourceType.ByteRTCVirtualBackgroundSourceTypeImage,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VirtualBackgroundSourceType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVirtualBackgroundSourceType.ByteRTCVirtualBackgroundSourceTypeColor] = exports.VirtualBackgroundSourceType.COLOR,
            _a[ByteRTCVirtualBackgroundSourceType.ByteRTCVirtualBackgroundSourceTypeImage] = exports.VirtualBackgroundSourceType.ByteRTCVirtualBackgroundSourceTypeImage,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VirtualBackgroundSourceType;
}());
var t_RemoteAudioStateChangeReason = /** @class */ (function () {
    function t_RemoteAudioStateChangeReason() {
    }
    t_RemoteAudioStateChangeReason.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_CONGESTION] = RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_CONGESTION,
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_RECOVERY] = RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_RECOVERY,
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_MUTED] = RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_MUTED,
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_UNMUTED] = RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_UNMUTED,
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_MUTED] = RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_MUTED,
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_UNMUTED] = RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_UNMUTED,
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_OFFLINE] = RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_OFFLINE,
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_INTERNAL] = RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_INTERNAL,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteAudioStateChangeReason.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_CONGESTION] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_CONGESTION,
            _a[RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_RECOVERY] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_RECOVERY,
            _a[RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_MUTED] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_MUTED,
            _a[RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_UNMUTED] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_UNMUTED,
            _a[RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_MUTED] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_MUTED,
            _a[RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_UNMUTED] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_UNMUTED,
            _a[RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_OFFLINE] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_OFFLINE,
            _a[RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_INTERNAL] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_INTERNAL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteAudioStateChangeReason.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_CONGESTION] = ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonNetworkCongestion,
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_RECOVERY] = ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonNetworkRecovery,
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_MUTED] = ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonLocalMuted,
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_UNMUTED] = ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonLocalUnmuted,
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_MUTED] = ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonRemoteMuted,
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_UNMUTED] = ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonRemoteUnmuted,
            _a[exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_OFFLINE] = ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonRemoteOffline,
            _a[exports.RemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonInternal] = ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonInternal,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteAudioStateChangeReason.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonNetworkCongestion] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_CONGESTION,
            _a[ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonNetworkRecovery] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_NETWORK_RECOVERY,
            _a[ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonLocalMuted] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_MUTED,
            _a[ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonLocalUnmuted] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_LOCAL_UNMUTED,
            _a[ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonRemoteMuted] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_MUTED,
            _a[ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonRemoteUnmuted] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_UNMUTED,
            _a[ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonRemoteOffline] = exports.RemoteAudioStateChangeReason.REMOTE_AUDIO_STATE_CHANGE_REASON_REMOTE_OFFLINE,
            _a[ByteRTCRemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonInternal] = exports.RemoteAudioStateChangeReason.ByteRTCRemoteAudioStateChangeReasonInternal,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RemoteAudioStateChangeReason;
}());
var t_PlayerError = /** @class */ (function () {
    function t_PlayerError() {
    }
    t_PlayerError.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PlayerError.OK] = PlayerError.OK,
            _a[exports.PlayerError.FORMAT_NOT_SUPPORT] = PlayerError.FORMAT_NOT_SUPPORT,
            _a[exports.PlayerError.INVALID_PATH] = PlayerError.INVALID_PATH,
            _a[exports.PlayerError.INVALID_STATE] = PlayerError.INVALID_STATE,
            _a[exports.PlayerError.INVALID_POSITION] = PlayerError.INVALID_POSITION,
            _a[exports.PlayerError.INVALID_VOLUME] = PlayerError.INVALID_VOLUME,
            _a[exports.PlayerError.INVALID_PITCH] = PlayerError.INVALID_PITCH,
            _a[exports.PlayerError.INVALID_AUDIO_TRACK_INDEX] = PlayerError.INVALID_AUDIO_TRACK_INDEX,
            _a[exports.PlayerError.INVALID_PLAYBACK_SPEED] = PlayerError.INVALID_PLAYBACK_SPEED,
            _a[exports.PlayerError.INVALID_EFFECT_ID] = PlayerError.INVALID_EFFECT_ID,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PlayerError.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[PlayerError.OK] = exports.PlayerError.OK,
            _a[PlayerError.FORMAT_NOT_SUPPORT] = exports.PlayerError.FORMAT_NOT_SUPPORT,
            _a[PlayerError.INVALID_PATH] = exports.PlayerError.INVALID_PATH,
            _a[PlayerError.INVALID_STATE] = exports.PlayerError.INVALID_STATE,
            _a[PlayerError.INVALID_POSITION] = exports.PlayerError.INVALID_POSITION,
            _a[PlayerError.INVALID_VOLUME] = exports.PlayerError.INVALID_VOLUME,
            _a[PlayerError.INVALID_PITCH] = exports.PlayerError.INVALID_PITCH,
            _a[PlayerError.INVALID_AUDIO_TRACK_INDEX] = exports.PlayerError.INVALID_AUDIO_TRACK_INDEX,
            _a[PlayerError.INVALID_PLAYBACK_SPEED] = exports.PlayerError.INVALID_PLAYBACK_SPEED,
            _a[PlayerError.INVALID_EFFECT_ID] = exports.PlayerError.INVALID_EFFECT_ID,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PlayerError.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PlayerError.OK] = ByteRTCPlayerError.ByteRTCPlayerErrorOK,
            _a[exports.PlayerError.FORMAT_NOT_SUPPORT] = ByteRTCPlayerError.ByteRTCPlayerErrorFormatNotSupport,
            _a[exports.PlayerError.ByteRTCPlayerErrorInvalidPath] = ByteRTCPlayerError.ByteRTCPlayerErrorInvalidPath,
            _a[exports.PlayerError.ByteRTCPlayerErrorInvalidState] = ByteRTCPlayerError.ByteRTCPlayerErrorInvalidState,
            _a[exports.PlayerError.ByteRTCPlayerErrorInvalidPosition] = ByteRTCPlayerError.ByteRTCPlayerErrorInvalidPosition,
            _a[exports.PlayerError.ByteRTCPlayerErrorInvalidVolume] = ByteRTCPlayerError.ByteRTCPlayerErrorInvalidVolume,
            _a[exports.PlayerError.ByteRTCPlayerErrorInvalidPitch] = ByteRTCPlayerError.ByteRTCPlayerErrorInvalidPitch,
            _a[exports.PlayerError.ByteRTCPlayerErrorInvalidAudioTrackIndex] = ByteRTCPlayerError.ByteRTCPlayerErrorInvalidAudioTrackIndex,
            _a[exports.PlayerError.ByteRTCPlayerErrorInvalidPlaybackSpeed] = ByteRTCPlayerError.ByteRTCPlayerErrorInvalidPlaybackSpeed,
            _a[exports.PlayerError.ByteRTCPlayerErrorInvalidEffectId] = ByteRTCPlayerError.ByteRTCPlayerErrorInvalidEffectId,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PlayerError.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCPlayerError.ByteRTCPlayerErrorOK] = exports.PlayerError.OK,
            _a[ByteRTCPlayerError.ByteRTCPlayerErrorFormatNotSupport] = exports.PlayerError.FORMAT_NOT_SUPPORT,
            _a[ByteRTCPlayerError.ByteRTCPlayerErrorInvalidPath] = exports.PlayerError.ByteRTCPlayerErrorInvalidPath,
            _a[ByteRTCPlayerError.ByteRTCPlayerErrorInvalidState] = exports.PlayerError.ByteRTCPlayerErrorInvalidState,
            _a[ByteRTCPlayerError.ByteRTCPlayerErrorInvalidPosition] = exports.PlayerError.ByteRTCPlayerErrorInvalidPosition,
            _a[ByteRTCPlayerError.ByteRTCPlayerErrorInvalidVolume] = exports.PlayerError.ByteRTCPlayerErrorInvalidVolume,
            _a[ByteRTCPlayerError.ByteRTCPlayerErrorInvalidPitch] = exports.PlayerError.ByteRTCPlayerErrorInvalidPitch,
            _a[ByteRTCPlayerError.ByteRTCPlayerErrorInvalidAudioTrackIndex] = exports.PlayerError.ByteRTCPlayerErrorInvalidAudioTrackIndex,
            _a[ByteRTCPlayerError.ByteRTCPlayerErrorInvalidPlaybackSpeed] = exports.PlayerError.ByteRTCPlayerErrorInvalidPlaybackSpeed,
            _a[ByteRTCPlayerError.ByteRTCPlayerErrorInvalidEffectId] = exports.PlayerError.ByteRTCPlayerErrorInvalidEffectId,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_PlayerError;
}());
var t_ReturnStatus = /** @class */ (function () {
    function t_ReturnStatus() {
    }
    t_ReturnStatus.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ReturnStatus.RETURN_STATUS_SUCCESS] = ReturnStatus.RETURN_STATUS_SUCCESS,
            _a[exports.ReturnStatus.RETURN_STATUS_FAILURE] = ReturnStatus.RETURN_STATUS_FAILURE,
            _a[exports.ReturnStatus.RETURN_STATUS_PARAMETER_ERR] = ReturnStatus.RETURN_STATUS_PARAMETER_ERR,
            _a[exports.ReturnStatus.RETURN_STATUS_WRONG_STATE] = ReturnStatus.RETURN_STATUS_WRONG_STATE,
            _a[exports.ReturnStatus.RETURN_STATUS_HAS_IN_ROOM] = ReturnStatus.RETURN_STATUS_HAS_IN_ROOM,
            _a[exports.ReturnStatus.RETURN_STATUS_HAS_IN_LOGIN] = ReturnStatus.RETURN_STATUS_HAS_IN_LOGIN,
            _a[exports.ReturnStatus.RETURN_STATUS_HAS_IN_ECHO_TEST] = ReturnStatus.RETURN_STATUS_HAS_IN_ECHO_TEST,
            _a[exports.ReturnStatus.RETURN_STATUS_NEITHER_VIDEO_NOR_AUDIO] = ReturnStatus.RETURN_STATUS_NEITHER_VIDEO_NOR_AUDIO,
            _a[exports.ReturnStatus.RETURN_STATUS_ROOMID_IN_USE] = ReturnStatus.RETURN_STATUS_ROOMID_IN_USE,
            _a[exports.ReturnStatus.RETURN_STATUS_SCREEN_NOT_SUPPORT] = ReturnStatus.RETURN_STATUS_SCREEN_NOT_SUPPORT,
            _a[exports.ReturnStatus.RETURN_STATUS_NOT_SUPPORT] = ReturnStatus.RETURN_STATUS_NOT_SUPPORT,
            _a[exports.ReturnStatus.RETURN_STATUS_RESOURCE_OVERFLOW] = ReturnStatus.RETURN_STATUS_RESOURCE_OVERFLOW,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_NO_FRAME] = ReturnStatus.RETURN_STATUS_AUDIO_NO_FRAME,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_NOT_IMPLEMENTED] = ReturnStatus.RETURN_STATUS_AUDIO_NOT_IMPLEMENTED,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_NO_PERMISSION] = ReturnStatus.RETURN_STATUS_AUDIO_NO_PERMISSION,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_NOT_EXISTS] = ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_NOT_EXISTS,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_FORMAT_NOT_SUPPORT] = ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_FORMAT_NOT_SUPPORT,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_NO_DEVICE] = ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_NO_DEVICE,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_CAN_NOT_USE] = ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_CAN_NOT_USE,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_INIT_FAILED] = ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_INIT_FAILED,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_START_FAILED] = ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_START_FAILED,
            _a[exports.ReturnStatus.RETURN_STATUS_NATIVE_IN_VALID] = ReturnStatus.RETURN_STATUS_NATIVE_IN_VALID,
            _a[exports.ReturnStatus.RETURN_STATUS_VIDEO_NOT_SUPPORT] = ReturnStatus.RETURN_STATUS_VIDEO_NOT_SUPPORT,
            _a[exports.ReturnStatus.RETURN_STATUS_VIDEO_TIMESTAMP_WARNING] = ReturnStatus.RETURN_STATUS_VIDEO_TIMESTAMP_WARNING,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ReturnStatus.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ReturnStatus.RETURN_STATUS_SUCCESS] = exports.ReturnStatus.RETURN_STATUS_SUCCESS,
            _a[ReturnStatus.RETURN_STATUS_FAILURE] = exports.ReturnStatus.RETURN_STATUS_FAILURE,
            _a[ReturnStatus.RETURN_STATUS_PARAMETER_ERR] = exports.ReturnStatus.RETURN_STATUS_PARAMETER_ERR,
            _a[ReturnStatus.RETURN_STATUS_WRONG_STATE] = exports.ReturnStatus.RETURN_STATUS_WRONG_STATE,
            _a[ReturnStatus.RETURN_STATUS_HAS_IN_ROOM] = exports.ReturnStatus.RETURN_STATUS_HAS_IN_ROOM,
            _a[ReturnStatus.RETURN_STATUS_HAS_IN_LOGIN] = exports.ReturnStatus.RETURN_STATUS_HAS_IN_LOGIN,
            _a[ReturnStatus.RETURN_STATUS_HAS_IN_ECHO_TEST] = exports.ReturnStatus.RETURN_STATUS_HAS_IN_ECHO_TEST,
            _a[ReturnStatus.RETURN_STATUS_NEITHER_VIDEO_NOR_AUDIO] = exports.ReturnStatus.RETURN_STATUS_NEITHER_VIDEO_NOR_AUDIO,
            _a[ReturnStatus.RETURN_STATUS_ROOMID_IN_USE] = exports.ReturnStatus.RETURN_STATUS_ROOMID_IN_USE,
            _a[ReturnStatus.RETURN_STATUS_SCREEN_NOT_SUPPORT] = exports.ReturnStatus.RETURN_STATUS_SCREEN_NOT_SUPPORT,
            _a[ReturnStatus.RETURN_STATUS_NOT_SUPPORT] = exports.ReturnStatus.RETURN_STATUS_NOT_SUPPORT,
            _a[ReturnStatus.RETURN_STATUS_RESOURCE_OVERFLOW] = exports.ReturnStatus.RETURN_STATUS_RESOURCE_OVERFLOW,
            _a[ReturnStatus.RETURN_STATUS_AUDIO_NO_FRAME] = exports.ReturnStatus.RETURN_STATUS_AUDIO_NO_FRAME,
            _a[ReturnStatus.RETURN_STATUS_AUDIO_NOT_IMPLEMENTED] = exports.ReturnStatus.RETURN_STATUS_AUDIO_NOT_IMPLEMENTED,
            _a[ReturnStatus.RETURN_STATUS_AUDIO_NO_PERMISSION] = exports.ReturnStatus.RETURN_STATUS_AUDIO_NO_PERMISSION,
            _a[ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_NOT_EXISTS] = exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_NOT_EXISTS,
            _a[ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_FORMAT_NOT_SUPPORT] = exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_FORMAT_NOT_SUPPORT,
            _a[ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_NO_DEVICE] = exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_NO_DEVICE,
            _a[ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_CAN_NOT_USE] = exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_CAN_NOT_USE,
            _a[ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_INIT_FAILED] = exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_INIT_FAILED,
            _a[ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_START_FAILED] = exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_START_FAILED,
            _a[ReturnStatus.RETURN_STATUS_NATIVE_IN_VALID] = exports.ReturnStatus.RETURN_STATUS_NATIVE_IN_VALID,
            _a[ReturnStatus.RETURN_STATUS_VIDEO_NOT_SUPPORT] = exports.ReturnStatus.RETURN_STATUS_VIDEO_NOT_SUPPORT,
            _a[ReturnStatus.RETURN_STATUS_VIDEO_TIMESTAMP_WARNING] = exports.ReturnStatus.RETURN_STATUS_VIDEO_TIMESTAMP_WARNING,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ReturnStatus.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ReturnStatus.RETURN_STATUS_SUCCESS] = ByteRTCReturnStatus.ByteRTCReturnStatusSuccess,
            _a[exports.ReturnStatus.RETURN_STATUS_FAILURE] = ByteRTCReturnStatus.ByteRTCReturnStatusFailure,
            _a[exports.ReturnStatus.RETURN_STATUS_PARAMETER_ERR] = ByteRTCReturnStatus.ByteRTCReturnStatusParameterErr,
            _a[exports.ReturnStatus.RETURN_STATUS_WRONG_STATE] = ByteRTCReturnStatus.ByteRTCReturnStatusWrongState,
            _a[exports.ReturnStatus.RETURN_STATUS_HAS_IN_ROOM] = ByteRTCReturnStatus.ByteRTCReturnStatusHasInRoom,
            _a[exports.ReturnStatus.RETURN_STATUS_HAS_IN_LOGIN] = ByteRTCReturnStatus.ByteRTCReturnStatusHasInLogin,
            _a[exports.ReturnStatus.RETURN_STATUS_HAS_IN_ECHO_TEST] = ByteRTCReturnStatus.ByteRTCReturnStatusHasInEchoTest,
            _a[exports.ReturnStatus.RETURN_STATUS_NEITHER_VIDEO_NOR_AUDIO] = ByteRTCReturnStatus.ByteRTCReturnStatusNeitherVideoNorAudio,
            _a[exports.ReturnStatus.RETURN_STATUS_ROOMID_IN_USE] = ByteRTCReturnStatus.ByteRTCReturnStatusRoomIdInUse,
            _a[exports.ReturnStatus.RETURN_STATUS_SCREEN_NOT_SUPPORT] = ByteRTCReturnStatus.ByteRTCReturnStatusScreenNotSupport,
            _a[exports.ReturnStatus.RETURN_STATUS_NOT_SUPPORT] = ByteRTCReturnStatus.ByteRTCReturnStatusNotSupport,
            _a[exports.ReturnStatus.RETURN_STATUS_RESOURCE_OVERFLOW] = ByteRTCReturnStatus.ByteRTCReturnStatusResourceOverflow,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_NO_FRAME] = ByteRTCReturnStatus.ByteRTCReturnStatusAudioNoFrame,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_NOT_IMPLEMENTED] = ByteRTCReturnStatus.ByteRTCReturnStatusAudioNotImplemented,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_NO_PERMISSION] = ByteRTCReturnStatus.ByteRTCReturnStatusAudioNoPermission,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_NOT_EXISTS] = ByteRTCReturnStatus.ByteRTCReturnStatusAudioDeviceNotExists,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_FORMAT_NOT_SUPPORT] = ByteRTCReturnStatus.ByteRTCReturnStatusAudioDeviceFormatNotSupport,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_NO_DEVICE] = ByteRTCReturnStatus.ByteRTCReturnStatusAudioDeviceNoDevice,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_CAN_NOT_USE] = ByteRTCReturnStatus.ByteRTCReturnStatusAudioDeviceCannotUse,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_INIT_FAILED] = ByteRTCReturnStatus.ByteRTCReturnStatusAudioDeviceInitFailed,
            _a[exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_START_FAILED] = ByteRTCReturnStatus.ByteRTCReturnStatusAudioDeviceStartFailed,
            _a[exports.ReturnStatus.RETURN_STATUS_NATIVE_IN_VALID] = ByteRTCReturnStatus.ByteRTCReturnStatusNativeInValid,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ReturnStatus.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusSuccess] = exports.ReturnStatus.RETURN_STATUS_SUCCESS,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusFailure] = exports.ReturnStatus.RETURN_STATUS_FAILURE,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusParameterErr] = exports.ReturnStatus.RETURN_STATUS_PARAMETER_ERR,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusWrongState] = exports.ReturnStatus.RETURN_STATUS_WRONG_STATE,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusHasInRoom] = exports.ReturnStatus.RETURN_STATUS_HAS_IN_ROOM,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusHasInLogin] = exports.ReturnStatus.RETURN_STATUS_HAS_IN_LOGIN,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusHasInEchoTest] = exports.ReturnStatus.RETURN_STATUS_HAS_IN_ECHO_TEST,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusNeitherVideoNorAudio] = exports.ReturnStatus.RETURN_STATUS_NEITHER_VIDEO_NOR_AUDIO,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusRoomIdInUse] = exports.ReturnStatus.RETURN_STATUS_ROOMID_IN_USE,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusScreenNotSupport] = exports.ReturnStatus.RETURN_STATUS_SCREEN_NOT_SUPPORT,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusNotSupport] = exports.ReturnStatus.RETURN_STATUS_NOT_SUPPORT,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusResourceOverflow] = exports.ReturnStatus.RETURN_STATUS_RESOURCE_OVERFLOW,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusAudioNoFrame] = exports.ReturnStatus.RETURN_STATUS_AUDIO_NO_FRAME,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusAudioNotImplemented] = exports.ReturnStatus.RETURN_STATUS_AUDIO_NOT_IMPLEMENTED,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusAudioNoPermission] = exports.ReturnStatus.RETURN_STATUS_AUDIO_NO_PERMISSION,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusAudioDeviceNotExists] = exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_NOT_EXISTS,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusAudioDeviceFormatNotSupport] = exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_FORMAT_NOT_SUPPORT,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusAudioDeviceNoDevice] = exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_NO_DEVICE,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusAudioDeviceCannotUse] = exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_CAN_NOT_USE,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusAudioDeviceInitFailed] = exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_INIT_FAILED,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusAudioDeviceStartFailed] = exports.ReturnStatus.RETURN_STATUS_AUDIO_DEVICE_START_FAILED,
            _a[ByteRTCReturnStatus.ByteRTCReturnStatusNativeInValid] = exports.ReturnStatus.RETURN_STATUS_NATIVE_IN_VALID,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ReturnStatus;
}());
var t_VideoPictureType = /** @class */ (function () {
    function t_VideoPictureType() {
    }
    t_VideoPictureType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoPictureType.VIDEO_PICTURE_TYPE_UNKNOWN] = VideoPictureType.VIDEO_PICTURE_TYPE_UNKNOWN,
            _a[exports.VideoPictureType.VIDEO_PICTURE_TYPE_I] = VideoPictureType.VIDEO_PICTURE_TYPE_I,
            _a[exports.VideoPictureType.VIDEO_PICTURE_TYPE_P] = VideoPictureType.VIDEO_PICTURE_TYPE_P,
            _a[exports.VideoPictureType.VIDEO_PICTURE_TYPE_B] = VideoPictureType.VIDEO_PICTURE_TYPE_B,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoPictureType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoPictureType.VIDEO_PICTURE_TYPE_UNKNOWN] = exports.VideoPictureType.VIDEO_PICTURE_TYPE_UNKNOWN,
            _a[VideoPictureType.VIDEO_PICTURE_TYPE_I] = exports.VideoPictureType.VIDEO_PICTURE_TYPE_I,
            _a[VideoPictureType.VIDEO_PICTURE_TYPE_P] = exports.VideoPictureType.VIDEO_PICTURE_TYPE_P,
            _a[VideoPictureType.VIDEO_PICTURE_TYPE_B] = exports.VideoPictureType.VIDEO_PICTURE_TYPE_B,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoPictureType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoPictureType.VIDEO_PICTURE_TYPE_UNKNOWN] = ByteRTCVideoPictureType.ByteRTCVideoPictureTypeUnknown,
            _a[exports.VideoPictureType.VIDEO_PICTURE_TYPE_I] = ByteRTCVideoPictureType.ByteRTCVideoPictureTypeI,
            _a[exports.VideoPictureType.VIDEO_PICTURE_TYPE_P] = ByteRTCVideoPictureType.ByteRTCVideoPictureTypeP,
            _a[exports.VideoPictureType.VIDEO_PICTURE_TYPE_B] = ByteRTCVideoPictureType.ByteRTCVideoPictureTypeB,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoPictureType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoPictureType.ByteRTCVideoPictureTypeUnknown] = exports.VideoPictureType.VIDEO_PICTURE_TYPE_UNKNOWN,
            _a[ByteRTCVideoPictureType.ByteRTCVideoPictureTypeI] = exports.VideoPictureType.VIDEO_PICTURE_TYPE_I,
            _a[ByteRTCVideoPictureType.ByteRTCVideoPictureTypeP] = exports.VideoPictureType.VIDEO_PICTURE_TYPE_P,
            _a[ByteRTCVideoPictureType.ByteRTCVideoPictureTypeB] = exports.VideoPictureType.VIDEO_PICTURE_TYPE_B,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoPictureType;
}());
var t_ColorSpace = /** @class */ (function () {
    function t_ColorSpace() {
    }
    t_ColorSpace.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ColorSpace.UNKNOWN] = ColorSpace.UNKNOWN,
            _a[exports.ColorSpace.BT601_LIMITED_RANGE] = ColorSpace.BT601_LIMITED_RANGE,
            _a[exports.ColorSpace.BT601_FULL_RANGE] = ColorSpace.BT601_FULL_RANGE,
            _a[exports.ColorSpace.BT709_LIMITED_RANGE] = ColorSpace.BT709_LIMITED_RANGE,
            _a[exports.ColorSpace.BT709_FULL_RANGE] = ColorSpace.BT709_FULL_RANGE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ColorSpace.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ColorSpace.UNKNOWN] = exports.ColorSpace.UNKNOWN,
            _a[ColorSpace.BT601_LIMITED_RANGE] = exports.ColorSpace.BT601_LIMITED_RANGE,
            _a[ColorSpace.BT601_FULL_RANGE] = exports.ColorSpace.BT601_FULL_RANGE,
            _a[ColorSpace.BT709_LIMITED_RANGE] = exports.ColorSpace.BT709_LIMITED_RANGE,
            _a[ColorSpace.BT709_FULL_RANGE] = exports.ColorSpace.BT709_FULL_RANGE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ColorSpace.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ColorSpace.UNKNOWN] = ByteRTCColorSpace.ByteRTCColorSpaceUnknown,
            _a[exports.ColorSpace.ByteRTCColorSpaceYCbCrBT601LimitedRange] = ByteRTCColorSpace.ByteRTCColorSpaceYCbCrBT601LimitedRange,
            _a[exports.ColorSpace.ByteRTCColorSpaceYCbCrBT601FullRange] = ByteRTCColorSpace.ByteRTCColorSpaceYCbCrBT601FullRange,
            _a[exports.ColorSpace.ByteRTCColorSpaceYCbCrBT709LimitedRange] = ByteRTCColorSpace.ByteRTCColorSpaceYCbCrBT709LimitedRange,
            _a[exports.ColorSpace.ByteRTCColorSpaceYCbCrBT709FullRange] = ByteRTCColorSpace.ByteRTCColorSpaceYCbCrBT709FullRange,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ColorSpace.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCColorSpace.ByteRTCColorSpaceUnknown] = exports.ColorSpace.UNKNOWN,
            _a[ByteRTCColorSpace.ByteRTCColorSpaceYCbCrBT601LimitedRange] = exports.ColorSpace.ByteRTCColorSpaceYCbCrBT601LimitedRange,
            _a[ByteRTCColorSpace.ByteRTCColorSpaceYCbCrBT601FullRange] = exports.ColorSpace.ByteRTCColorSpaceYCbCrBT601FullRange,
            _a[ByteRTCColorSpace.ByteRTCColorSpaceYCbCrBT709LimitedRange] = exports.ColorSpace.ByteRTCColorSpaceYCbCrBT709LimitedRange,
            _a[ByteRTCColorSpace.ByteRTCColorSpaceYCbCrBT709FullRange] = exports.ColorSpace.ByteRTCColorSpaceYCbCrBT709FullRange,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ColorSpace;
}());
var t_RemoteVideoState = /** @class */ (function () {
    function t_RemoteVideoState() {
    }
    t_RemoteVideoState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteVideoState.REMOTE_VIDEO_STATE_STOPPED] = RemoteVideoState.REMOTE_VIDEO_STATE_STOPPED,
            _a[exports.RemoteVideoState.REMOTE_VIDEO_STATE_STARTING] = RemoteVideoState.REMOTE_VIDEO_STATE_STARTING,
            _a[exports.RemoteVideoState.REMOTE_VIDEO_STATE_DECODING] = RemoteVideoState.REMOTE_VIDEO_STATE_DECODING,
            _a[exports.RemoteVideoState.REMOTE_VIDEO_STATE_FROZEN] = RemoteVideoState.REMOTE_VIDEO_STATE_FROZEN,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteVideoState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RemoteVideoState.REMOTE_VIDEO_STATE_STOPPED] = exports.RemoteVideoState.REMOTE_VIDEO_STATE_STOPPED,
            _a[RemoteVideoState.REMOTE_VIDEO_STATE_STARTING] = exports.RemoteVideoState.REMOTE_VIDEO_STATE_STARTING,
            _a[RemoteVideoState.REMOTE_VIDEO_STATE_DECODING] = exports.RemoteVideoState.REMOTE_VIDEO_STATE_DECODING,
            _a[RemoteVideoState.REMOTE_VIDEO_STATE_FROZEN] = exports.RemoteVideoState.REMOTE_VIDEO_STATE_FROZEN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteVideoState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteVideoState.REMOTE_VIDEO_STATE_STOPPED] = ByteRTCRemoteVideoState.ByteRTCRemoteVideoStateStopped,
            _a[exports.RemoteVideoState.REMOTE_VIDEO_STATE_STARTING] = ByteRTCRemoteVideoState.ByteRTCRemoteVideoStateStarting,
            _a[exports.RemoteVideoState.REMOTE_VIDEO_STATE_DECODING] = ByteRTCRemoteVideoState.ByteRTCRemoteVideoStateDecoding,
            _a[exports.RemoteVideoState.REMOTE_VIDEO_STATE_FROZEN] = ByteRTCRemoteVideoState.ByteRTCRemoteVideoStateFrozen,
            _a[exports.RemoteVideoState.ByteRTCRemoteVideoStateFailed] = ByteRTCRemoteVideoState.ByteRTCRemoteVideoStateFailed,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteVideoState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRemoteVideoState.ByteRTCRemoteVideoStateStopped] = exports.RemoteVideoState.REMOTE_VIDEO_STATE_STOPPED,
            _a[ByteRTCRemoteVideoState.ByteRTCRemoteVideoStateStarting] = exports.RemoteVideoState.REMOTE_VIDEO_STATE_STARTING,
            _a[ByteRTCRemoteVideoState.ByteRTCRemoteVideoStateDecoding] = exports.RemoteVideoState.REMOTE_VIDEO_STATE_DECODING,
            _a[ByteRTCRemoteVideoState.ByteRTCRemoteVideoStateFrozen] = exports.RemoteVideoState.REMOTE_VIDEO_STATE_FROZEN,
            _a[ByteRTCRemoteVideoState.ByteRTCRemoteVideoStateFailed] = exports.RemoteVideoState.ByteRTCRemoteVideoStateFailed,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RemoteVideoState;
}());
var t_HardwareEchoDetectionResult = /** @class */ (function () {
    function t_HardwareEchoDetectionResult() {
    }
    t_HardwareEchoDetectionResult.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_CANCELED] = HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_CANCELED,
            _a[exports.HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_UNKNOWN] = HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_UNKNOWN,
            _a[exports.HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_NORMAL] = HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_NORMAL,
            _a[exports.HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_POOR] = HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_POOR,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_HardwareEchoDetectionResult.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_CANCELED] = exports.HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_CANCELED,
            _a[HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_UNKNOWN] = exports.HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_UNKNOWN,
            _a[HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_NORMAL] = exports.HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_NORMAL,
            _a[HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_POOR] = exports.HardwareEchoDetectionResult.HARDWARE_ECHO_RESULT_POOR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_HardwareEchoDetectionResult.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.HardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionCanceled] = ByteRTCHardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionCanceled,
            _a[exports.HardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionUnknown] = ByteRTCHardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionUnknown,
            _a[exports.HardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionNormal] = ByteRTCHardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionNormal,
            _a[exports.HardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionPoor] = ByteRTCHardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionPoor,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_HardwareEchoDetectionResult.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCHardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionCanceled] = exports.HardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionCanceled,
            _a[ByteRTCHardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionUnknown] = exports.HardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionUnknown,
            _a[ByteRTCHardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionNormal] = exports.HardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionNormal,
            _a[ByteRTCHardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionPoor] = exports.HardwareEchoDetectionResult.ByteRTCHardwareEchoDetectionPoor,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_HardwareEchoDetectionResult;
}());
var t_RecordingState = /** @class */ (function () {
    function t_RecordingState() {
    }
    t_RecordingState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RecordingState.RECORDING_STATE_PROCESSING] = RecordingState.RECORDING_STATE_PROCESSING,
            _a[exports.RecordingState.RECORDING_STATE_SUCCESS] = RecordingState.RECORDING_STATE_SUCCESS,
            _a[exports.RecordingState.RECORDING_STATE_ERROE] = RecordingState.RECORDING_STATE_ERROE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RecordingState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RecordingState.RECORDING_STATE_PROCESSING] = exports.RecordingState.RECORDING_STATE_PROCESSING,
            _a[RecordingState.RECORDING_STATE_SUCCESS] = exports.RecordingState.RECORDING_STATE_SUCCESS,
            _a[RecordingState.RECORDING_STATE_ERROE] = exports.RecordingState.RECORDING_STATE_ERROE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RecordingState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RecordingState.RECORDING_STATE_PROCESSING] = ByteRTCRecordingState.ByteRTCRecordingStateProcessing,
            _a[exports.RecordingState.RECORDING_STATE_SUCCESS] = ByteRTCRecordingState.ByteRTCRecordingStateSuccess,
            _a[exports.RecordingState.ByteRTCRecordingStateError] = ByteRTCRecordingState.ByteRTCRecordingStateError,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RecordingState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRecordingState.ByteRTCRecordingStateProcessing] = exports.RecordingState.RECORDING_STATE_PROCESSING,
            _a[ByteRTCRecordingState.ByteRTCRecordingStateSuccess] = exports.RecordingState.RECORDING_STATE_SUCCESS,
            _a[ByteRTCRecordingState.ByteRTCRecordingStateError] = exports.RecordingState.ByteRTCRecordingStateError,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RecordingState;
}());
var t_NetworkDetectionLinkType = /** @class */ (function () {
    function t_NetworkDetectionLinkType() {
    }
    t_NetworkDetectionLinkType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.NetworkDetectionLinkType.UP] = NetworkDetectionLinkType.UP,
            _a[exports.NetworkDetectionLinkType.DOWN] = NetworkDetectionLinkType.DOWN,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_NetworkDetectionLinkType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[NetworkDetectionLinkType.UP] = exports.NetworkDetectionLinkType.UP,
            _a[NetworkDetectionLinkType.DOWN] = exports.NetworkDetectionLinkType.DOWN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_NetworkDetectionLinkType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.NetworkDetectionLinkType.UP] = ByteRTCNetworkDetectionLinkType.ByteRTCNetworkDetectionLinkTypeUp,
            _a[exports.NetworkDetectionLinkType.DOWN] = ByteRTCNetworkDetectionLinkType.ByteRTCNetworkDetectionLinkTypeDown,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_NetworkDetectionLinkType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCNetworkDetectionLinkType.ByteRTCNetworkDetectionLinkTypeUp] = exports.NetworkDetectionLinkType.UP,
            _a[ByteRTCNetworkDetectionLinkType.ByteRTCNetworkDetectionLinkTypeDown] = exports.NetworkDetectionLinkType.DOWN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_NetworkDetectionLinkType;
}());
var t_VideoDenoiseModeChangedReason = /** @class */ (function () {
    function t_VideoDenoiseModeChangedReason() {
    }
    t_VideoDenoiseModeChangedReason.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_NULL] = VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_NULL,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_API_OFF] = VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_API_OFF,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_API_ON] = VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_API_ON,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_DISABLED] = VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_DISABLED,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_ENABLED] = VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_ENABLED,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_CLOSE] = VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_CLOSE,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_OPEN] = VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_OPEN,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_RESOLUTION] = VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_RESOLUTION,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_INTERNAL_EXCEPTION] = VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_INTERNAL_EXCEPTION,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoDenoiseModeChangedReason.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_NULL] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_NULL,
            _a[VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_API_OFF] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_API_OFF,
            _a[VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_API_ON] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_API_ON,
            _a[VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_DISABLED] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_DISABLED,
            _a[VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_ENABLED] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_ENABLED,
            _a[VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_CLOSE] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_CLOSE,
            _a[VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_OPEN] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_OPEN,
            _a[VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_RESOLUTION] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_RESOLUTION,
            _a[VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_INTERNAL_EXCEPTION] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_INTERNAL_EXCEPTION,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoDenoiseModeChangedReason.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_NULL] = ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonNull,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_API_OFF] = ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonApiOff,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_API_ON] = ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonApiOn,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_DISABLED] = ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonConfigDisabled,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_ENABLED] = ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonConfigEnabled,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_CLOSE] = ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonDynamicClose,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_OPEN] = ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonDynamicOpen,
            _a[exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_RESOLUTION] = ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonResolution,
            _a[exports.VideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonInternalException] = ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonInternalException,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoDenoiseModeChangedReason.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonNull] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_NULL,
            _a[ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonApiOff] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_API_OFF,
            _a[ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonApiOn] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_API_ON,
            _a[ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonConfigDisabled] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_DISABLED,
            _a[ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonConfigEnabled] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_CONFIG_ENABLED,
            _a[ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonDynamicClose] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_CLOSE,
            _a[ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonDynamicOpen] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_DYNAMIC_OPEN,
            _a[ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonResolution] = exports.VideoDenoiseModeChangedReason.VIDEO_DENOISE_MODE_CHANGED_REASON_RESOLUTION,
            _a[ByteRTCVideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonInternalException] = exports.VideoDenoiseModeChangedReason.ByteRTCVideoDenoiseModeChangedReasonInternalException,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoDenoiseModeChangedReason;
}());
var t_AudioDeviceType = /** @class */ (function () {
    function t_AudioDeviceType() {
    }
    t_AudioDeviceType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioDeviceType.AUDIO_DEVICE_TYPE_UNKNOWN] = AudioDeviceType.AUDIO_DEVICE_TYPE_UNKNOWN,
            _a[exports.AudioDeviceType.AUDIO_DEVICE_TYPE_RENDER_DEVICE] = AudioDeviceType.AUDIO_DEVICE_TYPE_RENDER_DEVICE,
            _a[exports.AudioDeviceType.AUDIO_DEVICE_TYPE_CAPTURE_DEVICE] = AudioDeviceType.AUDIO_DEVICE_TYPE_CAPTURE_DEVICE,
            _a[exports.AudioDeviceType.AUDIO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE] = AudioDeviceType.AUDIO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioDeviceType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioDeviceType.AUDIO_DEVICE_TYPE_UNKNOWN] = exports.AudioDeviceType.AUDIO_DEVICE_TYPE_UNKNOWN,
            _a[AudioDeviceType.AUDIO_DEVICE_TYPE_RENDER_DEVICE] = exports.AudioDeviceType.AUDIO_DEVICE_TYPE_RENDER_DEVICE,
            _a[AudioDeviceType.AUDIO_DEVICE_TYPE_CAPTURE_DEVICE] = exports.AudioDeviceType.AUDIO_DEVICE_TYPE_CAPTURE_DEVICE,
            _a[AudioDeviceType.AUDIO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE] = exports.AudioDeviceType.AUDIO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioDeviceType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioDeviceType.AUDIO_DEVICE_TYPE_UNKNOWN] = ByteRTCAudioDeviceType.ByteRTCAudioDeviceTypeUnknown,
            _a[exports.AudioDeviceType.AUDIO_DEVICE_TYPE_RENDER_DEVICE] = ByteRTCAudioDeviceType.ByteRTCAudioDeviceTypeRenderDevice,
            _a[exports.AudioDeviceType.AUDIO_DEVICE_TYPE_CAPTURE_DEVICE] = ByteRTCAudioDeviceType.ByteRTCAudioDeviceTypeCaptureDevice,
            _a[exports.AudioDeviceType.AUDIO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE] = ByteRTCAudioDeviceType.ByteRTCAudioDeviceTypeScreenCaptureDevice,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioDeviceType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioDeviceType.ByteRTCAudioDeviceTypeUnknown] = exports.AudioDeviceType.AUDIO_DEVICE_TYPE_UNKNOWN,
            _a[ByteRTCAudioDeviceType.ByteRTCAudioDeviceTypeRenderDevice] = exports.AudioDeviceType.AUDIO_DEVICE_TYPE_RENDER_DEVICE,
            _a[ByteRTCAudioDeviceType.ByteRTCAudioDeviceTypeCaptureDevice] = exports.AudioDeviceType.AUDIO_DEVICE_TYPE_CAPTURE_DEVICE,
            _a[ByteRTCAudioDeviceType.ByteRTCAudioDeviceTypeScreenCaptureDevice] = exports.AudioDeviceType.AUDIO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioDeviceType;
}());
var t_SetRoomExtraInfoResult = /** @class */ (function () {
    function t_SetRoomExtraInfoResult() {
    }
    t_SetRoomExtraInfoResult.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SetRoomExtraInfoResult.SUCCESS] = SetRoomExtraInfoResult.SUCCESS,
            _a[exports.SetRoomExtraInfoResult.NOT_JOIN_ROOM] = SetRoomExtraInfoResult.NOT_JOIN_ROOM,
            _a[exports.SetRoomExtraInfoResult.KEY_IS_NULL] = SetRoomExtraInfoResult.KEY_IS_NULL,
            _a[exports.SetRoomExtraInfoResult.VALUE_IS_NULL] = SetRoomExtraInfoResult.VALUE_IS_NULL,
            _a[exports.SetRoomExtraInfoResult.UNKNOW] = SetRoomExtraInfoResult.UNKNOW,
            _a[exports.SetRoomExtraInfoResult.KEY_IS_EMPTY] = SetRoomExtraInfoResult.KEY_IS_EMPTY,
            _a[exports.SetRoomExtraInfoResult.TOO_OFTEN] = SetRoomExtraInfoResult.TOO_OFTEN,
            _a[exports.SetRoomExtraInfoResult.SILENT_USER] = SetRoomExtraInfoResult.SILENT_USER,
            _a[exports.SetRoomExtraInfoResult.KEY_TOO_LONG] = SetRoomExtraInfoResult.KEY_TOO_LONG,
            _a[exports.SetRoomExtraInfoResult.VALUE_TOO_LONG] = SetRoomExtraInfoResult.VALUE_TOO_LONG,
            _a[exports.SetRoomExtraInfoResult.SERVER_ERROR] = SetRoomExtraInfoResult.SERVER_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SetRoomExtraInfoResult.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[SetRoomExtraInfoResult.SUCCESS] = exports.SetRoomExtraInfoResult.SUCCESS,
            _a[SetRoomExtraInfoResult.NOT_JOIN_ROOM] = exports.SetRoomExtraInfoResult.NOT_JOIN_ROOM,
            _a[SetRoomExtraInfoResult.KEY_IS_NULL] = exports.SetRoomExtraInfoResult.KEY_IS_NULL,
            _a[SetRoomExtraInfoResult.VALUE_IS_NULL] = exports.SetRoomExtraInfoResult.VALUE_IS_NULL,
            _a[SetRoomExtraInfoResult.UNKNOW] = exports.SetRoomExtraInfoResult.UNKNOW,
            _a[SetRoomExtraInfoResult.KEY_IS_EMPTY] = exports.SetRoomExtraInfoResult.KEY_IS_EMPTY,
            _a[SetRoomExtraInfoResult.TOO_OFTEN] = exports.SetRoomExtraInfoResult.TOO_OFTEN,
            _a[SetRoomExtraInfoResult.SILENT_USER] = exports.SetRoomExtraInfoResult.SILENT_USER,
            _a[SetRoomExtraInfoResult.KEY_TOO_LONG] = exports.SetRoomExtraInfoResult.KEY_TOO_LONG,
            _a[SetRoomExtraInfoResult.VALUE_TOO_LONG] = exports.SetRoomExtraInfoResult.VALUE_TOO_LONG,
            _a[SetRoomExtraInfoResult.SERVER_ERROR] = exports.SetRoomExtraInfoResult.SERVER_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SetRoomExtraInfoResult.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SetRoomExtraInfoResult.SUCCESS] = ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultSuccess,
            _a[exports.SetRoomExtraInfoResult.NOT_JOIN_ROOM] = ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultNotJoinRoom,
            _a[exports.SetRoomExtraInfoResult.KEY_IS_NULL] = ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultKeyIsNull,
            _a[exports.SetRoomExtraInfoResult.VALUE_IS_NULL] = ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultValueIsNull,
            _a[exports.SetRoomExtraInfoResult.UNKNOW] = ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultUnknow,
            _a[exports.SetRoomExtraInfoResult.KEY_IS_EMPTY] = ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultKeyIsEmpty,
            _a[exports.SetRoomExtraInfoResult.TOO_OFTEN] = ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultTooOften,
            _a[exports.SetRoomExtraInfoResult.SILENT_USER] = ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultSilentUser,
            _a[exports.SetRoomExtraInfoResult.KEY_TOO_LONG] = ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultKeyTooLong,
            _a[exports.SetRoomExtraInfoResult.VALUE_TOO_LONG] = ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultValueTooLong,
            _a[exports.SetRoomExtraInfoResult.SERVER_ERROR] = ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultServerError,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SetRoomExtraInfoResult.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultSuccess] = exports.SetRoomExtraInfoResult.SUCCESS,
            _a[ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultNotJoinRoom] = exports.SetRoomExtraInfoResult.NOT_JOIN_ROOM,
            _a[ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultKeyIsNull] = exports.SetRoomExtraInfoResult.KEY_IS_NULL,
            _a[ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultValueIsNull] = exports.SetRoomExtraInfoResult.VALUE_IS_NULL,
            _a[ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultUnknow] = exports.SetRoomExtraInfoResult.UNKNOW,
            _a[ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultKeyIsEmpty] = exports.SetRoomExtraInfoResult.KEY_IS_EMPTY,
            _a[ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultTooOften] = exports.SetRoomExtraInfoResult.TOO_OFTEN,
            _a[ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultSilentUser] = exports.SetRoomExtraInfoResult.SILENT_USER,
            _a[ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultKeyTooLong] = exports.SetRoomExtraInfoResult.KEY_TOO_LONG,
            _a[ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultValueTooLong] = exports.SetRoomExtraInfoResult.VALUE_TOO_LONG,
            _a[ByteRTCSetRoomExtraInfoResult.ByteRTCSetRoomExtraInfoResultServerError] = exports.SetRoomExtraInfoResult.SERVER_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_SetRoomExtraInfoResult;
}());
var t_LocalProxyState = /** @class */ (function () {
    function t_LocalProxyState() {
    }
    t_LocalProxyState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalProxyState.CONNECTED] = LocalProxyState.CONNECTED,
            _a[exports.LocalProxyState.ERROR] = LocalProxyState.ERROR,
            _a[exports.LocalProxyState.INITED] = LocalProxyState.INITED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalProxyState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[LocalProxyState.CONNECTED] = exports.LocalProxyState.CONNECTED,
            _a[LocalProxyState.ERROR] = exports.LocalProxyState.ERROR,
            _a[LocalProxyState.INITED] = exports.LocalProxyState.INITED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalProxyState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalProxyState.CONNECTED] = ByteRTCLocalProxyState.ByteRTCLocalProxyStateConnected,
            _a[exports.LocalProxyState.ERROR] = ByteRTCLocalProxyState.ByteRTCLocalProxyStateError,
            _a[exports.LocalProxyState.ByteRTCLocalProxyStateInited] = ByteRTCLocalProxyState.ByteRTCLocalProxyStateInited,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalProxyState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCLocalProxyState.ByteRTCLocalProxyStateConnected] = exports.LocalProxyState.CONNECTED,
            _a[ByteRTCLocalProxyState.ByteRTCLocalProxyStateError] = exports.LocalProxyState.ERROR,
            _a[ByteRTCLocalProxyState.ByteRTCLocalProxyStateInited] = exports.LocalProxyState.ByteRTCLocalProxyStateInited,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_LocalProxyState;
}());
var t_AVSyncState = /** @class */ (function () {
    function t_AVSyncState() {
    }
    t_AVSyncState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AVSyncState.AV_SYNC_STATE_AUDIO_STREAM_REMOVE] = AVSyncState.AV_SYNC_STATE_AUDIO_STREAM_REMOVE,
            _a[exports.AVSyncState.AV_SYNC_STATE_VIDEO_STREAM_REMOVE] = AVSyncState.AV_SYNC_STATE_VIDEO_STREAM_REMOVE,
            _a[exports.AVSyncState.AV_SYNC_STATE_STREAM_SYNC_BEGIN] = AVSyncState.AV_SYNC_STATE_STREAM_SYNC_BEGIN,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AVSyncState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AVSyncState.AV_SYNC_STATE_AUDIO_STREAM_REMOVE] = exports.AVSyncState.AV_SYNC_STATE_AUDIO_STREAM_REMOVE,
            _a[AVSyncState.AV_SYNC_STATE_VIDEO_STREAM_REMOVE] = exports.AVSyncState.AV_SYNC_STATE_VIDEO_STREAM_REMOVE,
            _a[AVSyncState.AV_SYNC_STATE_STREAM_SYNC_BEGIN] = exports.AVSyncState.AV_SYNC_STATE_STREAM_SYNC_BEGIN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AVSyncState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AVSyncState.AV_SYNC_STATE_AUDIO_STREAM_REMOVE] = ByteRTCAVSyncState.ByteRTCAVSyncStateAudioStreamRemove,
            _a[exports.AVSyncState.AV_SYNC_STATE_VIDEO_STREAM_REMOVE] = ByteRTCAVSyncState.ByteRTCAVSyncStateVideoStreamRemove,
            _a[exports.AVSyncState.AV_SYNC_STATE_STREAM_SYNC_BEGIN] = ByteRTCAVSyncState.ByteRTCAVSyncStateAVStreamSyncBegin,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AVSyncState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAVSyncState.ByteRTCAVSyncStateAudioStreamRemove] = exports.AVSyncState.AV_SYNC_STATE_AUDIO_STREAM_REMOVE,
            _a[ByteRTCAVSyncState.ByteRTCAVSyncStateVideoStreamRemove] = exports.AVSyncState.AV_SYNC_STATE_VIDEO_STREAM_REMOVE,
            _a[ByteRTCAVSyncState.ByteRTCAVSyncStateAVStreamSyncBegin] = exports.AVSyncState.AV_SYNC_STATE_STREAM_SYNC_BEGIN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AVSyncState;
}());
var t_ChannelProfile = /** @class */ (function () {
    function t_ChannelProfile() {
    }
    t_ChannelProfile.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ChannelProfile.CHANNEL_PROFILE_COMMUNICATION] = ChannelProfile.CHANNEL_PROFILE_COMMUNICATION,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_GAME] = ChannelProfile.CHANNEL_PROFILE_GAME,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_CLOUD_GAME] = ChannelProfile.CHANNEL_PROFILE_CLOUD_GAME,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_LOW_LATENCY] = ChannelProfile.CHANNEL_PROFILE_LOW_LATENCY,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_CHAT] = ChannelProfile.CHANNEL_PROFILE_CHAT,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_CHAT_ROOM] = ChannelProfile.CHANNEL_PROFILE_CHAT_ROOM,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_LW_TOGETHER] = ChannelProfile.CHANNEL_PROFILE_LW_TOGETHER,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_GAME_HD] = ChannelProfile.CHANNEL_PROFILE_GAME_HD,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_CO_HOST] = ChannelProfile.CHANNEL_PROFILE_CO_HOST,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_KTV] = ChannelProfile.CHANNEL_PROFILE_KTV,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_CHORUS] = ChannelProfile.CHANNEL_PROFILE_CHORUS,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_GAME_STREAMING] = ChannelProfile.CHANNEL_PROFILE_GAME_STREAMING,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_LAN_LIVE_STREAMING] = ChannelProfile.CHANNEL_PROFILE_LAN_LIVE_STREAMING,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_MEETING_ROOM] = ChannelProfile.CHANNEL_PROFILE_MEETING_ROOM,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_CLASSROOM] = ChannelProfile.CHANNEL_PROFILE_CLASSROOM,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_INTERACTIVE_PODCAST] = ChannelProfile.CHANNEL_PROFILE_INTERACTIVE_PODCAST,
            _a[exports.ChannelProfile.CHANNEL_PROFIEL_VR_CHAT] = ChannelProfile.CHANNEL_PROFIEL_VR_CHAT,
            _a[exports.ChannelProfile.CHANNEL_PROFIEL_MEETING] = ChannelProfile.CHANNEL_PROFIEL_MEETING,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_LIVE_BROADCASTING] = ChannelProfile.CHANNEL_PROFILE_LIVE_BROADCASTING,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ChannelProfile.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ChannelProfile.CHANNEL_PROFILE_COMMUNICATION] = exports.ChannelProfile.CHANNEL_PROFILE_COMMUNICATION,
            _a[ChannelProfile.CHANNEL_PROFILE_GAME] = exports.ChannelProfile.CHANNEL_PROFILE_GAME,
            _a[ChannelProfile.CHANNEL_PROFILE_CLOUD_GAME] = exports.ChannelProfile.CHANNEL_PROFILE_CLOUD_GAME,
            _a[ChannelProfile.CHANNEL_PROFILE_LOW_LATENCY] = exports.ChannelProfile.CHANNEL_PROFILE_LOW_LATENCY,
            _a[ChannelProfile.CHANNEL_PROFILE_CHAT] = exports.ChannelProfile.CHANNEL_PROFILE_CHAT,
            _a[ChannelProfile.CHANNEL_PROFILE_CHAT_ROOM] = exports.ChannelProfile.CHANNEL_PROFILE_CHAT_ROOM,
            _a[ChannelProfile.CHANNEL_PROFILE_LW_TOGETHER] = exports.ChannelProfile.CHANNEL_PROFILE_LW_TOGETHER,
            _a[ChannelProfile.CHANNEL_PROFILE_GAME_HD] = exports.ChannelProfile.CHANNEL_PROFILE_GAME_HD,
            _a[ChannelProfile.CHANNEL_PROFILE_CO_HOST] = exports.ChannelProfile.CHANNEL_PROFILE_CO_HOST,
            _a[ChannelProfile.CHANNEL_PROFILE_KTV] = exports.ChannelProfile.CHANNEL_PROFILE_KTV,
            _a[ChannelProfile.CHANNEL_PROFILE_CHORUS] = exports.ChannelProfile.CHANNEL_PROFILE_CHORUS,
            _a[ChannelProfile.CHANNEL_PROFILE_GAME_STREAMING] = exports.ChannelProfile.CHANNEL_PROFILE_GAME_STREAMING,
            _a[ChannelProfile.CHANNEL_PROFILE_LAN_LIVE_STREAMING] = exports.ChannelProfile.CHANNEL_PROFILE_LAN_LIVE_STREAMING,
            _a[ChannelProfile.CHANNEL_PROFILE_MEETING_ROOM] = exports.ChannelProfile.CHANNEL_PROFILE_MEETING_ROOM,
            _a[ChannelProfile.CHANNEL_PROFILE_CLASSROOM] = exports.ChannelProfile.CHANNEL_PROFILE_CLASSROOM,
            _a[ChannelProfile.CHANNEL_PROFILE_INTERACTIVE_PODCAST] = exports.ChannelProfile.CHANNEL_PROFILE_INTERACTIVE_PODCAST,
            _a[ChannelProfile.CHANNEL_PROFIEL_VR_CHAT] = exports.ChannelProfile.CHANNEL_PROFIEL_VR_CHAT,
            _a[ChannelProfile.CHANNEL_PROFIEL_MEETING] = exports.ChannelProfile.CHANNEL_PROFIEL_MEETING,
            _a[ChannelProfile.CHANNEL_PROFILE_LIVE_BROADCASTING] = exports.ChannelProfile.CHANNEL_PROFILE_LIVE_BROADCASTING,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ChannelProfile.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ChannelProfile.CHANNEL_PROFILE_COMMUNICATION] = ByteRTCRoomProfile.ByteRTCRoomProfileCommunication,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_GAME] = ByteRTCRoomProfile.ByteRTCRoomProfileGame,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_CLOUD_GAME] = ByteRTCRoomProfile.ByteRTCRoomProfileCloudGame,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_LOW_LATENCY] = ByteRTCRoomProfile.ByteRTCRoomProfileLowLatency,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_CHAT] = ByteRTCRoomProfile.ByteRTCRoomProfileChat,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_CHAT_ROOM] = ByteRTCRoomProfile.ByteRTCRoomProfileChatRoom,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_LW_TOGETHER] = ByteRTCRoomProfile.ByteRTCRoomProfileLwTogether,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_GAME_HD] = ByteRTCRoomProfile.ByteRTCRoomProfileGameHD,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_CO_HOST] = ByteRTCRoomProfile.ByteRTCRoomProfileCoHost,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_KTV] = ByteRTCRoomProfile.ByteRTCRoomProfileKTV,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_CHORUS] = ByteRTCRoomProfile.ByteRTCRoomProfileChorus,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_GAME_STREAMING] = ByteRTCRoomProfile.ByteRTCRoomProfileGameStreaming,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_LAN_LIVE_STREAMING] = ByteRTCRoomProfile.ByteRTCRoomProfileLanLiveStreaming,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_MEETING_ROOM] = ByteRTCRoomProfile.ByteRTCRoomProfileMeetingRoom,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_CLASSROOM] = ByteRTCRoomProfile.ByteRTCRoomProfileClassroom,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_INTERACTIVE_PODCAST] = ByteRTCRoomProfile.ByteRTCRoomProfileInteractivePodcast,
            _a[exports.ChannelProfile.CHANNEL_PROFIEL_VR_CHAT] = ByteRTCRoomProfile.ByteRTCRoomProfileVRChat,
            _a[exports.ChannelProfile.CHANNEL_PROFIEL_MEETING] = ByteRTCRoomProfile.ByteRTCRoomProfileMeeting,
            _a[exports.ChannelProfile.CHANNEL_PROFILE_LIVE_BROADCASTING] = ByteRTCRoomProfile.ByteRTCRoomProfileLiveBroadcasting,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ChannelProfile.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileCommunication] = exports.ChannelProfile.CHANNEL_PROFILE_COMMUNICATION,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileGame] = exports.ChannelProfile.CHANNEL_PROFILE_GAME,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileCloudGame] = exports.ChannelProfile.CHANNEL_PROFILE_CLOUD_GAME,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileLowLatency] = exports.ChannelProfile.CHANNEL_PROFILE_LOW_LATENCY,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileChat] = exports.ChannelProfile.CHANNEL_PROFILE_CHAT,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileChatRoom] = exports.ChannelProfile.CHANNEL_PROFILE_CHAT_ROOM,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileLwTogether] = exports.ChannelProfile.CHANNEL_PROFILE_LW_TOGETHER,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileGameHD] = exports.ChannelProfile.CHANNEL_PROFILE_GAME_HD,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileCoHost] = exports.ChannelProfile.CHANNEL_PROFILE_CO_HOST,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileKTV] = exports.ChannelProfile.CHANNEL_PROFILE_KTV,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileChorus] = exports.ChannelProfile.CHANNEL_PROFILE_CHORUS,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileGameStreaming] = exports.ChannelProfile.CHANNEL_PROFILE_GAME_STREAMING,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileLanLiveStreaming] = exports.ChannelProfile.CHANNEL_PROFILE_LAN_LIVE_STREAMING,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileMeetingRoom] = exports.ChannelProfile.CHANNEL_PROFILE_MEETING_ROOM,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileClassroom] = exports.ChannelProfile.CHANNEL_PROFILE_CLASSROOM,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileInteractivePodcast] = exports.ChannelProfile.CHANNEL_PROFILE_INTERACTIVE_PODCAST,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileVRChat] = exports.ChannelProfile.CHANNEL_PROFIEL_VR_CHAT,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileMeeting] = exports.ChannelProfile.CHANNEL_PROFIEL_MEETING,
            _a[ByteRTCRoomProfile.ByteRTCRoomProfileLiveBroadcasting] = exports.ChannelProfile.CHANNEL_PROFILE_LIVE_BROADCASTING,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ChannelProfile;
}());
var t_MixedStreamClientMixVideoFormat = /** @class */ (function () {
    function t_MixedStreamClientMixVideoFormat() {
    }
    t_MixedStreamClientMixVideoFormat.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_TEXTURE_2D] = MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_TEXTURE_2D,
            _a[exports.MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_CVPIXEL_BUFFER_BGRA] = MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_CVPIXEL_BUFFER_BGRA,
            _a[exports.MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_I420] = MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_I420,
            _a[exports.MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_NV12] = MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_NV12,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamClientMixVideoFormat.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_TEXTURE_2D] = exports.MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_TEXTURE_2D,
            _a[MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_CVPIXEL_BUFFER_BGRA] = exports.MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_CVPIXEL_BUFFER_BGRA,
            _a[MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_I420] = exports.MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_I420,
            _a[MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_NV12] = exports.MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_YUV_NV12,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamClientMixVideoFormat.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_TEXTURE_2D] = ByteRTCMixedStreamClientMixVideoFormat.ByteRTCMixedStreamClientMixVideoFormatTexture2D,
            _a[exports.MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_CVPIXEL_BUFFER_BGRA] = ByteRTCMixedStreamClientMixVideoFormat.ByteRTCMixedStreamClientMixVideoFormatCVPixelBufferBGRA,
            _a[exports.MixedStreamClientMixVideoFormat.ByteRTCMixedStreamClientMixVideoFormatI420] = ByteRTCMixedStreamClientMixVideoFormat.ByteRTCMixedStreamClientMixVideoFormatI420,
            _a[exports.MixedStreamClientMixVideoFormat.ByteRTCMixedStreamClientMixVideoFormatNV12] = ByteRTCMixedStreamClientMixVideoFormat.ByteRTCMixedStreamClientMixVideoFormatNV12,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamClientMixVideoFormat.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMixedStreamClientMixVideoFormat.ByteRTCMixedStreamClientMixVideoFormatTexture2D] = exports.MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_TEXTURE_2D,
            _a[ByteRTCMixedStreamClientMixVideoFormat.ByteRTCMixedStreamClientMixVideoFormatCVPixelBufferBGRA] = exports.MixedStreamClientMixVideoFormat.MIXED_STREAM_CLIENT_MIX_VIDEO_FORMAT_CVPIXEL_BUFFER_BGRA,
            _a[ByteRTCMixedStreamClientMixVideoFormat.ByteRTCMixedStreamClientMixVideoFormatI420] = exports.MixedStreamClientMixVideoFormat.ByteRTCMixedStreamClientMixVideoFormatI420,
            _a[ByteRTCMixedStreamClientMixVideoFormat.ByteRTCMixedStreamClientMixVideoFormatNV12] = exports.MixedStreamClientMixVideoFormat.ByteRTCMixedStreamClientMixVideoFormatNV12,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MixedStreamClientMixVideoFormat;
}());
var t_PlayerState = /** @class */ (function () {
    function t_PlayerState() {
    }
    t_PlayerState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PlayerState.PRELOADED] = PlayerState.PRELOADED,
            _a[exports.PlayerState.OPENED] = PlayerState.OPENED,
            _a[exports.PlayerState.PLAYING] = PlayerState.PLAYING,
            _a[exports.PlayerState.PAUSED] = PlayerState.PAUSED,
            _a[exports.PlayerState.STOPPED] = PlayerState.STOPPED,
            _a[exports.PlayerState.FAILED] = PlayerState.FAILED,
            _a[exports.PlayerState.FINISHED] = PlayerState.FINISHED,
            _a[exports.PlayerState.IDLE] = PlayerState.IDLE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PlayerState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[PlayerState.PRELOADED] = exports.PlayerState.PRELOADED,
            _a[PlayerState.OPENED] = exports.PlayerState.OPENED,
            _a[PlayerState.PLAYING] = exports.PlayerState.PLAYING,
            _a[PlayerState.PAUSED] = exports.PlayerState.PAUSED,
            _a[PlayerState.STOPPED] = exports.PlayerState.STOPPED,
            _a[PlayerState.FAILED] = exports.PlayerState.FAILED,
            _a[PlayerState.FINISHED] = exports.PlayerState.FINISHED,
            _a[PlayerState.IDLE] = exports.PlayerState.IDLE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PlayerState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PlayerState.PRELOADED] = ByteRTCPlayerState.ByteRTCPlayerStatePreloaded,
            _a[exports.PlayerState.OPENED] = ByteRTCPlayerState.ByteRTCPlayerStateOpened,
            _a[exports.PlayerState.PLAYING] = ByteRTCPlayerState.ByteRTCPlayerStatePlaying,
            _a[exports.PlayerState.PAUSED] = ByteRTCPlayerState.ByteRTCPlayerStatePaused,
            _a[exports.PlayerState.STOPPED] = ByteRTCPlayerState.ByteRTCPlayerStateStopped,
            _a[exports.PlayerState.FAILED] = ByteRTCPlayerState.ByteRTCPlayerStateFailed,
            _a[exports.PlayerState.FINISHED] = ByteRTCPlayerState.ByteRTCPlayerStateFinished,
            _a[exports.PlayerState.ByteRTCPlayerStateIdle] = ByteRTCPlayerState.ByteRTCPlayerStateIdle,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PlayerState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCPlayerState.ByteRTCPlayerStatePreloaded] = exports.PlayerState.PRELOADED,
            _a[ByteRTCPlayerState.ByteRTCPlayerStateOpened] = exports.PlayerState.OPENED,
            _a[ByteRTCPlayerState.ByteRTCPlayerStatePlaying] = exports.PlayerState.PLAYING,
            _a[ByteRTCPlayerState.ByteRTCPlayerStatePaused] = exports.PlayerState.PAUSED,
            _a[ByteRTCPlayerState.ByteRTCPlayerStateStopped] = exports.PlayerState.STOPPED,
            _a[ByteRTCPlayerState.ByteRTCPlayerStateFailed] = exports.PlayerState.FAILED,
            _a[ByteRTCPlayerState.ByteRTCPlayerStateFinished] = exports.PlayerState.FINISHED,
            _a[ByteRTCPlayerState.ByteRTCPlayerStateIdle] = exports.PlayerState.ByteRTCPlayerStateIdle,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_PlayerState;
}());
var t_MixedStreamVideoType = /** @class */ (function () {
    function t_MixedStreamVideoType() {
    }
    t_MixedStreamVideoType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamVideoType.MIXED_STREAM_VIDEO_TYPE_MAIN] = MixedStreamVideoType.MIXED_STREAM_VIDEO_TYPE_MAIN,
            _a[exports.MixedStreamVideoType.MIXED_STREAM_VIDEO_TYPE_SCREEN] = MixedStreamVideoType.MIXED_STREAM_VIDEO_TYPE_SCREEN,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamVideoType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MixedStreamVideoType.MIXED_STREAM_VIDEO_TYPE_MAIN] = exports.MixedStreamVideoType.MIXED_STREAM_VIDEO_TYPE_MAIN,
            _a[MixedStreamVideoType.MIXED_STREAM_VIDEO_TYPE_SCREEN] = exports.MixedStreamVideoType.MIXED_STREAM_VIDEO_TYPE_SCREEN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamVideoType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamVideoType.MIXED_STREAM_VIDEO_TYPE_MAIN] = ByteRTCMixedStreamVideoType.ByteRTCMixedStreamVideoTypeMain,
            _a[exports.MixedStreamVideoType.MIXED_STREAM_VIDEO_TYPE_SCREEN] = ByteRTCMixedStreamVideoType.ByteRTCMixedStreamVideoTypeScreen,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamVideoType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMixedStreamVideoType.ByteRTCMixedStreamVideoTypeMain] = exports.MixedStreamVideoType.MIXED_STREAM_VIDEO_TYPE_MAIN,
            _a[ByteRTCMixedStreamVideoType.ByteRTCMixedStreamVideoTypeScreen] = exports.MixedStreamVideoType.MIXED_STREAM_VIDEO_TYPE_SCREEN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MixedStreamVideoType;
}());
var t_AudioPropertiesMode = /** @class */ (function () {
    function t_AudioPropertiesMode() {
    }
    t_AudioPropertiesMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioPropertiesMode.AUDIO_PROPERTIES_MODE_MICROPHONE] = AudioPropertiesMode.AUDIO_PROPERTIES_MODE_MICROPHONE,
            _a[exports.AudioPropertiesMode.AUDIO_PROPERTIES_MODE_AUDIOMIXING] = AudioPropertiesMode.AUDIO_PROPERTIES_MODE_AUDIOMIXING,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioPropertiesMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioPropertiesMode.AUDIO_PROPERTIES_MODE_MICROPHONE] = exports.AudioPropertiesMode.AUDIO_PROPERTIES_MODE_MICROPHONE,
            _a[AudioPropertiesMode.AUDIO_PROPERTIES_MODE_AUDIOMIXING] = exports.AudioPropertiesMode.AUDIO_PROPERTIES_MODE_AUDIOMIXING,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioPropertiesMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioPropertiesMode.AUDIO_PROPERTIES_MODE_MICROPHONE] = ByteRTCAudioPropertiesMode.ByteRTCAudioPropertiesModeMicrohone,
            _a[exports.AudioPropertiesMode.AUDIO_PROPERTIES_MODE_AUDIOMIXING] = ByteRTCAudioPropertiesMode.ByteRTCAudioPropertiesModeAudioMixing,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioPropertiesMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioPropertiesMode.ByteRTCAudioPropertiesModeMicrohone] = exports.AudioPropertiesMode.AUDIO_PROPERTIES_MODE_MICROPHONE,
            _a[ByteRTCAudioPropertiesMode.ByteRTCAudioPropertiesModeAudioMixing] = exports.AudioPropertiesMode.AUDIO_PROPERTIES_MODE_AUDIOMIXING,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioPropertiesMode;
}());
var t_VideoContentType = /** @class */ (function () {
    function t_VideoContentType() {
    }
    t_VideoContentType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoContentType.NORMAL_FRAME] = VideoContentType.NORMAL_FRAME,
            _a[exports.VideoContentType.BLACK_FRAME] = VideoContentType.BLACK_FRAME,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoContentType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoContentType.NORMAL_FRAME] = exports.VideoContentType.NORMAL_FRAME,
            _a[VideoContentType.BLACK_FRAME] = exports.VideoContentType.BLACK_FRAME,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoContentType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoContentType.NORMAL_FRAME] = ByteRTCVideoContentType.ByteRTCVideoContentTypeNormalFrame,
            _a[exports.VideoContentType.BLACK_FRAME] = ByteRTCVideoContentType.ByteRTCVideoContentTypeBlackFrame,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoContentType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoContentType.ByteRTCVideoContentTypeNormalFrame] = exports.VideoContentType.NORMAL_FRAME,
            _a[ByteRTCVideoContentType.ByteRTCVideoContentTypeBlackFrame] = exports.VideoContentType.BLACK_FRAME,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoContentType;
}());
var t_AudioSampleRate = /** @class */ (function () {
    function t_AudioSampleRate() {
    }
    t_AudioSampleRate.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioSampleRate.AUDIO_SAMPLE_RATE_AUTO] = AudioSampleRate.AUDIO_SAMPLE_RATE_AUTO,
            _a[exports.AudioSampleRate.AUDIO_SAMPLE_RATE_8000] = AudioSampleRate.AUDIO_SAMPLE_RATE_8000,
            _a[exports.AudioSampleRate.AUDIO_SAMPLE_RATE_16000] = AudioSampleRate.AUDIO_SAMPLE_RATE_16000,
            _a[exports.AudioSampleRate.AUDIO_SAMPLE_RATE_32000] = AudioSampleRate.AUDIO_SAMPLE_RATE_32000,
            _a[exports.AudioSampleRate.AUDIO_SAMPLE_RATE_44100] = AudioSampleRate.AUDIO_SAMPLE_RATE_44100,
            _a[exports.AudioSampleRate.AUDIO_SAMPLE_RATE_48000] = AudioSampleRate.AUDIO_SAMPLE_RATE_48000,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioSampleRate.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioSampleRate.AUDIO_SAMPLE_RATE_AUTO] = exports.AudioSampleRate.AUDIO_SAMPLE_RATE_AUTO,
            _a[AudioSampleRate.AUDIO_SAMPLE_RATE_8000] = exports.AudioSampleRate.AUDIO_SAMPLE_RATE_8000,
            _a[AudioSampleRate.AUDIO_SAMPLE_RATE_16000] = exports.AudioSampleRate.AUDIO_SAMPLE_RATE_16000,
            _a[AudioSampleRate.AUDIO_SAMPLE_RATE_32000] = exports.AudioSampleRate.AUDIO_SAMPLE_RATE_32000,
            _a[AudioSampleRate.AUDIO_SAMPLE_RATE_44100] = exports.AudioSampleRate.AUDIO_SAMPLE_RATE_44100,
            _a[AudioSampleRate.AUDIO_SAMPLE_RATE_48000] = exports.AudioSampleRate.AUDIO_SAMPLE_RATE_48000,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioSampleRate.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioSampleRate.AUDIO_SAMPLE_RATE_AUTO] = ByteRTCAudioSampleRate.ByteRTCAudioSampleRateAuto,
            _a[exports.AudioSampleRate.AUDIO_SAMPLE_RATE_8000] = ByteRTCAudioSampleRate.ByteRTCAudioSampleRate8000,
            _a[exports.AudioSampleRate.AUDIO_SAMPLE_RATE_16000] = ByteRTCAudioSampleRate.ByteRTCAudioSampleRate16000,
            _a[exports.AudioSampleRate.AUDIO_SAMPLE_RATE_32000] = ByteRTCAudioSampleRate.ByteRTCAudioSampleRate32000,
            _a[exports.AudioSampleRate.AUDIO_SAMPLE_RATE_44100] = ByteRTCAudioSampleRate.ByteRTCAudioSampleRate44100,
            _a[exports.AudioSampleRate.AUDIO_SAMPLE_RATE_48000] = ByteRTCAudioSampleRate.ByteRTCAudioSampleRate48000,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioSampleRate.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioSampleRate.ByteRTCAudioSampleRateAuto] = exports.AudioSampleRate.AUDIO_SAMPLE_RATE_AUTO,
            _a[ByteRTCAudioSampleRate.ByteRTCAudioSampleRate8000] = exports.AudioSampleRate.AUDIO_SAMPLE_RATE_8000,
            _a[ByteRTCAudioSampleRate.ByteRTCAudioSampleRate16000] = exports.AudioSampleRate.AUDIO_SAMPLE_RATE_16000,
            _a[ByteRTCAudioSampleRate.ByteRTCAudioSampleRate32000] = exports.AudioSampleRate.AUDIO_SAMPLE_RATE_32000,
            _a[ByteRTCAudioSampleRate.ByteRTCAudioSampleRate44100] = exports.AudioSampleRate.AUDIO_SAMPLE_RATE_44100,
            _a[ByteRTCAudioSampleRate.ByteRTCAudioSampleRate48000] = exports.AudioSampleRate.AUDIO_SAMPLE_RATE_48000,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioSampleRate;
}());
var t_LyricStatus = /** @class */ (function () {
    function t_LyricStatus() {
    }
    t_LyricStatus.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LyricStatus.NONE] = LyricStatus.NONE,
            _a[exports.LyricStatus.KRC] = LyricStatus.KRC,
            _a[exports.LyricStatus.LRC] = LyricStatus.LRC,
            _a[exports.LyricStatus.KRC_AND_LRC] = LyricStatus.KRC_AND_LRC,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LyricStatus.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[LyricStatus.NONE] = exports.LyricStatus.NONE,
            _a[LyricStatus.KRC] = exports.LyricStatus.KRC,
            _a[LyricStatus.LRC] = exports.LyricStatus.LRC,
            _a[LyricStatus.KRC_AND_LRC] = exports.LyricStatus.KRC_AND_LRC,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LyricStatus.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LyricStatus.NONE] = ByteRTCLyricStatus.ByteRTCLyricStatusNone,
            _a[exports.LyricStatus.KRC] = ByteRTCLyricStatus.ByteRTCLyricStatusKRC,
            _a[exports.LyricStatus.LRC] = ByteRTCLyricStatus.ByteRTCLyricStatusLRC,
            _a[exports.LyricStatus.KRC_AND_LRC] = ByteRTCLyricStatus.ByteRTCLyricStatusKRCAndLRC,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LyricStatus.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCLyricStatus.ByteRTCLyricStatusNone] = exports.LyricStatus.NONE,
            _a[ByteRTCLyricStatus.ByteRTCLyricStatusKRC] = exports.LyricStatus.KRC,
            _a[ByteRTCLyricStatus.ByteRTCLyricStatusLRC] = exports.LyricStatus.LRC,
            _a[ByteRTCLyricStatus.ByteRTCLyricStatusKRCAndLRC] = exports.LyricStatus.KRC_AND_LRC,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_LyricStatus;
}());
var t_MixedStreamVideoCodecType = /** @class */ (function () {
    function t_MixedStreamVideoCodecType() {
    }
    t_MixedStreamVideoCodecType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamVideoCodecType.MIXED_STREAM_VIDEO_CODEC_TYPE_H264] = MixedStreamVideoCodecType.MIXED_STREAM_VIDEO_CODEC_TYPE_H264,
            _a[exports.MixedStreamVideoCodecType.MIXED_STREAM_VIDEO_CODEC_TYPE_BYTEVC1] = MixedStreamVideoCodecType.MIXED_STREAM_VIDEO_CODEC_TYPE_BYTEVC1,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamVideoCodecType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MixedStreamVideoCodecType.MIXED_STREAM_VIDEO_CODEC_TYPE_H264] = exports.MixedStreamVideoCodecType.MIXED_STREAM_VIDEO_CODEC_TYPE_H264,
            _a[MixedStreamVideoCodecType.MIXED_STREAM_VIDEO_CODEC_TYPE_BYTEVC1] = exports.MixedStreamVideoCodecType.MIXED_STREAM_VIDEO_CODEC_TYPE_BYTEVC1,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamVideoCodecType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamVideoCodecType.MIXED_STREAM_VIDEO_CODEC_TYPE_H264] = ByteRTCMixedStreamVideoCodecType.ByteRTCMixedStreamVideoCodecTypeH264,
            _a[exports.MixedStreamVideoCodecType.MIXED_STREAM_VIDEO_CODEC_TYPE_BYTEVC1] = ByteRTCMixedStreamVideoCodecType.ByteRTCMixedStreamVideoCodecTypeByteVC1,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamVideoCodecType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMixedStreamVideoCodecType.ByteRTCMixedStreamVideoCodecTypeH264] = exports.MixedStreamVideoCodecType.MIXED_STREAM_VIDEO_CODEC_TYPE_H264,
            _a[ByteRTCMixedStreamVideoCodecType.ByteRTCMixedStreamVideoCodecTypeByteVC1] = exports.MixedStreamVideoCodecType.MIXED_STREAM_VIDEO_CODEC_TYPE_BYTEVC1,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MixedStreamVideoCodecType;
}());
var t_MuteState = /** @class */ (function () {
    function t_MuteState() {
    }
    t_MuteState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MuteState.MUTE_STATE_OFF] = MuteState.MUTE_STATE_OFF,
            _a[exports.MuteState.MUTE_STATE_ON] = MuteState.MUTE_STATE_ON,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MuteState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MuteState.MUTE_STATE_OFF] = exports.MuteState.MUTE_STATE_OFF,
            _a[MuteState.MUTE_STATE_ON] = exports.MuteState.MUTE_STATE_ON,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MuteState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MuteState.MUTE_STATE_OFF] = ByteRTCMuteState.ByteRTCMuteStateOff,
            _a[exports.MuteState.MUTE_STATE_ON] = ByteRTCMuteState.ByteRTCMuteStateOn,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MuteState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMuteState.ByteRTCMuteStateOff] = exports.MuteState.MUTE_STATE_OFF,
            _a[ByteRTCMuteState.ByteRTCMuteStateOn] = exports.MuteState.MUTE_STATE_ON,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MuteState;
}());
var t_ByteRTCStreamMixingType = /** @class */ (function () {
    function t_ByteRTCStreamMixingType() {
    }
    t_ByteRTCStreamMixingType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ByteRTCStreamMixingType.STREAM_MIXING_BY_SERVER] = ByteRTCStreamMixingType$1.STREAM_MIXING_BY_SERVER,
            _a[exports.ByteRTCStreamMixingType.STREAM_MIXING_BY_CLIENT] = ByteRTCStreamMixingType$1.STREAM_MIXING_BY_CLIENT,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ByteRTCStreamMixingType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCStreamMixingType$1.STREAM_MIXING_BY_SERVER] = exports.ByteRTCStreamMixingType.STREAM_MIXING_BY_SERVER,
            _a[ByteRTCStreamMixingType$1.STREAM_MIXING_BY_CLIENT] = exports.ByteRTCStreamMixingType.STREAM_MIXING_BY_CLIENT,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ByteRTCStreamMixingType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ByteRTCStreamMixingType.ByteRTCStreamMixingTypeByServer] = ByteRTCStreamMixingType.ByteRTCStreamMixingTypeByServer,
            _a[exports.ByteRTCStreamMixingType.ByteRTCStreamMixingTypeByClient] = ByteRTCStreamMixingType.ByteRTCStreamMixingTypeByClient,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ByteRTCStreamMixingType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCStreamMixingType.ByteRTCStreamMixingTypeByServer] = exports.ByteRTCStreamMixingType.ByteRTCStreamMixingTypeByServer,
            _a[ByteRTCStreamMixingType.ByteRTCStreamMixingTypeByClient] = exports.ByteRTCStreamMixingType.ByteRTCStreamMixingTypeByClient,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ByteRTCStreamMixingType;
}());
var t_MediaDeviceError = /** @class */ (function () {
    function t_MediaDeviceError() {
    }
    t_MediaDeviceError.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaDeviceError.MEDIA_DEVICE_ERROR_OK] = MediaDeviceError.MEDIA_DEVICE_ERROR_OK,
            _a[exports.MediaDeviceError.MEDIA_DEVICE_ERROR_NOPERMISSION] = MediaDeviceError.MEDIA_DEVICE_ERROR_NOPERMISSION,
            _a[exports.MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICEBUSY] = MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICEBUSY,
            _a[exports.MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICEFAILURE] = MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICEFAILURE,
            _a[exports.MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICENOTFOUND] = MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICENOTFOUND,
            _a[exports.MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICEDISCONNECTED] = MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICEDISCONNECTED,
            _a[exports.MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICENOCALLBACK] = MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICENOCALLBACK,
            _a[exports.MediaDeviceError.MEDIA_DEVICE_ERROR_UNSUPPORTFORMAT] = MediaDeviceError.MEDIA_DEVICE_ERROR_UNSUPPORTFORMAT,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaDeviceError.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MediaDeviceError.MEDIA_DEVICE_ERROR_OK] = exports.MediaDeviceError.MEDIA_DEVICE_ERROR_OK,
            _a[MediaDeviceError.MEDIA_DEVICE_ERROR_NOPERMISSION] = exports.MediaDeviceError.MEDIA_DEVICE_ERROR_NOPERMISSION,
            _a[MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICEBUSY] = exports.MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICEBUSY,
            _a[MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICEFAILURE] = exports.MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICEFAILURE,
            _a[MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICENOTFOUND] = exports.MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICENOTFOUND,
            _a[MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICEDISCONNECTED] = exports.MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICEDISCONNECTED,
            _a[MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICENOCALLBACK] = exports.MediaDeviceError.MEDIA_DEVICE_ERROR_DEVICENOCALLBACK,
            _a[MediaDeviceError.MEDIA_DEVICE_ERROR_UNSUPPORTFORMAT] = exports.MediaDeviceError.MEDIA_DEVICE_ERROR_UNSUPPORTFORMAT,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaDeviceError.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaDeviceError.ByteRTCMediaDeviceErrorOK] = ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorOK,
            _a[exports.MediaDeviceError.ByteRTCMediaDeviceErrorDeviceNoPermission] = ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorDeviceNoPermission,
            _a[exports.MediaDeviceError.ByteRTCMediaDeviceErrorDeviceBusy] = ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorDeviceBusy,
            _a[exports.MediaDeviceError.ByteRTCMediaDeviceErrorDeviceFailure] = ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorDeviceFailure,
            _a[exports.MediaDeviceError.ByteRTCMediaDeviceErrorDeviceNotFound] = ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorDeviceNotFound,
            _a[exports.MediaDeviceError.ByteRTCMediaDeviceErrorDeviceDisconnected] = ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorDeviceDisconnected,
            _a[exports.MediaDeviceError.ByteRTCMediaDeviceErrorDeviceNoCallback] = ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorDeviceNoCallback,
            _a[exports.MediaDeviceError.ByteRTCMediaDeviceErrorUNSupportFormat] = ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorUNSupportFormat,
            _a[exports.MediaDeviceError.ByteRTCMediaDeviceErrorNotFindGroupId] = ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorNotFindGroupId,
            _a[exports.MediaDeviceError.ByteRTCMediaDeviceErrorNotAvailableInBackground] = ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorNotAvailableInBackground,
            _a[exports.MediaDeviceError.ByteRTCMediaDeviceErrorVideoInUseByAnotherClient] = ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorVideoInUseByAnotherClient,
            _a[exports.MediaDeviceError.ByteRTCMediaDeviceErrorNotAvailableWithMultipleForegroundApps] = ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorNotAvailableWithMultipleForegroundApps,
            _a[exports.MediaDeviceError.ByteRTCMediaDeviceErrorNotAvailableDueToSystemPressure] = ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorNotAvailableDueToSystemPressure,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaDeviceError.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorOK] = exports.MediaDeviceError.ByteRTCMediaDeviceErrorOK,
            _a[ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorDeviceNoPermission] = exports.MediaDeviceError.ByteRTCMediaDeviceErrorDeviceNoPermission,
            _a[ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorDeviceBusy] = exports.MediaDeviceError.ByteRTCMediaDeviceErrorDeviceBusy,
            _a[ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorDeviceFailure] = exports.MediaDeviceError.ByteRTCMediaDeviceErrorDeviceFailure,
            _a[ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorDeviceNotFound] = exports.MediaDeviceError.ByteRTCMediaDeviceErrorDeviceNotFound,
            _a[ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorDeviceDisconnected] = exports.MediaDeviceError.ByteRTCMediaDeviceErrorDeviceDisconnected,
            _a[ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorDeviceNoCallback] = exports.MediaDeviceError.ByteRTCMediaDeviceErrorDeviceNoCallback,
            _a[ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorUNSupportFormat] = exports.MediaDeviceError.ByteRTCMediaDeviceErrorUNSupportFormat,
            _a[ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorNotFindGroupId] = exports.MediaDeviceError.ByteRTCMediaDeviceErrorNotFindGroupId,
            _a[ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorNotAvailableInBackground] = exports.MediaDeviceError.ByteRTCMediaDeviceErrorNotAvailableInBackground,
            _a[ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorVideoInUseByAnotherClient] = exports.MediaDeviceError.ByteRTCMediaDeviceErrorVideoInUseByAnotherClient,
            _a[ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorNotAvailableWithMultipleForegroundApps] = exports.MediaDeviceError.ByteRTCMediaDeviceErrorNotAvailableWithMultipleForegroundApps,
            _a[ByteRTCMediaDeviceError.ByteRTCMediaDeviceErrorNotAvailableDueToSystemPressure] = exports.MediaDeviceError.ByteRTCMediaDeviceErrorNotAvailableDueToSystemPressure,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MediaDeviceError;
}());
var t_AudioFrameSource = /** @class */ (function () {
    function t_AudioFrameSource() {
    }
    t_AudioFrameSource.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioFrameSource.AUDIO_FRAME_SOURCE_MIC] = AudioFrameSource.AUDIO_FRAME_SOURCE_MIC,
            _a[exports.AudioFrameSource.AUDIO_FRAME_SOURCE_PLAYBACK] = AudioFrameSource.AUDIO_FRAME_SOURCE_PLAYBACK,
            _a[exports.AudioFrameSource.AUDIO_FRAME_SOURCE_MIXED] = AudioFrameSource.AUDIO_FRAME_SOURCE_MIXED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioFrameSource.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioFrameSource.AUDIO_FRAME_SOURCE_MIC] = exports.AudioFrameSource.AUDIO_FRAME_SOURCE_MIC,
            _a[AudioFrameSource.AUDIO_FRAME_SOURCE_PLAYBACK] = exports.AudioFrameSource.AUDIO_FRAME_SOURCE_PLAYBACK,
            _a[AudioFrameSource.AUDIO_FRAME_SOURCE_MIXED] = exports.AudioFrameSource.AUDIO_FRAME_SOURCE_MIXED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioFrameSource.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioFrameSource.ByteRTCAudioFrameSourceTypeMic] = ByteRTCAudioFrameSource.ByteRTCAudioFrameSourceTypeMic,
            _a[exports.AudioFrameSource.ByteRTCAudioFrameSourceTypePlayback] = ByteRTCAudioFrameSource.ByteRTCAudioFrameSourceTypePlayback,
            _a[exports.AudioFrameSource.ByteRTCAudioFrameSourceTypeMixed] = ByteRTCAudioFrameSource.ByteRTCAudioFrameSourceTypeMixed,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioFrameSource.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioFrameSource.ByteRTCAudioFrameSourceTypeMic] = exports.AudioFrameSource.ByteRTCAudioFrameSourceTypeMic,
            _a[ByteRTCAudioFrameSource.ByteRTCAudioFrameSourceTypePlayback] = exports.AudioFrameSource.ByteRTCAudioFrameSourceTypePlayback,
            _a[ByteRTCAudioFrameSource.ByteRTCAudioFrameSourceTypeMixed] = exports.AudioFrameSource.ByteRTCAudioFrameSourceTypeMixed,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioFrameSource;
}());
var t_StreamRemoveReason = /** @class */ (function () {
    function t_StreamRemoveReason() {
    }
    t_StreamRemoveReason.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.StreamRemoveReason.STREAM_REMOVE_REASON_UNPUBLISH] = StreamRemoveReason.STREAM_REMOVE_REASON_UNPUBLISH,
            _a[exports.StreamRemoveReason.STREAM_REMOVE_REASON_PUBLISH_FAILED] = StreamRemoveReason.STREAM_REMOVE_REASON_PUBLISH_FAILED,
            _a[exports.StreamRemoveReason.STREAM_REMOVE_REASON_KEEP_LIVE_FAILED] = StreamRemoveReason.STREAM_REMOVE_REASON_KEEP_LIVE_FAILED,
            _a[exports.StreamRemoveReason.STREAM_REMOVE_REASON_CLIENT_DISCONNECTED] = StreamRemoveReason.STREAM_REMOVE_REASON_CLIENT_DISCONNECTED,
            _a[exports.StreamRemoveReason.STREAM_REMOVE_REASON_REPUBLISH] = StreamRemoveReason.STREAM_REMOVE_REASON_REPUBLISH,
            _a[exports.StreamRemoveReason.STREAM_REMOVE_REASON_OTHER] = StreamRemoveReason.STREAM_REMOVE_REASON_OTHER,
            _a[exports.StreamRemoveReason.STREAM_REMOVE_REASON_PUBLISH_PRIVILEGE_TOKEN_EXPIRED] = StreamRemoveReason.STREAM_REMOVE_REASON_PUBLISH_PRIVILEGE_TOKEN_EXPIRED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_StreamRemoveReason.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[StreamRemoveReason.STREAM_REMOVE_REASON_UNPUBLISH] = exports.StreamRemoveReason.STREAM_REMOVE_REASON_UNPUBLISH,
            _a[StreamRemoveReason.STREAM_REMOVE_REASON_PUBLISH_FAILED] = exports.StreamRemoveReason.STREAM_REMOVE_REASON_PUBLISH_FAILED,
            _a[StreamRemoveReason.STREAM_REMOVE_REASON_KEEP_LIVE_FAILED] = exports.StreamRemoveReason.STREAM_REMOVE_REASON_KEEP_LIVE_FAILED,
            _a[StreamRemoveReason.STREAM_REMOVE_REASON_CLIENT_DISCONNECTED] = exports.StreamRemoveReason.STREAM_REMOVE_REASON_CLIENT_DISCONNECTED,
            _a[StreamRemoveReason.STREAM_REMOVE_REASON_REPUBLISH] = exports.StreamRemoveReason.STREAM_REMOVE_REASON_REPUBLISH,
            _a[StreamRemoveReason.STREAM_REMOVE_REASON_OTHER] = exports.StreamRemoveReason.STREAM_REMOVE_REASON_OTHER,
            _a[StreamRemoveReason.STREAM_REMOVE_REASON_PUBLISH_PRIVILEGE_TOKEN_EXPIRED] = exports.StreamRemoveReason.STREAM_REMOVE_REASON_PUBLISH_PRIVILEGE_TOKEN_EXPIRED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_StreamRemoveReason.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.StreamRemoveReason.STREAM_REMOVE_REASON_UNPUBLISH] = ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonUnpublish,
            _a[exports.StreamRemoveReason.STREAM_REMOVE_REASON_PUBLISH_FAILED] = ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonPublishFailed,
            _a[exports.StreamRemoveReason.STREAM_REMOVE_REASON_KEEP_LIVE_FAILED] = ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonKeepLiveFailed,
            _a[exports.StreamRemoveReason.STREAM_REMOVE_REASON_CLIENT_DISCONNECTED] = ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonClientDisconnected,
            _a[exports.StreamRemoveReason.STREAM_REMOVE_REASON_REPUBLISH] = ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonRepublish,
            _a[exports.StreamRemoveReason.STREAM_REMOVE_REASON_OTHER] = ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonOther,
            _a[exports.StreamRemoveReason.ByteRTCStreamRemoveReasonPublishPrivilegeExpired] = ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonPublishPrivilegeExpired,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_StreamRemoveReason.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonUnpublish] = exports.StreamRemoveReason.STREAM_REMOVE_REASON_UNPUBLISH,
            _a[ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonPublishFailed] = exports.StreamRemoveReason.STREAM_REMOVE_REASON_PUBLISH_FAILED,
            _a[ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonKeepLiveFailed] = exports.StreamRemoveReason.STREAM_REMOVE_REASON_KEEP_LIVE_FAILED,
            _a[ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonClientDisconnected] = exports.StreamRemoveReason.STREAM_REMOVE_REASON_CLIENT_DISCONNECTED,
            _a[ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonRepublish] = exports.StreamRemoveReason.STREAM_REMOVE_REASON_REPUBLISH,
            _a[ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonOther] = exports.StreamRemoveReason.STREAM_REMOVE_REASON_OTHER,
            _a[ByteRTCStreamRemoveReason.ByteRTCStreamRemoveReasonPublishPrivilegeExpired] = exports.StreamRemoveReason.ByteRTCStreamRemoveReasonPublishPrivilegeExpired,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_StreamRemoveReason;
}());
var t_ForwardStreamError = /** @class */ (function () {
    function t_ForwardStreamError() {
    }
    t_ForwardStreamError.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ForwardStreamError.FORWARD_STREAM_ERROR_OK] = ForwardStreamError.FORWARD_STREAM_ERROR_OK,
            _a[exports.ForwardStreamError.FORWARD_STREAM_ERROR_RESPONSE] = ForwardStreamError.FORWARD_STREAM_ERROR_RESPONSE,
            _a[exports.ForwardStreamError.FORWARD_STREAM_ERROR_REMOTE_KICKED] = ForwardStreamError.FORWARD_STREAM_ERROR_REMOTE_KICKED,
            _a[exports.ForwardStreamError.FORWARD_STREAM_ERROR_NOT_SUPPORT] = ForwardStreamError.FORWARD_STREAM_ERROR_NOT_SUPPORT,
            _a[exports.ForwardStreamError.FORWARD_STREAM_ERROR_INVALID_ARGUMENT] = ForwardStreamError.FORWARD_STREAM_ERROR_INVALID_ARGUMENT,
            _a[exports.ForwardStreamError.FORWARD_STREAM_ERROR_INVALID_TOKEN] = ForwardStreamError.FORWARD_STREAM_ERROR_INVALID_TOKEN,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ForwardStreamError.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ForwardStreamError.FORWARD_STREAM_ERROR_OK] = exports.ForwardStreamError.FORWARD_STREAM_ERROR_OK,
            _a[ForwardStreamError.FORWARD_STREAM_ERROR_RESPONSE] = exports.ForwardStreamError.FORWARD_STREAM_ERROR_RESPONSE,
            _a[ForwardStreamError.FORWARD_STREAM_ERROR_REMOTE_KICKED] = exports.ForwardStreamError.FORWARD_STREAM_ERROR_REMOTE_KICKED,
            _a[ForwardStreamError.FORWARD_STREAM_ERROR_NOT_SUPPORT] = exports.ForwardStreamError.FORWARD_STREAM_ERROR_NOT_SUPPORT,
            _a[ForwardStreamError.FORWARD_STREAM_ERROR_INVALID_ARGUMENT] = exports.ForwardStreamError.FORWARD_STREAM_ERROR_INVALID_ARGUMENT,
            _a[ForwardStreamError.FORWARD_STREAM_ERROR_INVALID_TOKEN] = exports.ForwardStreamError.FORWARD_STREAM_ERROR_INVALID_TOKEN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ForwardStreamError.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ForwardStreamError.FORWARD_STREAM_ERROR_OK] = ByteRTCForwardStreamError.ByteRTCForwardStreamErrorOK,
            _a[exports.ForwardStreamError.FORWARD_STREAM_ERROR_RESPONSE] = ByteRTCForwardStreamError.ByteRTCForwardStreamErrorResponse,
            _a[exports.ForwardStreamError.FORWARD_STREAM_ERROR_REMOTE_KICKED] = ByteRTCForwardStreamError.ByteRTCForwardStreamErrorRemoteKicked,
            _a[exports.ForwardStreamError.FORWARD_STREAM_ERROR_NOT_SUPPORT] = ByteRTCForwardStreamError.ByteRTCForwardStreamErrorNotSupport,
            _a[exports.ForwardStreamError.ByteRTCForwardStreamErrorInvalidArgument] = ByteRTCForwardStreamError.ByteRTCForwardStreamErrorInvalidArgument,
            _a[exports.ForwardStreamError.ByteRTCForwardStreamErrorInvalidToken] = ByteRTCForwardStreamError.ByteRTCForwardStreamErrorInvalidToken,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ForwardStreamError.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCForwardStreamError.ByteRTCForwardStreamErrorOK] = exports.ForwardStreamError.FORWARD_STREAM_ERROR_OK,
            _a[ByteRTCForwardStreamError.ByteRTCForwardStreamErrorResponse] = exports.ForwardStreamError.FORWARD_STREAM_ERROR_RESPONSE,
            _a[ByteRTCForwardStreamError.ByteRTCForwardStreamErrorRemoteKicked] = exports.ForwardStreamError.FORWARD_STREAM_ERROR_REMOTE_KICKED,
            _a[ByteRTCForwardStreamError.ByteRTCForwardStreamErrorNotSupport] = exports.ForwardStreamError.FORWARD_STREAM_ERROR_NOT_SUPPORT,
            _a[ByteRTCForwardStreamError.ByteRTCForwardStreamErrorInvalidArgument] = exports.ForwardStreamError.ByteRTCForwardStreamErrorInvalidArgument,
            _a[ByteRTCForwardStreamError.ByteRTCForwardStreamErrorInvalidToken] = exports.ForwardStreamError.ByteRTCForwardStreamErrorInvalidToken,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ForwardStreamError;
}());
var t_NetworkDetectionStopReason = /** @class */ (function () {
    function t_NetworkDetectionStopReason() {
    }
    t_NetworkDetectionStopReason.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.NetworkDetectionStopReason.USER] = NetworkDetectionStopReason.USER,
            _a[exports.NetworkDetectionStopReason.TIMEOUT] = NetworkDetectionStopReason.TIMEOUT,
            _a[exports.NetworkDetectionStopReason.CONNECTION_LOST] = NetworkDetectionStopReason.CONNECTION_LOST,
            _a[exports.NetworkDetectionStopReason.STREAMING] = NetworkDetectionStopReason.STREAMING,
            _a[exports.NetworkDetectionStopReason.INNER_ERR] = NetworkDetectionStopReason.INNER_ERR,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_NetworkDetectionStopReason.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[NetworkDetectionStopReason.USER] = exports.NetworkDetectionStopReason.USER,
            _a[NetworkDetectionStopReason.TIMEOUT] = exports.NetworkDetectionStopReason.TIMEOUT,
            _a[NetworkDetectionStopReason.CONNECTION_LOST] = exports.NetworkDetectionStopReason.CONNECTION_LOST,
            _a[NetworkDetectionStopReason.STREAMING] = exports.NetworkDetectionStopReason.STREAMING,
            _a[NetworkDetectionStopReason.INNER_ERR] = exports.NetworkDetectionStopReason.INNER_ERR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_NetworkDetectionStopReason.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.NetworkDetectionStopReason.USER] = ByteRTCNetworkDetectionStopReason.ByteRTCNetworkDetectionStopReasonUser,
            _a[exports.NetworkDetectionStopReason.TIMEOUT] = ByteRTCNetworkDetectionStopReason.ByteRTCNetworkDetectionStopReasonTimeout,
            _a[exports.NetworkDetectionStopReason.CONNECTION_LOST] = ByteRTCNetworkDetectionStopReason.ByteRTCNetworkDetectionStopReasonConnectionLost,
            _a[exports.NetworkDetectionStopReason.STREAMING] = ByteRTCNetworkDetectionStopReason.ByteRTCNetworkDetectionStopReasonStreaming,
            _a[exports.NetworkDetectionStopReason.ByteRTCNetworkDetectionStopReasonInnerErr] = ByteRTCNetworkDetectionStopReason.ByteRTCNetworkDetectionStopReasonInnerErr,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_NetworkDetectionStopReason.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCNetworkDetectionStopReason.ByteRTCNetworkDetectionStopReasonUser] = exports.NetworkDetectionStopReason.USER,
            _a[ByteRTCNetworkDetectionStopReason.ByteRTCNetworkDetectionStopReasonTimeout] = exports.NetworkDetectionStopReason.TIMEOUT,
            _a[ByteRTCNetworkDetectionStopReason.ByteRTCNetworkDetectionStopReasonConnectionLost] = exports.NetworkDetectionStopReason.CONNECTION_LOST,
            _a[ByteRTCNetworkDetectionStopReason.ByteRTCNetworkDetectionStopReasonStreaming] = exports.NetworkDetectionStopReason.STREAMING,
            _a[ByteRTCNetworkDetectionStopReason.ByteRTCNetworkDetectionStopReasonInnerErr] = exports.NetworkDetectionStopReason.ByteRTCNetworkDetectionStopReasonInnerErr,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_NetworkDetectionStopReason;
}());
var t_VideoDenoiseMode = /** @class */ (function () {
    function t_VideoDenoiseMode() {
    }
    t_VideoDenoiseMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoDenoiseMode.VIDEO_DENOISE_MODE_OFF] = VideoDenoiseMode.VIDEO_DENOISE_MODE_OFF,
            _a[exports.VideoDenoiseMode.VIDEO_DENOISE_MODE_AUTO] = VideoDenoiseMode.VIDEO_DENOISE_MODE_AUTO,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoDenoiseMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoDenoiseMode.VIDEO_DENOISE_MODE_OFF] = exports.VideoDenoiseMode.VIDEO_DENOISE_MODE_OFF,
            _a[VideoDenoiseMode.VIDEO_DENOISE_MODE_AUTO] = exports.VideoDenoiseMode.VIDEO_DENOISE_MODE_AUTO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoDenoiseMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoDenoiseMode.VIDEO_DENOISE_MODE_OFF] = ByteRTCVideoDenoiseMode.ByteRTCVideoDenoiseModeOff,
            _a[exports.VideoDenoiseMode.VIDEO_DENOISE_MODE_AUTO] = ByteRTCVideoDenoiseMode.ByteRTCVideoDenoiseModeAuto,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoDenoiseMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoDenoiseMode.ByteRTCVideoDenoiseModeOff] = exports.VideoDenoiseMode.VIDEO_DENOISE_MODE_OFF,
            _a[ByteRTCVideoDenoiseMode.ByteRTCVideoDenoiseModeAuto] = exports.VideoDenoiseMode.VIDEO_DENOISE_MODE_AUTO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoDenoiseMode;
}());
var t_AudioRecordingState = /** @class */ (function () {
    function t_AudioRecordingState() {
    }
    t_AudioRecordingState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioRecordingState.AUDIO_RECORDING_STATE_ERROR] = AudioRecordingState.AUDIO_RECORDING_STATE_ERROR,
            _a[exports.AudioRecordingState.AUDIO_RECORDING_STATE_PROCESSING] = AudioRecordingState.AUDIO_RECORDING_STATE_PROCESSING,
            _a[exports.AudioRecordingState.AUDIO_RECORDING_STATE_SUCCESS] = AudioRecordingState.AUDIO_RECORDING_STATE_SUCCESS,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioRecordingState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioRecordingState.AUDIO_RECORDING_STATE_ERROR] = exports.AudioRecordingState.AUDIO_RECORDING_STATE_ERROR,
            _a[AudioRecordingState.AUDIO_RECORDING_STATE_PROCESSING] = exports.AudioRecordingState.AUDIO_RECORDING_STATE_PROCESSING,
            _a[AudioRecordingState.AUDIO_RECORDING_STATE_SUCCESS] = exports.AudioRecordingState.AUDIO_RECORDING_STATE_SUCCESS,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioRecordingState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioRecordingState.AUDIO_RECORDING_STATE_ERROR] = ByteRTCAudioRecordingState.ByteRTCAudioRecordingStateError,
            _a[exports.AudioRecordingState.AUDIO_RECORDING_STATE_PROCESSING] = ByteRTCAudioRecordingState.ByteRTCAudioRecordingStateProcessing,
            _a[exports.AudioRecordingState.AUDIO_RECORDING_STATE_SUCCESS] = ByteRTCAudioRecordingState.ByteRTCAudioRecordingStateSuccess,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioRecordingState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioRecordingState.ByteRTCAudioRecordingStateError] = exports.AudioRecordingState.AUDIO_RECORDING_STATE_ERROR,
            _a[ByteRTCAudioRecordingState.ByteRTCAudioRecordingStateProcessing] = exports.AudioRecordingState.AUDIO_RECORDING_STATE_PROCESSING,
            _a[ByteRTCAudioRecordingState.ByteRTCAudioRecordingStateSuccess] = exports.AudioRecordingState.AUDIO_RECORDING_STATE_SUCCESS,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioRecordingState;
}());
var t_MulDimSingScoringMode = /** @class */ (function () {
    function t_MulDimSingScoringMode() {
    }
    t_MulDimSingScoringMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MulDimSingScoringMode.MUL_DIM_SING_SCORING_MODE_NOTE] = MulDimSingScoringMode.MUL_DIM_SING_SCORING_MODE_NOTE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MulDimSingScoringMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MulDimSingScoringMode.MUL_DIM_SING_SCORING_MODE_NOTE] = exports.MulDimSingScoringMode.MUL_DIM_SING_SCORING_MODE_NOTE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MulDimSingScoringMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MulDimSingScoringMode.MUL_DIM_SING_SCORING_MODE_NOTE] = ByteRTCMulDimSingScoringMode.ByteRTCMulDimSingScoringModeNote,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MulDimSingScoringMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMulDimSingScoringMode.ByteRTCMulDimSingScoringModeNote] = exports.MulDimSingScoringMode.MUL_DIM_SING_SCORING_MODE_NOTE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MulDimSingScoringMode;
}());
var t_AudioPlaybackDevice = /** @class */ (function () {
    function t_AudioPlaybackDevice() {
    }
    t_AudioPlaybackDevice.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET] = AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET,
            _a[exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_EARPIECE] = AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_EARPIECE,
            _a[exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_SPEAKERPHONE] = AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_SPEAKERPHONE,
            _a[exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET_BLUETOOTH] = AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET_BLUETOOTH,
            _a[exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET_USB] = AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET_USB,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioPlaybackDevice.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET] = exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET,
            _a[AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_EARPIECE] = exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_EARPIECE,
            _a[AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_SPEAKERPHONE] = exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_SPEAKERPHONE,
            _a[AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET_BLUETOOTH] = exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET_BLUETOOTH,
            _a[AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET_USB] = exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET_USB,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioPlaybackDevice.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET] = ByteRTCAudioPlaybackDevice.ByteRTCAudioPlaybackDeviceHeadset,
            _a[exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_EARPIECE] = ByteRTCAudioPlaybackDevice.ByteRTCAudioPlaybackDeviceEarpiece,
            _a[exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_SPEAKERPHONE] = ByteRTCAudioPlaybackDevice.ByteRTCAudioPlaybackDeviceSpeakerphone,
            _a[exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET_BLUETOOTH] = ByteRTCAudioPlaybackDevice.ByteRTCAudioPlaybackDeviceHeadsetBluetooth,
            _a[exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET_USB] = ByteRTCAudioPlaybackDevice.ByteRTCAudioPlaybackDeviceHeadsetUSB,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioPlaybackDevice.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioPlaybackDevice.ByteRTCAudioPlaybackDeviceHeadset] = exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET,
            _a[ByteRTCAudioPlaybackDevice.ByteRTCAudioPlaybackDeviceEarpiece] = exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_EARPIECE,
            _a[ByteRTCAudioPlaybackDevice.ByteRTCAudioPlaybackDeviceSpeakerphone] = exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_SPEAKERPHONE,
            _a[ByteRTCAudioPlaybackDevice.ByteRTCAudioPlaybackDeviceHeadsetBluetooth] = exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET_BLUETOOTH,
            _a[ByteRTCAudioPlaybackDevice.ByteRTCAudioPlaybackDeviceHeadsetUSB] = exports.AudioPlaybackDevice.AUDIO_PLAYBACK_DEVICE_HEADSET_USB,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioPlaybackDevice;
}());
var t_VideoPixelFormat = /** @class */ (function () {
    function t_VideoPixelFormat() {
    }
    t_VideoPixelFormat.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoPixelFormat.UNKNOWN] = VideoPixelFormat.UNKNOWN,
            _a[exports.VideoPixelFormat.I420] = VideoPixelFormat.I420,
            _a[exports.VideoPixelFormat.NV21] = VideoPixelFormat.NV21,
            _a[exports.VideoPixelFormat.RGBA] = VideoPixelFormat.RGBA,
            _a[exports.VideoPixelFormat.NV12] = VideoPixelFormat.NV12,
            _a[exports.VideoPixelFormat.TEXTURE_2D] = VideoPixelFormat.TEXTURE_2D,
            _a[exports.VideoPixelFormat.TEXTURE_OES] = VideoPixelFormat.TEXTURE_OES,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoPixelFormat.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoPixelFormat.UNKNOWN] = exports.VideoPixelFormat.UNKNOWN,
            _a[VideoPixelFormat.I420] = exports.VideoPixelFormat.I420,
            _a[VideoPixelFormat.NV21] = exports.VideoPixelFormat.NV21,
            _a[VideoPixelFormat.RGBA] = exports.VideoPixelFormat.RGBA,
            _a[VideoPixelFormat.NV12] = exports.VideoPixelFormat.NV12,
            _a[VideoPixelFormat.TEXTURE_2D] = exports.VideoPixelFormat.TEXTURE_2D,
            _a[VideoPixelFormat.TEXTURE_OES] = exports.VideoPixelFormat.TEXTURE_OES,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoPixelFormat.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoPixelFormat.UNKNOWN] = ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatUnknown,
            _a[exports.VideoPixelFormat.I420] = ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatI420,
            _a[exports.VideoPixelFormat.NV21] = ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatNV21,
            _a[exports.VideoPixelFormat.RGBA] = ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatRGBA,
            _a[exports.VideoPixelFormat.NV12] = ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatNV12,
            _a[exports.VideoPixelFormat.ByteRTCVideoPixelFormatBGRA] = ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatBGRA,
            _a[exports.VideoPixelFormat.ByteRTCVideoPixelFormatIMC2] = ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatIMC2,
            _a[exports.VideoPixelFormat.ByteRTCVideoPixelFormatARGB] = ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatARGB,
            _a[exports.VideoPixelFormat.ByteRTCVideoPixelFormatGLTexture2D] = ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatGLTexture2D,
            _a[exports.VideoPixelFormat.ByteRTCVideoPixelFormatGLTextureOES] = ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatGLTextureOES,
            _a[exports.VideoPixelFormat.ByteRTCVideoPixelFormatCVPixelBuffer] = ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatCVPixelBuffer,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoPixelFormat.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatUnknown] = exports.VideoPixelFormat.UNKNOWN,
            _a[ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatI420] = exports.VideoPixelFormat.I420,
            _a[ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatNV21] = exports.VideoPixelFormat.NV21,
            _a[ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatRGBA] = exports.VideoPixelFormat.RGBA,
            _a[ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatNV12] = exports.VideoPixelFormat.NV12,
            _a[ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatBGRA] = exports.VideoPixelFormat.ByteRTCVideoPixelFormatBGRA,
            _a[ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatIMC2] = exports.VideoPixelFormat.ByteRTCVideoPixelFormatIMC2,
            _a[ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatARGB] = exports.VideoPixelFormat.ByteRTCVideoPixelFormatARGB,
            _a[ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatGLTexture2D] = exports.VideoPixelFormat.ByteRTCVideoPixelFormatGLTexture2D,
            _a[ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatGLTextureOES] = exports.VideoPixelFormat.ByteRTCVideoPixelFormatGLTextureOES,
            _a[ByteRTCVideoPixelFormat.ByteRTCVideoPixelFormatCVPixelBuffer] = exports.VideoPixelFormat.ByteRTCVideoPixelFormatCVPixelBuffer,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoPixelFormat;
}());
var t_AudioChannel = /** @class */ (function () {
    function t_AudioChannel() {
    }
    t_AudioChannel.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioChannel.AUDIO_CHANNEL_AUTO] = AudioChannel.AUDIO_CHANNEL_AUTO,
            _a[exports.AudioChannel.AUDIO_CHANNEL_MONO] = AudioChannel.AUDIO_CHANNEL_MONO,
            _a[exports.AudioChannel.AUDIO_CHANNEL_STEREO] = AudioChannel.AUDIO_CHANNEL_STEREO,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioChannel.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioChannel.AUDIO_CHANNEL_AUTO] = exports.AudioChannel.AUDIO_CHANNEL_AUTO,
            _a[AudioChannel.AUDIO_CHANNEL_MONO] = exports.AudioChannel.AUDIO_CHANNEL_MONO,
            _a[AudioChannel.AUDIO_CHANNEL_STEREO] = exports.AudioChannel.AUDIO_CHANNEL_STEREO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioChannel.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioChannel.AUDIO_CHANNEL_AUTO] = ByteRTCAudioChannel.ByteRTCAudioChannelAuto,
            _a[exports.AudioChannel.AUDIO_CHANNEL_MONO] = ByteRTCAudioChannel.ByteRTCAudioChannelMono,
            _a[exports.AudioChannel.AUDIO_CHANNEL_STEREO] = ByteRTCAudioChannel.ByteRTCAudioChannelStereo,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioChannel.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioChannel.ByteRTCAudioChannelAuto] = exports.AudioChannel.AUDIO_CHANNEL_AUTO,
            _a[ByteRTCAudioChannel.ByteRTCAudioChannelMono] = exports.AudioChannel.AUDIO_CHANNEL_MONO,
            _a[ByteRTCAudioChannel.ByteRTCAudioChannelStereo] = exports.AudioChannel.AUDIO_CHANNEL_STEREO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioChannel;
}());
var t_DownloadFileType = /** @class */ (function () {
    function t_DownloadFileType() {
    }
    t_DownloadFileType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.DownloadFileType.MUSIC] = DownloadFileType.MUSIC,
            _a[exports.DownloadFileType.KRC] = DownloadFileType.KRC,
            _a[exports.DownloadFileType.LRC] = DownloadFileType.LRC,
            _a[exports.DownloadFileType.MIDI] = DownloadFileType.MIDI,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_DownloadFileType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[DownloadFileType.MUSIC] = exports.DownloadFileType.MUSIC,
            _a[DownloadFileType.KRC] = exports.DownloadFileType.KRC,
            _a[DownloadFileType.LRC] = exports.DownloadFileType.LRC,
            _a[DownloadFileType.MIDI] = exports.DownloadFileType.MIDI,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_DownloadFileType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.DownloadFileType.MUSIC] = ByteRTCDownloadFileType.ByteRTCDownloadFileTypeMusic,
            _a[exports.DownloadFileType.KRC] = ByteRTCDownloadFileType.ByteRTCDownloadFileTypeKRC,
            _a[exports.DownloadFileType.LRC] = ByteRTCDownloadFileType.ByteRTCDownloadFileTypeLRC,
            _a[exports.DownloadFileType.MIDI] = ByteRTCDownloadFileType.ByteRTCDownloadFileTypeMIDI,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_DownloadFileType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCDownloadFileType.ByteRTCDownloadFileTypeMusic] = exports.DownloadFileType.MUSIC,
            _a[ByteRTCDownloadFileType.ByteRTCDownloadFileTypeKRC] = exports.DownloadFileType.KRC,
            _a[ByteRTCDownloadFileType.ByteRTCDownloadFileTypeLRC] = exports.DownloadFileType.LRC,
            _a[ByteRTCDownloadFileType.ByteRTCDownloadFileTypeMIDI] = exports.DownloadFileType.MIDI,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_DownloadFileType;
}());
var t_ProblemFeedbackOption = /** @class */ (function () {
    function t_ProblemFeedbackOption() {
    }
    t_ProblemFeedbackOption.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ProblemFeedbackOption.NONE] = ProblemFeedbackOption.NONE,
            _a[exports.ProblemFeedbackOption.OTHER_MESSAGE] = ProblemFeedbackOption.OTHER_MESSAGE,
            _a[exports.ProblemFeedbackOption.DISCONNECTED] = ProblemFeedbackOption.DISCONNECTED,
            _a[exports.ProblemFeedbackOption.EAR_BACK_DELAY] = ProblemFeedbackOption.EAR_BACK_DELAY,
            _a[exports.ProblemFeedbackOption.LOCAL_NOISE] = ProblemFeedbackOption.LOCAL_NOISE,
            _a[exports.ProblemFeedbackOption.LOCAL_AUDIO_LAGGING] = ProblemFeedbackOption.LOCAL_AUDIO_LAGGING,
            _a[exports.ProblemFeedbackOption.LOCAL_NO_AUDIO] = ProblemFeedbackOption.LOCAL_NO_AUDIO,
            _a[exports.ProblemFeedbackOption.LOCAL_AUDIO_STRENGTH] = ProblemFeedbackOption.LOCAL_AUDIO_STRENGTH,
            _a[exports.ProblemFeedbackOption.LOCAL_ECHO] = ProblemFeedbackOption.LOCAL_ECHO,
            _a[exports.ProblemFeedbackOption.LOCAL_VIDEO_FUZZY] = ProblemFeedbackOption.LOCAL_VIDEO_FUZZY,
            _a[exports.ProblemFeedbackOption.LOCAL_NOT_SYNC] = ProblemFeedbackOption.LOCAL_NOT_SYNC,
            _a[exports.ProblemFeedbackOption.LOCAL_VIDEO_LAGGING] = ProblemFeedbackOption.LOCAL_VIDEO_LAGGING,
            _a[exports.ProblemFeedbackOption.LOCAL_NO_VIDEO] = ProblemFeedbackOption.LOCAL_NO_VIDEO,
            _a[exports.ProblemFeedbackOption.REMOTE_NOISE] = ProblemFeedbackOption.REMOTE_NOISE,
            _a[exports.ProblemFeedbackOption.REMOTE_AUDIO_LAGGING] = ProblemFeedbackOption.REMOTE_AUDIO_LAGGING,
            _a[exports.ProblemFeedbackOption.REMOTE_NO_AUDIO] = ProblemFeedbackOption.REMOTE_NO_AUDIO,
            _a[exports.ProblemFeedbackOption.REMOTE_AUDIO_STRENGTH] = ProblemFeedbackOption.REMOTE_AUDIO_STRENGTH,
            _a[exports.ProblemFeedbackOption.REMOTE_ECHO] = ProblemFeedbackOption.REMOTE_ECHO,
            _a[exports.ProblemFeedbackOption.REMOTE_VIDEO_FUZZY] = ProblemFeedbackOption.REMOTE_VIDEO_FUZZY,
            _a[exports.ProblemFeedbackOption.REMOTE_NOT_SYNC] = ProblemFeedbackOption.REMOTE_NOT_SYNC,
            _a[exports.ProblemFeedbackOption.REMOTE_VIDEO_LAGGING] = ProblemFeedbackOption.REMOTE_VIDEO_LAGGING,
            _a[exports.ProblemFeedbackOption.REMOTE_NO_VIDEO] = ProblemFeedbackOption.REMOTE_NO_VIDEO,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ProblemFeedbackOption.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ProblemFeedbackOption.NONE] = exports.ProblemFeedbackOption.NONE,
            _a[ProblemFeedbackOption.OTHER_MESSAGE] = exports.ProblemFeedbackOption.OTHER_MESSAGE,
            _a[ProblemFeedbackOption.DISCONNECTED] = exports.ProblemFeedbackOption.DISCONNECTED,
            _a[ProblemFeedbackOption.EAR_BACK_DELAY] = exports.ProblemFeedbackOption.EAR_BACK_DELAY,
            _a[ProblemFeedbackOption.LOCAL_NOISE] = exports.ProblemFeedbackOption.LOCAL_NOISE,
            _a[ProblemFeedbackOption.LOCAL_AUDIO_LAGGING] = exports.ProblemFeedbackOption.LOCAL_AUDIO_LAGGING,
            _a[ProblemFeedbackOption.LOCAL_NO_AUDIO] = exports.ProblemFeedbackOption.LOCAL_NO_AUDIO,
            _a[ProblemFeedbackOption.LOCAL_AUDIO_STRENGTH] = exports.ProblemFeedbackOption.LOCAL_AUDIO_STRENGTH,
            _a[ProblemFeedbackOption.LOCAL_ECHO] = exports.ProblemFeedbackOption.LOCAL_ECHO,
            _a[ProblemFeedbackOption.LOCAL_VIDEO_FUZZY] = exports.ProblemFeedbackOption.LOCAL_VIDEO_FUZZY,
            _a[ProblemFeedbackOption.LOCAL_NOT_SYNC] = exports.ProblemFeedbackOption.LOCAL_NOT_SYNC,
            _a[ProblemFeedbackOption.LOCAL_VIDEO_LAGGING] = exports.ProblemFeedbackOption.LOCAL_VIDEO_LAGGING,
            _a[ProblemFeedbackOption.LOCAL_NO_VIDEO] = exports.ProblemFeedbackOption.LOCAL_NO_VIDEO,
            _a[ProblemFeedbackOption.REMOTE_NOISE] = exports.ProblemFeedbackOption.REMOTE_NOISE,
            _a[ProblemFeedbackOption.REMOTE_AUDIO_LAGGING] = exports.ProblemFeedbackOption.REMOTE_AUDIO_LAGGING,
            _a[ProblemFeedbackOption.REMOTE_NO_AUDIO] = exports.ProblemFeedbackOption.REMOTE_NO_AUDIO,
            _a[ProblemFeedbackOption.REMOTE_AUDIO_STRENGTH] = exports.ProblemFeedbackOption.REMOTE_AUDIO_STRENGTH,
            _a[ProblemFeedbackOption.REMOTE_ECHO] = exports.ProblemFeedbackOption.REMOTE_ECHO,
            _a[ProblemFeedbackOption.REMOTE_VIDEO_FUZZY] = exports.ProblemFeedbackOption.REMOTE_VIDEO_FUZZY,
            _a[ProblemFeedbackOption.REMOTE_NOT_SYNC] = exports.ProblemFeedbackOption.REMOTE_NOT_SYNC,
            _a[ProblemFeedbackOption.REMOTE_VIDEO_LAGGING] = exports.ProblemFeedbackOption.REMOTE_VIDEO_LAGGING,
            _a[ProblemFeedbackOption.REMOTE_NO_VIDEO] = exports.ProblemFeedbackOption.REMOTE_NO_VIDEO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ProblemFeedbackOption.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ProblemFeedbackOption.NONE] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionNone,
            _a[exports.ProblemFeedbackOption.OTHER_MESSAGE] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionOtherMessage,
            _a[exports.ProblemFeedbackOption.DISCONNECTED] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionDisconnected,
            _a[exports.ProblemFeedbackOption.EAR_BACK_DELAY] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionEarBackDelay,
            _a[exports.ProblemFeedbackOption.LOCAL_NOISE] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalNoise,
            _a[exports.ProblemFeedbackOption.LOCAL_AUDIO_LAGGING] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalAudioLagging,
            _a[exports.ProblemFeedbackOption.LOCAL_NO_AUDIO] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalNoAudio,
            _a[exports.ProblemFeedbackOption.LOCAL_AUDIO_STRENGTH] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalAudioStrength,
            _a[exports.ProblemFeedbackOption.LOCAL_ECHO] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalEcho,
            _a[exports.ProblemFeedbackOption.LOCAL_VIDEO_FUZZY] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalVideoFuzzy,
            _a[exports.ProblemFeedbackOption.LOCAL_NOT_SYNC] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalNotSync,
            _a[exports.ProblemFeedbackOption.LOCAL_VIDEO_LAGGING] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalVideoLagging,
            _a[exports.ProblemFeedbackOption.LOCAL_NO_VIDEO] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalNoVideo,
            _a[exports.ProblemFeedbackOption.REMOTE_NOISE] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteNoise,
            _a[exports.ProblemFeedbackOption.REMOTE_AUDIO_LAGGING] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteAudioLagging,
            _a[exports.ProblemFeedbackOption.REMOTE_NO_AUDIO] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteNoAudio,
            _a[exports.ProblemFeedbackOption.REMOTE_AUDIO_STRENGTH] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteAudioStrength,
            _a[exports.ProblemFeedbackOption.REMOTE_ECHO] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteEcho,
            _a[exports.ProblemFeedbackOption.REMOTE_VIDEO_FUZZY] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteVideoFuzzy,
            _a[exports.ProblemFeedbackOption.REMOTE_NOT_SYNC] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteNotSync,
            _a[exports.ProblemFeedbackOption.REMOTE_VIDEO_LAGGING] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteVideoLagging,
            _a[exports.ProblemFeedbackOption.REMOTE_NO_VIDEO] = ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteNoVideo,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ProblemFeedbackOption.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionNone] = exports.ProblemFeedbackOption.NONE,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionOtherMessage] = exports.ProblemFeedbackOption.OTHER_MESSAGE,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionDisconnected] = exports.ProblemFeedbackOption.DISCONNECTED,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionEarBackDelay] = exports.ProblemFeedbackOption.EAR_BACK_DELAY,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalNoise] = exports.ProblemFeedbackOption.LOCAL_NOISE,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalAudioLagging] = exports.ProblemFeedbackOption.LOCAL_AUDIO_LAGGING,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalNoAudio] = exports.ProblemFeedbackOption.LOCAL_NO_AUDIO,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalAudioStrength] = exports.ProblemFeedbackOption.LOCAL_AUDIO_STRENGTH,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalEcho] = exports.ProblemFeedbackOption.LOCAL_ECHO,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalVideoFuzzy] = exports.ProblemFeedbackOption.LOCAL_VIDEO_FUZZY,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalNotSync] = exports.ProblemFeedbackOption.LOCAL_NOT_SYNC,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalVideoLagging] = exports.ProblemFeedbackOption.LOCAL_VIDEO_LAGGING,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionLocalNoVideo] = exports.ProblemFeedbackOption.LOCAL_NO_VIDEO,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteNoise] = exports.ProblemFeedbackOption.REMOTE_NOISE,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteAudioLagging] = exports.ProblemFeedbackOption.REMOTE_AUDIO_LAGGING,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteNoAudio] = exports.ProblemFeedbackOption.REMOTE_NO_AUDIO,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteAudioStrength] = exports.ProblemFeedbackOption.REMOTE_AUDIO_STRENGTH,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteEcho] = exports.ProblemFeedbackOption.REMOTE_ECHO,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteVideoFuzzy] = exports.ProblemFeedbackOption.REMOTE_VIDEO_FUZZY,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteNotSync] = exports.ProblemFeedbackOption.REMOTE_NOT_SYNC,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteVideoLagging] = exports.ProblemFeedbackOption.REMOTE_VIDEO_LAGGING,
            _a[ByteRTCProblemFeedbackOption.ByteRTCProblemFeedbackOptionRemoteNoVideo] = exports.ProblemFeedbackOption.REMOTE_NO_VIDEO,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ProblemFeedbackOption;
}());
var t_UserOnlineStatus = /** @class */ (function () {
    function t_UserOnlineStatus() {
    }
    t_UserOnlineStatus.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.UserOnlineStatus.USER_ONLINE_STATUS_OFFLINE] = UserOnlineStatus.USER_ONLINE_STATUS_OFFLINE,
            _a[exports.UserOnlineStatus.USER_ONLINE_STATUS_ONLINE] = UserOnlineStatus.USER_ONLINE_STATUS_ONLINE,
            _a[exports.UserOnlineStatus.USER_ONLINE_STATUS_UNREACHABLE] = UserOnlineStatus.USER_ONLINE_STATUS_UNREACHABLE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_UserOnlineStatus.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[UserOnlineStatus.USER_ONLINE_STATUS_OFFLINE] = exports.UserOnlineStatus.USER_ONLINE_STATUS_OFFLINE,
            _a[UserOnlineStatus.USER_ONLINE_STATUS_ONLINE] = exports.UserOnlineStatus.USER_ONLINE_STATUS_ONLINE,
            _a[UserOnlineStatus.USER_ONLINE_STATUS_UNREACHABLE] = exports.UserOnlineStatus.USER_ONLINE_STATUS_UNREACHABLE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_UserOnlineStatus.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.UserOnlineStatus.ByteRTCUserOnlineStatusOffline] = ByteRTCUserOnlineStatus.ByteRTCUserOnlineStatusOffline,
            _a[exports.UserOnlineStatus.ByteRTCUserOnlineStatusOnline] = ByteRTCUserOnlineStatus.ByteRTCUserOnlineStatusOnline,
            _a[exports.UserOnlineStatus.ByteRTCUserOnlineStatusUnreachable] = ByteRTCUserOnlineStatus.ByteRTCUserOnlineStatusUnreachable,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_UserOnlineStatus.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCUserOnlineStatus.ByteRTCUserOnlineStatusOffline] = exports.UserOnlineStatus.ByteRTCUserOnlineStatusOffline,
            _a[ByteRTCUserOnlineStatus.ByteRTCUserOnlineStatusOnline] = exports.UserOnlineStatus.ByteRTCUserOnlineStatusOnline,
            _a[ByteRTCUserOnlineStatus.ByteRTCUserOnlineStatusUnreachable] = exports.UserOnlineStatus.ByteRTCUserOnlineStatusUnreachable,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_UserOnlineStatus;
}());
var t_VideoFrameType = /** @class */ (function () {
    function t_VideoFrameType() {
    }
    t_VideoFrameType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoFrameType.RAW_MEMORY] = VideoFrameType.RAW_MEMORY,
            _a[exports.VideoFrameType.GL_TEXTURE] = VideoFrameType.GL_TEXTURE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoFrameType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoFrameType.RAW_MEMORY] = exports.VideoFrameType.RAW_MEMORY,
            _a[VideoFrameType.GL_TEXTURE] = exports.VideoFrameType.GL_TEXTURE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoFrameType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoFrameType.RAW_MEMORY] = ByteRTCVideoFrameType.ByteRTCVideoFrameTypeRawMemory,
            _a[exports.VideoFrameType.ByteRTCVideoFrameTypePixelBuffer] = ByteRTCVideoFrameType.ByteRTCVideoFrameTypePixelBuffer,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoFrameType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoFrameType.ByteRTCVideoFrameTypeRawMemory] = exports.VideoFrameType.RAW_MEMORY,
            _a[ByteRTCVideoFrameType.ByteRTCVideoFrameTypePixelBuffer] = exports.VideoFrameType.ByteRTCVideoFrameTypePixelBuffer,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoFrameType;
}());
var t_TranscoderContentControlType = /** @class */ (function () {
    function t_TranscoderContentControlType() {
    }
    t_TranscoderContentControlType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.TranscoderContentControlType.HAS_AUDIO_AND_VIDEO] = TranscoderContentControlType.HAS_AUDIO_AND_VIDEO,
            _a[exports.TranscoderContentControlType.HAS_AUDIO_ONLY] = TranscoderContentControlType.HAS_AUDIO_ONLY,
            _a[exports.TranscoderContentControlType.HAS_VIDEO_ONLY] = TranscoderContentControlType.HAS_VIDEO_ONLY,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_TranscoderContentControlType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[TranscoderContentControlType.HAS_AUDIO_AND_VIDEO] = exports.TranscoderContentControlType.HAS_AUDIO_AND_VIDEO,
            _a[TranscoderContentControlType.HAS_AUDIO_ONLY] = exports.TranscoderContentControlType.HAS_AUDIO_ONLY,
            _a[TranscoderContentControlType.HAS_VIDEO_ONLY] = exports.TranscoderContentControlType.HAS_VIDEO_ONLY,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_TranscoderContentControlType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.TranscoderContentControlType.HAS_AUDIO_AND_VIDEO] = ByteRTCTranscoderContentControlType.ByteRTCTranscoderContentControlTypeHasAudioAndVideo,
            _a[exports.TranscoderContentControlType.HAS_AUDIO_ONLY] = ByteRTCTranscoderContentControlType.ByteRTCTranscoderContentControlTypeHasAudioOnly,
            _a[exports.TranscoderContentControlType.HAS_VIDEO_ONLY] = ByteRTCTranscoderContentControlType.ByteRTCTranscoderContentControlTypeHasVideoOnly,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_TranscoderContentControlType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCTranscoderContentControlType.ByteRTCTranscoderContentControlTypeHasAudioAndVideo] = exports.TranscoderContentControlType.HAS_AUDIO_AND_VIDEO,
            _a[ByteRTCTranscoderContentControlType.ByteRTCTranscoderContentControlTypeHasAudioOnly] = exports.TranscoderContentControlType.HAS_AUDIO_ONLY,
            _a[ByteRTCTranscoderContentControlType.ByteRTCTranscoderContentControlTypeHasVideoOnly] = exports.TranscoderContentControlType.HAS_VIDEO_ONLY,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_TranscoderContentControlType;
}());
var t_AudioMixingState = /** @class */ (function () {
    function t_AudioMixingState() {
    }
    t_AudioMixingState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_PRELOADED] = AudioMixingState.AUDIO_MIXING_STATE_PRELOADED,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_PLAYING] = AudioMixingState.AUDIO_MIXING_STATE_PLAYING,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_PAUSED] = AudioMixingState.AUDIO_MIXING_STATE_PAUSED,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_STOPPED] = AudioMixingState.AUDIO_MIXING_STATE_STOPPED,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_FAILED] = AudioMixingState.AUDIO_MIXING_STATE_FAILED,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_FINISHED] = AudioMixingState.AUDIO_MIXING_STATE_FINISHED,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_PCM_ENABLED] = AudioMixingState.AUDIO_MIXING_STATE_PCM_ENABLED,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_PCM_DISABLED] = AudioMixingState.AUDIO_MIXING_STATE_PCM_DISABLED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioMixingState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioMixingState.AUDIO_MIXING_STATE_PRELOADED] = exports.AudioMixingState.AUDIO_MIXING_STATE_PRELOADED,
            _a[AudioMixingState.AUDIO_MIXING_STATE_PLAYING] = exports.AudioMixingState.AUDIO_MIXING_STATE_PLAYING,
            _a[AudioMixingState.AUDIO_MIXING_STATE_PAUSED] = exports.AudioMixingState.AUDIO_MIXING_STATE_PAUSED,
            _a[AudioMixingState.AUDIO_MIXING_STATE_STOPPED] = exports.AudioMixingState.AUDIO_MIXING_STATE_STOPPED,
            _a[AudioMixingState.AUDIO_MIXING_STATE_FAILED] = exports.AudioMixingState.AUDIO_MIXING_STATE_FAILED,
            _a[AudioMixingState.AUDIO_MIXING_STATE_FINISHED] = exports.AudioMixingState.AUDIO_MIXING_STATE_FINISHED,
            _a[AudioMixingState.AUDIO_MIXING_STATE_PCM_ENABLED] = exports.AudioMixingState.AUDIO_MIXING_STATE_PCM_ENABLED,
            _a[AudioMixingState.AUDIO_MIXING_STATE_PCM_DISABLED] = exports.AudioMixingState.AUDIO_MIXING_STATE_PCM_DISABLED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioMixingState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_PRELOADED] = ByteRTCAudioMixingState.ByteRTCAudioMixingStatePreloaded,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_PLAYING] = ByteRTCAudioMixingState.ByteRTCAudioMixingStatePlaying,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_PAUSED] = ByteRTCAudioMixingState.ByteRTCAudioMixingStatePaused,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_STOPPED] = ByteRTCAudioMixingState.ByteRTCAudioMixingStateStopped,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_FAILED] = ByteRTCAudioMixingState.ByteRTCAudioMixingStateFailed,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_FINISHED] = ByteRTCAudioMixingState.ByteRTCAudioMixingStateFinished,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_PCM_ENABLED] = ByteRTCAudioMixingState.ByteRTCAudioMixingStatePCMEnabled,
            _a[exports.AudioMixingState.AUDIO_MIXING_STATE_PCM_DISABLED] = ByteRTCAudioMixingState.ByteRTCAudioMixingStatePCMDisabled,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioMixingState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioMixingState.ByteRTCAudioMixingStatePreloaded] = exports.AudioMixingState.AUDIO_MIXING_STATE_PRELOADED,
            _a[ByteRTCAudioMixingState.ByteRTCAudioMixingStatePlaying] = exports.AudioMixingState.AUDIO_MIXING_STATE_PLAYING,
            _a[ByteRTCAudioMixingState.ByteRTCAudioMixingStatePaused] = exports.AudioMixingState.AUDIO_MIXING_STATE_PAUSED,
            _a[ByteRTCAudioMixingState.ByteRTCAudioMixingStateStopped] = exports.AudioMixingState.AUDIO_MIXING_STATE_STOPPED,
            _a[ByteRTCAudioMixingState.ByteRTCAudioMixingStateFailed] = exports.AudioMixingState.AUDIO_MIXING_STATE_FAILED,
            _a[ByteRTCAudioMixingState.ByteRTCAudioMixingStateFinished] = exports.AudioMixingState.AUDIO_MIXING_STATE_FINISHED,
            _a[ByteRTCAudioMixingState.ByteRTCAudioMixingStatePCMEnabled] = exports.AudioMixingState.AUDIO_MIXING_STATE_PCM_ENABLED,
            _a[ByteRTCAudioMixingState.ByteRTCAudioMixingStatePCMDisabled] = exports.AudioMixingState.AUDIO_MIXING_STATE_PCM_DISABLED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioMixingState;
}());
var t_MixedStreamType = /** @class */ (function () {
    function t_MixedStreamType() {
    }
    t_MixedStreamType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamType.MIXED_STREAM_TYPE_BY_SERVER] = MixedStreamType.MIXED_STREAM_TYPE_BY_SERVER,
            _a[exports.MixedStreamType.MIXED_STREAM_TYPE_BY_CLIENT] = MixedStreamType.MIXED_STREAM_TYPE_BY_CLIENT,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MixedStreamType.MIXED_STREAM_TYPE_BY_SERVER] = exports.MixedStreamType.MIXED_STREAM_TYPE_BY_SERVER,
            _a[MixedStreamType.MIXED_STREAM_TYPE_BY_CLIENT] = exports.MixedStreamType.MIXED_STREAM_TYPE_BY_CLIENT,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamType.ByteRTCMixedStreamByServer] = ByteRTCMixedStreamType.ByteRTCMixedStreamByServer,
            _a[exports.MixedStreamType.ByteRTCMixedStreamByClient] = ByteRTCMixedStreamType.ByteRTCMixedStreamByClient,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMixedStreamType.ByteRTCMixedStreamByServer] = exports.MixedStreamType.ByteRTCMixedStreamByServer,
            _a[ByteRTCMixedStreamType.ByteRTCMixedStreamByClient] = exports.MixedStreamType.ByteRTCMixedStreamByClient,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MixedStreamType;
}());
var t_AudioQuality = /** @class */ (function () {
    function t_AudioQuality() {
    }
    t_AudioQuality.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioQuality.AUDIO_QUALITY_LOW] = AudioQuality.AUDIO_QUALITY_LOW,
            _a[exports.AudioQuality.AUDIO_QUALITY_MEDIUM] = AudioQuality.AUDIO_QUALITY_MEDIUM,
            _a[exports.AudioQuality.AUDIO_QUALITY_HIGH] = AudioQuality.AUDIO_QUALITY_HIGH,
            _a[exports.AudioQuality.AUDIO_QUALITY_ULTRA_HIGH] = AudioQuality.AUDIO_QUALITY_ULTRA_HIGH,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioQuality.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioQuality.AUDIO_QUALITY_LOW] = exports.AudioQuality.AUDIO_QUALITY_LOW,
            _a[AudioQuality.AUDIO_QUALITY_MEDIUM] = exports.AudioQuality.AUDIO_QUALITY_MEDIUM,
            _a[AudioQuality.AUDIO_QUALITY_HIGH] = exports.AudioQuality.AUDIO_QUALITY_HIGH,
            _a[AudioQuality.AUDIO_QUALITY_ULTRA_HIGH] = exports.AudioQuality.AUDIO_QUALITY_ULTRA_HIGH,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioQuality.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioQuality.AUDIO_QUALITY_LOW] = ByteRTCAudioQuality.ByteRTCAudioQualityLow,
            _a[exports.AudioQuality.AUDIO_QUALITY_MEDIUM] = ByteRTCAudioQuality.ByteRTCAudioQualityMedium,
            _a[exports.AudioQuality.AUDIO_QUALITY_HIGH] = ByteRTCAudioQuality.ByteRTCAudioQualityHigh,
            _a[exports.AudioQuality.AUDIO_QUALITY_ULTRA_HIGH] = ByteRTCAudioQuality.ByteRTCAudioQualityUltraHigh,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioQuality.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioQuality.ByteRTCAudioQualityLow] = exports.AudioQuality.AUDIO_QUALITY_LOW,
            _a[ByteRTCAudioQuality.ByteRTCAudioQualityMedium] = exports.AudioQuality.AUDIO_QUALITY_MEDIUM,
            _a[ByteRTCAudioQuality.ByteRTCAudioQualityHigh] = exports.AudioQuality.AUDIO_QUALITY_HIGH,
            _a[ByteRTCAudioQuality.ByteRTCAudioQualityUltraHigh] = exports.AudioQuality.AUDIO_QUALITY_ULTRA_HIGH,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioQuality;
}());
var t_MediaPlayerCustomSourceSeekWhence = /** @class */ (function () {
    function t_MediaPlayerCustomSourceSeekWhence() {
    }
    t_MediaPlayerCustomSourceSeekWhence.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaPlayerCustomSourceSeekWhence.SET] = MediaPlayerCustomSourceSeekWhence.SET,
            _a[exports.MediaPlayerCustomSourceSeekWhence.CUR] = MediaPlayerCustomSourceSeekWhence.CUR,
            _a[exports.MediaPlayerCustomSourceSeekWhence.END] = MediaPlayerCustomSourceSeekWhence.END,
            _a[exports.MediaPlayerCustomSourceSeekWhence.SIZE] = MediaPlayerCustomSourceSeekWhence.SIZE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaPlayerCustomSourceSeekWhence.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MediaPlayerCustomSourceSeekWhence.SET] = exports.MediaPlayerCustomSourceSeekWhence.SET,
            _a[MediaPlayerCustomSourceSeekWhence.CUR] = exports.MediaPlayerCustomSourceSeekWhence.CUR,
            _a[MediaPlayerCustomSourceSeekWhence.END] = exports.MediaPlayerCustomSourceSeekWhence.END,
            _a[MediaPlayerCustomSourceSeekWhence.SIZE] = exports.MediaPlayerCustomSourceSeekWhence.SIZE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaPlayerCustomSourceSeekWhence.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaPlayerCustomSourceSeekWhence.SET] = ByteRTCMediaPlayerCustomSourceSeekWhence.ByteRTCMediaPlayerCustomSourceSeekWhenceSet,
            _a[exports.MediaPlayerCustomSourceSeekWhence.CUR] = ByteRTCMediaPlayerCustomSourceSeekWhence.ByteRTCMediaPlayerCustomSourceSeekWhenceCur,
            _a[exports.MediaPlayerCustomSourceSeekWhence.END] = ByteRTCMediaPlayerCustomSourceSeekWhence.ByteRTCMediaPlayerCustomSourceSeekWhenceEnd,
            _a[exports.MediaPlayerCustomSourceSeekWhence.SIZE] = ByteRTCMediaPlayerCustomSourceSeekWhence.ByteRTCMediaPlayerCustomSourceSeekWhenceSize,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaPlayerCustomSourceSeekWhence.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMediaPlayerCustomSourceSeekWhence.ByteRTCMediaPlayerCustomSourceSeekWhenceSet] = exports.MediaPlayerCustomSourceSeekWhence.SET,
            _a[ByteRTCMediaPlayerCustomSourceSeekWhence.ByteRTCMediaPlayerCustomSourceSeekWhenceCur] = exports.MediaPlayerCustomSourceSeekWhence.CUR,
            _a[ByteRTCMediaPlayerCustomSourceSeekWhence.ByteRTCMediaPlayerCustomSourceSeekWhenceEnd] = exports.MediaPlayerCustomSourceSeekWhence.END,
            _a[ByteRTCMediaPlayerCustomSourceSeekWhence.ByteRTCMediaPlayerCustomSourceSeekWhenceSize] = exports.MediaPlayerCustomSourceSeekWhence.SIZE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MediaPlayerCustomSourceSeekWhence;
}());
var t_MixedStreamLayoutRegionType = /** @class */ (function () {
    function t_MixedStreamLayoutRegionType() {
    }
    t_MixedStreamLayoutRegionType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamLayoutRegionType.MIXED_STREAM_LAYOUT_REGION_TYPE_VIDEO_STREAM] = MixedStreamLayoutRegionType.MIXED_STREAM_LAYOUT_REGION_TYPE_VIDEO_STREAM,
            _a[exports.MixedStreamLayoutRegionType.MIXED_STREAM_LAYOUT_REGION_TYPE_IMAGE] = MixedStreamLayoutRegionType.MIXED_STREAM_LAYOUT_REGION_TYPE_IMAGE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamLayoutRegionType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MixedStreamLayoutRegionType.MIXED_STREAM_LAYOUT_REGION_TYPE_VIDEO_STREAM] = exports.MixedStreamLayoutRegionType.MIXED_STREAM_LAYOUT_REGION_TYPE_VIDEO_STREAM,
            _a[MixedStreamLayoutRegionType.MIXED_STREAM_LAYOUT_REGION_TYPE_IMAGE] = exports.MixedStreamLayoutRegionType.MIXED_STREAM_LAYOUT_REGION_TYPE_IMAGE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamLayoutRegionType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamLayoutRegionType.MIXED_STREAM_LAYOUT_REGION_TYPE_VIDEO_STREAM] = ByteRTCMixedStreamLayoutRegionType.ByteRTCMixedStreamLayoutRegionTypeVideoStream,
            _a[exports.MixedStreamLayoutRegionType.ByteRTCMixedStreamLayoutRegionTypeImage] = ByteRTCMixedStreamLayoutRegionType.ByteRTCMixedStreamLayoutRegionTypeImage,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamLayoutRegionType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMixedStreamLayoutRegionType.ByteRTCMixedStreamLayoutRegionTypeVideoStream] = exports.MixedStreamLayoutRegionType.MIXED_STREAM_LAYOUT_REGION_TYPE_VIDEO_STREAM,
            _a[ByteRTCMixedStreamLayoutRegionType.ByteRTCMixedStreamLayoutRegionTypeImage] = exports.MixedStreamLayoutRegionType.ByteRTCMixedStreamLayoutRegionTypeImage,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MixedStreamLayoutRegionType;
}());
var t_LogoutReason = /** @class */ (function () {
    function t_LogoutReason() {
    }
    t_LogoutReason.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LogoutReason.LOGOUT_REASON_LOGOUT] = LogoutReason.LOGOUT_REASON_LOGOUT,
            _a[exports.LogoutReason.LOGOUT_REASON_DUPLICATE_LOGIN] = LogoutReason.LOGOUT_REASON_DUPLICATE_LOGIN,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LogoutReason.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[LogoutReason.LOGOUT_REASON_LOGOUT] = exports.LogoutReason.LOGOUT_REASON_LOGOUT,
            _a[LogoutReason.LOGOUT_REASON_DUPLICATE_LOGIN] = exports.LogoutReason.LOGOUT_REASON_DUPLICATE_LOGIN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LogoutReason.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LogoutReason.ByteRTCLogoutReasonLogout] = ByteRTCLogoutReason.ByteRTCLogoutReasonLogout,
            _a[exports.LogoutReason.ByteRTCLogoutReasonDuplicateLogin] = ByteRTCLogoutReason.ByteRTCLogoutReasonDuplicateLogin,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LogoutReason.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCLogoutReason.ByteRTCLogoutReasonLogout] = exports.LogoutReason.ByteRTCLogoutReasonLogout,
            _a[ByteRTCLogoutReason.ByteRTCLogoutReasonDuplicateLogin] = exports.LogoutReason.ByteRTCLogoutReasonDuplicateLogin,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_LogoutReason;
}());
var t_VideoRenderMirrorType = /** @class */ (function () {
    function t_VideoRenderMirrorType() {
    }
    t_VideoRenderMirrorType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoRenderMirrorType.ON] = VideoRenderMirrorType.ON,
            _a[exports.VideoRenderMirrorType.OFF] = VideoRenderMirrorType.OFF,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoRenderMirrorType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoRenderMirrorType.ON] = exports.VideoRenderMirrorType.ON,
            _a[VideoRenderMirrorType.OFF] = exports.VideoRenderMirrorType.OFF,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoRenderMirrorType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoRenderMirrorType.ON] = ByteRTCVideoRenderMirrorType.ByteRTCVideoRenderMirrorTypeOn,
            _a[exports.VideoRenderMirrorType.OFF] = ByteRTCVideoRenderMirrorType.ByteRTCVideoRenderMirrorTypeOff,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoRenderMirrorType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoRenderMirrorType.ByteRTCVideoRenderMirrorTypeOn] = exports.VideoRenderMirrorType.ON,
            _a[ByteRTCVideoRenderMirrorType.ByteRTCVideoRenderMirrorTypeOff] = exports.VideoRenderMirrorType.OFF,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoRenderMirrorType;
}());
var t_MixedStreamSEIContentMode = /** @class */ (function () {
    function t_MixedStreamSEIContentMode() {
    }
    t_MixedStreamSEIContentMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamSEIContentMode.MIXED_STREAM_SEI_CONTENT_MODE_DEFAULT] = MixedStreamSEIContentMode.MIXED_STREAM_SEI_CONTENT_MODE_DEFAULT,
            _a[exports.MixedStreamSEIContentMode.MIXED_STREAM_SEI_CONTENT_MODE_ENABLE_VOLUME_INDICATION] = MixedStreamSEIContentMode.MIXED_STREAM_SEI_CONTENT_MODE_ENABLE_VOLUME_INDICATION,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamSEIContentMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MixedStreamSEIContentMode.MIXED_STREAM_SEI_CONTENT_MODE_DEFAULT] = exports.MixedStreamSEIContentMode.MIXED_STREAM_SEI_CONTENT_MODE_DEFAULT,
            _a[MixedStreamSEIContentMode.MIXED_STREAM_SEI_CONTENT_MODE_ENABLE_VOLUME_INDICATION] = exports.MixedStreamSEIContentMode.MIXED_STREAM_SEI_CONTENT_MODE_ENABLE_VOLUME_INDICATION,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamSEIContentMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamSEIContentMode.MIXED_STREAM_SEI_CONTENT_MODE_DEFAULT] = ByteRTCMixedStreamSEIContentMode.ByteRTCMixedStreamSEIContentModeDefault,
            _a[exports.MixedStreamSEIContentMode.MIXED_STREAM_SEI_CONTENT_MODE_ENABLE_VOLUME_INDICATION] = ByteRTCMixedStreamSEIContentMode.ByteRTCMixedStreamSEIContentModeEnableVolumeIndication,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamSEIContentMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMixedStreamSEIContentMode.ByteRTCMixedStreamSEIContentModeDefault] = exports.MixedStreamSEIContentMode.MIXED_STREAM_SEI_CONTENT_MODE_DEFAULT,
            _a[ByteRTCMixedStreamSEIContentMode.ByteRTCMixedStreamSEIContentModeEnableVolumeIndication] = exports.MixedStreamSEIContentMode.MIXED_STREAM_SEI_CONTENT_MODE_ENABLE_VOLUME_INDICATION,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MixedStreamSEIContentMode;
}());
var t_AudioMixingError = /** @class */ (function () {
    function t_AudioMixingError() {
    }
    t_AudioMixingError.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_OK] = AudioMixingError.AUDIO_MIXING_ERROR_OK,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_PRELOAD_FAILED] = AudioMixingError.AUDIO_MIXING_ERROR_PRELOAD_FAILED,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_START_FAILED] = AudioMixingError.AUDIO_MIXING_ERROR_START_FAILED,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_SET_POSITION_FAILED] = AudioMixingError.AUDIO_MIXING_ERROR_SET_POSITION_FAILED,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_LOAD_CONFLICT] = AudioMixingError.AUDIO_MIXING_ERROR_LOAD_CONFLICT,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_ID_NOT_FOUND] = AudioMixingError.AUDIO_MIXING_ERROR_ID_NOT_FOUND,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_INVALID_VOLUME] = AudioMixingError.AUDIO_MIXING_ERROR_INVALID_VOLUME,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_ID_TYPE_NOT_MATCH] = AudioMixingError.AUDIO_MIXING_ERROR_ID_TYPE_NOT_MATCH,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_ID_TYPE_INVALID_PITCH] = AudioMixingError.AUDIO_MIXING_ERROR_ID_TYPE_INVALID_PITCH,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_INVALID_AUDIO_TRACK] = AudioMixingError.AUDIO_MIXING_ERROR_INVALID_AUDIO_TRACK,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_IS_STARTING] = AudioMixingError.AUDIO_MIXING_ERROR_IS_STARTING,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_INVALID_PLAYBACK_SPEED] = AudioMixingError.AUDIO_MIXING_ERROR_INVALID_PLAYBACK_SPEED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioMixingError.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioMixingError.AUDIO_MIXING_ERROR_OK] = exports.AudioMixingError.AUDIO_MIXING_ERROR_OK,
            _a[AudioMixingError.AUDIO_MIXING_ERROR_PRELOAD_FAILED] = exports.AudioMixingError.AUDIO_MIXING_ERROR_PRELOAD_FAILED,
            _a[AudioMixingError.AUDIO_MIXING_ERROR_START_FAILED] = exports.AudioMixingError.AUDIO_MIXING_ERROR_START_FAILED,
            _a[AudioMixingError.AUDIO_MIXING_ERROR_SET_POSITION_FAILED] = exports.AudioMixingError.AUDIO_MIXING_ERROR_SET_POSITION_FAILED,
            _a[AudioMixingError.AUDIO_MIXING_ERROR_LOAD_CONFLICT] = exports.AudioMixingError.AUDIO_MIXING_ERROR_LOAD_CONFLICT,
            _a[AudioMixingError.AUDIO_MIXING_ERROR_ID_NOT_FOUND] = exports.AudioMixingError.AUDIO_MIXING_ERROR_ID_NOT_FOUND,
            _a[AudioMixingError.AUDIO_MIXING_ERROR_INVALID_VOLUME] = exports.AudioMixingError.AUDIO_MIXING_ERROR_INVALID_VOLUME,
            _a[AudioMixingError.AUDIO_MIXING_ERROR_ID_TYPE_NOT_MATCH] = exports.AudioMixingError.AUDIO_MIXING_ERROR_ID_TYPE_NOT_MATCH,
            _a[AudioMixingError.AUDIO_MIXING_ERROR_ID_TYPE_INVALID_PITCH] = exports.AudioMixingError.AUDIO_MIXING_ERROR_ID_TYPE_INVALID_PITCH,
            _a[AudioMixingError.AUDIO_MIXING_ERROR_INVALID_AUDIO_TRACK] = exports.AudioMixingError.AUDIO_MIXING_ERROR_INVALID_AUDIO_TRACK,
            _a[AudioMixingError.AUDIO_MIXING_ERROR_IS_STARTING] = exports.AudioMixingError.AUDIO_MIXING_ERROR_IS_STARTING,
            _a[AudioMixingError.AUDIO_MIXING_ERROR_INVALID_PLAYBACK_SPEED] = exports.AudioMixingError.AUDIO_MIXING_ERROR_INVALID_PLAYBACK_SPEED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioMixingError.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_OK] = ByteRTCAudioMixingError.ByteRTCAudioMixingErrorOk,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_PRELOAD_FAILED] = ByteRTCAudioMixingError.ByteRTCAudioMixingErrorPreloadFailed,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_START_FAILED] = ByteRTCAudioMixingError.ByteRTCAudioMixingErrorStartFailed,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_SET_POSITION_FAILED] = ByteRTCAudioMixingError.ByteRTCAudioMixingErrorSetPositionFailed,
            _a[exports.AudioMixingError.AUDIO_MIXING_ERROR_LOAD_CONFLICT] = ByteRTCAudioMixingError.ByteRTCAudioMixingErrorLoadConflict,
            _a[exports.AudioMixingError.ByteRTCAudioMixingErrorIdNotFound] = ByteRTCAudioMixingError.ByteRTCAudioMixingErrorIdNotFound,
            _a[exports.AudioMixingError.ByteRTCAudioMixingErrorInValidVolume] = ByteRTCAudioMixingError.ByteRTCAudioMixingErrorInValidVolume,
            _a[exports.AudioMixingError.ByteRTCAudioMixingErrorIdTypeNotMatch] = ByteRTCAudioMixingError.ByteRTCAudioMixingErrorIdTypeNotMatch,
            _a[exports.AudioMixingError.ByteRTCAudioMixingErrorInValidPitch] = ByteRTCAudioMixingError.ByteRTCAudioMixingErrorInValidPitch,
            _a[exports.AudioMixingError.ByteRTCAudioMixingErrorInValidAudioTrack] = ByteRTCAudioMixingError.ByteRTCAudioMixingErrorInValidAudioTrack,
            _a[exports.AudioMixingError.ByteRTCAudioMixingErrorIsStarting] = ByteRTCAudioMixingError.ByteRTCAudioMixingErrorIsStarting,
            _a[exports.AudioMixingError.ByteRTCAudioMixingErrorInValidPlaybackSpeed] = ByteRTCAudioMixingError.ByteRTCAudioMixingErrorInValidPlaybackSpeed,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioMixingError.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioMixingError.ByteRTCAudioMixingErrorOk] = exports.AudioMixingError.AUDIO_MIXING_ERROR_OK,
            _a[ByteRTCAudioMixingError.ByteRTCAudioMixingErrorPreloadFailed] = exports.AudioMixingError.AUDIO_MIXING_ERROR_PRELOAD_FAILED,
            _a[ByteRTCAudioMixingError.ByteRTCAudioMixingErrorStartFailed] = exports.AudioMixingError.AUDIO_MIXING_ERROR_START_FAILED,
            _a[ByteRTCAudioMixingError.ByteRTCAudioMixingErrorSetPositionFailed] = exports.AudioMixingError.AUDIO_MIXING_ERROR_SET_POSITION_FAILED,
            _a[ByteRTCAudioMixingError.ByteRTCAudioMixingErrorLoadConflict] = exports.AudioMixingError.AUDIO_MIXING_ERROR_LOAD_CONFLICT,
            _a[ByteRTCAudioMixingError.ByteRTCAudioMixingErrorIdNotFound] = exports.AudioMixingError.ByteRTCAudioMixingErrorIdNotFound,
            _a[ByteRTCAudioMixingError.ByteRTCAudioMixingErrorInValidVolume] = exports.AudioMixingError.ByteRTCAudioMixingErrorInValidVolume,
            _a[ByteRTCAudioMixingError.ByteRTCAudioMixingErrorIdTypeNotMatch] = exports.AudioMixingError.ByteRTCAudioMixingErrorIdTypeNotMatch,
            _a[ByteRTCAudioMixingError.ByteRTCAudioMixingErrorInValidPitch] = exports.AudioMixingError.ByteRTCAudioMixingErrorInValidPitch,
            _a[ByteRTCAudioMixingError.ByteRTCAudioMixingErrorInValidAudioTrack] = exports.AudioMixingError.ByteRTCAudioMixingErrorInValidAudioTrack,
            _a[ByteRTCAudioMixingError.ByteRTCAudioMixingErrorIsStarting] = exports.AudioMixingError.ByteRTCAudioMixingErrorIsStarting,
            _a[ByteRTCAudioMixingError.ByteRTCAudioMixingErrorInValidPlaybackSpeed] = exports.AudioMixingError.ByteRTCAudioMixingErrorInValidPlaybackSpeed,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioMixingError;
}());
var t_AACProfile = /** @class */ (function () {
    function t_AACProfile() {
    }
    t_AACProfile.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AACProfile.AAC_PROFILE_LC] = AACProfile.AAC_PROFILE_LC,
            _a[exports.AACProfile.AAC_PROFILE_HEV1] = AACProfile.AAC_PROFILE_HEV1,
            _a[exports.AACProfile.AAC_PROFILE_HEV2] = AACProfile.AAC_PROFILE_HEV2,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AACProfile.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AACProfile.AAC_PROFILE_LC] = exports.AACProfile.AAC_PROFILE_LC,
            _a[AACProfile.AAC_PROFILE_HEV1] = exports.AACProfile.AAC_PROFILE_HEV1,
            _a[AACProfile.AAC_PROFILE_HEV2] = exports.AACProfile.AAC_PROFILE_HEV2,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AACProfile.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AACProfile.AAC_PROFILE_LC] = ByteRTCAACProfile.ByteRTCAACProfileLC,
            _a[exports.AACProfile.AAC_PROFILE_HEV1] = ByteRTCAACProfile.ByteRTCAACProfileHEv1,
            _a[exports.AACProfile.AAC_PROFILE_HEV2] = ByteRTCAACProfile.ByteRTCAACProfileHEv2,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AACProfile.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAACProfile.ByteRTCAACProfileLC] = exports.AACProfile.AAC_PROFILE_LC,
            _a[ByteRTCAACProfile.ByteRTCAACProfileHEv1] = exports.AACProfile.AAC_PROFILE_HEV1,
            _a[ByteRTCAACProfile.ByteRTCAACProfileHEv2] = exports.AACProfile.AAC_PROFILE_HEV2,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AACProfile;
}());
var t_DataMessageSourceType = /** @class */ (function () {
    function t_DataMessageSourceType() {
    }
    t_DataMessageSourceType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.DataMessageSourceType.DATA_MESSAGE_SOURCE_TYPE_DEFAULT] = DataMessageSourceType.DATA_MESSAGE_SOURCE_TYPE_DEFAULT,
            _a[exports.DataMessageSourceType.DATA_MESSAGE_SOURCE_TYPE_SYSTEM] = DataMessageSourceType.DATA_MESSAGE_SOURCE_TYPE_SYSTEM,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_DataMessageSourceType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[DataMessageSourceType.DATA_MESSAGE_SOURCE_TYPE_DEFAULT] = exports.DataMessageSourceType.DATA_MESSAGE_SOURCE_TYPE_DEFAULT,
            _a[DataMessageSourceType.DATA_MESSAGE_SOURCE_TYPE_SYSTEM] = exports.DataMessageSourceType.DATA_MESSAGE_SOURCE_TYPE_SYSTEM,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_DataMessageSourceType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.DataMessageSourceType.DATA_MESSAGE_SOURCE_TYPE_DEFAULT] = ByteRTCDataMessageSourceType.ByteRTCDataMessageSourceTypeDefault,
            _a[exports.DataMessageSourceType.DATA_MESSAGE_SOURCE_TYPE_SYSTEM] = ByteRTCDataMessageSourceType.ByteRTCDataMessageSourceTypeSystem,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_DataMessageSourceType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCDataMessageSourceType.ByteRTCDataMessageSourceTypeDefault] = exports.DataMessageSourceType.DATA_MESSAGE_SOURCE_TYPE_DEFAULT,
            _a[ByteRTCDataMessageSourceType.ByteRTCDataMessageSourceTypeSystem] = exports.DataMessageSourceType.DATA_MESSAGE_SOURCE_TYPE_SYSTEM,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_DataMessageSourceType;
}());
var t_MediaPlayerCustomSourceMode = /** @class */ (function () {
    function t_MediaPlayerCustomSourceMode() {
    }
    t_MediaPlayerCustomSourceMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaPlayerCustomSourceMode.PUSH] = MediaPlayerCustomSourceMode.PUSH,
            _a[exports.MediaPlayerCustomSourceMode.PULL] = MediaPlayerCustomSourceMode.PULL,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaPlayerCustomSourceMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MediaPlayerCustomSourceMode.PUSH] = exports.MediaPlayerCustomSourceMode.PUSH,
            _a[MediaPlayerCustomSourceMode.PULL] = exports.MediaPlayerCustomSourceMode.PULL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaPlayerCustomSourceMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaPlayerCustomSourceMode.PUSH] = ByteRTCMediaPlayerCustomSourceMode.ByteRTCMediaPlayerCustomSourceModePush,
            _a[exports.MediaPlayerCustomSourceMode.PULL] = ByteRTCMediaPlayerCustomSourceMode.ByteRTCMediaPlayerCustomSourceModePull,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaPlayerCustomSourceMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMediaPlayerCustomSourceMode.ByteRTCMediaPlayerCustomSourceModePush] = exports.MediaPlayerCustomSourceMode.PUSH,
            _a[ByteRTCMediaPlayerCustomSourceMode.ByteRTCMediaPlayerCustomSourceModePull] = exports.MediaPlayerCustomSourceMode.PULL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MediaPlayerCustomSourceMode;
}());
var t_KTVPlayerErrorCode = /** @class */ (function () {
    function t_KTVPlayerErrorCode() {
    }
    t_KTVPlayerErrorCode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.KTVPlayerErrorCode.OK] = KTVPlayerErrorCode.OK,
            _a[exports.KTVPlayerErrorCode.FILE_NOT_EXIST] = KTVPlayerErrorCode.FILE_NOT_EXIST,
            _a[exports.KTVPlayerErrorCode.FILE_ERROR] = KTVPlayerErrorCode.FILE_ERROR,
            _a[exports.KTVPlayerErrorCode.NOT_JOIN_ROOM] = KTVPlayerErrorCode.NOT_JOIN_ROOM,
            _a[exports.KTVPlayerErrorCode.PARAM] = KTVPlayerErrorCode.PARAM,
            _a[exports.KTVPlayerErrorCode.START_ERROR] = KTVPlayerErrorCode.START_ERROR,
            _a[exports.KTVPlayerErrorCode.MIX_ID_ERROR] = KTVPlayerErrorCode.MIX_ID_ERROR,
            _a[exports.KTVPlayerErrorCode.POSITION_ERROR] = KTVPlayerErrorCode.POSITION_ERROR,
            _a[exports.KTVPlayerErrorCode.AUDIO_VOLUME_ERROR] = KTVPlayerErrorCode.AUDIO_VOLUME_ERROR,
            _a[exports.KTVPlayerErrorCode.TYPE_ERROR] = KTVPlayerErrorCode.TYPE_ERROR,
            _a[exports.KTVPlayerErrorCode.PITCH_ERROR] = KTVPlayerErrorCode.PITCH_ERROR,
            _a[exports.KTVPlayerErrorCode.AUDIO_TRACK_ERROR] = KTVPlayerErrorCode.AUDIO_TRACK_ERROR,
            _a[exports.KTVPlayerErrorCode.STARTING_ERROR] = KTVPlayerErrorCode.STARTING_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_KTVPlayerErrorCode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[KTVPlayerErrorCode.OK] = exports.KTVPlayerErrorCode.OK,
            _a[KTVPlayerErrorCode.FILE_NOT_EXIST] = exports.KTVPlayerErrorCode.FILE_NOT_EXIST,
            _a[KTVPlayerErrorCode.FILE_ERROR] = exports.KTVPlayerErrorCode.FILE_ERROR,
            _a[KTVPlayerErrorCode.NOT_JOIN_ROOM] = exports.KTVPlayerErrorCode.NOT_JOIN_ROOM,
            _a[KTVPlayerErrorCode.PARAM] = exports.KTVPlayerErrorCode.PARAM,
            _a[KTVPlayerErrorCode.START_ERROR] = exports.KTVPlayerErrorCode.START_ERROR,
            _a[KTVPlayerErrorCode.MIX_ID_ERROR] = exports.KTVPlayerErrorCode.MIX_ID_ERROR,
            _a[KTVPlayerErrorCode.POSITION_ERROR] = exports.KTVPlayerErrorCode.POSITION_ERROR,
            _a[KTVPlayerErrorCode.AUDIO_VOLUME_ERROR] = exports.KTVPlayerErrorCode.AUDIO_VOLUME_ERROR,
            _a[KTVPlayerErrorCode.TYPE_ERROR] = exports.KTVPlayerErrorCode.TYPE_ERROR,
            _a[KTVPlayerErrorCode.PITCH_ERROR] = exports.KTVPlayerErrorCode.PITCH_ERROR,
            _a[KTVPlayerErrorCode.AUDIO_TRACK_ERROR] = exports.KTVPlayerErrorCode.AUDIO_TRACK_ERROR,
            _a[KTVPlayerErrorCode.STARTING_ERROR] = exports.KTVPlayerErrorCode.STARTING_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_KTVPlayerErrorCode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeOK] = ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeOK,
            _a[exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeFileNotExist] = ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeFileNotExist,
            _a[exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeFileError] = ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeFileError,
            _a[exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeNotJoinRoom] = ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeNotJoinRoom,
            _a[exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeParam] = ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeParam,
            _a[exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeStartError] = ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeStartError,
            _a[exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeMixIdError] = ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeMixIdError,
            _a[exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodePositionError] = ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodePositionError,
            _a[exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeAudioVolumeError] = ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeAudioVolumeError,
            _a[exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeTypeError] = ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeTypeError,
            _a[exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodePitchError] = ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodePitchError,
            _a[exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeAudioTrackError] = ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeAudioTrackError,
            _a[exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeStartingError] = ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeStartingError,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_KTVPlayerErrorCode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeOK] = exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeOK,
            _a[ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeFileNotExist] = exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeFileNotExist,
            _a[ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeFileError] = exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeFileError,
            _a[ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeNotJoinRoom] = exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeNotJoinRoom,
            _a[ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeParam] = exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeParam,
            _a[ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeStartError] = exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeStartError,
            _a[ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeMixIdError] = exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeMixIdError,
            _a[ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodePositionError] = exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodePositionError,
            _a[ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeAudioVolumeError] = exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeAudioVolumeError,
            _a[ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeTypeError] = exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeTypeError,
            _a[ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodePitchError] = exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodePitchError,
            _a[ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeAudioTrackError] = exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeAudioTrackError,
            _a[ByteRTCKTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeStartingError] = exports.KTVPlayerErrorCode.ByteRTCKTVPlayerErrorCodeStartingError,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_KTVPlayerErrorCode;
}());
var t_RemoteVideoStateChangeReason = /** @class */ (function () {
    function t_RemoteVideoStateChangeReason() {
    }
    t_RemoteVideoStateChangeReason.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_CONGESTION] = RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_CONGESTION,
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_RECOVERY] = RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_RECOVERY,
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_MUTED] = RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_MUTED,
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_UNMUTED] = RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_UNMUTED,
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_MUTED] = RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_MUTED,
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_UNMUTED] = RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_UNMUTED,
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_OFFLINE] = RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_OFFLINE,
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_INTERNAL] = RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_INTERNAL,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteVideoStateChangeReason.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_CONGESTION] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_CONGESTION,
            _a[RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_RECOVERY] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_RECOVERY,
            _a[RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_MUTED] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_MUTED,
            _a[RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_UNMUTED] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_UNMUTED,
            _a[RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_MUTED] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_MUTED,
            _a[RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_UNMUTED] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_UNMUTED,
            _a[RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_OFFLINE] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_OFFLINE,
            _a[RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_INTERNAL] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_INTERNAL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteVideoStateChangeReason.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_CONGESTION] = ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonNetworkCongestion,
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_RECOVERY] = ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonNetworkRecovery,
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_MUTED] = ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonLocalMuted,
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_UNMUTED] = ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonLocalUnmuted,
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_MUTED] = ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonRemoteMuted,
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_UNMUTED] = ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonRemoteUnmuted,
            _a[exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_OFFLINE] = ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonRemoteOffline,
            _a[exports.RemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonInternal] = ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonInternal,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteVideoStateChangeReason.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonNetworkCongestion] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_CONGESTION,
            _a[ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonNetworkRecovery] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_NETWORK_RECOVERY,
            _a[ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonLocalMuted] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_MUTED,
            _a[ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonLocalUnmuted] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_LOCAL_UNMUTED,
            _a[ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonRemoteMuted] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_MUTED,
            _a[ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonRemoteUnmuted] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_UNMUTED,
            _a[ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonRemoteOffline] = exports.RemoteVideoStateChangeReason.REMOTE_VIDEO_STATE_CHANGE_REASON_REMOTE_OFFLINE,
            _a[ByteRTCRemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonInternal] = exports.RemoteVideoStateChangeReason.ByteRTCRemoteVideoStateChangeReasonInternal,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RemoteVideoStateChangeReason;
}());
var t_PerformanceAlarmReason = /** @class */ (function () {
    function t_PerformanceAlarmReason() {
    }
    t_PerformanceAlarmReason.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PerformanceAlarmReason.BANDWIDTH_RESUMED] = PerformanceAlarmReason.BANDWIDTH_RESUMED,
            _a[exports.PerformanceAlarmReason.BANDWIDTH_FALLBACKED] = PerformanceAlarmReason.BANDWIDTH_FALLBACKED,
            _a[exports.PerformanceAlarmReason.PERFORMANCE_FALLBACKED] = PerformanceAlarmReason.PERFORMANCE_FALLBACKED,
            _a[exports.PerformanceAlarmReason.PERFORMANCE_RESUMED] = PerformanceAlarmReason.PERFORMANCE_RESUMED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PerformanceAlarmReason.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[PerformanceAlarmReason.BANDWIDTH_RESUMED] = exports.PerformanceAlarmReason.BANDWIDTH_RESUMED,
            _a[PerformanceAlarmReason.BANDWIDTH_FALLBACKED] = exports.PerformanceAlarmReason.BANDWIDTH_FALLBACKED,
            _a[PerformanceAlarmReason.PERFORMANCE_FALLBACKED] = exports.PerformanceAlarmReason.PERFORMANCE_FALLBACKED,
            _a[PerformanceAlarmReason.PERFORMANCE_RESUMED] = exports.PerformanceAlarmReason.PERFORMANCE_RESUMED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PerformanceAlarmReason.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PerformanceAlarmReason.BANDWIDTH_RESUMED] = ByteRTCPerformanceAlarmReason.ByteRTCPerformanceAlarmReasonBandwidthResumed,
            _a[exports.PerformanceAlarmReason.ByteRTCPerformanceAlarmReasonBandwidthFallback] = ByteRTCPerformanceAlarmReason.ByteRTCPerformanceAlarmReasonBandwidthFallback,
            _a[exports.PerformanceAlarmReason.ByteRTCPerformanceAlarmReasonFallback] = ByteRTCPerformanceAlarmReason.ByteRTCPerformanceAlarmReasonFallback,
            _a[exports.PerformanceAlarmReason.ByteRTCPerformanceAlarmReasonResumed] = ByteRTCPerformanceAlarmReason.ByteRTCPerformanceAlarmReasonResumed,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PerformanceAlarmReason.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCPerformanceAlarmReason.ByteRTCPerformanceAlarmReasonBandwidthResumed] = exports.PerformanceAlarmReason.BANDWIDTH_RESUMED,
            _a[ByteRTCPerformanceAlarmReason.ByteRTCPerformanceAlarmReasonBandwidthFallback] = exports.PerformanceAlarmReason.ByteRTCPerformanceAlarmReasonBandwidthFallback,
            _a[ByteRTCPerformanceAlarmReason.ByteRTCPerformanceAlarmReasonFallback] = exports.PerformanceAlarmReason.ByteRTCPerformanceAlarmReasonFallback,
            _a[ByteRTCPerformanceAlarmReason.ByteRTCPerformanceAlarmReasonResumed] = exports.PerformanceAlarmReason.ByteRTCPerformanceAlarmReasonResumed,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_PerformanceAlarmReason;
}());
var t_VideoDeviceType = /** @class */ (function () {
    function t_VideoDeviceType() {
    }
    t_VideoDeviceType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoDeviceType.VIDEO_DEVICE_TYPE_UNKNOWN] = VideoDeviceType.VIDEO_DEVICE_TYPE_UNKNOWN,
            _a[exports.VideoDeviceType.VIDEO_DEVICE_TYPE_RENDER_DEVICE] = VideoDeviceType.VIDEO_DEVICE_TYPE_RENDER_DEVICE,
            _a[exports.VideoDeviceType.VIDEO_DEVICE_TYPE_CAPTURE_DEVICE] = VideoDeviceType.VIDEO_DEVICE_TYPE_CAPTURE_DEVICE,
            _a[exports.VideoDeviceType.VIDEO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE] = VideoDeviceType.VIDEO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoDeviceType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoDeviceType.VIDEO_DEVICE_TYPE_UNKNOWN] = exports.VideoDeviceType.VIDEO_DEVICE_TYPE_UNKNOWN,
            _a[VideoDeviceType.VIDEO_DEVICE_TYPE_RENDER_DEVICE] = exports.VideoDeviceType.VIDEO_DEVICE_TYPE_RENDER_DEVICE,
            _a[VideoDeviceType.VIDEO_DEVICE_TYPE_CAPTURE_DEVICE] = exports.VideoDeviceType.VIDEO_DEVICE_TYPE_CAPTURE_DEVICE,
            _a[VideoDeviceType.VIDEO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE] = exports.VideoDeviceType.VIDEO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoDeviceType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoDeviceType.VIDEO_DEVICE_TYPE_UNKNOWN] = ByteRTCVideoDeviceType.ByteRTCVideoDeviceTypeUnknown,
            _a[exports.VideoDeviceType.VIDEO_DEVICE_TYPE_RENDER_DEVICE] = ByteRTCVideoDeviceType.ByteRTCVideoDeviceTypeRenderDevice,
            _a[exports.VideoDeviceType.VIDEO_DEVICE_TYPE_CAPTURE_DEVICE] = ByteRTCVideoDeviceType.ByteRTCVideoDeviceTypeCaptureDevice,
            _a[exports.VideoDeviceType.VIDEO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE] = ByteRTCVideoDeviceType.ByteRTCVideoDeviceTypeScreenCaptureDevice,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoDeviceType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoDeviceType.ByteRTCVideoDeviceTypeUnknown] = exports.VideoDeviceType.VIDEO_DEVICE_TYPE_UNKNOWN,
            _a[ByteRTCVideoDeviceType.ByteRTCVideoDeviceTypeRenderDevice] = exports.VideoDeviceType.VIDEO_DEVICE_TYPE_RENDER_DEVICE,
            _a[ByteRTCVideoDeviceType.ByteRTCVideoDeviceTypeCaptureDevice] = exports.VideoDeviceType.VIDEO_DEVICE_TYPE_CAPTURE_DEVICE,
            _a[ByteRTCVideoDeviceType.ByteRTCVideoDeviceTypeScreenCaptureDevice] = exports.VideoDeviceType.VIDEO_DEVICE_TYPE_SCREEN_CAPTURE_DEVICE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoDeviceType;
}());
var t_MediaPlayerCustomSourceStreamType = /** @class */ (function () {
    function t_MediaPlayerCustomSourceStreamType() {
    }
    t_MediaPlayerCustomSourceStreamType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaPlayerCustomSourceStreamType.RAW] = MediaPlayerCustomSourceStreamType.RAW,
            _a[exports.MediaPlayerCustomSourceStreamType.ENCODED] = MediaPlayerCustomSourceStreamType.ENCODED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaPlayerCustomSourceStreamType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MediaPlayerCustomSourceStreamType.RAW] = exports.MediaPlayerCustomSourceStreamType.RAW,
            _a[MediaPlayerCustomSourceStreamType.ENCODED] = exports.MediaPlayerCustomSourceStreamType.ENCODED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaPlayerCustomSourceStreamType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaPlayerCustomSourceStreamType.RAW] = ByteRTCMediaPlayerCustomSourceStreamType.ByteRTCMediaPlayerCustomSourceStreamTypeRaw,
            _a[exports.MediaPlayerCustomSourceStreamType.ENCODED] = ByteRTCMediaPlayerCustomSourceStreamType.ByteRTCMediaPlayerCustomSourceStreamTypeEncoded,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaPlayerCustomSourceStreamType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMediaPlayerCustomSourceStreamType.ByteRTCMediaPlayerCustomSourceStreamTypeRaw] = exports.MediaPlayerCustomSourceStreamType.RAW,
            _a[ByteRTCMediaPlayerCustomSourceStreamType.ByteRTCMediaPlayerCustomSourceStreamTypeEncoded] = exports.MediaPlayerCustomSourceStreamType.ENCODED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MediaPlayerCustomSourceStreamType;
}());
var t_MusicFilterType = /** @class */ (function () {
    function t_MusicFilterType() {
    }
    t_MusicFilterType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MusicFilterType.NONE] = MusicFilterType.NONE,
            _a[exports.MusicFilterType.WITHOUT_LYRIC] = MusicFilterType.WITHOUT_LYRIC,
            _a[exports.MusicFilterType.UNSUPPORTED_SCORE] = MusicFilterType.UNSUPPORTED_SCORE,
            _a[exports.MusicFilterType.UNSUPPORTED_ACCOMPANY] = MusicFilterType.UNSUPPORTED_ACCOMPANY,
            _a[exports.MusicFilterType.UNSUPPORTED_CLIMAX] = MusicFilterType.UNSUPPORTED_CLIMAX,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MusicFilterType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MusicFilterType.NONE] = exports.MusicFilterType.NONE,
            _a[MusicFilterType.WITHOUT_LYRIC] = exports.MusicFilterType.WITHOUT_LYRIC,
            _a[MusicFilterType.UNSUPPORTED_SCORE] = exports.MusicFilterType.UNSUPPORTED_SCORE,
            _a[MusicFilterType.UNSUPPORTED_ACCOMPANY] = exports.MusicFilterType.UNSUPPORTED_ACCOMPANY,
            _a[MusicFilterType.UNSUPPORTED_CLIMAX] = exports.MusicFilterType.UNSUPPORTED_CLIMAX,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MusicFilterType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MusicFilterType.NONE] = ByteRTCMusicFilterType.ByteRTCMusicFilterTypeNone,
            _a[exports.MusicFilterType.WITHOUT_LYRIC] = ByteRTCMusicFilterType.ByteRTCMusicFilterTypeWithoutLyric,
            _a[exports.MusicFilterType.UNSUPPORTED_SCORE] = ByteRTCMusicFilterType.ByteRTCMusicFilterTypeUnsupportedScore,
            _a[exports.MusicFilterType.ByteRTCMusicFilterTypeUnsupportedAccopmay] = ByteRTCMusicFilterType.ByteRTCMusicFilterTypeUnsupportedAccopmay,
            _a[exports.MusicFilterType.ByteRTCMusicFilterTypeUnsupportedClimx] = ByteRTCMusicFilterType.ByteRTCMusicFilterTypeUnsupportedClimx,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MusicFilterType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMusicFilterType.ByteRTCMusicFilterTypeNone] = exports.MusicFilterType.NONE,
            _a[ByteRTCMusicFilterType.ByteRTCMusicFilterTypeWithoutLyric] = exports.MusicFilterType.WITHOUT_LYRIC,
            _a[ByteRTCMusicFilterType.ByteRTCMusicFilterTypeUnsupportedScore] = exports.MusicFilterType.UNSUPPORTED_SCORE,
            _a[ByteRTCMusicFilterType.ByteRTCMusicFilterTypeUnsupportedAccopmay] = exports.MusicFilterType.ByteRTCMusicFilterTypeUnsupportedAccopmay,
            _a[ByteRTCMusicFilterType.ByteRTCMusicFilterTypeUnsupportedClimx] = exports.MusicFilterType.ByteRTCMusicFilterTypeUnsupportedClimx,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MusicFilterType;
}());
var t_LocalVideoRenderPosition = /** @class */ (function () {
    function t_LocalVideoRenderPosition() {
    }
    t_LocalVideoRenderPosition.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalVideoRenderPosition.AFTER_CAPTURE] = LocalVideoRenderPosition.AFTER_CAPTURE,
            _a[exports.LocalVideoRenderPosition.AFTER_PREPROCESS] = LocalVideoRenderPosition.AFTER_PREPROCESS,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalVideoRenderPosition.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[LocalVideoRenderPosition.AFTER_CAPTURE] = exports.LocalVideoRenderPosition.AFTER_CAPTURE,
            _a[LocalVideoRenderPosition.AFTER_PREPROCESS] = exports.LocalVideoRenderPosition.AFTER_PREPROCESS,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalVideoRenderPosition.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalVideoRenderPosition.AFTER_CAPTURE] = ByteRTCLocalVideoRenderPosition.ByteRTCLocalVideoRenderPositionAfterCapture,
            _a[exports.LocalVideoRenderPosition.AFTER_PREPROCESS] = ByteRTCLocalVideoRenderPosition.ByteRTCLocalVideoRenderPositionAfterPreprocess,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalVideoRenderPosition.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCLocalVideoRenderPosition.ByteRTCLocalVideoRenderPositionAfterCapture] = exports.LocalVideoRenderPosition.AFTER_CAPTURE,
            _a[ByteRTCLocalVideoRenderPosition.ByteRTCLocalVideoRenderPositionAfterPreprocess] = exports.LocalVideoRenderPosition.AFTER_PREPROCESS,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_LocalVideoRenderPosition;
}());
var t_AudioReportMode = /** @class */ (function () {
    function t_AudioReportMode() {
    }
    t_AudioReportMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioReportMode.AUDIO_REPORT_MODE_NORMAL] = AudioReportMode.AUDIO_REPORT_MODE_NORMAL,
            _a[exports.AudioReportMode.AUDIO_REPORT_MODE_DISCONNECT] = AudioReportMode.AUDIO_REPORT_MODE_DISCONNECT,
            _a[exports.AudioReportMode.AUDIO_REPORT_MODE_RESET] = AudioReportMode.AUDIO_REPORT_MODE_RESET,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioReportMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioReportMode.AUDIO_REPORT_MODE_NORMAL] = exports.AudioReportMode.AUDIO_REPORT_MODE_NORMAL,
            _a[AudioReportMode.AUDIO_REPORT_MODE_DISCONNECT] = exports.AudioReportMode.AUDIO_REPORT_MODE_DISCONNECT,
            _a[AudioReportMode.AUDIO_REPORT_MODE_RESET] = exports.AudioReportMode.AUDIO_REPORT_MODE_RESET,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioReportMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioReportMode.AUDIO_REPORT_MODE_NORMAL] = ByteRTCAudioReportMode.ByteRTCAudioReportModeNormal,
            _a[exports.AudioReportMode.AUDIO_REPORT_MODE_DISCONNECT] = ByteRTCAudioReportMode.ByteRTCAudioReportModeDisconnect,
            _a[exports.AudioReportMode.AUDIO_REPORT_MODE_RESET] = ByteRTCAudioReportMode.ByteRTCAudioReportModeReset,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioReportMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioReportMode.ByteRTCAudioReportModeNormal] = exports.AudioReportMode.AUDIO_REPORT_MODE_NORMAL,
            _a[ByteRTCAudioReportMode.ByteRTCAudioReportModeDisconnect] = exports.AudioReportMode.AUDIO_REPORT_MODE_DISCONNECT,
            _a[ByteRTCAudioReportMode.ByteRTCAudioReportModeReset] = exports.AudioReportMode.AUDIO_REPORT_MODE_RESET,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioReportMode;
}());
var t_FirstFramePlayState = /** @class */ (function () {
    function t_FirstFramePlayState() {
    }
    t_FirstFramePlayState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.FirstFramePlayState.FIRST_FRAME_PLAY_STATE_PLAYING] = FirstFramePlayState.FIRST_FRAME_PLAY_STATE_PLAYING,
            _a[exports.FirstFramePlayState.FIRST_FRAME_PLAY_STATE_END] = FirstFramePlayState.FIRST_FRAME_PLAY_STATE_END,
            _a[exports.FirstFramePlayState.FIRST_FRAME_PLAY_STATE_PLAYED] = FirstFramePlayState.FIRST_FRAME_PLAY_STATE_PLAYED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_FirstFramePlayState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[FirstFramePlayState.FIRST_FRAME_PLAY_STATE_PLAYING] = exports.FirstFramePlayState.FIRST_FRAME_PLAY_STATE_PLAYING,
            _a[FirstFramePlayState.FIRST_FRAME_PLAY_STATE_END] = exports.FirstFramePlayState.FIRST_FRAME_PLAY_STATE_END,
            _a[FirstFramePlayState.FIRST_FRAME_PLAY_STATE_PLAYED] = exports.FirstFramePlayState.FIRST_FRAME_PLAY_STATE_PLAYED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_FirstFramePlayState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.FirstFramePlayState.FIRST_FRAME_PLAY_STATE_PLAYING] = ByteRTCFirstFramePlayState.ByteRTCFirstFramePlayStatePlaying,
            _a[exports.FirstFramePlayState.FIRST_FRAME_PLAY_STATE_END] = ByteRTCFirstFramePlayState.ByteRTCFirstFramePlayStateEnd,
            _a[exports.FirstFramePlayState.ByteRTCFirstFramePlayStatePlay] = ByteRTCFirstFramePlayState.ByteRTCFirstFramePlayStatePlay,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_FirstFramePlayState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCFirstFramePlayState.ByteRTCFirstFramePlayStatePlaying] = exports.FirstFramePlayState.FIRST_FRAME_PLAY_STATE_PLAYING,
            _a[ByteRTCFirstFramePlayState.ByteRTCFirstFramePlayStateEnd] = exports.FirstFramePlayState.FIRST_FRAME_PLAY_STATE_END,
            _a[ByteRTCFirstFramePlayState.ByteRTCFirstFramePlayStatePlay] = exports.FirstFramePlayState.ByteRTCFirstFramePlayStatePlay,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_FirstFramePlayState;
}());
var t_VideoApplyRotation = /** @class */ (function () {
    function t_VideoApplyRotation() {
    }
    t_VideoApplyRotation.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoApplyRotation.DEFAULT] = VideoApplyRotation.DEFAULT,
            _a[exports.VideoApplyRotation.DEGREE_0] = VideoApplyRotation.DEGREE_0,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoApplyRotation.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoApplyRotation.DEFAULT] = exports.VideoApplyRotation.DEFAULT,
            _a[VideoApplyRotation.DEGREE_0] = exports.VideoApplyRotation.DEGREE_0,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoApplyRotation.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoApplyRotation.DEFAULT] = ByteRTCVideoApplyRotation.ByteRTCVideoApplyRotationDefault,
            _a[exports.VideoApplyRotation.ByteRTCVideoApplyRotation0] = ByteRTCVideoApplyRotation.ByteRTCVideoApplyRotation0,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoApplyRotation.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoApplyRotation.ByteRTCVideoApplyRotationDefault] = exports.VideoApplyRotation.DEFAULT,
            _a[ByteRTCVideoApplyRotation.ByteRTCVideoApplyRotation0] = exports.VideoApplyRotation.ByteRTCVideoApplyRotation0,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoApplyRotation;
}());
var t_VideoSuperResolutionModeChangedReason = /** @class */ (function () {
    function t_VideoSuperResolutionModeChangedReason() {
    }
    t_VideoSuperResolutionModeChangedReason.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_OFF] = VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_OFF,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_ON] = VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_ON,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_RESOLUTION_EXCEED] = VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_RESOLUTION_EXCEED,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OVER_USE] = VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OVER_USE,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DEVICE_NOT_SUPPORT] = VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DEVICE_NOT_SUPPORT,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DYNAMIC_CLOSE] = VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DYNAMIC_CLOSE,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_DISABLED] = VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_DISABLED,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_ENABLED] = VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_ENABLED,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_NO_COMPONENT] = VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_NO_COMPONENT,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_STREAM_NOT_EXIST] = VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_STREAM_NOT_EXIST,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoSuperResolutionModeChangedReason.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_OFF] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_OFF,
            _a[VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_ON] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_ON,
            _a[VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_RESOLUTION_EXCEED] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_RESOLUTION_EXCEED,
            _a[VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OVER_USE] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OVER_USE,
            _a[VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DEVICE_NOT_SUPPORT] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DEVICE_NOT_SUPPORT,
            _a[VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DYNAMIC_CLOSE] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DYNAMIC_CLOSE,
            _a[VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_DISABLED] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_DISABLED,
            _a[VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_ENABLED] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_ENABLED,
            _a[VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_NO_COMPONENT] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_NO_COMPONENT,
            _a[VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_STREAM_NOT_EXIST] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_STREAM_NOT_EXIST,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoSuperResolutionModeChangedReason.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_OFF] = ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonAPIOff,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_ON] = ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonAPIOn,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_RESOLUTION_EXCEED] = ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonResolutionExceed,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OVER_USE] = ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonOverUse,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DEVICE_NOT_SUPPORT] = ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonDeviceNotSupport,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DYNAMIC_CLOSE] = ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonDynamicClose,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_DISABLED] = ByteRTCVideoSuperResolutionModeChangedReason
                .ByteRTCVideoSuperResolutionModeChangedReasonOtherSettingDisabled,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_ENABLED] = ByteRTCVideoSuperResolutionModeChangedReason
                .ByteRTCVideoSuperResolutionModeChangedReasonOtherSettingEnabled,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_NO_COMPONENT] = ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonNoComponent,
            _a[exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_STREAM_NOT_EXIST] = ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonStreamNotExist,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_VideoSuperResolutionModeChangedReason.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonAPIOff] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_OFF,
            _a[ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonAPIOn] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_API_ON,
            _a[ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonResolutionExceed] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_RESOLUTION_EXCEED,
            _a[ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonOverUse] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OVER_USE,
            _a[ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonDeviceNotSupport] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DEVICE_NOT_SUPPORT,
            _a[ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonDynamicClose] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_DYNAMIC_CLOSE,
            _a[ByteRTCVideoSuperResolutionModeChangedReason
                .ByteRTCVideoSuperResolutionModeChangedReasonOtherSettingDisabled] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_DISABLED,
            _a[ByteRTCVideoSuperResolutionModeChangedReason
                .ByteRTCVideoSuperResolutionModeChangedReasonOtherSettingEnabled] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_OTHER_SETTING_ENABLED,
            _a[ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonNoComponent] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_NO_COMPONENT,
            _a[ByteRTCVideoSuperResolutionModeChangedReason.ByteRTCVideoSuperResolutionModeChangedReasonStreamNotExist] = exports.VideoSuperResolutionModeChangedReason.VIDEO_SUPER_RESOLUTION_MODE_CHANGED_REASON_STREAM_NOT_EXIST,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_VideoSuperResolutionModeChangedReason;
}());
var t_LocalAudioStreamState = /** @class */ (function () {
    function t_LocalAudioStreamState() {
    }
    t_LocalAudioStreamState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_STOPPED] = LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_STOPPED,
            _a[exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_RECORDING] = LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_RECORDING,
            _a[exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_ENCODING] = LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_ENCODING,
            _a[exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_FAILED] = LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_FAILED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalAudioStreamState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_STOPPED] = exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_STOPPED,
            _a[LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_RECORDING] = exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_RECORDING,
            _a[LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_ENCODING] = exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_ENCODING,
            _a[LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_FAILED] = exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_FAILED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalAudioStreamState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_STOPPED] = ByteRTCLocalAudioStreamState.ByteRTCLocalAudioStreamStateStopped,
            _a[exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_RECORDING] = ByteRTCLocalAudioStreamState.ByteRTCLocalAudioStreamStateRecording,
            _a[exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_ENCODING] = ByteRTCLocalAudioStreamState.ByteRTCLocalAudioStreamStateEncoding,
            _a[exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_FAILED] = ByteRTCLocalAudioStreamState.ByteRTCLocalAudioStreamStateFailed,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalAudioStreamState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCLocalAudioStreamState.ByteRTCLocalAudioStreamStateStopped] = exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_STOPPED,
            _a[ByteRTCLocalAudioStreamState.ByteRTCLocalAudioStreamStateRecording] = exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_RECORDING,
            _a[ByteRTCLocalAudioStreamState.ByteRTCLocalAudioStreamStateEncoding] = exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_ENCODING,
            _a[ByteRTCLocalAudioStreamState.ByteRTCLocalAudioStreamStateFailed] = exports.LocalAudioStreamState.LOCAL_AUDIO_STREAM_STATE_FAILED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_LocalAudioStreamState;
}());
var t_LocalVideoStreamState = /** @class */ (function () {
    function t_LocalVideoStreamState() {
    }
    t_LocalVideoStreamState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_STOPPED] = LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_STOPPED,
            _a[exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_RECORDING] = LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_RECORDING,
            _a[exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_ENCODING] = LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_ENCODING,
            _a[exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_FAILED] = LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_FAILED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalVideoStreamState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_STOPPED] = exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_STOPPED,
            _a[LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_RECORDING] = exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_RECORDING,
            _a[LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_ENCODING] = exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_ENCODING,
            _a[LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_FAILED] = exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_FAILED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalVideoStreamState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_STOPPED] = ByteRTCLocalVideoStreamState.ByteRTCLocalVideoStreamStateStopped,
            _a[exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_RECORDING] = ByteRTCLocalVideoStreamState.ByteRTCLocalVideoStreamStateRecording,
            _a[exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_ENCODING] = ByteRTCLocalVideoStreamState.ByteRTCLocalVideoStreamStateEncoding,
            _a[exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_FAILED] = ByteRTCLocalVideoStreamState.ByteRTCLocalVideoStreamStateFailed,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalVideoStreamState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCLocalVideoStreamState.ByteRTCLocalVideoStreamStateStopped] = exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_STOPPED,
            _a[ByteRTCLocalVideoStreamState.ByteRTCLocalVideoStreamStateRecording] = exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_RECORDING,
            _a[ByteRTCLocalVideoStreamState.ByteRTCLocalVideoStreamStateEncoding] = exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_ENCODING,
            _a[ByteRTCLocalVideoStreamState.ByteRTCLocalVideoStreamStateFailed] = exports.LocalVideoStreamState.LOCAL_VIDEO_STREAM_STATE_FAILED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_LocalVideoStreamState;
}());
var t_RemoteAudioState = /** @class */ (function () {
    function t_RemoteAudioState() {
    }
    t_RemoteAudioState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteAudioState.REMOTE_AUDIO_STATE_STOPPED] = RemoteAudioState.REMOTE_AUDIO_STATE_STOPPED,
            _a[exports.RemoteAudioState.REMOTE_AUDIO_STATE_STARTING] = RemoteAudioState.REMOTE_AUDIO_STATE_STARTING,
            _a[exports.RemoteAudioState.REMOTE_AUDIO_STATE_DECODING] = RemoteAudioState.REMOTE_AUDIO_STATE_DECODING,
            _a[exports.RemoteAudioState.REMOTE_AUDIO_STATE_FROZEN] = RemoteAudioState.REMOTE_AUDIO_STATE_FROZEN,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteAudioState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RemoteAudioState.REMOTE_AUDIO_STATE_STOPPED] = exports.RemoteAudioState.REMOTE_AUDIO_STATE_STOPPED,
            _a[RemoteAudioState.REMOTE_AUDIO_STATE_STARTING] = exports.RemoteAudioState.REMOTE_AUDIO_STATE_STARTING,
            _a[RemoteAudioState.REMOTE_AUDIO_STATE_DECODING] = exports.RemoteAudioState.REMOTE_AUDIO_STATE_DECODING,
            _a[RemoteAudioState.REMOTE_AUDIO_STATE_FROZEN] = exports.RemoteAudioState.REMOTE_AUDIO_STATE_FROZEN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteAudioState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RemoteAudioState.REMOTE_AUDIO_STATE_STOPPED] = ByteRTCRemoteAudioState.ByteRTCRemoteAudioStateStopped,
            _a[exports.RemoteAudioState.REMOTE_AUDIO_STATE_STARTING] = ByteRTCRemoteAudioState.ByteRTCRemoteAudioStateStarting,
            _a[exports.RemoteAudioState.REMOTE_AUDIO_STATE_DECODING] = ByteRTCRemoteAudioState.ByteRTCRemoteAudioStateDecoding,
            _a[exports.RemoteAudioState.REMOTE_AUDIO_STATE_FROZEN] = ByteRTCRemoteAudioState.ByteRTCRemoteAudioStateFrozen,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RemoteAudioState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRemoteAudioState.ByteRTCRemoteAudioStateStopped] = exports.RemoteAudioState.REMOTE_AUDIO_STATE_STOPPED,
            _a[ByteRTCRemoteAudioState.ByteRTCRemoteAudioStateStarting] = exports.RemoteAudioState.REMOTE_AUDIO_STATE_STARTING,
            _a[ByteRTCRemoteAudioState.ByteRTCRemoteAudioStateDecoding] = exports.RemoteAudioState.REMOTE_AUDIO_STATE_DECODING,
            _a[ByteRTCRemoteAudioState.ByteRTCRemoteAudioStateFrozen] = exports.RemoteAudioState.REMOTE_AUDIO_STATE_FROZEN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RemoteAudioState;
}());
var t_LocalProxyError = /** @class */ (function () {
    function t_LocalProxyError() {
    }
    t_LocalProxyError.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalProxyError.OK] = LocalProxyError.OK,
            _a[exports.LocalProxyError.SOCKS5_VERSION_ERROR] = LocalProxyError.SOCKS5_VERSION_ERROR,
            _a[exports.LocalProxyError.SOCKS5_FORMAT_ERROR] = LocalProxyError.SOCKS5_FORMAT_ERROR,
            _a[exports.LocalProxyError.SOCKS5_INVALID_VALUE] = LocalProxyError.SOCKS5_INVALID_VALUE,
            _a[exports.LocalProxyError.SOCKS5_USER_PASS_NOT_GIVEN] = LocalProxyError.SOCKS5_USER_PASS_NOT_GIVEN,
            _a[exports.LocalProxyError.SOCKS5_TCP_CLOSED] = LocalProxyError.SOCKS5_TCP_CLOSED,
            _a[exports.LocalProxyError.HTTP_TUNNEL_FAILED] = LocalProxyError.HTTP_TUNNEL_FAILED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalProxyError.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[LocalProxyError.OK] = exports.LocalProxyError.OK,
            _a[LocalProxyError.SOCKS5_VERSION_ERROR] = exports.LocalProxyError.SOCKS5_VERSION_ERROR,
            _a[LocalProxyError.SOCKS5_FORMAT_ERROR] = exports.LocalProxyError.SOCKS5_FORMAT_ERROR,
            _a[LocalProxyError.SOCKS5_INVALID_VALUE] = exports.LocalProxyError.SOCKS5_INVALID_VALUE,
            _a[LocalProxyError.SOCKS5_USER_PASS_NOT_GIVEN] = exports.LocalProxyError.SOCKS5_USER_PASS_NOT_GIVEN,
            _a[LocalProxyError.SOCKS5_TCP_CLOSED] = exports.LocalProxyError.SOCKS5_TCP_CLOSED,
            _a[LocalProxyError.HTTP_TUNNEL_FAILED] = exports.LocalProxyError.HTTP_TUNNEL_FAILED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalProxyError.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalProxyError.OK] = ByteRTCLocalProxyError.ByteRTCLocalProxyErrorOK,
            _a[exports.LocalProxyError.SOCKS5_VERSION_ERROR] = ByteRTCLocalProxyError.ByteRTCLocalProxyErrorSocks5VersionError,
            _a[exports.LocalProxyError.SOCKS5_FORMAT_ERROR] = ByteRTCLocalProxyError.ByteRTCLocalProxyErrorSocks5FormatError,
            _a[exports.LocalProxyError.SOCKS5_INVALID_VALUE] = ByteRTCLocalProxyError.ByteRTCLocalProxyErrorSocks5InvalidValue,
            _a[exports.LocalProxyError.SOCKS5_USER_PASS_NOT_GIVEN] = ByteRTCLocalProxyError.ByteRTCLocalProxyErrorSocks5UserPassNotGiven,
            _a[exports.LocalProxyError.SOCKS5_TCP_CLOSED] = ByteRTCLocalProxyError.ByteRTCLocalProxyErrorSocks5TcpClosed,
            _a[exports.LocalProxyError.HTTP_TUNNEL_FAILED] = ByteRTCLocalProxyError.ByteRTCLocalProxyErrorHttpTunnelFailed,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalProxyError.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCLocalProxyError.ByteRTCLocalProxyErrorOK] = exports.LocalProxyError.OK,
            _a[ByteRTCLocalProxyError.ByteRTCLocalProxyErrorSocks5VersionError] = exports.LocalProxyError.SOCKS5_VERSION_ERROR,
            _a[ByteRTCLocalProxyError.ByteRTCLocalProxyErrorSocks5FormatError] = exports.LocalProxyError.SOCKS5_FORMAT_ERROR,
            _a[ByteRTCLocalProxyError.ByteRTCLocalProxyErrorSocks5InvalidValue] = exports.LocalProxyError.SOCKS5_INVALID_VALUE,
            _a[ByteRTCLocalProxyError.ByteRTCLocalProxyErrorSocks5UserPassNotGiven] = exports.LocalProxyError.SOCKS5_USER_PASS_NOT_GIVEN,
            _a[ByteRTCLocalProxyError.ByteRTCLocalProxyErrorSocks5TcpClosed] = exports.LocalProxyError.SOCKS5_TCP_CLOSED,
            _a[ByteRTCLocalProxyError.ByteRTCLocalProxyErrorHttpTunnelFailed] = exports.LocalProxyError.HTTP_TUNNEL_FAILED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_LocalProxyError;
}());
var t_MediaDeviceState = /** @class */ (function () {
    function t_MediaDeviceState() {
    }
    t_MediaDeviceState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaDeviceState.MEDIA_DEVICE_STATE_STARTED] = MediaDeviceState.MEDIA_DEVICE_STATE_STARTED,
            _a[exports.MediaDeviceState.MEDIA_DEVICE_STATE_STOPPED] = MediaDeviceState.MEDIA_DEVICE_STATE_STOPPED,
            _a[exports.MediaDeviceState.MEDIA_DEVICE_STATE_RUNTIMEERROR] = MediaDeviceState.MEDIA_DEVICE_STATE_RUNTIMEERROR,
            _a[exports.MediaDeviceState.MEDIA_DEVICE_STATE_ADDED] = MediaDeviceState.MEDIA_DEVICE_STATE_ADDED,
            _a[exports.MediaDeviceState.MEDIA_DEVICE_STATE_REMOVED] = MediaDeviceState.MEDIA_DEVICE_STATE_REMOVED,
            _a[exports.MediaDeviceState.MEDIA_DEVICE_STATE_INTERRUPTION_BEGAN] = MediaDeviceState.MEDIA_DEVICE_STATE_INTERRUPTION_BEGAN,
            _a[exports.MediaDeviceState.MEDIA_DEVICE_STATE_INTERRUPTION_ENDED] = MediaDeviceState.MEDIA_DEVICE_STATE_INTERRUPTION_ENDED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaDeviceState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MediaDeviceState.MEDIA_DEVICE_STATE_STARTED] = exports.MediaDeviceState.MEDIA_DEVICE_STATE_STARTED,
            _a[MediaDeviceState.MEDIA_DEVICE_STATE_STOPPED] = exports.MediaDeviceState.MEDIA_DEVICE_STATE_STOPPED,
            _a[MediaDeviceState.MEDIA_DEVICE_STATE_RUNTIMEERROR] = exports.MediaDeviceState.MEDIA_DEVICE_STATE_RUNTIMEERROR,
            _a[MediaDeviceState.MEDIA_DEVICE_STATE_ADDED] = exports.MediaDeviceState.MEDIA_DEVICE_STATE_ADDED,
            _a[MediaDeviceState.MEDIA_DEVICE_STATE_REMOVED] = exports.MediaDeviceState.MEDIA_DEVICE_STATE_REMOVED,
            _a[MediaDeviceState.MEDIA_DEVICE_STATE_INTERRUPTION_BEGAN] = exports.MediaDeviceState.MEDIA_DEVICE_STATE_INTERRUPTION_BEGAN,
            _a[MediaDeviceState.MEDIA_DEVICE_STATE_INTERRUPTION_ENDED] = exports.MediaDeviceState.MEDIA_DEVICE_STATE_INTERRUPTION_ENDED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaDeviceState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MediaDeviceState.ByteRTCMediaDeviceStateStarted] = ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateStarted,
            _a[exports.MediaDeviceState.ByteRTCMediaDeviceStateStopped] = ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateStopped,
            _a[exports.MediaDeviceState.ByteRTCMediaDeviceStateRuntimeError] = ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateRuntimeError,
            _a[exports.MediaDeviceState.ByteRTCMediaDeviceStateAdded] = ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateAdded,
            _a[exports.MediaDeviceState.ByteRTCMediaDeviceStateRemoved] = ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateRemoved,
            _a[exports.MediaDeviceState.ByteRTCMediaDeviceStateInterruptionBegan] = ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateInterruptionBegan,
            _a[exports.MediaDeviceState.ByteRTCMediaDeviceStateInterruptionEnded] = ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateInterruptionEnded,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MediaDeviceState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateStarted] = exports.MediaDeviceState.ByteRTCMediaDeviceStateStarted,
            _a[ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateStopped] = exports.MediaDeviceState.ByteRTCMediaDeviceStateStopped,
            _a[ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateRuntimeError] = exports.MediaDeviceState.ByteRTCMediaDeviceStateRuntimeError,
            _a[ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateAdded] = exports.MediaDeviceState.ByteRTCMediaDeviceStateAdded,
            _a[ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateRemoved] = exports.MediaDeviceState.ByteRTCMediaDeviceStateRemoved,
            _a[ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateInterruptionBegan] = exports.MediaDeviceState.ByteRTCMediaDeviceStateInterruptionBegan,
            _a[ByteRTCMediaDeviceState.ByteRTCMediaDeviceStateInterruptionEnded] = exports.MediaDeviceState.ByteRTCMediaDeviceStateInterruptionEnded,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MediaDeviceState;
}());
var t_LocalProxyType = /** @class */ (function () {
    function t_LocalProxyType() {
    }
    t_LocalProxyType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalProxyType.SOCKS5] = LocalProxyType.SOCKS5,
            _a[exports.LocalProxyType.HTTP_TUNNEL] = LocalProxyType.HTTP_TUNNEL,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalProxyType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[LocalProxyType.SOCKS5] = exports.LocalProxyType.SOCKS5,
            _a[LocalProxyType.HTTP_TUNNEL] = exports.LocalProxyType.HTTP_TUNNEL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalProxyType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LocalProxyType.SOCKS5] = ByteRTCLocalProxyType.ByteRTCLocalProxyTypeSocks5,
            _a[exports.LocalProxyType.HTTP_TUNNEL] = ByteRTCLocalProxyType.ByteRTCLocalProxyTypeHttpTunnel,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LocalProxyType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCLocalProxyType.ByteRTCLocalProxyTypeSocks5] = exports.LocalProxyType.SOCKS5,
            _a[ByteRTCLocalProxyType.ByteRTCLocalProxyTypeHttpTunnel] = exports.LocalProxyType.HTTP_TUNNEL,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_LocalProxyType;
}());
var t_PlayState = /** @class */ (function () {
    function t_PlayState() {
    }
    t_PlayState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PlayState.PLAYING] = PlayState.PLAYING,
            _a[exports.PlayState.PAUSED] = PlayState.PAUSED,
            _a[exports.PlayState.FAILED] = PlayState.FAILED,
            _a[exports.PlayState.FINISHED] = PlayState.FINISHED,
            _a[exports.PlayState.STOPPED] = PlayState.STOPPED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PlayState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[PlayState.PLAYING] = exports.PlayState.PLAYING,
            _a[PlayState.PAUSED] = exports.PlayState.PAUSED,
            _a[PlayState.FAILED] = exports.PlayState.FAILED,
            _a[PlayState.FINISHED] = exports.PlayState.FINISHED,
            _a[PlayState.STOPPED] = exports.PlayState.STOPPED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PlayState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PlayState.PLAYING] = ByteRTCPlayState.ByteRTCPlayStatePlaying,
            _a[exports.PlayState.PAUSED] = ByteRTCPlayState.ByteRTCPlayStatePaused,
            _a[exports.PlayState.FAILED] = ByteRTCPlayState.ByteRTCPlayStateFailed,
            _a[exports.PlayState.FINISHED] = ByteRTCPlayState.ByteRTCPlayStateFinished,
            _a[exports.PlayState.ByteRTCPlayStateStoped] = ByteRTCPlayState.ByteRTCPlayStateStoped,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PlayState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCPlayState.ByteRTCPlayStatePlaying] = exports.PlayState.PLAYING,
            _a[ByteRTCPlayState.ByteRTCPlayStatePaused] = exports.PlayState.PAUSED,
            _a[ByteRTCPlayState.ByteRTCPlayStateFailed] = exports.PlayState.FAILED,
            _a[ByteRTCPlayState.ByteRTCPlayStateFinished] = exports.PlayState.FINISHED,
            _a[ByteRTCPlayState.ByteRTCPlayStateStoped] = exports.PlayState.ByteRTCPlayStateStoped,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_PlayState;
}());
var t_SubtitleState = /** @class */ (function () {
    function t_SubtitleState() {
    }
    t_SubtitleState.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SubtitleState.SUBTITLE_STATE_STARTED] = SubtitleState.SUBTITLE_STATE_STARTED,
            _a[exports.SubtitleState.SUBTITLE_STATE_STOPED] = SubtitleState.SUBTITLE_STATE_STOPED,
            _a[exports.SubtitleState.SUBTITLE_STATE_ERROR] = SubtitleState.SUBTITLE_STATE_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubtitleState.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[SubtitleState.SUBTITLE_STATE_STARTED] = exports.SubtitleState.SUBTITLE_STATE_STARTED,
            _a[SubtitleState.SUBTITLE_STATE_STOPED] = exports.SubtitleState.SUBTITLE_STATE_STOPED,
            _a[SubtitleState.SUBTITLE_STATE_ERROR] = exports.SubtitleState.SUBTITLE_STATE_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubtitleState.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SubtitleState.SUBTITLE_STATE_STARTED] = ByteRTCSubtitleState.ByteRTCSubtitleStateStarted,
            _a[exports.SubtitleState.SUBTITLE_STATE_STOPED] = ByteRTCSubtitleState.ByteRTCSubtitleStateStoped,
            _a[exports.SubtitleState.SUBTITLE_STATE_ERROR] = ByteRTCSubtitleState.ByteRTCSubtitleStateError,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubtitleState.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCSubtitleState.ByteRTCSubtitleStateStarted] = exports.SubtitleState.SUBTITLE_STATE_STARTED,
            _a[ByteRTCSubtitleState.ByteRTCSubtitleStateStoped] = exports.SubtitleState.SUBTITLE_STATE_STOPED,
            _a[ByteRTCSubtitleState.ByteRTCSubtitleStateError] = exports.SubtitleState.SUBTITLE_STATE_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_SubtitleState;
}());
var t_MixedStreamRenderMode = /** @class */ (function () {
    function t_MixedStreamRenderMode() {
    }
    t_MixedStreamRenderMode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_HIDDEN] = MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_HIDDEN,
            _a[exports.MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_FIT] = MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_FIT,
            _a[exports.MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_ADAPTIVE] = MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_ADAPTIVE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamRenderMode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_HIDDEN] = exports.MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_HIDDEN,
            _a[MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_FIT] = exports.MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_FIT,
            _a[MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_ADAPTIVE] = exports.MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_ADAPTIVE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamRenderMode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_HIDDEN] = ByteRTCMixedStreamRenderMode.ByteRTCMixedStreamRenderModeHidden,
            _a[exports.MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_FIT] = ByteRTCMixedStreamRenderMode.ByteRTCMixedStreamRenderModeFit,
            _a[exports.MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_ADAPTIVE] = ByteRTCMixedStreamRenderMode.ByteRTCMixedStreamRenderModeAdaptive,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_MixedStreamRenderMode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCMixedStreamRenderMode.ByteRTCMixedStreamRenderModeHidden] = exports.MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_HIDDEN,
            _a[ByteRTCMixedStreamRenderMode.ByteRTCMixedStreamRenderModeFit] = exports.MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_FIT,
            _a[ByteRTCMixedStreamRenderMode.ByteRTCMixedStreamRenderModeAdaptive] = exports.MixedStreamRenderMode.MIXED_STREAM_RENDER_MODE_ADAPTIVE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_MixedStreamRenderMode;
}());
var t_SEIStreamUpdateEventType = /** @class */ (function () {
    function t_SEIStreamUpdateEventType() {
    }
    t_SEIStreamUpdateEventType.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SEIStreamUpdateEventType.STREAM_ADD] = SEIStreamUpdateEvent.STREAM_ADD,
            _a[exports.SEIStreamUpdateEventType.STREAM_REMOVE] = SEIStreamUpdateEvent.STREAM_REMOVE,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SEIStreamUpdateEventType.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[SEIStreamUpdateEvent.STREAM_ADD] = exports.SEIStreamUpdateEventType.STREAM_ADD,
            _a[SEIStreamUpdateEvent.STREAM_REMOVE] = exports.SEIStreamUpdateEventType.STREAM_REMOVE,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SEIStreamUpdateEventType.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SEIStreamUpdateEventType.ByteRTCSEIStreamEventTypeStreamAdd] = ByteRTCSEIStreamEventType.ByteRTCSEIStreamEventTypeStreamAdd,
            _a[exports.SEIStreamUpdateEventType.ByteRTCSEIStreamEventTypeStreamRemove] = ByteRTCSEIStreamEventType.ByteRTCSEIStreamEventTypeStreamRemove,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SEIStreamUpdateEventType.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCSEIStreamEventType.ByteRTCSEIStreamEventTypeStreamAdd] = exports.SEIStreamUpdateEventType.ByteRTCSEIStreamEventTypeStreamAdd,
            _a[ByteRTCSEIStreamEventType.ByteRTCSEIStreamEventTypeStreamRemove] = exports.SEIStreamUpdateEventType.ByteRTCSEIStreamEventTypeStreamRemove,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_SEIStreamUpdateEventType;
}());

exports.UserMessageSendResult = void 0;
(function (UserMessageSendResult) {
    /** {en}
     * @platform android
     * @brief The message has been sent successfully.
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_SUCCESS"] = 0] = "USER_MESSAGE_SEND_RESULT_SUCCESS";
    /** {en}
     * @platform android
     * @brief Failure. Sending timeout.
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_TIMEOUT"] = 1] = "USER_MESSAGE_SEND_RESULT_TIMEOUT";
    /** {en}
     * @platform android
     * @brief Failure. Channel disconnected.
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_BROKEN"] = 2] = "USER_MESSAGE_SEND_RESULT_BROKEN";
    /** {en}
     * @platform android
     * @brief Failure. Recipient not found.
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_NO_RECEIVER"] = 3] = "USER_MESSAGE_SEND_RESULT_NO_RECEIVER";
    /** {en}
     * @platform android
     * @brief Failure. The remote user did not logged in or joining the room.
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_NO_RELAY_PATH"] = 4] = "USER_MESSAGE_SEND_RESULT_NO_RELAY_PATH";
    /** {en}
     * @platform android
     * @brief Failure. Exceeds QPS limit.
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_EXCEED_QPS"] = 5] = "USER_MESSAGE_SEND_RESULT_EXCEED_QPS";
    /** {en}
     * @platform android
     * @brief Failure. The sender of the message did not join the room
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_NOT_JOIN"] = 6] = "USER_MESSAGE_SEND_RESULT_NOT_JOIN";
    /** {en}
     * @platform android
     * @brief Failure. The connection has not completed initialization.
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_INIT"] = 7] = "USER_MESSAGE_SEND_RESULT_INIT";
    /** {en}
     * @platform android
     * @brief Failure. No data transmission channel connection available
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_NO_CONNECTION"] = 8] = "USER_MESSAGE_SEND_RESULT_NO_CONNECTION";
    /** {en}
     * @platform android
     * @brief Failure. Message exceeds the range of the permitted size, 64 KB.
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH"] = 9] = "USER_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH";
    /** {en}
     * @platform android
     * @brief Failure. The id of the recipient is empty
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_EMPTY_USER"] = 10] = "USER_MESSAGE_SEND_RESULT_EMPTY_USER";
    /** {en}
     * @platform android
     * @brief Failure. The sender of the message did not log in.
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_NOT_LOGIN"] = 11] = "USER_MESSAGE_SEND_RESULT_NOT_LOGIN";
    /** {en}
     * @platform android
     * @brief Failure. No parameters were set before sending the message to the business-side server
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_SERVER_PARAMS_NOT_SET"] = 12] = "USER_MESSAGE_SEND_RESULT_SERVER_PARAMS_NOT_SET";
    /** {en}
     * @platform android
     * @brief Failure. Unknown error
     *
     */
    UserMessageSendResult[UserMessageSendResult["USER_MESSAGE_SEND_RESULT_UNKNOWN"] = 13] = "USER_MESSAGE_SEND_RESULT_UNKNOWN";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultSuccess"] = 14] = "ByteRTCUserMessageSendResultSuccess";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultTimeout"] = 15] = "ByteRTCUserMessageSendResultTimeout";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultNetworkDisconnected"] = 16] = "ByteRTCUserMessageSendResultNetworkDisconnected";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultNoReceiver"] = 17] = "ByteRTCUserMessageSendResultNoReceiver";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultNoRelayPath"] = 18] = "ByteRTCUserMessageSendResultNoRelayPath";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultExceedQPS"] = 19] = "ByteRTCUserMessageSendResultExceedQPS";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultE2BSSendFailed"] = 20] = "ByteRTCUserMessageSendResultE2BSSendFailed";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultE2BSReturnFailed"] = 21] = "ByteRTCUserMessageSendResultE2BSReturnFailed";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultNotJoin"] = 22] = "ByteRTCUserMessageSendResultNotJoin";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultInit"] = 23] = "ByteRTCUserMessageSendResultInit";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultNoConnection"] = 24] = "ByteRTCUserMessageSendResultNoConnection";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultExceedMaxLength"] = 25] = "ByteRTCUserMessageSendResultExceedMaxLength";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultEmptyUser"] = 26] = "ByteRTCUserMessageSendResultEmptyUser";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultNotLogin"] = 27] = "ByteRTCUserMessageSendResultNotLogin";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultServerParamsNotSet"] = 28] = "ByteRTCUserMessageSendResultServerParamsNotSet";
    UserMessageSendResult[UserMessageSendResult["ByteRTCUserMessageSendResultUnknown"] = 29] = "ByteRTCUserMessageSendResultUnknown";
})(exports.UserMessageSendResult || (exports.UserMessageSendResult = {}));
exports.AudioRecordingErrorCode = void 0;
(function (AudioRecordingErrorCode) {
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_ALREADY_STARTED"] = 0] = "AUDIO_RECORDING_ERROR_CODE_ALREADY_STARTED";
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_NOT_STARTED"] = 1] = "AUDIO_RECORDING_ERROR_CODE_NOT_STARTED";
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_OK"] = 2] = "AUDIO_RECORDING_ERROR_CODE_OK";
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_NO_PERMISSION"] = 3] = "AUDIO_RECORDING_ERROR_CODE_NO_PERMISSION";
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_NOT_IN_ROOM"] = 4] = "AUDIO_RECORDING_ERROR_CODE_NOT_IN_ROOM";
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_NOT_SUPPORT"] = 5] = "AUDIO_RECORDING_ERROR_CODE_NOT_SUPPORT";
    AudioRecordingErrorCode[AudioRecordingErrorCode["AUDIO_RECORDING_ERROR_CODE_OTHER"] = 6] = "AUDIO_RECORDING_ERROR_CODE_OTHER";
    AudioRecordingErrorCode[AudioRecordingErrorCode["ByteRTCAudioRecordingErrorCodeOk"] = 7] = "ByteRTCAudioRecordingErrorCodeOk";
    AudioRecordingErrorCode[AudioRecordingErrorCode["ByteRTCAudioRecordingErrorCodeNoPermission"] = 8] = "ByteRTCAudioRecordingErrorCodeNoPermission";
    AudioRecordingErrorCode[AudioRecordingErrorCode["ByteRTCAudioRecordingErrorNotInRoom"] = 9] = "ByteRTCAudioRecordingErrorNotInRoom";
    AudioRecordingErrorCode[AudioRecordingErrorCode["ByteRTCAudioRecordingErrorCodeNotSupport"] = 10] = "ByteRTCAudioRecordingErrorCodeNotSupport";
    AudioRecordingErrorCode[AudioRecordingErrorCode["ByteRTCAudioRecordingErrorCodeOther"] = 11] = "ByteRTCAudioRecordingErrorCodeOther";
})(exports.AudioRecordingErrorCode || (exports.AudioRecordingErrorCode = {}));
exports.KTVErrorCode = void 0;
(function (KTVErrorCode) {
    KTVErrorCode[KTVErrorCode["OK"] = 0] = "OK";
    KTVErrorCode[KTVErrorCode["APPID_INVALID"] = 1] = "APPID_INVALID";
    KTVErrorCode[KTVErrorCode["PARAS_INVALID"] = 2] = "PARAS_INVALID";
    KTVErrorCode[KTVErrorCode["GET_MUSIC_FAILED"] = 3] = "GET_MUSIC_FAILED";
    KTVErrorCode[KTVErrorCode["GET_LYRIC_FAILED"] = 4] = "GET_LYRIC_FAILED";
    KTVErrorCode[KTVErrorCode["MUSIC_TAKEDOWN"] = 5] = "MUSIC_TAKEDOWN";
    KTVErrorCode[KTVErrorCode["MUSIC_DOWNLOAD"] = 6] = "MUSIC_DOWNLOAD";
    KTVErrorCode[KTVErrorCode["MIDI_DOWNLOAD_FAILED"] = 7] = "MIDI_DOWNLOAD_FAILED";
    KTVErrorCode[KTVErrorCode["SYSTEM_BUSY"] = 8] = "SYSTEM_BUSY";
    KTVErrorCode[KTVErrorCode["NETWORK"] = 9] = "NETWORK";
    KTVErrorCode[KTVErrorCode["NOT_JOIN_ROOM"] = 10] = "NOT_JOIN_ROOM";
    KTVErrorCode[KTVErrorCode["PARSE_DATA"] = 11] = "PARSE_DATA";
    KTVErrorCode[KTVErrorCode["DOWNLOADING"] = 12] = "DOWNLOADING";
    KTVErrorCode[KTVErrorCode["INTERNAL_DOMAIN"] = 13] = "INTERNAL_DOMAIN";
    KTVErrorCode[KTVErrorCode["INSUFFICIENT_DISK_SPACE"] = 14] = "INSUFFICIENT_DISK_SPACE";
    KTVErrorCode[KTVErrorCode["MUSIC_DECRYPTION_FAILED"] = 15] = "MUSIC_DECRYPTION_FAILED";
    KTVErrorCode[KTVErrorCode["FILE_RENAME_FAILED"] = 16] = "FILE_RENAME_FAILED";
    KTVErrorCode[KTVErrorCode["DOWNLOAD_TIMEOUT"] = 17] = "DOWNLOAD_TIMEOUT";
    KTVErrorCode[KTVErrorCode["CLEAR_CACHE_FAILED"] = 18] = "CLEAR_CACHE_FAILED";
    KTVErrorCode[KTVErrorCode["DOWNLOAD_CANCELED"] = 19] = "DOWNLOAD_CANCELED";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeOK"] = 20] = "ByteRTCKTVErrorCodeOK";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeAppidInValid"] = 21] = "ByteRTCKTVErrorCodeAppidInValid";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeParasInValid"] = 22] = "ByteRTCKTVErrorCodeParasInValid";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeGetMusicFailed"] = 23] = "ByteRTCKTVErrorCodeGetMusicFailed";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeGetLyricFailed"] = 24] = "ByteRTCKTVErrorCodeGetLyricFailed";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeMusicTakedown"] = 25] = "ByteRTCKTVErrorCodeMusicTakedown";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeMusicDownload"] = 26] = "ByteRTCKTVErrorCodeMusicDownload";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeMidiDownloadFailed"] = 27] = "ByteRTCKTVErrorCodeMidiDownloadFailed";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeSystemBusy"] = 28] = "ByteRTCKTVErrorCodeSystemBusy";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeNetwork"] = 29] = "ByteRTCKTVErrorCodeNetwork";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeNotJoinRoom"] = 30] = "ByteRTCKTVErrorCodeNotJoinRoom";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeParseData"] = 31] = "ByteRTCKTVErrorCodeParseData";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeDownloading"] = 32] = "ByteRTCKTVErrorCodeDownloading";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeInternal"] = 33] = "ByteRTCKTVErrorCodeInternal";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeInsufficientDiskSpace"] = 34] = "ByteRTCKTVErrorCodeInsufficientDiskSpace";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeMusicDecryptionFailed"] = 35] = "ByteRTCKTVErrorCodeMusicDecryptionFailed";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeFileRenameFailed"] = 36] = "ByteRTCKTVErrorCodeFileRenameFailed";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeDownloadTimeOut"] = 37] = "ByteRTCKTVErrorCodeDownloadTimeOut";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeClearCacheFailed"] = 38] = "ByteRTCKTVErrorCodeClearCacheFailed";
    KTVErrorCode[KTVErrorCode["ByteRTCKTVErrorCodeDownloadCanceled"] = 39] = "ByteRTCKTVErrorCodeDownloadCanceled";
})(exports.KTVErrorCode || (exports.KTVErrorCode = {}));
exports.PublicStreamErrorCode = void 0;
(function (PublicStreamErrorCode) {
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_SUCCESS"] = 0] = "ERROR_CODE_SUCCESS";
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_PUSH_PARAM_ERROR"] = 1] = "ERROR_CODE_PUSH_PARAM_ERROR";
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_PUSH_INTERNAL_ERROR"] = 2] = "ERROR_CODE_PUSH_INTERNAL_ERROR";
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_PUSH_ERROR"] = 3] = "ERROR_CODE_PUSH_ERROR";
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_PUSH_TIMEOUT"] = 4] = "ERROR_CODE_PUSH_TIMEOUT";
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_PULL_NO_PUSH_STREAM"] = 5] = "ERROR_CODE_PULL_NO_PUSH_STREAM";
    PublicStreamErrorCode[PublicStreamErrorCode["ERROR_CODE_PUSH_STATE_ERROR"] = 6] = "ERROR_CODE_PUSH_STATE_ERROR";
    PublicStreamErrorCode[PublicStreamErrorCode["ByteRTCPublicStreamErrorCodePushStatusError"] = 7] = "ByteRTCPublicStreamErrorCodePushStatusError";
})(exports.PublicStreamErrorCode || (exports.PublicStreamErrorCode = {}));
exports.SubtitleErrorCode = void 0;
(function (SubtitleErrorCode) {
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_UNKNOW"] = 0] = "SUBTITLE_ERROR_CODE_UNKNOW";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_SUCCESS"] = 1] = "SUBTITLE_ERROR_CODE_SUCCESS";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_POST_PROCESS_ERROR"] = 2] = "SUBTITLE_ERROR_CODE_POST_PROCESS_ERROR";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_ASR_CONNECTION_ERROR"] = 3] = "SUBTITLE_ERROR_CODE_ASR_CONNECTION_ERROR";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_ASR_SERVICE_ERROR"] = 4] = "SUBTITLE_ERROR_CODE_ASR_SERVICE_ERROR";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_BEFORE_JOIN_ROOM"] = 5] = "SUBTITLE_ERROR_CODE_BEFORE_JOIN_ROOM";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_ALREADY_ON"] = 6] = "SUBTITLE_ERROR_CODE_ALREADY_ON";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_UNSUPPORTED_LANGUAGE"] = 7] = "SUBTITLE_ERROR_CODE_UNSUPPORTED_LANGUAGE";
    SubtitleErrorCode[SubtitleErrorCode["SUBTITLE_ERROR_CODE_POST_PROCESS_TIMEOUT"] = 8] = "SUBTITLE_ERROR_CODE_POST_PROCESS_TIMEOUT";
    SubtitleErrorCode[SubtitleErrorCode["ByteRTCSubtitleErrorCodeUnknow"] = 9] = "ByteRTCSubtitleErrorCodeUnknow";
    SubtitleErrorCode[SubtitleErrorCode["ByteRTCSubtitleErrorCodeSuccess"] = 10] = "ByteRTCSubtitleErrorCodeSuccess";
    SubtitleErrorCode[SubtitleErrorCode["ByteRTCSubtitleErrorCodePostProcessError"] = 11] = "ByteRTCSubtitleErrorCodePostProcessError";
    SubtitleErrorCode[SubtitleErrorCode["ByteRTCSubtitleErrorCodeASRConnectionError"] = 12] = "ByteRTCSubtitleErrorCodeASRConnectionError";
    SubtitleErrorCode[SubtitleErrorCode["ByteRTCSubtitleErrorCodeASRServiceError"] = 13] = "ByteRTCSubtitleErrorCodeASRServiceError";
    SubtitleErrorCode[SubtitleErrorCode["ByteRTCSubtitleErrorCodeBeforeJoinRoom"] = 14] = "ByteRTCSubtitleErrorCodeBeforeJoinRoom";
    SubtitleErrorCode[SubtitleErrorCode["ByteRTCSubtitleErrorCodeAlreadyOn"] = 15] = "ByteRTCSubtitleErrorCodeAlreadyOn";
    SubtitleErrorCode[SubtitleErrorCode["ByteRTCSubtitleErrorCodeUnsupportedLanguage"] = 16] = "ByteRTCSubtitleErrorCodeUnsupportedLanguage";
    SubtitleErrorCode[SubtitleErrorCode["ByteRTCSubtitleErrorCodePostProcessTimeout"] = 17] = "ByteRTCSubtitleErrorCodePostProcessTimeout";
})(exports.SubtitleErrorCode || (exports.SubtitleErrorCode = {}));
exports.ErrorCode = void 0;
(function (ErrorCode) {
    /** {en}
     * @platform android
     * @brief Token  is invalid. Returned by {@link onRoomStateChanged onRoomStateChanged}. <br>
     *        The token used when entering the room is invalid or expired. The user is required to retrieve the token and call the `updateToken` method to update the token.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_INVALID_TOKEN"] = 0] = "ERROR_CODE_INVALID_TOKEN";
    /** {en}
     * @platform android
     * @brief Join room error. Returned by {@link onRoomStateChanged onRoomStateChanged}. <br>
     * An unknown error occurred while entering the room, which caused the joining room to fail. Users are required to rejoin the room.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_JOIN_ROOM"] = 1] = "ERROR_CODE_JOIN_ROOM";
    /** {en}
     * @platform android
     * @brief No permission to publish audio & video streams. Returned by {@link onRoomStateChanged onRoomStateChanged}. <br>
     *        The user failed to publish the audio & video stream in the room. The reason for the failure is that the user does not have permission to publish the stream.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_NO_PUBLISH_PERMISSION"] = 2] = "ERROR_CODE_NO_PUBLISH_PERMISSION";
    /** {en}
     * @platform android
     * @brief No subscription permissions for audio & video streams. Returned by {@link onStreamStateChanged onStreamStateChanged}. <br>
     *        The user failed to subscribe to the audio & video stream in the room where the user is located. The reason for the failure is that the user does not have permission to subscribe to the stream.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_NO_SUBSCRIBE_PERMISSION"] = 3] = "ERROR_CODE_NO_SUBSCRIBE_PERMISSION";
    /** {en}
     * @platform android
     * @brief The user has been removed from the room because the same user joined the room on the other client. Returned by {@link onRoomStateChanged onRoomStateChanged}.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_DUPLICATE_LOGIN"] = 4] = "ERROR_CODE_DUPLICATE_LOGIN";
    /** {en}
     * @platform android
     * @brief The App ID parameter is abnormal. <br>
     *        The App ID parameter passed in when the engine was created is empty.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_APP_ID_NULL"] = 5] = "ERROR_CODE_APP_ID_NULL";
    /** {en}
     * @platform android
     * @brief The user has been remove from the room by the administrator via a OpenAPI call. Returned by {@link onRoomStateChanged onRoomStateChanged}.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_KICKED_OUT"] = 6] = "ERROR_CODE_KICKED_OUT";
    /** {en}
     * @platform android
     * @brief When calling `createRoom`, if the roomId is illegal, it will return null and throw the error. Returned by {@link onCreateRoomStateChanged onCreateRoomStateChanged}.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_ROOM_ID_ILLEGAL"] = 7] = "ERROR_CODE_ROOM_ID_ILLEGAL";
    /** {en}
     * @platform android
     * @brief Token expired. Call `joinRoom` to rejoin with a valid Token. Returned by {@link onRoomStateChanged onRoomStateChanged}.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_TOKEN_EXPIRED"] = 8] = "ERROR_CODE_TOKEN_EXPIRED";
    /** {en}
     * @platform android
     * @brief The Token you provided when calling `updateToken` is invalid. Returned by {@link onRoomStateChanged onRoomStateChanged}.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_UPDATE_TOKEN_WITH_INVALID_TOKEN"] = 9] = "ERROR_CODE_UPDATE_TOKEN_WITH_INVALID_TOKEN";
    /** {en}
     * @platform android
     * @brief Users have been removed from the room because the administrator dismissed the room by calling OpenAPI. Returned by {@link onRoomStateChanged onRoomStateChanged}.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_ROOM_DISMISS"] = 10] = "ERROR_CODE_ROOM_DISMISS";
    /** {en}
     * @platform android
     * @brief A room with the same roomId already exists during the call echo test. Returned by {@link onCreateRoomStateChanged onCreateRoomStateChanged}.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_ROOM_ALREADY_EXIST"] = 12] = "ERROR_CODE_ROOM_ALREADY_EXIST";
    /** {en}
     * @platform android
     * @brief The local user joins multiple rooms with different uid. Returned by {@link onRoomStateChanged onRoomStateChanged}. <br>
     *        In the same engine instance, users need to use the same uid to join different rooms.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_USER_ID_DIFFERENT"] = 13] = "ERROR_CODE_USER_ID_DIFFERENT";
    /** {en}
     * @platform android
     * @brief The room has banned before the user calls `joinRoom`. Returned by {@link onRoomStateChanged onRoomStateChanged}.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_JOIN_ROOM_ROOM_FORBIDDEN"] = 22] = "ERROR_CODE_JOIN_ROOM_ROOM_FORBIDDEN";
    /** {en}
     * @platform android
     * @brief The user has banned before calling `joinRoom`. Returned by {@link onRoomStateChanged onRoomStateChanged}.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_JOIN_ROOM_USER_FORBIDDEN"] = 23] = "ERROR_CODE_JOIN_ROOM_USER_FORBIDDEN";
    /** {en}
     * @platform android
     * @brief Failed to subscribe to streams because the total number of subscribed streams has exceeded the upper limit. Returned by {@link onRoomStateChanged onRoomStateChanged}. <br>
     *        In order to ensure the performance and quality of audio & video calls in the game scenario, the server will limit the total number of audio & video streams subscribed by the user. When the total number of audio & video streams subscribed by the user has reached the maximum, continuing to subscribe to more streams will fail, and the user will receive this error notification.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_OVER_SUBSCRIBE_LIMIT"] = 25] = "ERROR_CODE_OVER_SUBSCRIBE_LIMIT";
    /** {en}
     * @platform android
     * @brief Failed to publish video stream because the total number of published streams has exceeded the upper limit. Returned by {@link onStreamStateChanged onStreamStateChanged}. <br>
     *        RTC will limit the total number of streams published in a single room, including video, audio, and screen streams. Local users will fail to publish streams to the room when the maximum number of published streams in the room has been reached, and will receive this error notification.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_OVER_STREAM_PUBLISH_LIMIT"] = 27] = "ERROR_CODE_OVER_STREAM_PUBLISH_LIMIT";
    /** {en}
     * @platform android
     * @brief A/V synchronization failed. <br>
     *        Current source audio ID has been set by other video publishers in the same room. <br>
     *        One single audio source cannot be synchronized with multiple video sources at the same time. <br>
     *        Returned by {@link onStreamStateChanged onStreamStateChanged}.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_INVALID_AUDIO_SYNC_USERID_REPEATED"] = 28] = "ERROR_CODE_INVALID_AUDIO_SYNC_USERID_REPEATED";
    /** {en}
     * @platform android
     * @brief The user has been removed from the room due to the abnormal status of server. Returned by {@link onRoomStateChanged onRoomStateChanged}. <br>
     *        SDK  is disconnected with the signaling server. It will not reconnect automatically. Please contact technical support.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_ABNORMAL_SERVER_STATUS"] = 29] = "ERROR_CODE_ABNORMAL_SERVER_STATUS";
    /** {en}
     * @platform android
     * @deprecated since 3.52, use ERROR_CODE_OVER_STREAM_PUBLISH_LIMIT(-1080) instead
     * @brief Publishing the screen stream failed, and the total number of publishing streams exceeded the upper limit. The <br>
     *        RTC will limit the total number of streams published in a single room, including video, audio, and screen streams. <br>
     *        Local users will fail to publish streams to the room when the maximum number of published streams in the room has been reached, and will receive this error notification.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_OVER_SCREEN_PUBLISH_LIMIT"] = 32] = "ERROR_CODE_OVER_SCREEN_PUBLISH_LIMIT";
    /** {en}
     * @platform android
     * @deprecated since 3.52, use ERROR_CODE_OVER_STREAM_PUBLISH_LIMIT(-1080) instead
     * @brief The total number of published video streams exceeds the upper limit. <br>
     *        The RTC system limits the number of video streams posted in a single room. If the maximum number of video streams posted in the room has been reached, local users will fail to post video streams to the room again and will receive this error notification.
     *
     */
    ErrorCode[ErrorCode["ERROR_CODE_OVER_VIDEO_PUBLISH_LIMIT"] = 33] = "ERROR_CODE_OVER_VIDEO_PUBLISH_LIMIT";
    ErrorCode[ErrorCode["ByteRTCErrorCodeInvalidToken"] = 34] = "ByteRTCErrorCodeInvalidToken";
    ErrorCode[ErrorCode["ByteRTCErrorCodeJoinRoom"] = 35] = "ByteRTCErrorCodeJoinRoom";
    ErrorCode[ErrorCode["ByteRTCErrorCodeNoPublishPermission"] = 36] = "ByteRTCErrorCodeNoPublishPermission";
    ErrorCode[ErrorCode["ByteRTCErrorCodeNoSubscribePermission"] = 37] = "ByteRTCErrorCodeNoSubscribePermission";
    ErrorCode[ErrorCode["ByteRTCErrorCodeDuplicateLogin"] = 38] = "ByteRTCErrorCodeDuplicateLogin";
    ErrorCode[ErrorCode["ByteRTCErrorCodeKickedOut"] = 39] = "ByteRTCErrorCodeKickedOut";
    ErrorCode[ErrorCode["ByteRTCErrorCodeRoomIdIllegal"] = 40] = "ByteRTCErrorCodeRoomIdIllegal";
    ErrorCode[ErrorCode["ByteRTCErrorCodeTokenExpired"] = 41] = "ByteRTCErrorCodeTokenExpired";
    ErrorCode[ErrorCode["ByteRTCErrorCodeUpdateTokenWithInvalidToken"] = 42] = "ByteRTCErrorCodeUpdateTokenWithInvalidToken";
    ErrorCode[ErrorCode["ByteRTCErrorCodeRoomDismiss"] = 43] = "ByteRTCErrorCodeRoomDismiss";
    ErrorCode[ErrorCode["ByteRTCRoomAlreadyExist"] = 45] = "ByteRTCRoomAlreadyExist";
    ErrorCode[ErrorCode["ByteRTCUserIDDifferent"] = 46] = "ByteRTCUserIDDifferent";
    ErrorCode[ErrorCode["ByteRTCErrorCodeJoinRoomRoomForbidden"] = 55] = "ByteRTCErrorCodeJoinRoomRoomForbidden";
    ErrorCode[ErrorCode["ByteRTCErrorCodeJoinRoomUserForbidden"] = 56] = "ByteRTCErrorCodeJoinRoomUserForbidden";
    ErrorCode[ErrorCode["ByteRTCErrorCodeOverStreamSubscribeLimit"] = 57] = "ByteRTCErrorCodeOverStreamSubscribeLimit";
    ErrorCode[ErrorCode["ByteRTCErrorCodeOverStreamPublishLimit"] = 58] = "ByteRTCErrorCodeOverStreamPublishLimit";
    ErrorCode[ErrorCode["ByteRTCErrorCodInvalidAudioSyncUidRepeated"] = 59] = "ByteRTCErrorCodInvalidAudioSyncUidRepeated";
    ErrorCode[ErrorCode["ByteRTCErrorCodeAbnormalServerStatus"] = 60] = "ByteRTCErrorCodeAbnormalServerStatus";
    ErrorCode[ErrorCode["ByteRTCErrorCodeOverScreenPublishLimit"] = 64] = "ByteRTCErrorCodeOverScreenPublishLimit";
    ErrorCode[ErrorCode["ByteRTCErrorCodeOverVideoPublishLimit"] = 65] = "ByteRTCErrorCodeOverVideoPublishLimit";
})(exports.ErrorCode || (exports.ErrorCode = {}));
exports.WarningCode = void 0;
(function (WarningCode) {
    /** {en}
     * @platform android
     * @brief Failed to enter the room. Returned by {@link onRoomStateChanged onRoomStateChanged}. <br>
     *        When you enter the room for the first time or disconnect and reconnect due to poor network condition, the room entry failed due to a server error. The SDK automatically retries to join the room.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_JOIN_ROOM_FAILED"] = 0] = "WARNING_CODE_JOIN_ROOM_FAILED";
    /** {en}
     * @platform android
     * @brief Release audio & video stream failed. Returned by {@link onStreamStateChanged onStreamStateChanged}. <br>
     *        When you publish audio & video streams in your room, the publication fails due to a server error. The SDK automatically retries the release.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_PUBLISH_STREAM_FAILED"] = 1] = "WARNING_CODE_PUBLISH_STREAM_FAILED";
    /** {en}
     * @platform android
     * @brief Subscription to audio & video stream failed. Returned by {@link onStreamStateChanged onStreamStateChanged}. <br>
     *         The subscription failed because the audio & video stream for the subscription could not be found in the current room. The SDK will automatically retry the subscription. If the subscription fails, it is recommended that you exit the retry.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_SUBSCRIBE_STREAM_FAILED404"] = 2] = "WARNING_CODE_SUBSCRIBE_STREAM_FAILED404";
    /** {en}
     * @platform android
     * @brief Subscription to audio & video stream failed. Returned by {@link onStreamStateChanged onStreamStateChanged}. <br>
     *        When you subscribe to audio & video streams in your room, the subscription fails due to a server error. The SDK automatically retries the subscription.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_SUBSCRIBE_STREAM_FAILED5XX"] = 3] = "WARNING_CODE_SUBSCRIBE_STREAM_FAILED5XX";
    /** {en}
     * @platform android
     * @brief This warning is triggered when a call to `setUserVisibility` sets its own visibility to false and then attempts to publish the flow. Returned by {@link onStreamStateChanged onStreamStateChanged}.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_PUBLISH_STREAM_FORBIDEN"] = 6] = "WARNING_CODE_PUBLISH_STREAM_FORBIDEN";
    /** {en}
     * @platform android
     * @brief Sending a custom broadcast message failed, you are not currently in the room.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_SEND_CUSTOM_MESSAGE"] = 7] = "WARNING_CODE_SEND_CUSTOM_MESSAGE";
    /** {en}
     * @platform android
     * @brief When the number of people in the room exceeds 500, stop sending `onUserJoined` and `onUserLeave` callbacks to existing users in the room, and prompt all users in the room via broadcast. Returned by {@link onRoomStateChanged onRoomStateChanged}.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_RECEIVE_USER_NOTIFY_STOP"] = 8] = "WARNING_CODE_RECEIVE_USER_NOTIFY_STOP";
    /** {en}
     * @platform android
     * @brief User had published in other room. Returned by {@link onStreamStateChanged onStreamStateChanged}.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_USER_IN_PUBLISH"] = 9] = "WARNING_CODE_USER_IN_PUBLISH";
    /** {en}
     * @platform android
     * @brief A room with the same roomId already exists. The newly created room instance has replaced the old one. Returned by {@link onRoomStateChanged onRoomStateChanged}.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_OLD_ROOM_BEEN_REPLACED"] = 10] = "WARNING_CODE_OLD_ROOM_BEEN_REPLACED";
    /** {en}
     * @platform android
     * @brief this API has been banned for the engine is in echo testing mode.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_IN_ECHO_TEST_MODE"] = 11] = "WARNING_CODE_IN_ECHO_TEST_MODE";
    /** {en}
     * @platform android
     * @brief The camera permission is abnormal, and the current application does not obtain the camera permission.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_NO_CAMERA_PERMISSION"] = 12] = "WARNING_CODE_NO_CAMERA_PERMISSION";
    /** {en}
     * @platform android
     * @brief Setting the screen audio capture type by calling {@link setScreenAudioSourceType setScreenAudioSourceType} after {@link publishScreen publishScreen} is not supported.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_SET_SCREEN_AUDIO_SOURCE_TYPE_FAILED"] = 13] = "WARNING_CODE_SET_SCREEN_AUDIO_SOURCE_TYPE_FAILED";
    /** {en}
     * @platform android
     * @brief After {@link publishScreen publishScreen}, calling {@link setScreenAudioStreamIndex setScreenAudioStreamIndex} to set the screen audio share publication type is not supported
     *
     */
    WarningCode[WarningCode["WARNING_CODE_SET_SCREEN_STREAM_INDEX_FAILED"] = 14] = "WARNING_CODE_SET_SCREEN_STREAM_INDEX_FAILED";
    /** {en}
     * @platform android
     * @brief Invalid pitch value setting
     *
     */
    WarningCode[WarningCode["WARNING_CODE_SET_SCREEN_STREAM_INVALID_VOICE_PITCH"] = 15] = "WARNING_CODE_SET_SCREEN_STREAM_INVALID_VOICE_PITCH";
    /** {en}
     * @platform android
     * @brief Mixed use of old and new interfaces for external audio sources
     *
     */
    WarningCode[WarningCode["WARNING_CODE_INVALID_CALL_FOR_EXT_AUDIO"] = 16] = "WARNING_CODE_INVALID_CALL_FOR_EXT_AUDIO";
    /** {en}
     * @platform android
     * @brief Authorization failure for [BytePlus Audio SDK](https://go.byteplus.com/audio-sdk). Contact the technical supporters.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_INVALID_SAMI_APPKEY_OR_TOKEN"] = 17] = "WARNING_CODE_INVALID_SAMI_APPKEY_OR_TOKEN";
    /** {en}
     * @platform android
     * @brief Failure to get the resource for [BytePlus Audio SDK](https://go.byteplus.com/audio-sdk). Input the right DAT path or contact the technical supporters.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_INVALID_RESOURCE_PATH"] = 18] = "WARNING_CODE_INVALID_RESOURCE_PATH";
    /** {en}
     * @platform android
     * @brief Failure to load the library for [BytePlus Audio SDK](https://go.byteplus.com/audio-sdk). Use right library or contact the technical supporters.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_LOAD_SAMI_LIBRARY_FAILED"] = 19] = "WARNING_CODE_LOAD_SAMI_LIBRARY_FAILED";
    /** {en}
     * @platform android
     * @brief The audio effect is not supported by [BytePlus Audio SDK](https://go.byteplus.com/audio-sdk). Contact the technical supporters.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_INVALID_SAMI_EFFECT_TYPE"] = 20] = "WARNING_CODE_INVALID_SAMI_EFFECT_TYPE";
    /** {en}
     * @platform android
     * @deprecated since 3.45 and will be deleted in 3.51.
     * @brief Failed to get room information Warning
     * @note SDK Failed to get room information (including timeout, returning an error code other than 200), try again every two seconds. <br>
     *         After 5 consecutive failures, report the warning and continue to try again. <br>
     *        Suggest to prompt the user: Failed to enter the room, please try again later
     *
     */
    WarningCode[WarningCode["WARNING_CODE_GET_ROOM_FAILED"] = 21] = "WARNING_CODE_GET_ROOM_FAILED";
    /** {en}
     * @platform android
     * @deprecated since 3.45 and will be deleted in 3.51.
     * @brief When automatic subscription mode is not turned off, trying to turn on manual subscription mode will trigger this warning. <br>
     *        You need to turn off the automatic subscription mode before entering the room, and then call the {@link subscribeUserStream subscribeUserStream} method to manually subscribe to the audio & video stream.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_SUBSCRIBE_STREAM_FORBIDEN"] = 22] = "WARNING_CODE_SUBSCRIBE_STREAM_FORBIDEN";
    /** {en}
     * @platform android
     * @deprecated since 3.45 and will be deleted in 3.51.
     * @brief there is a room with the same roomId
     *
     */
    WarningCode[WarningCode["WARNING_CODE_ROOM_ID_ALREADY_EXIST"] = 23] = "WARNING_CODE_ROOM_ID_ALREADY_EXIST";
    /** {en}
     * @platform android
     * @brief The microphone permission is abnormal, and the current application does not obtain microphone permission.
     * @deprecated since 3.45 and will be deleted in 3.51, use {@link MediaDeviceError MediaDeviceError}.MEDIA_DEVICE_ERROR_NOPERMISSION instead.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_NO_MICROPHONE_PERMISSION"] = 24] = "WARNING_CODE_NO_MICROPHONE_PERMISSION";
    /** {en}
     * @platform android
     * @brief The audio capture device failed to start. <br>
     *        Failed to start the audio capture device, the current device may be occupied by other applications.
     * @deprecated since 3.45 and will be deleted in 3.51, use {@link MediaDeviceError MediaDeviceError}.MEDIA_DEVICE_ERROR_DEVICEFAILURE instead.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_RECODING_DEVICE_START_FAILED"] = 25] = "WARNING_CODE_RECODING_DEVICE_START_FAILED";
    /** {en}
     * @platform android
     * @brief Audio playback device startup failure warning. <br>
     *        It may be due to insufficient system resources or wrong parameters.
     * @deprecated since 3.45 and will be deleted in 3.51, use {@link MediaDeviceError MediaDeviceError}.MEDIA_DEVICE_ERROR_DEVICEFAILURE instead.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_PLAYOUT_DEVICE_START_FAILED"] = 26] = "WARNING_CODE_PLAYOUT_DEVICE_START_FAILED";
    /** {en}
     * @platform android
     * @brief No audio acquisition equipment available. <br>
     *        Failed to start the audio capture device, please insert the available audio capture device.
     * @deprecated since 3.45 and will be deleted in 3.51, use {@link MediaDeviceError MediaDeviceError}.MEDIA_DEVICE_ERROR_DEVICENOTFOUND instead.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_NO_RECORDING_DEVICE"] = 27] = "WARNING_CODE_NO_RECORDING_DEVICE";
    /** {en}
     * @platform android
     * @brief No audio playback device available. <br>
     *        Failed to start the audio playback device, please insert the available audio playback device.
     * @deprecated since 3.45 and will be deleted in 3.51, use {@link MediaDeviceError MediaDeviceError}.MEDIA_DEVICE_ERROR_DEVICENOTFOUND instead.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_NO_PLAYOUT_DEVICE"] = 28] = "WARNING_CODE_NO_PLAYOUT_DEVICE";
    /** {en}
     * @platform android
     * @brief The current audio equipment has not collected valid sound data, please check and replace the audio acquisition equipment.
     * @deprecated since 3.45 and will be deleted in 3.51, use {@link MediaDeviceWarning MediaDeviceWarning}.MEDIA_DEVICE_WARNING_CAPTURE_SILENCE instead.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_RECORDING_SILENCE"] = 29] = "WARNING_CODE_RECORDING_SILENCE";
    /** {en}
     * @platform android
     * @brief Media device misoperation warning. <br>
     *        When using custom acquisition, the internal acquisition switch cannot be called, and this warning will be triggered when called.
     * @deprecated since 3.45 and will be deleted in 3.51, use {@link MediaDeviceWarning MediaDeviceWarning}.MEDIA_DEVICE_WARNING_OPERATION_DENIED instead.
     *
     */
    WarningCode[WarningCode["WARNING_CODE_MEDIA_DEVICE_OPERATION_DENIED"] = 30] = "WARNING_CODE_MEDIA_DEVICE_OPERATION_DENIED";
    WarningCode[WarningCode["ByteRTCWarningCodeJoinRoomFailed"] = 31] = "ByteRTCWarningCodeJoinRoomFailed";
    WarningCode[WarningCode["ByteRTCWarningCodePublishStreamFailed"] = 32] = "ByteRTCWarningCodePublishStreamFailed";
    WarningCode[WarningCode["ByteRTCWarningCodeSubscribeStreamFailed404"] = 33] = "ByteRTCWarningCodeSubscribeStreamFailed404";
    WarningCode[WarningCode["ByteRTCWarningCodeSubscribeStreamFailed5xx"] = 34] = "ByteRTCWarningCodeSubscribeStreamFailed5xx";
    WarningCode[WarningCode["ByteRTCWarningCodePublishStreamForbiden"] = 37] = "ByteRTCWarningCodePublishStreamForbiden";
    WarningCode[WarningCode["ByteRTCWarningCodeSendCustomMessage"] = 38] = "ByteRTCWarningCodeSendCustomMessage";
    WarningCode[WarningCode["ByteRTCWarningCodeCodeUserNotifyStop"] = 39] = "ByteRTCWarningCodeCodeUserNotifyStop";
    WarningCode[WarningCode["ByteRTCWarningCodeUserInPublish"] = 40] = "ByteRTCWarningCodeUserInPublish";
    WarningCode[WarningCode["ByteRTCWarningCodeOldRoomBeenReplaced"] = 41] = "ByteRTCWarningCodeOldRoomBeenReplaced";
    WarningCode[WarningCode["ByteRTCWarningCodeInEchoTestMode"] = 42] = "ByteRTCWarningCodeInEchoTestMode";
    WarningCode[WarningCode["ByteRTCWarningCodeNoCameraPermission"] = 43] = "ByteRTCWarningCodeNoCameraPermission";
    WarningCode[WarningCode["ByteRTCWarningSetScreenAudioSourceTypeFailed"] = 44] = "ByteRTCWarningSetScreenAudioSourceTypeFailed";
    WarningCode[WarningCode["ByteRTCWarningSetScreenAudioStreamIndexFailed"] = 45] = "ByteRTCWarningSetScreenAudioStreamIndexFailed";
    WarningCode[WarningCode["ByteRTCWarningInvalidVoicePitch"] = 46] = "ByteRTCWarningInvalidVoicePitch";
    WarningCode[WarningCode["ByteRTCWarningInvalidCallForExtAudio"] = 47] = "ByteRTCWarningInvalidCallForExtAudio";
    WarningCode[WarningCode["ByteRTCWarningCodeInvalidCanvasHandle"] = 48] = "ByteRTCWarningCodeInvalidCanvasHandle";
    WarningCode[WarningCode["ByteRTCWarningCodeInvaildSamiAppkeyORToken"] = 49] = "ByteRTCWarningCodeInvaildSamiAppkeyORToken";
    WarningCode[WarningCode["ByteRTCWarningCodeInvaildSamiResourcePath"] = 50] = "ByteRTCWarningCodeInvaildSamiResourcePath";
    WarningCode[WarningCode["ByteRTCWarningCodeLoadSamiLibraryFailed"] = 51] = "ByteRTCWarningCodeLoadSamiLibraryFailed";
    WarningCode[WarningCode["ByteRTCWarningCodeInvaildSamiEffectType"] = 52] = "ByteRTCWarningCodeInvaildSamiEffectType";
    WarningCode[WarningCode["ByteRTCWarningCodeGetRoomFailed"] = 53] = "ByteRTCWarningCodeGetRoomFailed";
    WarningCode[WarningCode["ByteRTCWarningCodeSubscribeStreamForbiden"] = 54] = "ByteRTCWarningCodeSubscribeStreamForbiden";
    WarningCode[WarningCode["ByteRTCWarningCodeRoomAlreadyExist"] = 55] = "ByteRTCWarningCodeRoomAlreadyExist";
    WarningCode[WarningCode["ByteRTCWarningCodeNoMicrophonePermission"] = 56] = "ByteRTCWarningCodeNoMicrophonePermission";
    WarningCode[WarningCode["ByteRTCWarningCodeAudioDeviceManagerRecordingStartFail"] = 57] = "ByteRTCWarningCodeAudioDeviceManagerRecordingStartFail";
    WarningCode[WarningCode["ByteRTCWarningCodeAudioDeviceManagerPlayoutStartFail"] = 58] = "ByteRTCWarningCodeAudioDeviceManagerPlayoutStartFail";
    WarningCode[WarningCode["ByteRTCWarningCodeNoRecordingDevice"] = 59] = "ByteRTCWarningCodeNoRecordingDevice";
    WarningCode[WarningCode["ByteRTCWarningCodeNoPlayoutDevice"] = 60] = "ByteRTCWarningCodeNoPlayoutDevice";
    WarningCode[WarningCode["ByteRTCWarningCodeRecordingSilence"] = 61] = "ByteRTCWarningCodeRecordingSilence";
    WarningCode[WarningCode["ByteRTCWarningCodeMediaDeviceOperationDennied"] = 62] = "ByteRTCWarningCodeMediaDeviceOperationDennied";
})(exports.WarningCode || (exports.WarningCode = {}));
exports.RoomMessageSendResult = void 0;
(function (RoomMessageSendResult) {
    /** {en}
     * @platform android
     * @brief Success
     *
     */
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_SUCCESS"] = 0] = "ROOM_MESSAGE_SEND_RESULT_SUCCESS";
    /** {en}
     * @platform android
     * @brief Failure. Exceeds QPS limit.
     *
     */
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_EXCEED_QPS"] = 1] = "ROOM_MESSAGE_SEND_RESULT_EXCEED_QPS";
    /** {en}
     * @platform android
     * @brief Failure. The sender of the message is not in the room.
     *
     */
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_NOT_JOIN"] = 2] = "ROOM_MESSAGE_SEND_RESULT_NOT_JOIN";
    /** {en}
     * @platform android
     * @brief Failure. The connection is not initialized.
     *
     */
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_INIT"] = 3] = "ROOM_MESSAGE_SEND_RESULT_INIT";
    /** {en}
     * @platform android
     * @brief Failure. No data transmission channel connection available.
     *
     */
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_NO_CONNECTION"] = 4] = "ROOM_MESSAGE_SEND_RESULT_NO_CONNECTION";
    /** {en}
     * @platform android
     * @brief Failure. Message exceeds 64KB.
     *
     */
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH"] = 5] = "ROOM_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH";
    /** {en}
     * @platform android
     * @brief Failure. Unknown error.
     *
     */
    RoomMessageSendResult[RoomMessageSendResult["ROOM_MESSAGE_SEND_RESULT_UNKNOWN"] = 6] = "ROOM_MESSAGE_SEND_RESULT_UNKNOWN";
    RoomMessageSendResult[RoomMessageSendResult["ByteRTCRoomMessageSendResultSuccess"] = 7] = "ByteRTCRoomMessageSendResultSuccess";
    RoomMessageSendResult[RoomMessageSendResult["ByteRTCRoomMessageSendResultTimeout"] = 8] = "ByteRTCRoomMessageSendResultTimeout";
    RoomMessageSendResult[RoomMessageSendResult["ByteRTCRoomMessageSendResultNetworkDisconnected"] = 9] = "ByteRTCRoomMessageSendResultNetworkDisconnected";
    RoomMessageSendResult[RoomMessageSendResult["ByteRTCRoomMessageSendResultExceedQPS"] = 10] = "ByteRTCRoomMessageSendResultExceedQPS";
    RoomMessageSendResult[RoomMessageSendResult["ByteRTCRoomMessageSendResultNotJoin"] = 11] = "ByteRTCRoomMessageSendResultNotJoin";
    RoomMessageSendResult[RoomMessageSendResult["ByteRTCRoomMessageSendResultInit"] = 12] = "ByteRTCRoomMessageSendResultInit";
    RoomMessageSendResult[RoomMessageSendResult["ByteRTCRoomMessageSendResultNoConnection"] = 13] = "ByteRTCRoomMessageSendResultNoConnection";
    RoomMessageSendResult[RoomMessageSendResult["ByteRTCRoomMessageSendResultExceedMaxLength"] = 14] = "ByteRTCRoomMessageSendResultExceedMaxLength";
    RoomMessageSendResult[RoomMessageSendResult["ByteRTCRoomMessageSendResultUnknown"] = 15] = "ByteRTCRoomMessageSendResultUnknown";
})(exports.RoomMessageSendResult || (exports.RoomMessageSendResult = {}));
exports.LoginErrorCode = void 0;
(function (LoginErrorCode) {
    /** {en}
     * @platform android
     * @brief Call the `login` method to log in successfully.
     *
     */
    LoginErrorCode[LoginErrorCode["LOGIN_ERROR_CODE_SUCCESS"] = 0] = "LOGIN_ERROR_CODE_SUCCESS";
    /** {en}
     * @platform android
     * @brief The Token used when calling the `login` method is invalid or expired. The user is required to re-acquire the token.
     *
     */
    LoginErrorCode[LoginErrorCode["LOGIN_ERROR_CODE_INVALID_TOKEN"] = 1] = "LOGIN_ERROR_CODE_INVALID_TOKEN";
    /** {en}
     * @platform android
     * @brief Login error. <br>
     *        An unknown error occurred when calling the `login` method, which caused the login to fail and requires re-login.
     *
     */
    LoginErrorCode[LoginErrorCode["LOGIN_ERROR_CODE_LOGIN_FAILED"] = 2] = "LOGIN_ERROR_CODE_LOGIN_FAILED";
    /** {en}
     * @platform android
     * @brief There was a problem with the user ID passed in when the `login` method was called.
     *
     */
    LoginErrorCode[LoginErrorCode["LOGIN_ERROR_CODE_INVALID_USER_ID"] = 3] = "LOGIN_ERROR_CODE_INVALID_USER_ID";
    /** {en}
     * @platform android
     * @brief Server error when calling `login` to log in.
     *
     */
    LoginErrorCode[LoginErrorCode["LOGIN_ERROR_CODE_SERVER_ERROR"] = 4] = "LOGIN_ERROR_CODE_SERVER_ERROR";
    LoginErrorCode[LoginErrorCode["ByteRTCLoginErrorCodeSuccess"] = 5] = "ByteRTCLoginErrorCodeSuccess";
    LoginErrorCode[LoginErrorCode["ByteRTCLoginErrorCodeInvalidToken"] = 6] = "ByteRTCLoginErrorCodeInvalidToken";
    LoginErrorCode[LoginErrorCode["ByteRTCLoginErrorCodeLoginFailed"] = 7] = "ByteRTCLoginErrorCodeLoginFailed";
    LoginErrorCode[LoginErrorCode["ByteRTCLoginErrorCodeInvalidUserId"] = 8] = "ByteRTCLoginErrorCodeInvalidUserId";
    LoginErrorCode[LoginErrorCode["ByteRTCLoginErrorCodeServerError"] = 9] = "ByteRTCLoginErrorCodeServerError";
})(exports.LoginErrorCode || (exports.LoginErrorCode = {}));
var t_WarningCode = /** @class */ (function () {
    function t_WarningCode() {
    }
    t_WarningCode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.WarningCode.WARNING_CODE_JOIN_ROOM_FAILED] = WarningCode.WARNING_CODE_JOIN_ROOM_FAILED,
            _a[exports.WarningCode.WARNING_CODE_PUBLISH_STREAM_FAILED] = WarningCode.WARNING_CODE_PUBLISH_STREAM_FAILED,
            _a[exports.WarningCode.WARNING_CODE_SUBSCRIBE_STREAM_FAILED404] = WarningCode.WARNING_CODE_SUBSCRIBE_STREAM_FAILED404,
            _a[exports.WarningCode.WARNING_CODE_SUBSCRIBE_STREAM_FAILED5XX] = WarningCode.WARNING_CODE_SUBSCRIBE_STREAM_FAILED5XX,
            _a[exports.WarningCode.WARNING_CODE_PUBLISH_STREAM_FORBIDEN] = WarningCode.WARNING_CODE_PUBLISH_STREAM_FORBIDEN,
            _a[exports.WarningCode.WARNING_CODE_SEND_CUSTOM_MESSAGE] = WarningCode.WARNING_CODE_SEND_CUSTOM_MESSAGE,
            _a[exports.WarningCode.WARNING_CODE_RECEIVE_USER_NOTIFY_STOP] = WarningCode.WARNING_CODE_RECEIVE_USER_NOTIFY_STOP,
            _a[exports.WarningCode.WARNING_CODE_USER_IN_PUBLISH] = WarningCode.WARNING_CODE_USER_IN_PUBLISH,
            _a[exports.WarningCode.WARNING_CODE_OLD_ROOM_BEEN_REPLACED] = WarningCode.WARNING_CODE_OLD_ROOM_BEEN_REPLACED,
            _a[exports.WarningCode.WARNING_CODE_IN_ECHO_TEST_MODE] = WarningCode.WARNING_CODE_IN_ECHO_TEST_MODE,
            _a[exports.WarningCode.WARNING_CODE_NO_CAMERA_PERMISSION] = WarningCode.WARNING_CODE_NO_CAMERA_PERMISSION,
            _a[exports.WarningCode.WARNING_CODE_SET_SCREEN_AUDIO_SOURCE_TYPE_FAILED] = WarningCode.WARNING_CODE_SET_SCREEN_AUDIO_SOURCE_TYPE_FAILED,
            _a[exports.WarningCode.WARNING_CODE_SET_SCREEN_STREAM_INDEX_FAILED] = WarningCode.WARNING_CODE_SET_SCREEN_STREAM_INDEX_FAILED,
            _a[exports.WarningCode.WARNING_CODE_SET_SCREEN_STREAM_INVALID_VOICE_PITCH] = WarningCode.WARNING_CODE_SET_SCREEN_STREAM_INVALID_VOICE_PITCH,
            _a[exports.WarningCode.WARNING_CODE_INVALID_CALL_FOR_EXT_AUDIO] = WarningCode.WARNING_CODE_INVALID_CALL_FOR_EXT_AUDIO,
            _a[exports.WarningCode.WARNING_CODE_INVALID_SAMI_APPKEY_OR_TOKEN] = WarningCode.WARNING_CODE_INVALID_SAMI_APPKEY_OR_TOKEN,
            _a[exports.WarningCode.WARNING_CODE_INVALID_RESOURCE_PATH] = WarningCode.WARNING_CODE_INVALID_RESOURCE_PATH,
            _a[exports.WarningCode.WARNING_CODE_LOAD_SAMI_LIBRARY_FAILED] = WarningCode.WARNING_CODE_LOAD_SAMI_LIBRARY_FAILED,
            _a[exports.WarningCode.WARNING_CODE_INVALID_SAMI_EFFECT_TYPE] = WarningCode.WARNING_CODE_INVALID_SAMI_EFFECT_TYPE,
            _a[exports.WarningCode.WARNING_CODE_GET_ROOM_FAILED] = WarningCode.WARNING_CODE_GET_ROOM_FAILED,
            _a[exports.WarningCode.WARNING_CODE_SUBSCRIBE_STREAM_FORBIDEN] = WarningCode.WARNING_CODE_SUBSCRIBE_STREAM_FORBIDEN,
            _a[exports.WarningCode.WARNING_CODE_ROOM_ID_ALREADY_EXIST] = WarningCode.WARNING_CODE_ROOM_ID_ALREADY_EXIST,
            _a[exports.WarningCode.WARNING_CODE_NO_MICROPHONE_PERMISSION] = WarningCode.WARNING_CODE_NO_MICROPHONE_PERMISSION,
            _a[exports.WarningCode.WARNING_CODE_RECODING_DEVICE_START_FAILED] = WarningCode.WARNING_CODE_RECODING_DEVICE_START_FAILED,
            _a[exports.WarningCode.WARNING_CODE_PLAYOUT_DEVICE_START_FAILED] = WarningCode.WARNING_CODE_PLAYOUT_DEVICE_START_FAILED,
            _a[exports.WarningCode.WARNING_CODE_NO_RECORDING_DEVICE] = WarningCode.WARNING_CODE_NO_RECORDING_DEVICE,
            _a[exports.WarningCode.WARNING_CODE_NO_PLAYOUT_DEVICE] = WarningCode.WARNING_CODE_NO_PLAYOUT_DEVICE,
            _a[exports.WarningCode.WARNING_CODE_RECORDING_SILENCE] = WarningCode.WARNING_CODE_RECORDING_SILENCE,
            _a[exports.WarningCode.WARNING_CODE_MEDIA_DEVICE_OPERATION_DENIED] = WarningCode.WARNING_CODE_MEDIA_DEVICE_OPERATION_DENIED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_WarningCode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[WarningCode.WARNING_CODE_JOIN_ROOM_FAILED] = exports.WarningCode.WARNING_CODE_JOIN_ROOM_FAILED,
            _a[WarningCode.WARNING_CODE_PUBLISH_STREAM_FAILED] = exports.WarningCode.WARNING_CODE_PUBLISH_STREAM_FAILED,
            _a[WarningCode.WARNING_CODE_SUBSCRIBE_STREAM_FAILED404] = exports.WarningCode.WARNING_CODE_SUBSCRIBE_STREAM_FAILED404,
            _a[WarningCode.WARNING_CODE_SUBSCRIBE_STREAM_FAILED5XX] = exports.WarningCode.WARNING_CODE_SUBSCRIBE_STREAM_FAILED5XX,
            _a[WarningCode.WARNING_CODE_PUBLISH_STREAM_FORBIDEN] = exports.WarningCode.WARNING_CODE_PUBLISH_STREAM_FORBIDEN,
            _a[WarningCode.WARNING_CODE_SEND_CUSTOM_MESSAGE] = exports.WarningCode.WARNING_CODE_SEND_CUSTOM_MESSAGE,
            _a[WarningCode.WARNING_CODE_RECEIVE_USER_NOTIFY_STOP] = exports.WarningCode.WARNING_CODE_RECEIVE_USER_NOTIFY_STOP,
            _a[WarningCode.WARNING_CODE_USER_IN_PUBLISH] = exports.WarningCode.WARNING_CODE_USER_IN_PUBLISH,
            _a[WarningCode.WARNING_CODE_OLD_ROOM_BEEN_REPLACED] = exports.WarningCode.WARNING_CODE_OLD_ROOM_BEEN_REPLACED,
            _a[WarningCode.WARNING_CODE_IN_ECHO_TEST_MODE] = exports.WarningCode.WARNING_CODE_IN_ECHO_TEST_MODE,
            _a[WarningCode.WARNING_CODE_NO_CAMERA_PERMISSION] = exports.WarningCode.WARNING_CODE_NO_CAMERA_PERMISSION,
            _a[WarningCode.WARNING_CODE_SET_SCREEN_AUDIO_SOURCE_TYPE_FAILED] = exports.WarningCode.WARNING_CODE_SET_SCREEN_AUDIO_SOURCE_TYPE_FAILED,
            _a[WarningCode.WARNING_CODE_SET_SCREEN_STREAM_INDEX_FAILED] = exports.WarningCode.WARNING_CODE_SET_SCREEN_STREAM_INDEX_FAILED,
            _a[WarningCode.WARNING_CODE_SET_SCREEN_STREAM_INVALID_VOICE_PITCH] = exports.WarningCode.WARNING_CODE_SET_SCREEN_STREAM_INVALID_VOICE_PITCH,
            _a[WarningCode.WARNING_CODE_INVALID_CALL_FOR_EXT_AUDIO] = exports.WarningCode.WARNING_CODE_INVALID_CALL_FOR_EXT_AUDIO,
            _a[WarningCode.WARNING_CODE_INVALID_SAMI_APPKEY_OR_TOKEN] = exports.WarningCode.WARNING_CODE_INVALID_SAMI_APPKEY_OR_TOKEN,
            _a[WarningCode.WARNING_CODE_INVALID_RESOURCE_PATH] = exports.WarningCode.WARNING_CODE_INVALID_RESOURCE_PATH,
            _a[WarningCode.WARNING_CODE_LOAD_SAMI_LIBRARY_FAILED] = exports.WarningCode.WARNING_CODE_LOAD_SAMI_LIBRARY_FAILED,
            _a[WarningCode.WARNING_CODE_INVALID_SAMI_EFFECT_TYPE] = exports.WarningCode.WARNING_CODE_INVALID_SAMI_EFFECT_TYPE,
            _a[WarningCode.WARNING_CODE_GET_ROOM_FAILED] = exports.WarningCode.WARNING_CODE_GET_ROOM_FAILED,
            _a[WarningCode.WARNING_CODE_SUBSCRIBE_STREAM_FORBIDEN] = exports.WarningCode.WARNING_CODE_SUBSCRIBE_STREAM_FORBIDEN,
            _a[WarningCode.WARNING_CODE_ROOM_ID_ALREADY_EXIST] = exports.WarningCode.WARNING_CODE_ROOM_ID_ALREADY_EXIST,
            _a[WarningCode.WARNING_CODE_NO_MICROPHONE_PERMISSION] = exports.WarningCode.WARNING_CODE_NO_MICROPHONE_PERMISSION,
            _a[WarningCode.WARNING_CODE_RECODING_DEVICE_START_FAILED] = exports.WarningCode.WARNING_CODE_RECODING_DEVICE_START_FAILED,
            _a[WarningCode.WARNING_CODE_PLAYOUT_DEVICE_START_FAILED] = exports.WarningCode.WARNING_CODE_PLAYOUT_DEVICE_START_FAILED,
            _a[WarningCode.WARNING_CODE_NO_RECORDING_DEVICE] = exports.WarningCode.WARNING_CODE_NO_RECORDING_DEVICE,
            _a[WarningCode.WARNING_CODE_NO_PLAYOUT_DEVICE] = exports.WarningCode.WARNING_CODE_NO_PLAYOUT_DEVICE,
            _a[WarningCode.WARNING_CODE_RECORDING_SILENCE] = exports.WarningCode.WARNING_CODE_RECORDING_SILENCE,
            _a[WarningCode.WARNING_CODE_MEDIA_DEVICE_OPERATION_DENIED] = exports.WarningCode.WARNING_CODE_MEDIA_DEVICE_OPERATION_DENIED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_WarningCode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.WarningCode.ByteRTCWarningCodeJoinRoomFailed] = ByteRTCWarningCode.ByteRTCWarningCodeJoinRoomFailed,
            _a[exports.WarningCode.ByteRTCWarningCodePublishStreamFailed] = ByteRTCWarningCode.ByteRTCWarningCodePublishStreamFailed,
            _a[exports.WarningCode.ByteRTCWarningCodeSubscribeStreamFailed404] = ByteRTCWarningCode.ByteRTCWarningCodeSubscribeStreamFailed404,
            _a[exports.WarningCode.ByteRTCWarningCodeSubscribeStreamFailed5xx] = ByteRTCWarningCode.ByteRTCWarningCodeSubscribeStreamFailed5xx,
            _a[exports.WarningCode.ByteRTCWarningCodePublishStreamForbiden] = ByteRTCWarningCode.ByteRTCWarningCodePublishStreamForbiden,
            _a[exports.WarningCode.ByteRTCWarningCodeSendCustomMessage] = ByteRTCWarningCode.ByteRTCWarningCodeSendCustomMessage,
            _a[exports.WarningCode.ByteRTCWarningCodeCodeUserNotifyStop] = ByteRTCWarningCode.ByteRTCWarningCodeCodeUserNotifyStop,
            _a[exports.WarningCode.ByteRTCWarningCodeUserInPublish] = ByteRTCWarningCode.ByteRTCWarningCodeUserInPublish,
            _a[exports.WarningCode.ByteRTCWarningCodeOldRoomBeenReplaced] = ByteRTCWarningCode.ByteRTCWarningCodeOldRoomBeenReplaced,
            _a[exports.WarningCode.ByteRTCWarningCodeInEchoTestMode] = ByteRTCWarningCode.ByteRTCWarningCodeInEchoTestMode,
            _a[exports.WarningCode.ByteRTCWarningCodeNoCameraPermission] = ByteRTCWarningCode.ByteRTCWarningCodeNoCameraPermission,
            _a[exports.WarningCode.ByteRTCWarningSetScreenAudioSourceTypeFailed] = ByteRTCWarningCode.ByteRTCWarningSetScreenAudioSourceTypeFailed,
            _a[exports.WarningCode.ByteRTCWarningSetScreenAudioStreamIndexFailed] = ByteRTCWarningCode.ByteRTCWarningSetScreenAudioStreamIndexFailed,
            _a[exports.WarningCode.ByteRTCWarningInvalidVoicePitch] = ByteRTCWarningCode.ByteRTCWarningInvalidVoicePitch,
            _a[exports.WarningCode.ByteRTCWarningInvalidCallForExtAudio] = ByteRTCWarningCode.ByteRTCWarningInvalidCallForExtAudio,
            _a[exports.WarningCode.ByteRTCWarningCodeInvalidCanvasHandle] = ByteRTCWarningCode.ByteRTCWarningCodeInvalidCanvasHandle,
            _a[exports.WarningCode.ByteRTCWarningCodeInvaildSamiAppkeyORToken] = ByteRTCWarningCode.ByteRTCWarningCodeInvaildSamiAppkeyORToken,
            _a[exports.WarningCode.ByteRTCWarningCodeInvaildSamiResourcePath] = ByteRTCWarningCode.ByteRTCWarningCodeInvaildSamiResourcePath,
            _a[exports.WarningCode.ByteRTCWarningCodeLoadSamiLibraryFailed] = ByteRTCWarningCode.ByteRTCWarningCodeLoadSamiLibraryFailed,
            _a[exports.WarningCode.ByteRTCWarningCodeInvaildSamiEffectType] = ByteRTCWarningCode.ByteRTCWarningCodeInvaildSamiEffectType,
            _a[exports.WarningCode.ByteRTCWarningCodeGetRoomFailed] = ByteRTCWarningCode.ByteRTCWarningCodeGetRoomFailed,
            _a[exports.WarningCode.ByteRTCWarningCodeSubscribeStreamForbiden] = ByteRTCWarningCode.ByteRTCWarningCodeSubscribeStreamForbiden,
            _a[exports.WarningCode.ByteRTCWarningCodeRoomAlreadyExist] = ByteRTCWarningCode.ByteRTCWarningCodeRoomAlreadyExist,
            _a[exports.WarningCode.ByteRTCWarningCodeNoMicrophonePermission] = ByteRTCWarningCode.ByteRTCWarningCodeNoMicrophonePermission,
            _a[exports.WarningCode.ByteRTCWarningCodeAudioDeviceManagerRecordingStartFail] = ByteRTCWarningCode.ByteRTCWarningCodeAudioDeviceManagerRecordingStartFail,
            _a[exports.WarningCode.ByteRTCWarningCodeAudioDeviceManagerPlayoutStartFail] = ByteRTCWarningCode.ByteRTCWarningCodeAudioDeviceManagerPlayoutStartFail,
            _a[exports.WarningCode.ByteRTCWarningCodeNoRecordingDevice] = ByteRTCWarningCode.ByteRTCWarningCodeNoRecordingDevice,
            _a[exports.WarningCode.ByteRTCWarningCodeNoPlayoutDevice] = ByteRTCWarningCode.ByteRTCWarningCodeNoPlayoutDevice,
            _a[exports.WarningCode.ByteRTCWarningCodeRecordingSilence] = ByteRTCWarningCode.ByteRTCWarningCodeRecordingSilence,
            _a[exports.WarningCode.ByteRTCWarningCodeMediaDeviceOperationDennied] = ByteRTCWarningCode.ByteRTCWarningCodeMediaDeviceOperationDennied,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_WarningCode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCWarningCode.ByteRTCWarningCodeJoinRoomFailed] = exports.WarningCode.ByteRTCWarningCodeJoinRoomFailed,
            _a[ByteRTCWarningCode.ByteRTCWarningCodePublishStreamFailed] = exports.WarningCode.ByteRTCWarningCodePublishStreamFailed,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeSubscribeStreamFailed404] = exports.WarningCode.ByteRTCWarningCodeSubscribeStreamFailed404,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeSubscribeStreamFailed5xx] = exports.WarningCode.ByteRTCWarningCodeSubscribeStreamFailed5xx,
            _a[ByteRTCWarningCode.ByteRTCWarningCodePublishStreamForbiden] = exports.WarningCode.ByteRTCWarningCodePublishStreamForbiden,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeSendCustomMessage] = exports.WarningCode.ByteRTCWarningCodeSendCustomMessage,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeCodeUserNotifyStop] = exports.WarningCode.ByteRTCWarningCodeCodeUserNotifyStop,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeUserInPublish] = exports.WarningCode.ByteRTCWarningCodeUserInPublish,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeOldRoomBeenReplaced] = exports.WarningCode.ByteRTCWarningCodeOldRoomBeenReplaced,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeInEchoTestMode] = exports.WarningCode.ByteRTCWarningCodeInEchoTestMode,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeNoCameraPermission] = exports.WarningCode.ByteRTCWarningCodeNoCameraPermission,
            _a[ByteRTCWarningCode.ByteRTCWarningSetScreenAudioSourceTypeFailed] = exports.WarningCode.ByteRTCWarningSetScreenAudioSourceTypeFailed,
            _a[ByteRTCWarningCode.ByteRTCWarningSetScreenAudioStreamIndexFailed] = exports.WarningCode.ByteRTCWarningSetScreenAudioStreamIndexFailed,
            _a[ByteRTCWarningCode.ByteRTCWarningInvalidVoicePitch] = exports.WarningCode.ByteRTCWarningInvalidVoicePitch,
            _a[ByteRTCWarningCode.ByteRTCWarningInvalidCallForExtAudio] = exports.WarningCode.ByteRTCWarningInvalidCallForExtAudio,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeInvalidCanvasHandle] = exports.WarningCode.ByteRTCWarningCodeInvalidCanvasHandle,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeInvaildSamiAppkeyORToken] = exports.WarningCode.ByteRTCWarningCodeInvaildSamiAppkeyORToken,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeInvaildSamiResourcePath] = exports.WarningCode.ByteRTCWarningCodeInvaildSamiResourcePath,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeLoadSamiLibraryFailed] = exports.WarningCode.ByteRTCWarningCodeLoadSamiLibraryFailed,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeInvaildSamiEffectType] = exports.WarningCode.ByteRTCWarningCodeInvaildSamiEffectType,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeGetRoomFailed] = exports.WarningCode.ByteRTCWarningCodeGetRoomFailed,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeSubscribeStreamForbiden] = exports.WarningCode.ByteRTCWarningCodeSubscribeStreamForbiden,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeRoomAlreadyExist] = exports.WarningCode.ByteRTCWarningCodeRoomAlreadyExist,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeNoMicrophonePermission] = exports.WarningCode.ByteRTCWarningCodeNoMicrophonePermission,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeAudioDeviceManagerRecordingStartFail] = exports.WarningCode.ByteRTCWarningCodeAudioDeviceManagerRecordingStartFail,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeAudioDeviceManagerPlayoutStartFail] = exports.WarningCode.ByteRTCWarningCodeAudioDeviceManagerPlayoutStartFail,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeNoRecordingDevice] = exports.WarningCode.ByteRTCWarningCodeNoRecordingDevice,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeNoPlayoutDevice] = exports.WarningCode.ByteRTCWarningCodeNoPlayoutDevice,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeRecordingSilence] = exports.WarningCode.ByteRTCWarningCodeRecordingSilence,
            _a[ByteRTCWarningCode.ByteRTCWarningCodeMediaDeviceOperationDennied] = exports.WarningCode.ByteRTCWarningCodeMediaDeviceOperationDennied,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_WarningCode;
}());
var t_ErrorCode = /** @class */ (function () {
    function t_ErrorCode() {
    }
    t_ErrorCode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ErrorCode.ERROR_CODE_INVALID_TOKEN] = ErrorCode.ERROR_CODE_INVALID_TOKEN,
            _a[exports.ErrorCode.ERROR_CODE_JOIN_ROOM] = ErrorCode.ERROR_CODE_JOIN_ROOM,
            _a[exports.ErrorCode.ERROR_CODE_NO_PUBLISH_PERMISSION] = ErrorCode.ERROR_CODE_NO_PUBLISH_PERMISSION,
            _a[exports.ErrorCode.ERROR_CODE_NO_SUBSCRIBE_PERMISSION] = ErrorCode.ERROR_CODE_NO_SUBSCRIBE_PERMISSION,
            _a[exports.ErrorCode.ERROR_CODE_DUPLICATE_LOGIN] = ErrorCode.ERROR_CODE_DUPLICATE_LOGIN,
            _a[exports.ErrorCode.ERROR_CODE_APP_ID_NULL] = ErrorCode.ERROR_CODE_APP_ID_NULL,
            _a[exports.ErrorCode.ERROR_CODE_KICKED_OUT] = ErrorCode.ERROR_CODE_KICKED_OUT,
            _a[exports.ErrorCode.ERROR_CODE_ROOM_ID_ILLEGAL] = ErrorCode.ERROR_CODE_ROOM_ID_ILLEGAL,
            _a[exports.ErrorCode.ERROR_CODE_TOKEN_EXPIRED] = ErrorCode.ERROR_CODE_TOKEN_EXPIRED,
            _a[exports.ErrorCode.ERROR_CODE_UPDATE_TOKEN_WITH_INVALID_TOKEN] = ErrorCode.ERROR_CODE_UPDATE_TOKEN_WITH_INVALID_TOKEN,
            _a[exports.ErrorCode.ERROR_CODE_ROOM_DISMISS] = ErrorCode.ERROR_CODE_ROOM_DISMISS,
            _a[exports.ErrorCode.ERROR_CODE_ROOM_ALREADY_EXIST] = ErrorCode.ERROR_CODE_ROOM_ALREADY_EXIST,
            _a[exports.ErrorCode.ERROR_CODE_USER_ID_DIFFERENT] = ErrorCode.ERROR_CODE_USER_ID_DIFFERENT,
            _a[exports.ErrorCode.ERROR_CODE_JOIN_ROOM_ROOM_FORBIDDEN] = ErrorCode.ERROR_CODE_JOIN_ROOM_ROOM_FORBIDDEN,
            _a[exports.ErrorCode.ERROR_CODE_JOIN_ROOM_USER_FORBIDDEN] = ErrorCode.ERROR_CODE_JOIN_ROOM_USER_FORBIDDEN,
            _a[exports.ErrorCode.ERROR_CODE_OVER_SUBSCRIBE_LIMIT] = ErrorCode.ERROR_CODE_OVER_SUBSCRIBE_LIMIT,
            _a[exports.ErrorCode.ERROR_CODE_OVER_STREAM_PUBLISH_LIMIT] = ErrorCode.ERROR_CODE_OVER_STREAM_PUBLISH_LIMIT,
            _a[exports.ErrorCode.ERROR_CODE_INVALID_AUDIO_SYNC_USERID_REPEATED] = ErrorCode.ERROR_CODE_INVALID_AUDIO_SYNC_USERID_REPEATED,
            _a[exports.ErrorCode.ERROR_CODE_ABNORMAL_SERVER_STATUS] = ErrorCode.ERROR_CODE_ABNORMAL_SERVER_STATUS,
            _a[exports.ErrorCode.ERROR_CODE_OVER_SCREEN_PUBLISH_LIMIT] = ErrorCode.ERROR_CODE_OVER_SCREEN_PUBLISH_LIMIT,
            _a[exports.ErrorCode.ERROR_CODE_OVER_VIDEO_PUBLISH_LIMIT] = ErrorCode.ERROR_CODE_OVER_VIDEO_PUBLISH_LIMIT,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ErrorCode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ErrorCode.ERROR_CODE_INVALID_TOKEN] = exports.ErrorCode.ERROR_CODE_INVALID_TOKEN,
            _a[ErrorCode.ERROR_CODE_JOIN_ROOM] = exports.ErrorCode.ERROR_CODE_JOIN_ROOM,
            _a[ErrorCode.ERROR_CODE_NO_PUBLISH_PERMISSION] = exports.ErrorCode.ERROR_CODE_NO_PUBLISH_PERMISSION,
            _a[ErrorCode.ERROR_CODE_NO_SUBSCRIBE_PERMISSION] = exports.ErrorCode.ERROR_CODE_NO_SUBSCRIBE_PERMISSION,
            _a[ErrorCode.ERROR_CODE_DUPLICATE_LOGIN] = exports.ErrorCode.ERROR_CODE_DUPLICATE_LOGIN,
            _a[ErrorCode.ERROR_CODE_APP_ID_NULL] = exports.ErrorCode.ERROR_CODE_APP_ID_NULL,
            _a[ErrorCode.ERROR_CODE_KICKED_OUT] = exports.ErrorCode.ERROR_CODE_KICKED_OUT,
            _a[ErrorCode.ERROR_CODE_ROOM_ID_ILLEGAL] = exports.ErrorCode.ERROR_CODE_ROOM_ID_ILLEGAL,
            _a[ErrorCode.ERROR_CODE_TOKEN_EXPIRED] = exports.ErrorCode.ERROR_CODE_TOKEN_EXPIRED,
            _a[ErrorCode.ERROR_CODE_UPDATE_TOKEN_WITH_INVALID_TOKEN] = exports.ErrorCode.ERROR_CODE_UPDATE_TOKEN_WITH_INVALID_TOKEN,
            _a[ErrorCode.ERROR_CODE_ROOM_DISMISS] = exports.ErrorCode.ERROR_CODE_ROOM_DISMISS,
            _a[ErrorCode.ERROR_CODE_ROOM_ALREADY_EXIST] = exports.ErrorCode.ERROR_CODE_ROOM_ALREADY_EXIST,
            _a[ErrorCode.ERROR_CODE_USER_ID_DIFFERENT] = exports.ErrorCode.ERROR_CODE_USER_ID_DIFFERENT,
            _a[ErrorCode.ERROR_CODE_JOIN_ROOM_ROOM_FORBIDDEN] = exports.ErrorCode.ERROR_CODE_JOIN_ROOM_ROOM_FORBIDDEN,
            _a[ErrorCode.ERROR_CODE_JOIN_ROOM_USER_FORBIDDEN] = exports.ErrorCode.ERROR_CODE_JOIN_ROOM_USER_FORBIDDEN,
            _a[ErrorCode.ERROR_CODE_OVER_SUBSCRIBE_LIMIT] = exports.ErrorCode.ERROR_CODE_OVER_SUBSCRIBE_LIMIT,
            _a[ErrorCode.ERROR_CODE_OVER_STREAM_PUBLISH_LIMIT] = exports.ErrorCode.ERROR_CODE_OVER_STREAM_PUBLISH_LIMIT,
            _a[ErrorCode.ERROR_CODE_INVALID_AUDIO_SYNC_USERID_REPEATED] = exports.ErrorCode.ERROR_CODE_INVALID_AUDIO_SYNC_USERID_REPEATED,
            _a[ErrorCode.ERROR_CODE_ABNORMAL_SERVER_STATUS] = exports.ErrorCode.ERROR_CODE_ABNORMAL_SERVER_STATUS,
            _a[ErrorCode.ERROR_CODE_OVER_SCREEN_PUBLISH_LIMIT] = exports.ErrorCode.ERROR_CODE_OVER_SCREEN_PUBLISH_LIMIT,
            _a[ErrorCode.ERROR_CODE_OVER_VIDEO_PUBLISH_LIMIT] = exports.ErrorCode.ERROR_CODE_OVER_VIDEO_PUBLISH_LIMIT,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ErrorCode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.ErrorCode.ByteRTCErrorCodeInvalidToken] = ByteRTCErrorCode.ByteRTCErrorCodeInvalidToken,
            _a[exports.ErrorCode.ByteRTCErrorCodeJoinRoom] = ByteRTCErrorCode.ByteRTCErrorCodeJoinRoom,
            _a[exports.ErrorCode.ByteRTCErrorCodeNoPublishPermission] = ByteRTCErrorCode.ByteRTCErrorCodeNoPublishPermission,
            _a[exports.ErrorCode.ByteRTCErrorCodeNoSubscribePermission] = ByteRTCErrorCode.ByteRTCErrorCodeNoSubscribePermission,
            _a[exports.ErrorCode.ByteRTCErrorCodeDuplicateLogin] = ByteRTCErrorCode.ByteRTCErrorCodeDuplicateLogin,
            _a[exports.ErrorCode.ByteRTCErrorCodeKickedOut] = ByteRTCErrorCode.ByteRTCErrorCodeKickedOut,
            _a[exports.ErrorCode.ByteRTCErrorCodeRoomIdIllegal] = ByteRTCErrorCode.ByteRTCErrorCodeRoomIdIllegal,
            _a[exports.ErrorCode.ByteRTCErrorCodeTokenExpired] = ByteRTCErrorCode.ByteRTCErrorCodeTokenExpired,
            _a[exports.ErrorCode.ByteRTCErrorCodeUpdateTokenWithInvalidToken] = ByteRTCErrorCode.ByteRTCErrorCodeUpdateTokenWithInvalidToken,
            _a[exports.ErrorCode.ByteRTCErrorCodeRoomDismiss] = ByteRTCErrorCode.ByteRTCErrorCodeRoomDismiss,
            _a[exports.ErrorCode.ByteRTCRoomAlreadyExist] = ByteRTCErrorCode.ByteRTCRoomAlreadyExist,
            _a[exports.ErrorCode.ByteRTCUserIDDifferent] = ByteRTCErrorCode.ByteRTCUserIDDifferent,
            _a[exports.ErrorCode.ByteRTCErrorCodeJoinRoomRoomForbidden] = ByteRTCErrorCode.ByteRTCErrorCodeJoinRoomRoomForbidden,
            _a[exports.ErrorCode.ByteRTCErrorCodeJoinRoomUserForbidden] = ByteRTCErrorCode.ByteRTCErrorCodeJoinRoomUserForbidden,
            _a[exports.ErrorCode.ByteRTCErrorCodeOverStreamSubscribeLimit] = ByteRTCErrorCode.ByteRTCErrorCodeOverStreamSubscribeLimit,
            _a[exports.ErrorCode.ByteRTCErrorCodeOverStreamPublishLimit] = ByteRTCErrorCode.ByteRTCErrorCodeOverStreamPublishLimit,
            _a[exports.ErrorCode.ByteRTCErrorCodInvalidAudioSyncUidRepeated] = ByteRTCErrorCode.ByteRTCErrorCodInvalidAudioSyncUidRepeated,
            _a[exports.ErrorCode.ByteRTCErrorCodeAbnormalServerStatus] = ByteRTCErrorCode.ByteRTCErrorCodeAbnormalServerStatus,
            _a[exports.ErrorCode.ByteRTCErrorCodeOverScreenPublishLimit] = ByteRTCErrorCode.ByteRTCErrorCodeOverScreenPublishLimit,
            _a[exports.ErrorCode.ByteRTCErrorCodeOverVideoPublishLimit] = ByteRTCErrorCode.ByteRTCErrorCodeOverVideoPublishLimit,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_ErrorCode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCErrorCode.ByteRTCErrorCodeInvalidToken] = exports.ErrorCode.ByteRTCErrorCodeInvalidToken,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeJoinRoom] = exports.ErrorCode.ByteRTCErrorCodeJoinRoom,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeNoPublishPermission] = exports.ErrorCode.ByteRTCErrorCodeNoPublishPermission,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeNoSubscribePermission] = exports.ErrorCode.ByteRTCErrorCodeNoSubscribePermission,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeDuplicateLogin] = exports.ErrorCode.ByteRTCErrorCodeDuplicateLogin,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeKickedOut] = exports.ErrorCode.ByteRTCErrorCodeKickedOut,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeRoomIdIllegal] = exports.ErrorCode.ByteRTCErrorCodeRoomIdIllegal,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeTokenExpired] = exports.ErrorCode.ByteRTCErrorCodeTokenExpired,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeUpdateTokenWithInvalidToken] = exports.ErrorCode.ByteRTCErrorCodeUpdateTokenWithInvalidToken,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeRoomDismiss] = exports.ErrorCode.ByteRTCErrorCodeRoomDismiss,
            _a[ByteRTCErrorCode.ByteRTCRoomAlreadyExist] = exports.ErrorCode.ByteRTCRoomAlreadyExist,
            _a[ByteRTCErrorCode.ByteRTCUserIDDifferent] = exports.ErrorCode.ByteRTCUserIDDifferent,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeJoinRoomRoomForbidden] = exports.ErrorCode.ByteRTCErrorCodeJoinRoomRoomForbidden,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeJoinRoomUserForbidden] = exports.ErrorCode.ByteRTCErrorCodeJoinRoomUserForbidden,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeOverStreamSubscribeLimit] = exports.ErrorCode.ByteRTCErrorCodeOverStreamSubscribeLimit,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeOverStreamPublishLimit] = exports.ErrorCode.ByteRTCErrorCodeOverStreamPublishLimit,
            _a[ByteRTCErrorCode.ByteRTCErrorCodInvalidAudioSyncUidRepeated] = exports.ErrorCode.ByteRTCErrorCodInvalidAudioSyncUidRepeated,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeAbnormalServerStatus] = exports.ErrorCode.ByteRTCErrorCodeAbnormalServerStatus,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeOverScreenPublishLimit] = exports.ErrorCode.ByteRTCErrorCodeOverScreenPublishLimit,
            _a[ByteRTCErrorCode.ByteRTCErrorCodeOverVideoPublishLimit] = exports.ErrorCode.ByteRTCErrorCodeOverVideoPublishLimit,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_ErrorCode;
}());
var t_LoginErrorCode = /** @class */ (function () {
    function t_LoginErrorCode() {
    }
    t_LoginErrorCode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LoginErrorCode.LOGIN_ERROR_CODE_SUCCESS] = LoginErrorCode.LOGIN_ERROR_CODE_SUCCESS,
            _a[exports.LoginErrorCode.LOGIN_ERROR_CODE_INVALID_TOKEN] = LoginErrorCode.LOGIN_ERROR_CODE_INVALID_TOKEN,
            _a[exports.LoginErrorCode.LOGIN_ERROR_CODE_LOGIN_FAILED] = LoginErrorCode.LOGIN_ERROR_CODE_LOGIN_FAILED,
            _a[exports.LoginErrorCode.LOGIN_ERROR_CODE_INVALID_USER_ID] = LoginErrorCode.LOGIN_ERROR_CODE_INVALID_USER_ID,
            _a[exports.LoginErrorCode.LOGIN_ERROR_CODE_SERVER_ERROR] = LoginErrorCode.LOGIN_ERROR_CODE_SERVER_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LoginErrorCode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[LoginErrorCode.LOGIN_ERROR_CODE_SUCCESS] = exports.LoginErrorCode.LOGIN_ERROR_CODE_SUCCESS,
            _a[LoginErrorCode.LOGIN_ERROR_CODE_INVALID_TOKEN] = exports.LoginErrorCode.LOGIN_ERROR_CODE_INVALID_TOKEN,
            _a[LoginErrorCode.LOGIN_ERROR_CODE_LOGIN_FAILED] = exports.LoginErrorCode.LOGIN_ERROR_CODE_LOGIN_FAILED,
            _a[LoginErrorCode.LOGIN_ERROR_CODE_INVALID_USER_ID] = exports.LoginErrorCode.LOGIN_ERROR_CODE_INVALID_USER_ID,
            _a[LoginErrorCode.LOGIN_ERROR_CODE_SERVER_ERROR] = exports.LoginErrorCode.LOGIN_ERROR_CODE_SERVER_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LoginErrorCode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.LoginErrorCode.ByteRTCLoginErrorCodeSuccess] = ByteRTCLoginErrorCode.ByteRTCLoginErrorCodeSuccess,
            _a[exports.LoginErrorCode.ByteRTCLoginErrorCodeInvalidToken] = ByteRTCLoginErrorCode.ByteRTCLoginErrorCodeInvalidToken,
            _a[exports.LoginErrorCode.ByteRTCLoginErrorCodeLoginFailed] = ByteRTCLoginErrorCode.ByteRTCLoginErrorCodeLoginFailed,
            _a[exports.LoginErrorCode.ByteRTCLoginErrorCodeInvalidUserId] = ByteRTCLoginErrorCode.ByteRTCLoginErrorCodeInvalidUserId,
            _a[exports.LoginErrorCode.ByteRTCLoginErrorCodeServerError] = ByteRTCLoginErrorCode.ByteRTCLoginErrorCodeServerError,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_LoginErrorCode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCLoginErrorCode.ByteRTCLoginErrorCodeSuccess] = exports.LoginErrorCode.ByteRTCLoginErrorCodeSuccess,
            _a[ByteRTCLoginErrorCode.ByteRTCLoginErrorCodeInvalidToken] = exports.LoginErrorCode.ByteRTCLoginErrorCodeInvalidToken,
            _a[ByteRTCLoginErrorCode.ByteRTCLoginErrorCodeLoginFailed] = exports.LoginErrorCode.ByteRTCLoginErrorCodeLoginFailed,
            _a[ByteRTCLoginErrorCode.ByteRTCLoginErrorCodeInvalidUserId] = exports.LoginErrorCode.ByteRTCLoginErrorCodeInvalidUserId,
            _a[ByteRTCLoginErrorCode.ByteRTCLoginErrorCodeServerError] = exports.LoginErrorCode.ByteRTCLoginErrorCodeServerError,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_LoginErrorCode;
}());
var t_UserMessageSendResult = /** @class */ (function () {
    function t_UserMessageSendResult() {
    }
    t_UserMessageSendResult.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_SUCCESS] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_SUCCESS,
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_TIMEOUT] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_TIMEOUT,
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_BROKEN] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_BROKEN,
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NO_RECEIVER] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NO_RECEIVER,
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NO_RELAY_PATH] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NO_RELAY_PATH,
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_EXCEED_QPS] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_EXCEED_QPS,
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NOT_JOIN] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NOT_JOIN,
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_INIT] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_INIT,
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NO_CONNECTION] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NO_CONNECTION,
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH,
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_EMPTY_USER] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_EMPTY_USER,
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NOT_LOGIN] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NOT_LOGIN,
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_SERVER_PARAMS_NOT_SET] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_SERVER_PARAMS_NOT_SET,
            _a[exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_UNKNOWN] = UserMessageSendResult.USER_MESSAGE_SEND_RESULT_UNKNOWN,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_UserMessageSendResult.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_SUCCESS] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_SUCCESS,
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_TIMEOUT] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_TIMEOUT,
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_BROKEN] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_BROKEN,
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NO_RECEIVER] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NO_RECEIVER,
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NO_RELAY_PATH] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NO_RELAY_PATH,
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_EXCEED_QPS] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_EXCEED_QPS,
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NOT_JOIN] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NOT_JOIN,
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_INIT] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_INIT,
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NO_CONNECTION] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NO_CONNECTION,
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH,
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_EMPTY_USER] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_EMPTY_USER,
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NOT_LOGIN] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_NOT_LOGIN,
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_SERVER_PARAMS_NOT_SET] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_SERVER_PARAMS_NOT_SET,
            _a[UserMessageSendResult.USER_MESSAGE_SEND_RESULT_UNKNOWN] = exports.UserMessageSendResult.USER_MESSAGE_SEND_RESULT_UNKNOWN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_UserMessageSendResult.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultSuccess] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultSuccess,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultTimeout] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultTimeout,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultNetworkDisconnected] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultNetworkDisconnected,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultNoReceiver] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultNoReceiver,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultNoRelayPath] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultNoRelayPath,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultExceedQPS] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultExceedQPS,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultE2BSSendFailed] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultE2BSSendFailed,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultE2BSReturnFailed] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultE2BSReturnFailed,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultNotJoin] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultNotJoin,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultInit] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultInit,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultNoConnection] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultNoConnection,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultExceedMaxLength] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultExceedMaxLength,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultEmptyUser] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultEmptyUser,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultNotLogin] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultNotLogin,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultServerParamsNotSet] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultServerParamsNotSet,
            _a[exports.UserMessageSendResult.ByteRTCUserMessageSendResultUnknown] = ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultUnknown,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_UserMessageSendResult.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultSuccess] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultSuccess,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultTimeout] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultTimeout,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultNetworkDisconnected] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultNetworkDisconnected,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultNoReceiver] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultNoReceiver,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultNoRelayPath] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultNoRelayPath,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultExceedQPS] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultExceedQPS,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultE2BSSendFailed] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultE2BSSendFailed,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultE2BSReturnFailed] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultE2BSReturnFailed,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultNotJoin] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultNotJoin,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultInit] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultInit,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultNoConnection] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultNoConnection,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultExceedMaxLength] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultExceedMaxLength,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultEmptyUser] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultEmptyUser,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultNotLogin] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultNotLogin,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultServerParamsNotSet] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultServerParamsNotSet,
            _a[ByteRTCUserMessageSendResult.ByteRTCUserMessageSendResultUnknown] = exports.UserMessageSendResult.ByteRTCUserMessageSendResultUnknown,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_UserMessageSendResult;
}());
var t_AudioRecordingErrorCode = /** @class */ (function () {
    function t_AudioRecordingErrorCode() {
    }
    t_AudioRecordingErrorCode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_ALREADY_STARTED] = AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_ALREADY_STARTED,
            _a[exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_STARTED] = AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_STARTED,
            _a[exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_OK] = AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_OK,
            _a[exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NO_PERMISSION] = AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NO_PERMISSION,
            _a[exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_IN_ROOM] = AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_IN_ROOM,
            _a[exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_SUPPORT] = AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_SUPPORT,
            _a[exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_OTHER] = AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_OTHER,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioRecordingErrorCode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_ALREADY_STARTED] = exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_ALREADY_STARTED,
            _a[AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_STARTED] = exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_STARTED,
            _a[AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_OK] = exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_OK,
            _a[AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NO_PERMISSION] = exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NO_PERMISSION,
            _a[AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_IN_ROOM] = exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_IN_ROOM,
            _a[AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_SUPPORT] = exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_SUPPORT,
            _a[AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_OTHER] = exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_OTHER,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioRecordingErrorCode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_ALREADY_STARTED] = ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingAlreadyStarted,
            _a[exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_STARTED] = ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingNotStarted,
            _a[exports.AudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeOk] = ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeOk,
            _a[exports.AudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeNoPermission] = ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeNoPermission,
            _a[exports.AudioRecordingErrorCode.ByteRTCAudioRecordingErrorNotInRoom] = ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingErrorNotInRoom,
            _a[exports.AudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeNotSupport] = ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeNotSupport,
            _a[exports.AudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeOther] = ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeOther,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_AudioRecordingErrorCode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingAlreadyStarted] = exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_ALREADY_STARTED,
            _a[ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingNotStarted] = exports.AudioRecordingErrorCode.AUDIO_RECORDING_ERROR_CODE_NOT_STARTED,
            _a[ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeOk] = exports.AudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeOk,
            _a[ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeNoPermission] = exports.AudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeNoPermission,
            _a[ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingErrorNotInRoom] = exports.AudioRecordingErrorCode.ByteRTCAudioRecordingErrorNotInRoom,
            _a[ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeNotSupport] = exports.AudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeNotSupport,
            _a[ByteRTCAudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeOther] = exports.AudioRecordingErrorCode.ByteRTCAudioRecordingErrorCodeOther,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_AudioRecordingErrorCode;
}());
var t_PublicStreamErrorCode = /** @class */ (function () {
    function t_PublicStreamErrorCode() {
    }
    t_PublicStreamErrorCode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PublicStreamErrorCode.ERROR_CODE_SUCCESS] = PublicStreamErrorCode.ERROR_CODE_SUCCESS,
            _a[exports.PublicStreamErrorCode.ERROR_CODE_PUSH_PARAM_ERROR] = PublicStreamErrorCode.ERROR_CODE_PUSH_PARAM_ERROR,
            _a[exports.PublicStreamErrorCode.ERROR_CODE_PUSH_INTERNAL_ERROR] = PublicStreamErrorCode.ERROR_CODE_PUSH_INTERNAL_ERROR,
            _a[exports.PublicStreamErrorCode.ERROR_CODE_PUSH_ERROR] = PublicStreamErrorCode.ERROR_CODE_PUSH_ERROR,
            _a[exports.PublicStreamErrorCode.ERROR_CODE_PUSH_TIMEOUT] = PublicStreamErrorCode.ERROR_CODE_PUSH_TIMEOUT,
            _a[exports.PublicStreamErrorCode.ERROR_CODE_PULL_NO_PUSH_STREAM] = PublicStreamErrorCode.ERROR_CODE_PULL_NO_PUSH_STREAM,
            _a[exports.PublicStreamErrorCode.ERROR_CODE_PUSH_STATE_ERROR] = PublicStreamErrorCode.ERROR_CODE_PUSH_STATE_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PublicStreamErrorCode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[PublicStreamErrorCode.ERROR_CODE_SUCCESS] = exports.PublicStreamErrorCode.ERROR_CODE_SUCCESS,
            _a[PublicStreamErrorCode.ERROR_CODE_PUSH_PARAM_ERROR] = exports.PublicStreamErrorCode.ERROR_CODE_PUSH_PARAM_ERROR,
            _a[PublicStreamErrorCode.ERROR_CODE_PUSH_INTERNAL_ERROR] = exports.PublicStreamErrorCode.ERROR_CODE_PUSH_INTERNAL_ERROR,
            _a[PublicStreamErrorCode.ERROR_CODE_PUSH_ERROR] = exports.PublicStreamErrorCode.ERROR_CODE_PUSH_ERROR,
            _a[PublicStreamErrorCode.ERROR_CODE_PUSH_TIMEOUT] = exports.PublicStreamErrorCode.ERROR_CODE_PUSH_TIMEOUT,
            _a[PublicStreamErrorCode.ERROR_CODE_PULL_NO_PUSH_STREAM] = exports.PublicStreamErrorCode.ERROR_CODE_PULL_NO_PUSH_STREAM,
            _a[PublicStreamErrorCode.ERROR_CODE_PUSH_STATE_ERROR] = exports.PublicStreamErrorCode.ERROR_CODE_PUSH_STATE_ERROR,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PublicStreamErrorCode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.PublicStreamErrorCode.ERROR_CODE_SUCCESS] = ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodeSuccess,
            _a[exports.PublicStreamErrorCode.ERROR_CODE_PUSH_PARAM_ERROR] = ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodePushParamError,
            _a[exports.PublicStreamErrorCode.ERROR_CODE_PUSH_INTERNAL_ERROR] = ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodePushInternalError,
            _a[exports.PublicStreamErrorCode.ERROR_CODE_PUSH_ERROR] = ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodePushError,
            _a[exports.PublicStreamErrorCode.ERROR_CODE_PUSH_TIMEOUT] = ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodePushTimeOut,
            _a[exports.PublicStreamErrorCode.ERROR_CODE_PULL_NO_PUSH_STREAM] = ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodePullNoPushStream,
            _a[exports.PublicStreamErrorCode.ByteRTCPublicStreamErrorCodePushStatusError] = ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodePushStatusError,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_PublicStreamErrorCode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodeSuccess] = exports.PublicStreamErrorCode.ERROR_CODE_SUCCESS,
            _a[ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodePushParamError] = exports.PublicStreamErrorCode.ERROR_CODE_PUSH_PARAM_ERROR,
            _a[ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodePushInternalError] = exports.PublicStreamErrorCode.ERROR_CODE_PUSH_INTERNAL_ERROR,
            _a[ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodePushError] = exports.PublicStreamErrorCode.ERROR_CODE_PUSH_ERROR,
            _a[ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodePushTimeOut] = exports.PublicStreamErrorCode.ERROR_CODE_PUSH_TIMEOUT,
            _a[ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodePullNoPushStream] = exports.PublicStreamErrorCode.ERROR_CODE_PULL_NO_PUSH_STREAM,
            _a[ByteRTCPublicStreamErrorCode.ByteRTCPublicStreamErrorCodePushStatusError] = exports.PublicStreamErrorCode.ByteRTCPublicStreamErrorCodePushStatusError,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_PublicStreamErrorCode;
}());
var t_RoomMessageSendResult = /** @class */ (function () {
    function t_RoomMessageSendResult() {
    }
    t_RoomMessageSendResult.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_SUCCESS] = RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_SUCCESS,
            _a[exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_EXCEED_QPS] = RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_EXCEED_QPS,
            _a[exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_NOT_JOIN] = RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_NOT_JOIN,
            _a[exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_INIT] = RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_INIT,
            _a[exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_NO_CONNECTION] = RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_NO_CONNECTION,
            _a[exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH] = RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH,
            _a[exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_UNKNOWN] = RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_UNKNOWN,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RoomMessageSendResult.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_SUCCESS] = exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_SUCCESS,
            _a[RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_EXCEED_QPS] = exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_EXCEED_QPS,
            _a[RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_NOT_JOIN] = exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_NOT_JOIN,
            _a[RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_INIT] = exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_INIT,
            _a[RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_NO_CONNECTION] = exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_NO_CONNECTION,
            _a[RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH] = exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_EXCEED_MAX_LENGTH,
            _a[RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_UNKNOWN] = exports.RoomMessageSendResult.ROOM_MESSAGE_SEND_RESULT_UNKNOWN,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RoomMessageSendResult.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultSuccess] = ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultSuccess,
            _a[exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultTimeout] = ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultTimeout,
            _a[exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultNetworkDisconnected] = ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultNetworkDisconnected,
            _a[exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultExceedQPS] = ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultExceedQPS,
            _a[exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultNotJoin] = ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultNotJoin,
            _a[exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultInit] = ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultInit,
            _a[exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultNoConnection] = ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultNoConnection,
            _a[exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultExceedMaxLength] = ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultExceedMaxLength,
            _a[exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultUnknown] = ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultUnknown,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_RoomMessageSendResult.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultSuccess] = exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultSuccess,
            _a[ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultTimeout] = exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultTimeout,
            _a[ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultNetworkDisconnected] = exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultNetworkDisconnected,
            _a[ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultExceedQPS] = exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultExceedQPS,
            _a[ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultNotJoin] = exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultNotJoin,
            _a[ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultInit] = exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultInit,
            _a[ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultNoConnection] = exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultNoConnection,
            _a[ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultExceedMaxLength] = exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultExceedMaxLength,
            _a[ByteRTCRoomMessageSendResult.ByteRTCRoomMessageSendResultUnknown] = exports.RoomMessageSendResult.ByteRTCRoomMessageSendResultUnknown,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_RoomMessageSendResult;
}());
var t_SubtitleErrorCode = /** @class */ (function () {
    function t_SubtitleErrorCode() {
    }
    t_SubtitleErrorCode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_UNKNOW] = SubtitleErrorCode.SUBTITLE_ERROR_CODE_UNKNOW,
            _a[exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_SUCCESS] = SubtitleErrorCode.SUBTITLE_ERROR_CODE_SUCCESS,
            _a[exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_POST_PROCESS_ERROR] = SubtitleErrorCode.SUBTITLE_ERROR_CODE_POST_PROCESS_ERROR,
            _a[exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_ASR_CONNECTION_ERROR] = SubtitleErrorCode.SUBTITLE_ERROR_CODE_ASR_CONNECTION_ERROR,
            _a[exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_ASR_SERVICE_ERROR] = SubtitleErrorCode.SUBTITLE_ERROR_CODE_ASR_SERVICE_ERROR,
            _a[exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_BEFORE_JOIN_ROOM] = SubtitleErrorCode.SUBTITLE_ERROR_CODE_BEFORE_JOIN_ROOM,
            _a[exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_ALREADY_ON] = SubtitleErrorCode.SUBTITLE_ERROR_CODE_ALREADY_ON,
            _a[exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_UNSUPPORTED_LANGUAGE] = SubtitleErrorCode.SUBTITLE_ERROR_CODE_UNSUPPORTED_LANGUAGE,
            _a[exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_POST_PROCESS_TIMEOUT] = SubtitleErrorCode.SUBTITLE_ERROR_CODE_POST_PROCESS_TIMEOUT,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubtitleErrorCode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[SubtitleErrorCode.SUBTITLE_ERROR_CODE_UNKNOW] = exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_UNKNOW,
            _a[SubtitleErrorCode.SUBTITLE_ERROR_CODE_SUCCESS] = exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_SUCCESS,
            _a[SubtitleErrorCode.SUBTITLE_ERROR_CODE_POST_PROCESS_ERROR] = exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_POST_PROCESS_ERROR,
            _a[SubtitleErrorCode.SUBTITLE_ERROR_CODE_ASR_CONNECTION_ERROR] = exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_ASR_CONNECTION_ERROR,
            _a[SubtitleErrorCode.SUBTITLE_ERROR_CODE_ASR_SERVICE_ERROR] = exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_ASR_SERVICE_ERROR,
            _a[SubtitleErrorCode.SUBTITLE_ERROR_CODE_BEFORE_JOIN_ROOM] = exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_BEFORE_JOIN_ROOM,
            _a[SubtitleErrorCode.SUBTITLE_ERROR_CODE_ALREADY_ON] = exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_ALREADY_ON,
            _a[SubtitleErrorCode.SUBTITLE_ERROR_CODE_UNSUPPORTED_LANGUAGE] = exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_UNSUPPORTED_LANGUAGE,
            _a[SubtitleErrorCode.SUBTITLE_ERROR_CODE_POST_PROCESS_TIMEOUT] = exports.SubtitleErrorCode.SUBTITLE_ERROR_CODE_POST_PROCESS_TIMEOUT,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubtitleErrorCode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeUnknow] = ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeUnknow,
            _a[exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeSuccess] = ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeSuccess,
            _a[exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodePostProcessError] = ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodePostProcessError,
            _a[exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeASRConnectionError] = ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeASRConnectionError,
            _a[exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeASRServiceError] = ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeASRServiceError,
            _a[exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeBeforeJoinRoom] = ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeBeforeJoinRoom,
            _a[exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeAlreadyOn] = ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeAlreadyOn,
            _a[exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeUnsupportedLanguage] = ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeUnsupportedLanguage,
            _a[exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodePostProcessTimeout] = ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodePostProcessTimeout,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_SubtitleErrorCode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeUnknow] = exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeUnknow,
            _a[ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeSuccess] = exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeSuccess,
            _a[ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodePostProcessError] = exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodePostProcessError,
            _a[ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeASRConnectionError] = exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeASRConnectionError,
            _a[ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeASRServiceError] = exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeASRServiceError,
            _a[ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeBeforeJoinRoom] = exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeBeforeJoinRoom,
            _a[ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeAlreadyOn] = exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeAlreadyOn,
            _a[ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodeUnsupportedLanguage] = exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodeUnsupportedLanguage,
            _a[ByteRTCSubtitleErrorCode.ByteRTCSubtitleErrorCodePostProcessTimeout] = exports.SubtitleErrorCode.ByteRTCSubtitleErrorCodePostProcessTimeout,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_SubtitleErrorCode;
}());
var t_KTVErrorCode = /** @class */ (function () {
    function t_KTVErrorCode() {
    }
    t_KTVErrorCode.ts_to_android = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.KTVErrorCode.OK] = KTVErrorCode.OK,
            _a[exports.KTVErrorCode.APPID_INVALID] = KTVErrorCode.APPID_INVALID,
            _a[exports.KTVErrorCode.PARAS_INVALID] = KTVErrorCode.PARAS_INVALID,
            _a[exports.KTVErrorCode.GET_MUSIC_FAILED] = KTVErrorCode.GET_MUSIC_FAILED,
            _a[exports.KTVErrorCode.GET_LYRIC_FAILED] = KTVErrorCode.GET_LYRIC_FAILED,
            _a[exports.KTVErrorCode.MUSIC_TAKEDOWN] = KTVErrorCode.MUSIC_TAKEDOWN,
            _a[exports.KTVErrorCode.MUSIC_DOWNLOAD] = KTVErrorCode.MUSIC_DOWNLOAD,
            _a[exports.KTVErrorCode.MIDI_DOWNLOAD_FAILED] = KTVErrorCode.MIDI_DOWNLOAD_FAILED,
            _a[exports.KTVErrorCode.SYSTEM_BUSY] = KTVErrorCode.SYSTEM_BUSY,
            _a[exports.KTVErrorCode.NETWORK] = KTVErrorCode.NETWORK,
            _a[exports.KTVErrorCode.NOT_JOIN_ROOM] = KTVErrorCode.NOT_JOIN_ROOM,
            _a[exports.KTVErrorCode.PARSE_DATA] = KTVErrorCode.PARSE_DATA,
            _a[exports.KTVErrorCode.DOWNLOADING] = KTVErrorCode.DOWNLOADING,
            _a[exports.KTVErrorCode.INTERNAL_DOMAIN] = KTVErrorCode.INTERNAL_DOMAIN,
            _a[exports.KTVErrorCode.INSUFFICIENT_DISK_SPACE] = KTVErrorCode.INSUFFICIENT_DISK_SPACE,
            _a[exports.KTVErrorCode.MUSIC_DECRYPTION_FAILED] = KTVErrorCode.MUSIC_DECRYPTION_FAILED,
            _a[exports.KTVErrorCode.FILE_RENAME_FAILED] = KTVErrorCode.FILE_RENAME_FAILED,
            _a[exports.KTVErrorCode.DOWNLOAD_TIMEOUT] = KTVErrorCode.DOWNLOAD_TIMEOUT,
            _a[exports.KTVErrorCode.CLEAR_CACHE_FAILED] = KTVErrorCode.CLEAR_CACHE_FAILED,
            _a[exports.KTVErrorCode.DOWNLOAD_CANCELED] = KTVErrorCode.DOWNLOAD_CANCELED,
            _a);
        if (!(value in $m)) {
            throw new Error('android not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_KTVErrorCode.android_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[KTVErrorCode.OK] = exports.KTVErrorCode.OK,
            _a[KTVErrorCode.APPID_INVALID] = exports.KTVErrorCode.APPID_INVALID,
            _a[KTVErrorCode.PARAS_INVALID] = exports.KTVErrorCode.PARAS_INVALID,
            _a[KTVErrorCode.GET_MUSIC_FAILED] = exports.KTVErrorCode.GET_MUSIC_FAILED,
            _a[KTVErrorCode.GET_LYRIC_FAILED] = exports.KTVErrorCode.GET_LYRIC_FAILED,
            _a[KTVErrorCode.MUSIC_TAKEDOWN] = exports.KTVErrorCode.MUSIC_TAKEDOWN,
            _a[KTVErrorCode.MUSIC_DOWNLOAD] = exports.KTVErrorCode.MUSIC_DOWNLOAD,
            _a[KTVErrorCode.MIDI_DOWNLOAD_FAILED] = exports.KTVErrorCode.MIDI_DOWNLOAD_FAILED,
            _a[KTVErrorCode.SYSTEM_BUSY] = exports.KTVErrorCode.SYSTEM_BUSY,
            _a[KTVErrorCode.NETWORK] = exports.KTVErrorCode.NETWORK,
            _a[KTVErrorCode.NOT_JOIN_ROOM] = exports.KTVErrorCode.NOT_JOIN_ROOM,
            _a[KTVErrorCode.PARSE_DATA] = exports.KTVErrorCode.PARSE_DATA,
            _a[KTVErrorCode.DOWNLOADING] = exports.KTVErrorCode.DOWNLOADING,
            _a[KTVErrorCode.INTERNAL_DOMAIN] = exports.KTVErrorCode.INTERNAL_DOMAIN,
            _a[KTVErrorCode.INSUFFICIENT_DISK_SPACE] = exports.KTVErrorCode.INSUFFICIENT_DISK_SPACE,
            _a[KTVErrorCode.MUSIC_DECRYPTION_FAILED] = exports.KTVErrorCode.MUSIC_DECRYPTION_FAILED,
            _a[KTVErrorCode.FILE_RENAME_FAILED] = exports.KTVErrorCode.FILE_RENAME_FAILED,
            _a[KTVErrorCode.DOWNLOAD_TIMEOUT] = exports.KTVErrorCode.DOWNLOAD_TIMEOUT,
            _a[KTVErrorCode.CLEAR_CACHE_FAILED] = exports.KTVErrorCode.CLEAR_CACHE_FAILED,
            _a[KTVErrorCode.DOWNLOAD_CANCELED] = exports.KTVErrorCode.DOWNLOAD_CANCELED,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_KTVErrorCode.ts_to_ios = function (value) {
        var _a;
        var $m = (_a = {},
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeOK] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeOK,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeAppidInValid] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeAppidInValid,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeParasInValid] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeParasInValid,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeGetMusicFailed] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeGetMusicFailed,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeGetLyricFailed] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeGetLyricFailed,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeMusicTakedown] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeMusicTakedown,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeMusicDownload] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeMusicDownload,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeMidiDownloadFailed] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeMidiDownloadFailed,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeSystemBusy] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeSystemBusy,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeNetwork] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeNetwork,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeNotJoinRoom] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeNotJoinRoom,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeParseData] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeParseData,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeDownloading] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeDownloading,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeInternal] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeInternal,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeInsufficientDiskSpace] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeInsufficientDiskSpace,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeMusicDecryptionFailed] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeMusicDecryptionFailed,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeFileRenameFailed] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeFileRenameFailed,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeDownloadTimeOut] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeDownloadTimeOut,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeClearCacheFailed] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeClearCacheFailed,
            _a[exports.KTVErrorCode.ByteRTCKTVErrorCodeDownloadCanceled] = ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeDownloadCanceled,
            _a);
        if (!(value in $m)) {
            throw new Error('ios not support:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    t_KTVErrorCode.ios_to_ts = function (value) {
        var _a;
        var $m = (_a = {},
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeOK] = exports.KTVErrorCode.ByteRTCKTVErrorCodeOK,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeAppidInValid] = exports.KTVErrorCode.ByteRTCKTVErrorCodeAppidInValid,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeParasInValid] = exports.KTVErrorCode.ByteRTCKTVErrorCodeParasInValid,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeGetMusicFailed] = exports.KTVErrorCode.ByteRTCKTVErrorCodeGetMusicFailed,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeGetLyricFailed] = exports.KTVErrorCode.ByteRTCKTVErrorCodeGetLyricFailed,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeMusicTakedown] = exports.KTVErrorCode.ByteRTCKTVErrorCodeMusicTakedown,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeMusicDownload] = exports.KTVErrorCode.ByteRTCKTVErrorCodeMusicDownload,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeMidiDownloadFailed] = exports.KTVErrorCode.ByteRTCKTVErrorCodeMidiDownloadFailed,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeSystemBusy] = exports.KTVErrorCode.ByteRTCKTVErrorCodeSystemBusy,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeNetwork] = exports.KTVErrorCode.ByteRTCKTVErrorCodeNetwork,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeNotJoinRoom] = exports.KTVErrorCode.ByteRTCKTVErrorCodeNotJoinRoom,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeParseData] = exports.KTVErrorCode.ByteRTCKTVErrorCodeParseData,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeDownloading] = exports.KTVErrorCode.ByteRTCKTVErrorCodeDownloading,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeInternal] = exports.KTVErrorCode.ByteRTCKTVErrorCodeInternal,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeInsufficientDiskSpace] = exports.KTVErrorCode.ByteRTCKTVErrorCodeInsufficientDiskSpace,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeMusicDecryptionFailed] = exports.KTVErrorCode.ByteRTCKTVErrorCodeMusicDecryptionFailed,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeFileRenameFailed] = exports.KTVErrorCode.ByteRTCKTVErrorCodeFileRenameFailed,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeDownloadTimeOut] = exports.KTVErrorCode.ByteRTCKTVErrorCodeDownloadTimeOut,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeClearCacheFailed] = exports.KTVErrorCode.ByteRTCKTVErrorCodeClearCacheFailed,
            _a[ByteRTCKTVErrorCode.ByteRTCKTVErrorCodeDownloadCanceled] = exports.KTVErrorCode.ByteRTCKTVErrorCodeDownloadCanceled,
            _a);
        if (!(value in $m)) {
            throw new Error('invalid value:' + value);
        }
        // @ts-ignore
        return $m[value];
    };
    return t_KTVErrorCode;
}());

var android_RTCVideoEventHandler = /** @class */ (function (_super) {
    __extends(android_RTCVideoEventHandler, _super);
    function android_RTCVideoEventHandler(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    android_RTCVideoEventHandler.prototype.onWarning = function (warn) {
        if (!this._instance['onWarning']) {
            return;
        }
        return this._instance['onWarning'](t_WarningCode.android_to_ts(warn));
    };
    android_RTCVideoEventHandler.prototype.onError = function (err) {
        if (!this._instance['onError']) {
            return;
        }
        return this._instance['onError'](t_ErrorCode.android_to_ts(err));
    };
    android_RTCVideoEventHandler.prototype.onExtensionAccessError = function (extensionName, msg) {
        if (!this._instance['onExtensionAccessError']) {
            return;
        }
        return this._instance['onExtensionAccessError'](String(extensionName), String(msg));
    };
    android_RTCVideoEventHandler.prototype.onSysStats = function (stats) {
        if (!this._instance['onSysStats']) {
            return;
        }
        return this._instance['onSysStats'](packObject(stats, SysStats));
    };
    android_RTCVideoEventHandler.prototype.onNetworkTypeChanged = function (type) {
        if (!this._instance['onNetworkTypeChanged']) {
            return;
        }
        return this._instance['onNetworkTypeChanged'](t_RTCNetworkType.android_to_ts(type));
    };
    android_RTCVideoEventHandler.prototype.onUserStartVideoCapture = function (roomId, uid) {
        if (!this._instance['onUserStartVideoCapture']) {
            return;
        }
        return this._instance['onUserStartVideoCapture'](String(roomId), String(uid));
    };
    android_RTCVideoEventHandler.prototype.onUserStopVideoCapture = function (roomId, uid) {
        if (!this._instance['onUserStopVideoCapture']) {
            return;
        }
        return this._instance['onUserStopVideoCapture'](String(roomId), String(uid));
    };
    android_RTCVideoEventHandler.prototype.onCreateRoomStateChanged = function (roomId, errorCode) {
        if (!this._instance['onCreateRoomStateChanged']) {
            return;
        }
        return this._instance['onCreateRoomStateChanged'](String(roomId), Number(errorCode));
    };
    android_RTCVideoEventHandler.prototype.onUserStartAudioCapture = function (roomId, uid) {
        if (!this._instance['onUserStartAudioCapture']) {
            return;
        }
        return this._instance['onUserStartAudioCapture'](String(roomId), String(uid));
    };
    android_RTCVideoEventHandler.prototype.onUserStopAudioCapture = function (roomId, uid) {
        if (!this._instance['onUserStopAudioCapture']) {
            return;
        }
        return this._instance['onUserStopAudioCapture'](String(roomId), String(uid));
    };
    android_RTCVideoEventHandler.prototype.onLocalAudioStateChanged = function (state, error) {
        if (!this._instance['onLocalAudioStateChanged']) {
            return;
        }
        return this._instance['onLocalAudioStateChanged'](t_LocalAudioStreamState.android_to_ts(state), t_LocalAudioStreamError.android_to_ts(error));
    };
    android_RTCVideoEventHandler.prototype.onRemoteAudioStateChanged = function (key, state, reason) {
        if (!this._instance['onRemoteAudioStateChanged']) {
            return;
        }
        return this._instance['onRemoteAudioStateChanged'](packObject(key, RemoteStreamKey), t_RemoteAudioState.android_to_ts(state), t_RemoteAudioStateChangeReason.android_to_ts(reason));
    };
    android_RTCVideoEventHandler.prototype.onLocalVideoStateChanged = function (streamIndex, state, error) {
        if (!this._instance['onLocalVideoStateChanged']) {
            return;
        }
        return this._instance['onLocalVideoStateChanged'](t_StreamIndex.android_to_ts(streamIndex), t_LocalVideoStreamState.android_to_ts(state), t_LocalVideoStreamError.android_to_ts(error));
    };
    android_RTCVideoEventHandler.prototype.onRemoteVideoStateChanged = function (streamKey, videoState, videoStateReason) {
        if (!this._instance['onRemoteVideoStateChanged']) {
            return;
        }
        return this._instance['onRemoteVideoStateChanged'](packObject(streamKey, RemoteStreamKey), t_RemoteVideoState.android_to_ts(videoState), t_RemoteVideoStateChangeReason.android_to_ts(videoStateReason));
    };
    android_RTCVideoEventHandler.prototype.onFirstRemoteVideoFrameRendered = function (remoteStreamKey, frameInfo) {
        if (!this._instance['onFirstRemoteVideoFrameRendered']) {
            return;
        }
        return this._instance['onFirstRemoteVideoFrameRendered'](packObject(remoteStreamKey, RemoteStreamKey), packObject(frameInfo, VideoFrameInfo));
    };
    android_RTCVideoEventHandler.prototype.onFirstRemoteVideoFrameDecoded = function (remoteStreamKey, frameInfo) {
        if (!this._instance['onFirstRemoteVideoFrameDecoded']) {
            return;
        }
        return this._instance['onFirstRemoteVideoFrameDecoded'](packObject(remoteStreamKey, RemoteStreamKey), packObject(frameInfo, VideoFrameInfo));
    };
    android_RTCVideoEventHandler.prototype.onFirstLocalVideoFrameCaptured = function (streamIndex, frameInfo) {
        if (!this._instance['onFirstLocalVideoFrameCaptured']) {
            return;
        }
        return this._instance['onFirstLocalVideoFrameCaptured'](t_StreamIndex.android_to_ts(streamIndex), packObject(frameInfo, VideoFrameInfo));
    };
    android_RTCVideoEventHandler.prototype.onLocalVideoSizeChanged = function (streamIndex, frameInfo) {
        if (!this._instance['onLocalVideoSizeChanged']) {
            return;
        }
        return this._instance['onLocalVideoSizeChanged'](t_StreamIndex.android_to_ts(streamIndex), packObject(frameInfo, VideoFrameInfo));
    };
    android_RTCVideoEventHandler.prototype.onRemoteVideoSizeChanged = function (remoteStreamKey, frameInfo) {
        if (!this._instance['onRemoteVideoSizeChanged']) {
            return;
        }
        return this._instance['onRemoteVideoSizeChanged'](packObject(remoteStreamKey, RemoteStreamKey), packObject(frameInfo, VideoFrameInfo));
    };
    android_RTCVideoEventHandler.prototype.onConnectionStateChanged = function (state, reason) {
        if (!this._instance['onConnectionStateChanged']) {
            return;
        }
        return this._instance['onConnectionStateChanged'](t_ConnectionState.android_to_ts(state));
    };
    android_RTCVideoEventHandler.prototype.onAudioRouteChanged = function (route) {
        if (!this._instance['onAudioRouteChanged']) {
            return;
        }
        return this._instance['onAudioRouteChanged'](t_AudioRoute.android_to_ts(route));
    };
    android_RTCVideoEventHandler.prototype.onFirstLocalAudioFrame = function (streamIndex) {
        if (!this._instance['onFirstLocalAudioFrame']) {
            return;
        }
        return this._instance['onFirstLocalAudioFrame'](t_StreamIndex.android_to_ts(streamIndex));
    };
    android_RTCVideoEventHandler.prototype.onFirstRemoteAudioFrame = function (remoteStreamKey) {
        if (!this._instance['onFirstRemoteAudioFrame']) {
            return;
        }
        return this._instance['onFirstRemoteAudioFrame'](packObject(remoteStreamKey, RemoteStreamKey));
    };
    android_RTCVideoEventHandler.prototype.onSEIMessageReceived = function (remoteStreamKey, message) {
        if (!this._instance['onSEIMessageReceived']) {
            return;
        }
        return this._instance['onSEIMessageReceived'](packObject(remoteStreamKey, RemoteStreamKey), message);
    };
    android_RTCVideoEventHandler.prototype.onSEIStreamUpdate = function (remoteStreamKey, event) {
        if (!this._instance['onSEIStreamUpdate']) {
            return;
        }
        return this._instance['onSEIStreamUpdate'](packObject(remoteStreamKey, RemoteStreamKey), t_SEIStreamUpdateEventType.android_to_ts(event));
    };
    android_RTCVideoEventHandler.prototype.onLoginResult = function (uid, errorCode, elapsed) {
        if (!this._instance['onLoginResult']) {
            return;
        }
        return this._instance['onLoginResult'](String(uid), t_LoginErrorCode.android_to_ts(errorCode), Number(elapsed));
    };
    android_RTCVideoEventHandler.prototype.onLogout = function (reason) {
        if (!this._instance['onLogout']) {
            return;
        }
        return this._instance['onLogout'](t_LogoutReason.android_to_ts(reason));
    };
    android_RTCVideoEventHandler.prototype.onServerParamsSetResult = function (error) {
        if (!this._instance['onServerParamsSetResult']) {
            return;
        }
        return this._instance['onServerParamsSetResult'](Number(error));
    };
    android_RTCVideoEventHandler.prototype.onGetPeerOnlineStatus = function (peerUserId, status) {
        if (!this._instance['onGetPeerOnlineStatus']) {
            return;
        }
        return this._instance['onGetPeerOnlineStatus'](String(peerUserId), t_UserOnlineStatus.android_to_ts(status));
    };
    android_RTCVideoEventHandler.prototype.onUserMessageReceivedOutsideRoom = function (uid, message) {
        if (!this._instance['onUserMessageReceivedOutsideRoom']) {
            return;
        }
        return this._instance['onUserMessageReceivedOutsideRoom'](String(uid), String(message));
    };
    android_RTCVideoEventHandler.prototype.onUserBinaryMessageReceivedOutsideRoom = function (uid, message) {
        if (!this._instance['onUserBinaryMessageReceivedOutsideRoom']) {
            return;
        }
        return this._instance['onUserBinaryMessageReceivedOutsideRoom'](String(uid), message);
    };
    android_RTCVideoEventHandler.prototype.onUserMessageSendResultOutsideRoom = function (msgid, error) {
        if (!this._instance['onUserMessageSendResultOutsideRoom']) {
            return;
        }
        return this._instance['onUserMessageSendResultOutsideRoom'](Number(msgid), t_UserMessageSendResult.android_to_ts(error));
    };
    android_RTCVideoEventHandler.prototype.onServerMessageSendResult = function (msgid, error, message) {
        if (!this._instance['onServerMessageSendResult']) {
            return;
        }
        return this._instance['onServerMessageSendResult'](Number(msgid), t_UserMessageSendResult.android_to_ts(error), message);
    };
    android_RTCVideoEventHandler.prototype.onNetworkDetectionResult = function (type, quality, rtt, lostRate, bitrate, jitter) {
        if (!this._instance['onNetworkDetectionResult']) {
            return;
        }
        return this._instance['onNetworkDetectionResult'](t_NetworkDetectionLinkType.android_to_ts(type), t_NetworkQuality.android_to_ts(quality), Number(rtt), Number(lostRate), Number(bitrate), Number(jitter));
    };
    android_RTCVideoEventHandler.prototype.onNetworkDetectionStopped = function (reason) {
        if (!this._instance['onNetworkDetectionStopped']) {
            return;
        }
        return this._instance['onNetworkDetectionStopped'](t_NetworkDetectionStopReason.android_to_ts(reason));
    };
    android_RTCVideoEventHandler.prototype.onSimulcastSubscribeFallback = function (event) {
        if (!this._instance['onSimulcastSubscribeFallback']) {
            return;
        }
        return this._instance['onSimulcastSubscribeFallback'](packObject(event, RemoteStreamSwitchEvent));
    };
    android_RTCVideoEventHandler.prototype.onPerformanceAlarms = function (mode, roomId, reason, data) {
        if (!this._instance['onPerformanceAlarms']) {
            return;
        }
        return this._instance['onPerformanceAlarms'](t_PerformanceAlarmMode.android_to_ts(mode), String(roomId), t_PerformanceAlarmReason.android_to_ts(reason), packObject(data, SourceWantedData));
    };
    android_RTCVideoEventHandler.prototype.onAudioFrameSendStateChanged = function (roomId, user, state) {
        if (!this._instance['onAudioFrameSendStateChanged']) {
            return;
        }
        return this._instance['onAudioFrameSendStateChanged'](String(roomId), packObject(user, RTCUser), t_FirstFrameSendState.android_to_ts(state));
    };
    android_RTCVideoEventHandler.prototype.onVideoFrameSendStateChanged = function (roomId, user, state) {
        if (!this._instance['onVideoFrameSendStateChanged']) {
            return;
        }
        return this._instance['onVideoFrameSendStateChanged'](String(roomId), packObject(user, RTCUser), t_FirstFrameSendState.android_to_ts(state));
    };
    android_RTCVideoEventHandler.prototype.onScreenVideoFrameSendStateChanged = function (roomId, user, state) {
        if (!this._instance['onScreenVideoFrameSendStateChanged']) {
            return;
        }
        return this._instance['onScreenVideoFrameSendStateChanged'](String(roomId), packObject(user, RTCUser), t_FirstFrameSendState.android_to_ts(state));
    };
    android_RTCVideoEventHandler.prototype.onAudioFramePlayStateChanged = function (roomId, user, state) {
        if (!this._instance['onAudioFramePlayStateChanged']) {
            return;
        }
        return this._instance['onAudioFramePlayStateChanged'](String(roomId), packObject(user, RTCUser), t_FirstFramePlayState.android_to_ts(state));
    };
    android_RTCVideoEventHandler.prototype.onVideoFramePlayStateChanged = function (roomId, user, state) {
        if (!this._instance['onVideoFramePlayStateChanged']) {
            return;
        }
        return this._instance['onVideoFramePlayStateChanged'](String(roomId), packObject(user, RTCUser), t_FirstFramePlayState.android_to_ts(state));
    };
    android_RTCVideoEventHandler.prototype.onScreenVideoFramePlayStateChanged = function (roomId, user, state) {
        if (!this._instance['onScreenVideoFramePlayStateChanged']) {
            return;
        }
        return this._instance['onScreenVideoFramePlayStateChanged'](String(roomId), packObject(user, RTCUser), t_FirstFramePlayState.android_to_ts(state));
    };
    android_RTCVideoEventHandler.prototype.onAudioDeviceStateChanged = function (deviceID, deviceType, deviceState, deviceError) {
        if (!this._instance['onAudioDeviceStateChanged']) {
            return;
        }
        return this._instance['onAudioDeviceStateChanged'](String(deviceID), t_AudioDeviceType.android_to_ts(deviceType), t_MediaDeviceState.android_to_ts(deviceState), t_MediaDeviceError.android_to_ts(deviceError));
    };
    android_RTCVideoEventHandler.prototype.onVideoDeviceStateChanged = function (deviceID, deviceType, deviceState, deviceError) {
        if (!this._instance['onVideoDeviceStateChanged']) {
            return;
        }
        return this._instance['onVideoDeviceStateChanged'](String(deviceID), t_VideoDeviceType.android_to_ts(deviceType), t_MediaDeviceState.android_to_ts(deviceState), t_MediaDeviceError.android_to_ts(deviceError));
    };
    android_RTCVideoEventHandler.prototype.onAudioDeviceWarning = function (deviceID, deviceType, deviceWarning) {
        if (!this._instance['onAudioDeviceWarning']) {
            return;
        }
        return this._instance['onAudioDeviceWarning'](String(deviceID), t_AudioDeviceType.android_to_ts(deviceType), t_MediaDeviceWarning.android_to_ts(deviceWarning));
    };
    android_RTCVideoEventHandler.prototype.onVideoDeviceWarning = function (deviceID, deviceType, deviceWarning) {
        if (!this._instance['onVideoDeviceWarning']) {
            return;
        }
        return this._instance['onVideoDeviceWarning'](String(deviceID), t_VideoDeviceType.android_to_ts(deviceType), t_MediaDeviceWarning.android_to_ts(deviceWarning));
    };
    android_RTCVideoEventHandler.prototype.onRecordingStateUpdate = function (type, state, errorCode, info) {
        if (!this._instance['onRecordingStateUpdate']) {
            return;
        }
        return this._instance['onRecordingStateUpdate'](t_StreamIndex.android_to_ts(type), t_RecordingState.android_to_ts(state), t_RecordingErrorCode.android_to_ts(errorCode), packObject(info, RecordingInfo));
    };
    android_RTCVideoEventHandler.prototype.onRecordingProgressUpdate = function (type, progress, info) {
        if (!this._instance['onRecordingProgressUpdate']) {
            return;
        }
        return this._instance['onRecordingProgressUpdate'](t_StreamIndex.android_to_ts(type), packObject(progress, RecordingProgress), packObject(info, RecordingInfo));
    };
    android_RTCVideoEventHandler.prototype.onAudioRecordingStateUpdate = function (state, errorCode) {
        if (!this._instance['onAudioRecordingStateUpdate']) {
            return;
        }
        return this._instance['onAudioRecordingStateUpdate'](t_AudioRecordingState.android_to_ts(state), t_AudioRecordingErrorCode.android_to_ts(errorCode));
    };
    android_RTCVideoEventHandler.prototype.onAudioMixingPlayingProgress = function (mixId, progress) {
        if (!this._instance['onAudioMixingPlayingProgress']) {
            return;
        }
        return this._instance['onAudioMixingPlayingProgress'](Number(mixId), Number(progress));
    };
    android_RTCVideoEventHandler.prototype.onLocalAudioPropertiesReport = function (audioPropertiesInfos) {
        if (!this._instance['onLocalAudioPropertiesReport']) {
            return;
        }
        return this._instance['onLocalAudioPropertiesReport'](audioPropertiesInfos.map(function ($item) { return packObject($item, LocalAudioPropertiesInfo); }));
    };
    android_RTCVideoEventHandler.prototype.onRemoteAudioPropertiesReport = function (audioPropertiesInfos, totalRemoteVolume) {
        if (!this._instance['onRemoteAudioPropertiesReport']) {
            return;
        }
        return this._instance['onRemoteAudioPropertiesReport'](audioPropertiesInfos.map(function ($item) { return packObject($item, RemoteAudioPropertiesInfo); }), Number(totalRemoteVolume));
    };
    android_RTCVideoEventHandler.prototype.onActiveSpeaker = function (roomId, uid) {
        if (!this._instance['onActiveSpeaker']) {
            return;
        }
        return this._instance['onActiveSpeaker'](String(roomId), String(uid));
    };
    android_RTCVideoEventHandler.prototype.onStreamSyncInfoReceived = function (streamKey, streamType, data) {
        if (!this._instance['onStreamSyncInfoReceived']) {
            return;
        }
        return this._instance['onStreamSyncInfoReceived'](packObject(streamKey, RemoteStreamKey), t_SyncInfoStreamType.android_to_ts(streamType), data);
    };
    android_RTCVideoEventHandler.prototype.onPushPublicStreamResult = function (roomId, publicStreamId, error) {
        if (!this._instance['onPushPublicStreamResult']) {
            return;
        }
        return this._instance['onPushPublicStreamResult'](String(roomId), String(publicStreamId), t_PublicStreamErrorCode.android_to_ts(error));
    };
    android_RTCVideoEventHandler.prototype.onPlayPublicStreamResult = function (publicStreamId, error) {
        if (!this._instance['onPlayPublicStreamResult']) {
            return;
        }
        return this._instance['onPlayPublicStreamResult'](String(publicStreamId), t_PublicStreamErrorCode.android_to_ts(error));
    };
    android_RTCVideoEventHandler.prototype.onPublicStreamSEIMessageReceived = function (publicStreamId, message, sourceType) {
        if (!this._instance['onPublicStreamSEIMessageReceived']) {
            return;
        }
        return this._instance['onPublicStreamSEIMessageReceived'](String(publicStreamId), message, t_DataMessageSourceType.android_to_ts(sourceType));
    };
    android_RTCVideoEventHandler.prototype.onPublicStreamDataMessageReceived = function (publicStreamId, message, sourceType) {
        if (!this._instance['onPublicStreamDataMessageReceived']) {
            return;
        }
        return this._instance['onPublicStreamDataMessageReceived'](String(publicStreamId), message, t_DataMessageSourceType.android_to_ts(sourceType));
    };
    android_RTCVideoEventHandler.prototype.onFirstPublicStreamVideoFrameDecoded = function (publicStreamId, videoFrameInfo) {
        if (!this._instance['onFirstPublicStreamVideoFrameDecoded']) {
            return;
        }
        return this._instance['onFirstPublicStreamVideoFrameDecoded'](String(publicStreamId), packObject(videoFrameInfo, VideoFrameInfo));
    };
    android_RTCVideoEventHandler.prototype.onFirstPublicStreamAudioFrame = function (publicStreamId) {
        if (!this._instance['onFirstPublicStreamAudioFrame']) {
            return;
        }
        return this._instance['onFirstPublicStreamAudioFrame'](String(publicStreamId));
    };
    android_RTCVideoEventHandler.prototype.onEchoTestResult = function (result) {
        if (!this._instance['onEchoTestResult']) {
            return;
        }
        return this._instance['onEchoTestResult'](t_EchoTestResult.android_to_ts(result));
    };
    android_RTCVideoEventHandler.prototype.onCloudProxyConnected = function (interval) {
        if (!this._instance['onCloudProxyConnected']) {
            return;
        }
        return this._instance['onCloudProxyConnected'](Number(interval));
    };
    android_RTCVideoEventHandler.prototype.onHardwareEchoDetectionResult = function (hardwareEchoDetectionResult) {
        if (!this._instance['onHardwareEchoDetectionResult']) {
            return;
        }
        return this._instance['onHardwareEchoDetectionResult'](t_HardwareEchoDetectionResult.android_to_ts(hardwareEchoDetectionResult));
    };
    android_RTCVideoEventHandler.prototype.onLocalProxyStateChanged = function (localProxyType, localProxyState, localProxyError) {
        if (!this._instance['onLocalProxyStateChanged']) {
            return;
        }
        return this._instance['onLocalProxyStateChanged'](t_LocalProxyType.android_to_ts(localProxyType), t_LocalProxyState.android_to_ts(localProxyState), t_LocalProxyError.android_to_ts(localProxyError));
    };
    android_RTCVideoEventHandler.prototype.onUserMuteAudio = function (roomId, uid, muteState) {
        if (!this._instance['onUserMuteAudio']) {
            return;
        }
        return this._instance['onUserMuteAudio'](String(roomId), String(uid), t_MuteState.android_to_ts(muteState));
    };
    android_RTCVideoEventHandler.prototype.onUserMuteVideo = function (roomId, uid, muteState) {
        if (!this._instance['onUserMuteVideo']) {
            return;
        }
        return this._instance['onUserMuteVideo'](String(roomId), String(uid), t_MuteState.android_to_ts(muteState));
    };
    android_RTCVideoEventHandler.prototype.onAudioPlaybackDeviceChanged = function (device) {
        if (!this._instance['onAudioPlaybackDeviceChanged']) {
            return;
        }
        return this._instance['onAudioPlaybackDeviceChanged'](t_AudioPlaybackDevice.android_to_ts(device));
    };
    android_RTCVideoEventHandler.prototype.onMediaDeviceStateChanged = function (deviceID, deviceType, deviceState, deviceError) {
        if (!this._instance['onMediaDeviceStateChanged']) {
            return;
        }
        return this._instance['onMediaDeviceStateChanged'](String(deviceID), t_MediaDeviceType.android_to_ts(deviceType), t_MediaDeviceState.android_to_ts(deviceState), t_MediaDeviceError.android_to_ts(deviceError));
    };
    android_RTCVideoEventHandler.prototype.onMediaDeviceWarning = function (deviceID, deviceType, deviceWarning) {
        if (!this._instance['onMediaDeviceWarning']) {
            return;
        }
        return this._instance['onMediaDeviceWarning'](String(deviceID), t_MediaDeviceType.android_to_ts(deviceType), t_MediaDeviceWarning.android_to_ts(deviceWarning));
    };
    android_RTCVideoEventHandler.prototype.onHttpProxyState = function (state) {
        if (!this._instance['onHttpProxyState']) {
            return;
        }
        return this._instance['onHttpProxyState'](Number(state));
    };
    android_RTCVideoEventHandler.prototype.onHttpsProxyState = function (state) {
        if (!this._instance['onHttpsProxyState']) {
            return;
        }
        return this._instance['onHttpsProxyState'](Number(state));
    };
    android_RTCVideoEventHandler.prototype.onSocks5ProxyState = function (state, cmd, proxyAddress, localAddress, remoteAddress) {
        if (!this._instance['onSocks5ProxyState']) {
            return;
        }
        return this._instance['onSocks5ProxyState'](Number(state), String(cmd), String(proxyAddress), String(localAddress), String(remoteAddress));
    };
    android_RTCVideoEventHandler.prototype.onAudioMixingStateChanged = function (mixId, state, error) {
        if (!this._instance['onAudioMixingStateChanged']) {
            return;
        }
        return this._instance['onAudioMixingStateChanged'](Number(mixId), t_AudioMixingState.android_to_ts(state), t_AudioMixingError.android_to_ts(error));
    };
    return android_RTCVideoEventHandler;
}(IRTCVideoEventHandler));
var ios_RTCVideoEventHandler = /** @class */ (function (_super) {
    __extends(ios_RTCVideoEventHandler, _super);
    function ios_RTCVideoEventHandler(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    ios_RTCVideoEventHandler.prototype.rtcEngine$onWarning = function (engine, code) {
        if (!this._instance['onWarning']) {
            return;
        }
        return this._instance['onWarning'](t_WarningCode.ios_to_ts(code));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onError = function (engine, errorCode) {
        if (!this._instance['onError']) {
            return;
        }
        return this._instance['onError'](t_ErrorCode.ios_to_ts(errorCode));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onExtensionAccessError$msg = function (engine, extensionName, msg) {
        if (!this._instance['onExtensionAccessError']) {
            return;
        }
        return this._instance['onExtensionAccessError'](String(extensionName), String(msg));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onSysStats = function (engine, stats) {
        if (!this._instance['onSysStats']) {
            return;
        }
        return this._instance['onSysStats'](packObject(stats, SysStats));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onNetworkTypeChanged = function (engine, type) {
        if (!this._instance['onNetworkTypeChanged']) {
            return;
        }
        return this._instance['onNetworkTypeChanged'](t_RTCNetworkType.ios_to_ts(type));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onUserStartVideoCapture$uid = function (engine, roomId, uid) {
        if (!this._instance['onUserStartVideoCapture']) {
            return;
        }
        return this._instance['onUserStartVideoCapture'](String(roomId), String(uid));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onUserStopVideoCapture$uid = function (engine, roomId, uid) {
        if (!this._instance['onUserStopVideoCapture']) {
            return;
        }
        return this._instance['onUserStopVideoCapture'](String(roomId), String(uid));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onCreateRoomStateChanged$errorCode = function (engine, roomId, errorCode) {
        if (!this._instance['onCreateRoomStateChanged']) {
            return;
        }
        return this._instance['onCreateRoomStateChanged'](String(roomId), Number(errorCode));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onUserStartAudioCapture$uid = function (engine, roomId, userId) {
        if (!this._instance['onUserStartAudioCapture']) {
            return;
        }
        return this._instance['onUserStartAudioCapture'](String(roomId), String(userId));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onUserStopAudioCapture$uid = function (engine, roomId, userId) {
        if (!this._instance['onUserStopAudioCapture']) {
            return;
        }
        return this._instance['onUserStopAudioCapture'](String(roomId), String(userId));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onLocalAudioStateChanged$error = function (engine, state, error) {
        if (!this._instance['onLocalAudioStateChanged']) {
            return;
        }
        return this._instance['onLocalAudioStateChanged'](t_LocalAudioStreamState.ios_to_ts(state), t_LocalAudioStreamError.ios_to_ts(error));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onRemoteAudioStateChanged$state$reason = function (engine, key, state, reason) {
        if (!this._instance['onRemoteAudioStateChanged']) {
            return;
        }
        return this._instance['onRemoteAudioStateChanged'](packObject(key, RemoteStreamKey), t_RemoteAudioState.ios_to_ts(state), t_RemoteAudioStateChangeReason.ios_to_ts(reason));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onLocalVideoStateChanged$withStreamState$withStreamError = function (engine, streamIndex, state, error) {
        if (!this._instance['onLocalVideoStateChanged']) {
            return;
        }
        return this._instance['onLocalVideoStateChanged'](t_StreamIndex.ios_to_ts(streamIndex), t_LocalVideoStreamState.ios_to_ts(state), t_LocalVideoStreamError.ios_to_ts(error));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onRemoteVideoStateChanged$withVideoState$withVideoStateReason = function (engine, streamKey, state, reason) {
        if (!this._instance['onRemoteVideoStateChanged']) {
            return;
        }
        return this._instance['onRemoteVideoStateChanged'](packObject(streamKey, RemoteStreamKey), t_RemoteVideoState.ios_to_ts(state), t_RemoteVideoStateChangeReason.ios_to_ts(reason));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onFirstRemoteVideoFrameRendered$withFrameInfo = function (engine, streamKey, frameInfo) {
        if (!this._instance['onFirstRemoteVideoFrameRendered']) {
            return;
        }
        return this._instance['onFirstRemoteVideoFrameRendered'](packObject(streamKey, RemoteStreamKey), packObject(frameInfo, VideoFrameInfo));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onFirstRemoteVideoFrameDecoded$withFrameInfo = function (engine, streamKey, frameInfo) {
        if (!this._instance['onFirstRemoteVideoFrameDecoded']) {
            return;
        }
        return this._instance['onFirstRemoteVideoFrameDecoded'](packObject(streamKey, RemoteStreamKey), packObject(frameInfo, VideoFrameInfo));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onFirstLocalVideoFrameCaptured$withFrameInfo = function (engine, streamIndex, frameInfo) {
        if (!this._instance['onFirstLocalVideoFrameCaptured']) {
            return;
        }
        return this._instance['onFirstLocalVideoFrameCaptured'](t_StreamIndex.ios_to_ts(streamIndex), packObject(frameInfo, VideoFrameInfo));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onLocalVideoSizeChanged$withFrameInfo = function (engine, streamIndex, frameInfo) {
        if (!this._instance['onLocalVideoSizeChanged']) {
            return;
        }
        return this._instance['onLocalVideoSizeChanged'](t_StreamIndex.ios_to_ts(streamIndex), packObject(frameInfo, VideoFrameInfo));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onRemoteVideoSizeChanged$withFrameInfo = function (engine, streamKey, frameInfo) {
        if (!this._instance['onRemoteVideoSizeChanged']) {
            return;
        }
        return this._instance['onRemoteVideoSizeChanged'](packObject(streamKey, RemoteStreamKey), packObject(frameInfo, VideoFrameInfo));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onConnectionStateChanged = function (engine, state) {
        if (!this._instance['onConnectionStateChanged']) {
            return;
        }
        return this._instance['onConnectionStateChanged'](t_ConnectionState.ios_to_ts(state));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onAudioRouteChanged = function (engine, device) {
        if (!this._instance['onAudioRouteChanged']) {
            return;
        }
        return this._instance['onAudioRouteChanged'](t_AudioRoute.ios_to_ts(device));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onFirstLocalAudioFrame = function (engine, streamIndex) {
        if (!this._instance['onFirstLocalAudioFrame']) {
            return;
        }
        return this._instance['onFirstLocalAudioFrame'](t_StreamIndex.ios_to_ts(streamIndex));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onFirstRemoteAudioFrame = function (engine, key) {
        if (!this._instance['onFirstRemoteAudioFrame']) {
            return;
        }
        return this._instance['onFirstRemoteAudioFrame'](packObject(key, RemoteStreamKey));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onSEIMessageReceived$andMessage = function (engine, remoteStreamKey, message) {
        if (!this._instance['onSEIMessageReceived']) {
            return;
        }
        return this._instance['onSEIMessageReceived'](packObject(remoteStreamKey, RemoteStreamKey), message);
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onSEIStreamUpdate$eventType = function (engine, remoteStreamKey, eventType) {
        if (!this._instance['onSEIStreamUpdate']) {
            return;
        }
        return this._instance['onSEIStreamUpdate'](packObject(remoteStreamKey, RemoteStreamKey), t_SEIStreamUpdateEventType.ios_to_ts(eventType));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onLoginResult$errorCode$elapsed = function (engine, uid, errorCode, elapsed) {
        if (!this._instance['onLoginResult']) {
            return;
        }
        return this._instance['onLoginResult'](String(uid), t_LoginErrorCode.ios_to_ts(errorCode), Number(elapsed));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onLogout = function (engine, reason) {
        if (!this._instance['onLogout']) {
            return;
        }
        return this._instance['onLogout'](t_LogoutReason.ios_to_ts(reason));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onServerParamsSetResult = function (engine, errorCode) {
        if (!this._instance['onServerParamsSetResult']) {
            return;
        }
        return this._instance['onServerParamsSetResult'](Number(errorCode));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onGetPeerOnlineStatus$status = function (engine, peerUserId, status) {
        if (!this._instance['onGetPeerOnlineStatus']) {
            return;
        }
        return this._instance['onGetPeerOnlineStatus'](String(peerUserId), t_UserOnlineStatus.ios_to_ts(status));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onUserMessageReceivedOutsideRoom$message = function (engine, uid, message) {
        if (!this._instance['onUserMessageReceivedOutsideRoom']) {
            return;
        }
        return this._instance['onUserMessageReceivedOutsideRoom'](String(uid), String(message));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onUserBinaryMessageReceivedOutsideRoom$message = function (engine, uid, message) {
        if (!this._instance['onUserBinaryMessageReceivedOutsideRoom']) {
            return;
        }
        return this._instance['onUserBinaryMessageReceivedOutsideRoom'](String(uid), message);
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onUserMessageSendResultOutsideRoom$error = function (engine, msgid, error) {
        if (!this._instance['onUserMessageSendResultOutsideRoom']) {
            return;
        }
        return this._instance['onUserMessageSendResultOutsideRoom'](Number(msgid), t_UserMessageSendResult.ios_to_ts(error));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onServerMessageSendResult$error$message = function (engine, msgid, error, message) {
        if (!this._instance['onServerMessageSendResult']) {
            return;
        }
        return this._instance['onServerMessageSendResult'](Number(msgid), t_UserMessageSendResult.ios_to_ts(error), message);
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onNetworkDetectionResult$quality$rtt$lostRate$bitrate$jitter = function (engine, type, quality, rtt, lostRate, bitrate, jitter) {
        if (!this._instance['onNetworkDetectionResult']) {
            return;
        }
        return this._instance['onNetworkDetectionResult'](t_NetworkDetectionLinkType.ios_to_ts(type), t_NetworkQuality.ios_to_ts(quality), Number(rtt), Number(lostRate), Number(bitrate), Number(jitter));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onNetworkDetectionStopped = function (engine, errorCode) {
        if (!this._instance['onNetworkDetectionStopped']) {
            return;
        }
        return this._instance['onNetworkDetectionStopped'](t_NetworkDetectionStopReason.ios_to_ts(errorCode));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onSimulcastSubscribeFallback = function (engine, event) {
        if (!this._instance['onSimulcastSubscribeFallback']) {
            return;
        }
        return this._instance['onSimulcastSubscribeFallback'](packObject(event, RemoteStreamSwitchEvent));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onPerformanceAlarms$roomId$reason$sourceWantedData = function (engine, mode, roomId, reason, data) {
        if (!this._instance['onPerformanceAlarms']) {
            return;
        }
        return this._instance['onPerformanceAlarms'](t_PerformanceAlarmMode.ios_to_ts(mode), String(roomId), t_PerformanceAlarmReason.ios_to_ts(reason), packObject(data, SourceWantedData));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onAudioFrameSendStateChanged$rtcUser$state = function (engine, roomId, user, state) {
        if (!this._instance['onAudioFrameSendStateChanged']) {
            return;
        }
        return this._instance['onAudioFrameSendStateChanged'](String(roomId), packObject(user, RTCUser), t_FirstFrameSendState.ios_to_ts(state));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onVideoFrameSendStateChanged$rtcUser$state = function (engine, roomId, user, state) {
        if (!this._instance['onVideoFrameSendStateChanged']) {
            return;
        }
        return this._instance['onVideoFrameSendStateChanged'](String(roomId), packObject(user, RTCUser), t_FirstFrameSendState.ios_to_ts(state));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onScreenVideoFrameSendStateChanged$rtcUser$state = function (engine, roomId, user, state) {
        if (!this._instance['onScreenVideoFrameSendStateChanged']) {
            return;
        }
        return this._instance['onScreenVideoFrameSendStateChanged'](String(roomId), packObject(user, RTCUser), t_FirstFrameSendState.ios_to_ts(state));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onAudioFramePlayStateChanged$rtcUser$state = function (engine, roomId, user, state) {
        if (!this._instance['onAudioFramePlayStateChanged']) {
            return;
        }
        return this._instance['onAudioFramePlayStateChanged'](String(roomId), packObject(user, RTCUser), t_FirstFramePlayState.ios_to_ts(state));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onVideoFramePlayStateChanged$rtcUser$state = function (engine, roomId, user, state) {
        if (!this._instance['onVideoFramePlayStateChanged']) {
            return;
        }
        return this._instance['onVideoFramePlayStateChanged'](String(roomId), packObject(user, RTCUser), t_FirstFramePlayState.ios_to_ts(state));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onScreenVideoFramePlayStateChanged$rtcUser$state = function (engine, roomId, user, state) {
        if (!this._instance['onScreenVideoFramePlayStateChanged']) {
            return;
        }
        return this._instance['onScreenVideoFramePlayStateChanged'](String(roomId), packObject(user, RTCUser), t_FirstFramePlayState.ios_to_ts(state));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onAudioDeviceStateChanged$device_type$device_state$device_error = function (engine, deviceID, deviceType, deviceState, deviceError) {
        if (!this._instance['onAudioDeviceStateChanged']) {
            return;
        }
        return this._instance['onAudioDeviceStateChanged'](String(deviceID), t_AudioDeviceType.ios_to_ts(deviceType), t_MediaDeviceState.ios_to_ts(deviceState), t_MediaDeviceError.ios_to_ts(deviceError));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onVideoDeviceStateChanged$device_type$device_state$device_error = function (engine, deviceID, deviceType, deviceState, deviceError) {
        if (!this._instance['onVideoDeviceStateChanged']) {
            return;
        }
        return this._instance['onVideoDeviceStateChanged'](String(deviceID), t_VideoDeviceType.ios_to_ts(deviceType), t_MediaDeviceState.ios_to_ts(deviceState), t_MediaDeviceError.ios_to_ts(deviceError));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onAudioDeviceWarning$deviceType$deviceWarning = function (engine, deviceId, deviceType, deviceWarning) {
        if (!this._instance['onAudioDeviceWarning']) {
            return;
        }
        return this._instance['onAudioDeviceWarning'](String(deviceId), t_AudioDeviceType.ios_to_ts(deviceType), t_MediaDeviceWarning.ios_to_ts(deviceWarning));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onVideoDeviceWarning$deviceType$deviceWarning = function (engine, deviceId, deviceType, deviceWarning) {
        if (!this._instance['onVideoDeviceWarning']) {
            return;
        }
        return this._instance['onVideoDeviceWarning'](String(deviceId), t_VideoDeviceType.ios_to_ts(deviceType), t_MediaDeviceWarning.ios_to_ts(deviceWarning));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onRecordingStateUpdate$state$error_code$recording_info = function (engine, type, state, errorCode, recordingInfo) {
        if (!this._instance['onRecordingStateUpdate']) {
            return;
        }
        return this._instance['onRecordingStateUpdate'](t_StreamIndex.ios_to_ts(type), t_RecordingState.ios_to_ts(state), t_RecordingErrorCode.ios_to_ts(errorCode), packObject(recordingInfo, RecordingInfo));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onRecordingProgressUpdate$process$recording_info = function (engine, type, process, recordingInfo) {
        if (!this._instance['onRecordingProgressUpdate']) {
            return;
        }
        return this._instance['onRecordingProgressUpdate'](t_StreamIndex.ios_to_ts(type), packObject(process, RecordingProgress), packObject(recordingInfo, RecordingInfo));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onAudioRecordingStateUpdate$error_code = function (engine, state, errorCode) {
        if (!this._instance['onAudioRecordingStateUpdate']) {
            return;
        }
        return this._instance['onAudioRecordingStateUpdate'](t_AudioRecordingState.ios_to_ts(state), t_AudioRecordingErrorCode.ios_to_ts(errorCode));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onAudioMixingPlayingProgress$progress = function (engine, mixId, progress) {
        if (!this._instance['onAudioMixingPlayingProgress']) {
            return;
        }
        return this._instance['onAudioMixingPlayingProgress'](Number(mixId), Number(progress));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onLocalAudioPropertiesReport = function (engine, audioPropertiesInfos) {
        if (!this._instance['onLocalAudioPropertiesReport']) {
            return;
        }
        return this._instance['onLocalAudioPropertiesReport'](audioPropertiesInfos.map(function ($item) { return packObject($item, LocalAudioPropertiesInfo); }));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onRemoteAudioPropertiesReport$totalRemoteVolume = function (engine, audioPropertiesInfos, totalRemoteVolume) {
        if (!this._instance['onRemoteAudioPropertiesReport']) {
            return;
        }
        return this._instance['onRemoteAudioPropertiesReport'](audioPropertiesInfos.map(function ($item) { return packObject($item, RemoteAudioPropertiesInfo); }), Number(totalRemoteVolume));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onActiveSpeaker$uid = function (engine, roomId, uid) {
        if (!this._instance['onActiveSpeaker']) {
            return;
        }
        return this._instance['onActiveSpeaker'](String(roomId), String(uid));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onStreamSyncInfoReceived$streamType$data = function (engine, remoteStreamKey, streamType, data) {
        if (!this._instance['onStreamSyncInfoReceived']) {
            return;
        }
        return this._instance['onStreamSyncInfoReceived'](packObject(remoteStreamKey, RemoteStreamKey), t_SyncInfoStreamType.ios_to_ts(streamType), data);
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onPushPublicStreamResult$publicStreamId$errorCode = function (engine, roomId, streamId, errorCode) {
        if (!this._instance['onPushPublicStreamResult']) {
            return;
        }
        return this._instance['onPushPublicStreamResult'](String(roomId), String(streamId), t_PublicStreamErrorCode.ios_to_ts(errorCode));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onPlayPublicStreamResult$errorCode = function (engine, publicStreamId, errorCode) {
        if (!this._instance['onPlayPublicStreamResult']) {
            return;
        }
        return this._instance['onPlayPublicStreamResult'](String(publicStreamId), t_PublicStreamErrorCode.ios_to_ts(errorCode));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onPublicStreamSEIMessageReceived$andMessage$andSourceType = function (engine, publicStreamId, message, sourceType) {
        if (!this._instance['onPublicStreamSEIMessageReceived']) {
            return;
        }
        return this._instance['onPublicStreamSEIMessageReceived'](String(publicStreamId), message, t_DataMessageSourceType.ios_to_ts(sourceType));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onPublicStreamDataMessageReceived$andMessage$andSourceType = function (engine, publicStreamId, message, sourceType) {
        if (!this._instance['onPublicStreamDataMessageReceived']) {
            return;
        }
        return this._instance['onPublicStreamDataMessageReceived'](String(publicStreamId), message, t_DataMessageSourceType.ios_to_ts(sourceType));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onFirstPublicStreamVideoFrameDecoded$withFrameInfo = function (engine, publicStreamId, frameInfo) {
        if (!this._instance['onFirstPublicStreamVideoFrameDecoded']) {
            return;
        }
        return this._instance['onFirstPublicStreamVideoFrameDecoded'](String(publicStreamId), packObject(frameInfo, VideoFrameInfo));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onFirstPublicStreamAudioFrame = function (engine, publicStreamId) {
        if (!this._instance['onFirstPublicStreamAudioFrame']) {
            return;
        }
        return this._instance['onFirstPublicStreamAudioFrame'](String(publicStreamId));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onEchoTestResult = function (engine, result) {
        if (!this._instance['onEchoTestResult']) {
            return;
        }
        return this._instance['onEchoTestResult'](t_EchoTestResult.ios_to_ts(result));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onCloudProxyConnected = function (engine, interval) {
        if (!this._instance['onCloudProxyConnected']) {
            return;
        }
        return this._instance['onCloudProxyConnected'](Number(interval));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onHardwareEchoDetectionResult = function (engine, result) {
        if (!this._instance['onHardwareEchoDetectionResult']) {
            return;
        }
        return this._instance['onHardwareEchoDetectionResult'](t_HardwareEchoDetectionResult.ios_to_ts(result));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onLocalProxyStateChanged$withProxyState$withProxyError = function (engine, type, state, error) {
        if (!this._instance['onLocalProxyStateChanged']) {
            return;
        }
        return this._instance['onLocalProxyStateChanged'](t_LocalProxyType.ios_to_ts(type), t_LocalProxyState.ios_to_ts(state), t_LocalProxyError.ios_to_ts(error));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onUserMuteAudio$uid$muteState = function (engine, roomId, uid, muteState) {
        if (!this._instance['onUserMuteAudio']) {
            return;
        }
        return this._instance['onUserMuteAudio'](String(roomId), String(uid), t_MuteState.ios_to_ts(muteState));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onUserMuteVideo$uid$withMuteState = function (engine, roomId, uid, muteState) {
        if (!this._instance['onUserMuteVideo']) {
            return;
        }
        return this._instance['onUserMuteVideo'](String(roomId), String(uid), t_MuteState.ios_to_ts(muteState));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onAudioPlaybackDeviceChanged = function (engine, device) {
        if (!this._instance['onAudioPlaybackDeviceChanged']) {
            return;
        }
        return this._instance['onAudioPlaybackDeviceChanged'](t_AudioPlaybackDevice.ios_to_ts(device));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onMediaDeviceStateChanged$device_type$device_state$device_error = function (engine, deviceID, deviceType, deviceState, deviceError) {
        if (!this._instance['onMediaDeviceStateChanged']) {
            return;
        }
        return this._instance['onMediaDeviceStateChanged'](String(deviceID), t_MediaDeviceType.ios_to_ts(deviceType), t_MediaDeviceState.ios_to_ts(deviceState), t_MediaDeviceError.ios_to_ts(deviceError));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onMediaDeviceWarning$deviceType$deviceWarning = function (engine, deviceId, deviceType, deviceWarning) {
        if (!this._instance['onMediaDeviceWarning']) {
            return;
        }
        return this._instance['onMediaDeviceWarning'](String(deviceId), t_MediaDeviceType.ios_to_ts(deviceType), t_MediaDeviceWarning.ios_to_ts(deviceWarning));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onHttpProxyState = function (engine, state) {
        if (!this._instance['onHttpProxyState']) {
            return;
        }
        return this._instance['onHttpProxyState'](Number(state));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onHttpsProxyState = function (engine, state) {
        if (!this._instance['onHttpsProxyState']) {
            return;
        }
        return this._instance['onHttpsProxyState'](Number(state));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onSocks5ProxyState$cmd$proxy_address$local_address$remote_address = function (engine, state, cmd, proxyAddress, localAddress, remoteAddress) {
        if (!this._instance['onSocks5ProxyState']) {
            return;
        }
        return this._instance['onSocks5ProxyState'](Number(state), String(cmd), String(proxyAddress), String(localAddress), String(remoteAddress));
    };
    ios_RTCVideoEventHandler.prototype.rtcEngine$onAudioMixingStateChanged$state$error = function (engine, mixId, state, error) {
        if (!this._instance['onAudioMixingStateChanged']) {
            return;
        }
        return this._instance['onAudioMixingStateChanged'](Number(mixId), t_AudioMixingState.ios_to_ts(state), t_AudioMixingError.ios_to_ts(error));
    };
    return ios_RTCVideoEventHandler;
}(ByteRTCVideoDelegate));
var android_RTCRoomEventHandler = /** @class */ (function (_super) {
    __extends(android_RTCRoomEventHandler, _super);
    function android_RTCRoomEventHandler(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    android_RTCRoomEventHandler.prototype.onLeaveRoom = function (stats) {
        if (!this._instance['onLeaveRoom']) {
            return;
        }
        return this._instance['onLeaveRoom'](packObject(stats, RTCRoomStats));
    };
    android_RTCRoomEventHandler.prototype.onRoomStateChanged = function (roomId, uid, state, extraInfo) {
        if (!this._instance['onRoomStateChanged']) {
            return;
        }
        return this._instance['onRoomStateChanged'](String(roomId), String(uid), Number(state), String(extraInfo));
    };
    android_RTCRoomEventHandler.prototype.onStreamStateChanged = function (roomId, uid, state, extraInfo) {
        if (!this._instance['onStreamStateChanged']) {
            return;
        }
        return this._instance['onStreamStateChanged'](String(roomId), String(uid), Number(state), String(extraInfo));
    };
    android_RTCRoomEventHandler.prototype.onAVSyncStateChange = function (state) {
        if (!this._instance['onAVSyncStateChange']) {
            return;
        }
        return this._instance['onAVSyncStateChange'](t_AVSyncState.android_to_ts(state));
    };
    android_RTCRoomEventHandler.prototype.onRoomStats = function (stats) {
        if (!this._instance['onRoomStats']) {
            return;
        }
        return this._instance['onRoomStats'](packObject(stats, RTCRoomStats));
    };
    android_RTCRoomEventHandler.prototype.onUserJoined = function (userInfo, elapsed) {
        if (!this._instance['onUserJoined']) {
            return;
        }
        return this._instance['onUserJoined'](packObject(userInfo, UserInfo), Number(elapsed));
    };
    android_RTCRoomEventHandler.prototype.onUserLeave = function (uid, reason) {
        if (!this._instance['onUserLeave']) {
            return;
        }
        return this._instance['onUserLeave'](String(uid), t_RTCUserOfflineReason.android_to_ts(reason));
    };
    android_RTCRoomEventHandler.prototype.onTokenWillExpire = function () {
        if (!this._instance['onTokenWillExpire']) {
            return;
        }
        return this._instance['onTokenWillExpire']();
    };
    android_RTCRoomEventHandler.prototype.onPublishPrivilegeTokenWillExpire = function () {
        if (!this._instance['onPublishPrivilegeTokenWillExpire']) {
            return;
        }
        return this._instance['onPublishPrivilegeTokenWillExpire']();
    };
    android_RTCRoomEventHandler.prototype.onSubscribePrivilegeTokenWillExpire = function () {
        if (!this._instance['onSubscribePrivilegeTokenWillExpire']) {
            return;
        }
        return this._instance['onSubscribePrivilegeTokenWillExpire']();
    };
    android_RTCRoomEventHandler.prototype.onUserPublishStream = function (uid, type) {
        if (!this._instance['onUserPublishStream']) {
            return;
        }
        return this._instance['onUserPublishStream'](String(uid), t_MediaStreamType.android_to_ts(type));
    };
    android_RTCRoomEventHandler.prototype.onUserUnpublishStream = function (uid, type, reason) {
        if (!this._instance['onUserUnpublishStream']) {
            return;
        }
        return this._instance['onUserUnpublishStream'](String(uid), t_MediaStreamType.android_to_ts(type), t_StreamRemoveReason.android_to_ts(reason));
    };
    android_RTCRoomEventHandler.prototype.onUserPublishScreen = function (uid, type) {
        if (!this._instance['onUserPublishScreen']) {
            return;
        }
        return this._instance['onUserPublishScreen'](String(uid), t_MediaStreamType.android_to_ts(type));
    };
    android_RTCRoomEventHandler.prototype.onUserUnpublishScreen = function (uid, type, reason) {
        if (!this._instance['onUserUnpublishScreen']) {
            return;
        }
        return this._instance['onUserUnpublishScreen'](String(uid), t_MediaStreamType.android_to_ts(type), t_StreamRemoveReason.android_to_ts(reason));
    };
    android_RTCRoomEventHandler.prototype.onLocalStreamStats = function (stats) {
        if (!this._instance['onLocalStreamStats']) {
            return;
        }
        return this._instance['onLocalStreamStats'](packObject(stats, LocalStreamStats));
    };
    android_RTCRoomEventHandler.prototype.onRemoteStreamStats = function (stats) {
        if (!this._instance['onRemoteStreamStats']) {
            return;
        }
        return this._instance['onRemoteStreamStats'](packObject(stats, RemoteStreamStats));
    };
    android_RTCRoomEventHandler.prototype.onStreamSubscribed = function (stateCode, userId, info) {
        if (!this._instance['onStreamSubscribed']) {
            return;
        }
        return this._instance['onStreamSubscribed'](t_SubscribeState.android_to_ts(stateCode), String(userId), packObject(info, SubscribeConfig));
    };
    android_RTCRoomEventHandler.prototype.onRoomMessageReceived = function (uid, message) {
        if (!this._instance['onRoomMessageReceived']) {
            return;
        }
        return this._instance['onRoomMessageReceived'](String(uid), String(message));
    };
    android_RTCRoomEventHandler.prototype.onRoomBinaryMessageReceived = function (uid, message) {
        if (!this._instance['onRoomBinaryMessageReceived']) {
            return;
        }
        return this._instance['onRoomBinaryMessageReceived'](String(uid), message);
    };
    android_RTCRoomEventHandler.prototype.onUserMessageReceived = function (uid, message) {
        if (!this._instance['onUserMessageReceived']) {
            return;
        }
        return this._instance['onUserMessageReceived'](String(uid), String(message));
    };
    android_RTCRoomEventHandler.prototype.onUserBinaryMessageReceived = function (uid, message) {
        if (!this._instance['onUserBinaryMessageReceived']) {
            return;
        }
        return this._instance['onUserBinaryMessageReceived'](String(uid), message);
    };
    android_RTCRoomEventHandler.prototype.onUserMessageSendResult = function (msgid, error) {
        if (!this._instance['onUserMessageSendResult']) {
            return;
        }
        return this._instance['onUserMessageSendResult'](Number(msgid), t_UserMessageSendResult.android_to_ts(error));
    };
    android_RTCRoomEventHandler.prototype.onRoomMessageSendResult = function (msgid, error) {
        if (!this._instance['onRoomMessageSendResult']) {
            return;
        }
        return this._instance['onRoomMessageSendResult'](Number(msgid), t_RoomMessageSendResult.android_to_ts(error));
    };
    android_RTCRoomEventHandler.prototype.onVideoStreamBanned = function (uid, banned) {
        if (!this._instance['onVideoStreamBanned']) {
            return;
        }
        return this._instance['onVideoStreamBanned'](String(uid), banned);
    };
    android_RTCRoomEventHandler.prototype.onAudioStreamBanned = function (uid, banned) {
        if (!this._instance['onAudioStreamBanned']) {
            return;
        }
        return this._instance['onAudioStreamBanned'](String(uid), banned);
    };
    android_RTCRoomEventHandler.prototype.onForwardStreamStateChanged = function (stateInfos) {
        if (!this._instance['onForwardStreamStateChanged']) {
            return;
        }
        return this._instance['onForwardStreamStateChanged'](stateInfos.map(function ($item) { return packObject($item, ForwardStreamStateInfo); }));
    };
    android_RTCRoomEventHandler.prototype.onForwardStreamEvent = function (eventInfos) {
        if (!this._instance['onForwardStreamEvent']) {
            return;
        }
        return this._instance['onForwardStreamEvent'](eventInfos.map(function ($item) { return packObject($item, ForwardStreamEventInfo); }));
    };
    android_RTCRoomEventHandler.prototype.onNetworkQuality = function (localQuality, remoteQualities) {
        if (!this._instance['onNetworkQuality']) {
            return;
        }
        return this._instance['onNetworkQuality'](packObject(localQuality, NetworkQualityStats), remoteQualities.map(function ($item) { return packObject($item, NetworkQualityStats); }));
    };
    android_RTCRoomEventHandler.prototype.onSetRoomExtraInfoResult = function (taskId, error) {
        if (!this._instance['onSetRoomExtraInfoResult']) {
            return;
        }
        return this._instance['onSetRoomExtraInfoResult'](Number(taskId), t_SetRoomExtraInfoResult.android_to_ts(error));
    };
    android_RTCRoomEventHandler.prototype.onRoomExtraInfoUpdate = function (key, value, lastUpdateUserId, lastUpdateTimeMs) {
        if (!this._instance['onRoomExtraInfoUpdate']) {
            return;
        }
        return this._instance['onRoomExtraInfoUpdate'](String(key), String(value), String(lastUpdateUserId), Number(lastUpdateTimeMs));
    };
    android_RTCRoomEventHandler.prototype.onUserVisibilityChanged = function (currentUserVisibility, errorCode) {
        if (!this._instance['onUserVisibilityChanged']) {
            return;
        }
        return this._instance['onUserVisibilityChanged'](currentUserVisibility, t_UserVisibilityChangeError.android_to_ts(errorCode));
    };
    android_RTCRoomEventHandler.prototype.onSubtitleStateChanged = function (state, errorCode, errorMessage) {
        if (!this._instance['onSubtitleStateChanged']) {
            return;
        }
        return this._instance['onSubtitleStateChanged'](t_SubtitleState.android_to_ts(state), t_SubtitleErrorCode.android_to_ts(errorCode), String(errorMessage));
    };
    android_RTCRoomEventHandler.prototype.onSubtitleMessageReceived = function (subtitles) {
        if (!this._instance['onSubtitleMessageReceived']) {
            return;
        }
        return this._instance['onSubtitleMessageReceived'](subtitles.map(function ($item) { return packObject($item, SubtitleMessage); }));
    };
    android_RTCRoomEventHandler.prototype.onRoomWarning = function (warn) {
        if (!this._instance['onRoomWarning']) {
            return;
        }
        return this._instance['onRoomWarning'](t_WarningCode.android_to_ts(warn));
    };
    android_RTCRoomEventHandler.prototype.onRoomError = function (err) {
        if (!this._instance['onRoomError']) {
            return;
        }
        return this._instance['onRoomError'](t_ErrorCode.android_to_ts(err));
    };
    android_RTCRoomEventHandler.prototype.onStreamAdd = function (stream) {
        if (!this._instance['onStreamAdd']) {
            return;
        }
        return this._instance['onStreamAdd'](packObject(stream, RTCStream));
    };
    return android_RTCRoomEventHandler;
}(IRTCRoomEventHandler));
var ios_RTCRoomEventHandler = /** @class */ (function (_super) {
    __extends(ios_RTCRoomEventHandler, _super);
    function ios_RTCRoomEventHandler(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    ios_RTCRoomEventHandler.prototype.rtcRoom$onLeaveRoom = function (rtcRoom, stats) {
        if (!this._instance['onLeaveRoom']) {
            return;
        }
        return this._instance['onLeaveRoom'](packObject(stats, RTCRoomStats));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onRoomStateChanged$withUid$state$extraInfo = function (rtcRoom, roomId, uid, state, extraInfo) {
        if (!this._instance['onRoomStateChanged']) {
            return;
        }
        return this._instance['onRoomStateChanged'](String(roomId), String(uid), Number(state), String(extraInfo));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onStreamStateChanged$withUid$state$extraInfo = function (rtcRoom, roomId, uid, state, extraInfo) {
        if (!this._instance['onStreamStateChanged']) {
            return;
        }
        return this._instance['onStreamStateChanged'](String(roomId), String(uid), Number(state), String(extraInfo));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onAVSyncStateChange = function (rtcRoom, state) {
        if (!this._instance['onAVSyncStateChange']) {
            return;
        }
        return this._instance['onAVSyncStateChange'](t_AVSyncState.ios_to_ts(state));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onRoomStats = function (rtcRoom, stats) {
        if (!this._instance['onRoomStats']) {
            return;
        }
        return this._instance['onRoomStats'](packObject(stats, RTCRoomStats));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onUserJoined$elapsed = function (rtcRoom, userInfo, elapsed) {
        if (!this._instance['onUserJoined']) {
            return;
        }
        return this._instance['onUserJoined'](packObject(userInfo, UserInfo), Number(elapsed));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onUserLeave$reason = function (rtcRoom, uid, reason) {
        if (!this._instance['onUserLeave']) {
            return;
        }
        return this._instance['onUserLeave'](String(uid), t_RTCUserOfflineReason.ios_to_ts(reason));
    };
    ios_RTCRoomEventHandler.prototype.onTokenWillExpire = function (rtcRoom) {
        if (!this._instance['onTokenWillExpire']) {
            return;
        }
        return this._instance['onTokenWillExpire']();
    };
    ios_RTCRoomEventHandler.prototype.onPublishPrivilegeTokenWillExpire = function (rtcRoom) {
        if (!this._instance['onPublishPrivilegeTokenWillExpire']) {
            return;
        }
        return this._instance['onPublishPrivilegeTokenWillExpire']();
    };
    ios_RTCRoomEventHandler.prototype.onSubscribePrivilegeTokenWillExpire = function (rtcRoom) {
        if (!this._instance['onSubscribePrivilegeTokenWillExpire']) {
            return;
        }
        return this._instance['onSubscribePrivilegeTokenWillExpire']();
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onUserPublishStream$type = function (rtcRoom, userId, type) {
        if (!this._instance['onUserPublishStream']) {
            return;
        }
        return this._instance['onUserPublishStream'](String(userId), t_MediaStreamType.ios_to_ts(type));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onUserUnpublishStream$type$reason = function (rtcRoom, userId, type, reason) {
        if (!this._instance['onUserUnpublishStream']) {
            return;
        }
        return this._instance['onUserUnpublishStream'](String(userId), t_MediaStreamType.ios_to_ts(type), t_StreamRemoveReason.ios_to_ts(reason));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onUserPublishScreen$type = function (rtcRoom, userId, type) {
        if (!this._instance['onUserPublishScreen']) {
            return;
        }
        return this._instance['onUserPublishScreen'](String(userId), t_MediaStreamType.ios_to_ts(type));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onUserUnpublishScreen$type$reason = function (rtcRoom, userId, type, reason) {
        if (!this._instance['onUserUnpublishScreen']) {
            return;
        }
        return this._instance['onUserUnpublishScreen'](String(userId), t_MediaStreamType.ios_to_ts(type), t_StreamRemoveReason.ios_to_ts(reason));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onLocalStreamStats = function (rtcRoom, stats) {
        if (!this._instance['onLocalStreamStats']) {
            return;
        }
        return this._instance['onLocalStreamStats'](packObject(stats, LocalStreamStats));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onRemoteStreamStats = function (rtcRoom, stats) {
        if (!this._instance['onRemoteStreamStats']) {
            return;
        }
        return this._instance['onRemoteStreamStats'](packObject(stats, RemoteStreamStats));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onStreamSubscribed$userId$subscribeConfig = function (rtcRoom, state, userId, info) {
        if (!this._instance['onStreamSubscribed']) {
            return;
        }
        return this._instance['onStreamSubscribed'](t_SubscribeState.ios_to_ts(state), String(userId), packObject(info, SubscribeConfig));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onRoomMessageReceived$message = function (rtcRoom, uid, message) {
        if (!this._instance['onRoomMessageReceived']) {
            return;
        }
        return this._instance['onRoomMessageReceived'](String(uid), String(message));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onRoomBinaryMessageReceived$message = function (rtcRoom, uid, message) {
        if (!this._instance['onRoomBinaryMessageReceived']) {
            return;
        }
        return this._instance['onRoomBinaryMessageReceived'](String(uid), message);
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onUserMessageReceived$message = function (rtcRoom, uid, message) {
        if (!this._instance['onUserMessageReceived']) {
            return;
        }
        return this._instance['onUserMessageReceived'](String(uid), String(message));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onUserBinaryMessageReceived$message = function (rtcRoom, uid, message) {
        if (!this._instance['onUserBinaryMessageReceived']) {
            return;
        }
        return this._instance['onUserBinaryMessageReceived'](String(uid), message);
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onUserMessageSendResult$error = function (rtcRoom, msgid, error) {
        if (!this._instance['onUserMessageSendResult']) {
            return;
        }
        return this._instance['onUserMessageSendResult'](Number(msgid), t_UserMessageSendResult.ios_to_ts(error));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onRoomMessageSendResult$error = function (rtcRoom, msgid, error) {
        if (!this._instance['onRoomMessageSendResult']) {
            return;
        }
        return this._instance['onRoomMessageSendResult'](Number(msgid), t_RoomMessageSendResult.ios_to_ts(error));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onVideoStreamBanned$isBanned = function (rtcRoom, uid, banned) {
        if (!this._instance['onVideoStreamBanned']) {
            return;
        }
        return this._instance['onVideoStreamBanned'](String(uid), banned);
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onAudioStreamBanned$isBanned = function (rtcRoom, uid, banned) {
        if (!this._instance['onAudioStreamBanned']) {
            return;
        }
        return this._instance['onAudioStreamBanned'](String(uid), banned);
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onForwardStreamStateChanged = function (rtcRoom, infos) {
        if (!this._instance['onForwardStreamStateChanged']) {
            return;
        }
        return this._instance['onForwardStreamStateChanged'](infos.map(function ($item) { return packObject($item, ForwardStreamStateInfo); }));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onForwardStreamEvent = function (rtcRoom, infos) {
        if (!this._instance['onForwardStreamEvent']) {
            return;
        }
        return this._instance['onForwardStreamEvent'](infos.map(function ($item) { return packObject($item, ForwardStreamEventInfo); }));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onNetworkQuality$remoteQualities = function (rtcRoom, localQuality, remoteQualities) {
        if (!this._instance['onNetworkQuality']) {
            return;
        }
        return this._instance['onNetworkQuality'](packObject(localQuality, NetworkQualityStats), remoteQualities.map(function ($item) { return packObject($item, NetworkQualityStats); }));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onSetRoomExtraInfoResult$error = function (rtcRoom, taskId, error) {
        if (!this._instance['onSetRoomExtraInfoResult']) {
            return;
        }
        return this._instance['onSetRoomExtraInfoResult'](Number(taskId), t_SetRoomExtraInfoResult.ios_to_ts(error));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onRoomExtraInfoUpdate$value$lastUpdateUserId$lastUpdateTimeMs = function (rtcRoom, key, value, lastUpdateUserId, lastUpdateTimeMs) {
        if (!this._instance['onRoomExtraInfoUpdate']) {
            return;
        }
        return this._instance['onRoomExtraInfoUpdate'](String(key), String(value), String(lastUpdateUserId), Number(lastUpdateTimeMs));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onUserVisibilityChanged$errorCode = function (rtcRoom, currentUserVisibility, errorCode) {
        if (!this._instance['onUserVisibilityChanged']) {
            return;
        }
        return this._instance['onUserVisibilityChanged'](currentUserVisibility, t_UserVisibilityChangeError.ios_to_ts(errorCode));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onSubtitleStateChanged$errorCode$errorMessage = function (rtcRoom, state, errorCode, errorMessage) {
        if (!this._instance['onSubtitleStateChanged']) {
            return;
        }
        return this._instance['onSubtitleStateChanged'](t_SubtitleState.ios_to_ts(state), t_SubtitleErrorCode.ios_to_ts(errorCode), String(errorMessage));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onSubtitleMessageReceived = function (rtcRoom, subtitles) {
        if (!this._instance['onSubtitleMessageReceived']) {
            return;
        }
        return this._instance['onSubtitleMessageReceived'](subtitles.map(function ($item) { return packObject($item, SubtitleMessage); }));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onRoomWarning = function (rtcRoom, warningCode) {
        if (!this._instance['onRoomWarning']) {
            return;
        }
        return this._instance['onRoomWarning'](t_WarningCode.ios_to_ts(warningCode));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onRoomError = function (rtcRoom, errorCode) {
        if (!this._instance['onRoomError']) {
            return;
        }
        return this._instance['onRoomError'](t_ErrorCode.ios_to_ts(errorCode));
    };
    ios_RTCRoomEventHandler.prototype.rtcRoom$onStreamAdd = function (rtcRoom, stream) {
        if (!this._instance['onStreamAdd']) {
            return;
        }
        return this._instance['onStreamAdd'](packObject(stream, RTCStream));
    };
    return ios_RTCRoomEventHandler;
}(ByteRTCRoomDelegate));
var android_IAudioEffectPlayerEventHandler = /** @class */ (function (_super) {
    __extends(android_IAudioEffectPlayerEventHandler, _super);
    function android_IAudioEffectPlayerEventHandler(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    android_IAudioEffectPlayerEventHandler.prototype.onAudioEffectPlayerStateChanged = function (effectId, state, error) {
        if (!this._instance['onAudioEffectPlayerStateChanged']) {
            return;
        }
        return this._instance['onAudioEffectPlayerStateChanged'](Number(effectId), t_PlayerState.android_to_ts(state), t_PlayerError.android_to_ts(error));
    };
    return android_IAudioEffectPlayerEventHandler;
}(IAudioEffectPlayerEventHandler));
var ios_IAudioEffectPlayerEventHandler = /** @class */ (function (_super) {
    __extends(ios_IAudioEffectPlayerEventHandler, _super);
    function ios_IAudioEffectPlayerEventHandler(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    ios_IAudioEffectPlayerEventHandler.prototype.onAudioEffectPlayerStateChanged$state$error = function (effectId, state, error) {
        if (!this._instance['onAudioEffectPlayerStateChanged']) {
            return;
        }
        return this._instance['onAudioEffectPlayerStateChanged'](Number(effectId), t_PlayerState.ios_to_ts(state), t_PlayerError.ios_to_ts(error));
    };
    return ios_IAudioEffectPlayerEventHandler;
}(ByteRTCAudioEffectPlayerEventHandler));
var android_IPushSingleStreamToCDNObserver = /** @class */ (function (_super) {
    __extends(android_IPushSingleStreamToCDNObserver, _super);
    function android_IPushSingleStreamToCDNObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    android_IPushSingleStreamToCDNObserver.prototype.onStreamPushEvent = function (eventType, taskId, error) {
        if (!this._instance['onStreamPushEvent']) {
            return;
        }
        return this._instance['onStreamPushEvent'](t_RTCStreamSinglePushEvent.android_to_ts(eventType), String(taskId), Number(error));
    };
    return android_IPushSingleStreamToCDNObserver;
}(IPushSingleStreamToCDNObserver));
var ios_IPushSingleStreamToCDNObserver = /** @class */ (function (_super) {
    __extends(ios_IPushSingleStreamToCDNObserver, _super);
    function ios_IPushSingleStreamToCDNObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    ios_IPushSingleStreamToCDNObserver.prototype.onStreamPushEvent$taskId$error = function (event, taskID, errorCode) {
        if (!this._instance['onStreamPushEvent']) {
            return;
        }
        return this._instance['onStreamPushEvent'](t_RTCStreamSinglePushEvent.ios_to_ts(event), String(taskID), Number(errorCode));
    };
    return ios_IPushSingleStreamToCDNObserver;
}(ByteRTCPushSingleStreamToCDNObserver));
var android_IRemoteEncodedVideoFrameObserver = /** @class */ (function (_super) {
    __extends(android_IRemoteEncodedVideoFrameObserver, _super);
    function android_IRemoteEncodedVideoFrameObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    android_IRemoteEncodedVideoFrameObserver.prototype.onRemoteEncodedVideoFrame = function (streamKey, encodedVideoFrame) {
        if (!this._instance['onRemoteEncodedVideoFrame']) {
            return;
        }
        return this._instance['onRemoteEncodedVideoFrame'](packObject(streamKey, RemoteStreamKey), packObject(encodedVideoFrame, RTCEncodedVideoFrame));
    };
    return android_IRemoteEncodedVideoFrameObserver;
}(IRemoteEncodedVideoFrameObserver));
var ios_IRemoteEncodedVideoFrameObserver = /** @class */ (function (_super) {
    __extends(ios_IRemoteEncodedVideoFrameObserver, _super);
    function ios_IRemoteEncodedVideoFrameObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    ios_IRemoteEncodedVideoFrameObserver.prototype.onRemoteEncodedVideoFrame$withEncodedVideoFrame = function (streamKey, videoFrame) {
        if (!this._instance['onRemoteEncodedVideoFrame']) {
            return;
        }
        return this._instance['onRemoteEncodedVideoFrame'](packObject(streamKey, RemoteStreamKey), packObject(videoFrame, RTCEncodedVideoFrame));
    };
    return ios_IRemoteEncodedVideoFrameObserver;
}(ByteRTCRemoteEncodedVideoFrameObserver));
var android_IFaceDetectionObserver = /** @class */ (function (_super) {
    __extends(android_IFaceDetectionObserver, _super);
    function android_IFaceDetectionObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    android_IFaceDetectionObserver.prototype.onFaceDetectResult = function (result) {
        if (!this._instance['onFaceDetectResult']) {
            return;
        }
        return this._instance['onFaceDetectResult'](packObject(result, FaceDetectionResult));
    };
    return android_IFaceDetectionObserver;
}(IFaceDetectionObserver));
var ios_IFaceDetectionObserver = /** @class */ (function (_super) {
    __extends(ios_IFaceDetectionObserver, _super);
    function ios_IFaceDetectionObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    ios_IFaceDetectionObserver.prototype.onFaceDetectResult = function (result) {
        if (!this._instance['onFaceDetectResult']) {
            return;
        }
        return this._instance['onFaceDetectResult'](packObject(result, FaceDetectionResult));
    };
    return ios_IFaceDetectionObserver;
}(ByteRTCFaceDetectionObserver));
var android_IMixedStreamObserver = /** @class */ (function (_super) {
    __extends(android_IMixedStreamObserver, _super);
    function android_IMixedStreamObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    android_IMixedStreamObserver.prototype.onMixingEvent = function (eventType, taskId, error, mixType) {
        if (!this._instance['onMixingEvent']) {
            return;
        }
        return this._instance['onMixingEvent'](t_ByteRTCStreamMixingEvent.android_to_ts(eventType), String(taskId), t_RTCStreamMixingErrorCode.android_to_ts(error), t_MixedStreamType.android_to_ts(mixType));
    };
    return android_IMixedStreamObserver;
}(IMixedStreamObserver));
var ios_IMixedStreamObserver = /** @class */ (function (_super) {
    __extends(ios_IMixedStreamObserver, _super);
    function ios_IMixedStreamObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    ios_IMixedStreamObserver.prototype.onMixingEvent$taskId$error$mixType = function (event, taskId, errorCode, mixType) {
        if (!this._instance['onMixingEvent']) {
            return;
        }
        return this._instance['onMixingEvent'](t_ByteRTCStreamMixingEvent.ios_to_ts(event), String(taskId), t_RTCStreamMixingErrorCode.ios_to_ts(errorCode), t_MixedStreamType.ios_to_ts(mixType));
    };
    return ios_IMixedStreamObserver;
}(ByteRTCMixedStreamObserver));
var android_IMediaPlayerAudioFrameObserver = /** @class */ (function (_super) {
    __extends(android_IMediaPlayerAudioFrameObserver, _super);
    function android_IMediaPlayerAudioFrameObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    android_IMediaPlayerAudioFrameObserver.prototype.onFrame = function (playerId, frame) {
        if (!this._instance['onFrame']) {
            return;
        }
        return this._instance['onFrame'](Number(playerId), packObject(frame, IAudioFrame));
    };
    return android_IMediaPlayerAudioFrameObserver;
}(IMediaPlayerAudioFrameObserver));
var ios_IMediaPlayerAudioFrameObserver = /** @class */ (function (_super) {
    __extends(ios_IMediaPlayerAudioFrameObserver, _super);
    function ios_IMediaPlayerAudioFrameObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    ios_IMediaPlayerAudioFrameObserver.prototype.onFrame$audioFrame = function (playerId, audioFrame) {
        if (!this._instance['onFrame']) {
            return;
        }
        return this._instance['onFrame'](Number(playerId), packObject(audioFrame, IAudioFrame));
    };
    return ios_IMediaPlayerAudioFrameObserver;
}(ByteRTCMediaPlayerAudioFrameObserver));
var android_IAudioFileFrameObserver = /** @class */ (function (_super) {
    __extends(android_IAudioFileFrameObserver, _super);
    function android_IAudioFileFrameObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    android_IAudioFileFrameObserver.prototype.onAudioFileFrame = function (mixID, audioFrame) {
        if (!this._instance['onAudioFileFrame']) {
            return;
        }
        return this._instance['onAudioFileFrame'](Number(mixID), packObject(audioFrame, IAudioFrame));
    };
    return android_IAudioFileFrameObserver;
}(IAudioFileFrameObserver));
var ios_IAudioFileFrameObserver = /** @class */ (function (_super) {
    __extends(ios_IAudioFileFrameObserver, _super);
    function ios_IAudioFileFrameObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    ios_IAudioFileFrameObserver.prototype.onAudioFileFrame$audioFrame = function (mixID, audioFrame) {
        if (!this._instance['onAudioFileFrame']) {
            return;
        }
        return this._instance['onAudioFileFrame'](Number(mixID), packObject(audioFrame, IAudioFrame));
    };
    return ios_IAudioFileFrameObserver;
}(ByteRTCAudioFileFrameObserver));
var android_ILocalEncodedVideoFrameObserver = /** @class */ (function (_super) {
    __extends(android_ILocalEncodedVideoFrameObserver, _super);
    function android_ILocalEncodedVideoFrameObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    android_ILocalEncodedVideoFrameObserver.prototype.onLocalEncodedVideoFrame = function (streamIndex, encodedVideoFrame) {
        if (!this._instance['onLocalEncodedVideoFrame']) {
            return;
        }
        return this._instance['onLocalEncodedVideoFrame'](t_StreamIndex.android_to_ts(streamIndex), packObject(encodedVideoFrame, RTCEncodedVideoFrame));
    };
    return android_ILocalEncodedVideoFrameObserver;
}(ILocalEncodedVideoFrameObserver));
var ios_ILocalEncodedVideoFrameObserver = /** @class */ (function (_super) {
    __extends(ios_ILocalEncodedVideoFrameObserver, _super);
    function ios_ILocalEncodedVideoFrameObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    ios_ILocalEncodedVideoFrameObserver.prototype.onLocalEncodedVideoFrame$Frame = function (streamIndex, frame) {
        if (!this._instance['onLocalEncodedVideoFrame']) {
            return;
        }
        return this._instance['onLocalEncodedVideoFrame'](t_StreamIndex.ios_to_ts(streamIndex), packObject(frame, RTCEncodedVideoFrame));
    };
    return ios_ILocalEncodedVideoFrameObserver;
}(ByteRTCLocalEncodedVideoFrameObserver));
var android_IExternalVideoEncoderEventHandler = /** @class */ (function (_super) {
    __extends(android_IExternalVideoEncoderEventHandler, _super);
    function android_IExternalVideoEncoderEventHandler(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    android_IExternalVideoEncoderEventHandler.prototype.onStart = function (index) {
        if (!this._instance['onStart']) {
            return;
        }
        return this._instance['onStart'](t_StreamIndex.android_to_ts(index));
    };
    android_IExternalVideoEncoderEventHandler.prototype.onStop = function (index) {
        if (!this._instance['onStop']) {
            return;
        }
        return this._instance['onStop'](t_StreamIndex.android_to_ts(index));
    };
    android_IExternalVideoEncoderEventHandler.prototype.onRateUpdate = function (streamIndex, videoIndex, fps, bitrateKbps) {
        if (!this._instance['onRateUpdate']) {
            return;
        }
        return this._instance['onRateUpdate'](t_StreamIndex.android_to_ts(streamIndex), Number(videoIndex), Number(fps), Number(bitrateKbps));
    };
    android_IExternalVideoEncoderEventHandler.prototype.onRequestKeyFrame = function (streamIndex, videoIndex) {
        if (!this._instance['onRequestKeyFrame']) {
            return;
        }
        return this._instance['onRequestKeyFrame'](t_StreamIndex.android_to_ts(streamIndex), Number(videoIndex));
    };
    android_IExternalVideoEncoderEventHandler.prototype.onActiveVideoLayer = function (streamIndex, videoIndex, active) {
        if (!this._instance['onActiveVideoLayer']) {
            return;
        }
        return this._instance['onActiveVideoLayer'](t_StreamIndex.android_to_ts(streamIndex), Number(videoIndex), active);
    };
    return android_IExternalVideoEncoderEventHandler;
}(IExternalVideoEncoderEventHandler));
var ios_IExternalVideoEncoderEventHandler = /** @class */ (function (_super) {
    __extends(ios_IExternalVideoEncoderEventHandler, _super);
    function ios_IExternalVideoEncoderEventHandler(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    ios_IExternalVideoEncoderEventHandler.prototype.onStart = function (streamIndex) {
        if (!this._instance['onStart']) {
            return;
        }
        return this._instance['onStart'](t_StreamIndex.ios_to_ts(streamIndex));
    };
    ios_IExternalVideoEncoderEventHandler.prototype.onStop = function (streamIndex) {
        if (!this._instance['onStop']) {
            return;
        }
        return this._instance['onStop'](t_StreamIndex.ios_to_ts(streamIndex));
    };
    ios_IExternalVideoEncoderEventHandler.prototype.onRateUpdate$withVideoIndex$withFps$withBitRate = function (streamIndex, videoIndex, fps, bitRateKps) {
        if (!this._instance['onRateUpdate']) {
            return;
        }
        return this._instance['onRateUpdate'](t_StreamIndex.ios_to_ts(streamIndex), Number(videoIndex), Number(fps), Number(bitRateKps));
    };
    ios_IExternalVideoEncoderEventHandler.prototype.onRequestKeyFrame$withVideoIndex = function (streamIndex, videoIndex) {
        if (!this._instance['onRequestKeyFrame']) {
            return;
        }
        return this._instance['onRequestKeyFrame'](t_StreamIndex.ios_to_ts(streamIndex), Number(videoIndex));
    };
    ios_IExternalVideoEncoderEventHandler.prototype.onActiveVideoLayer$withVideoIndex$withActive = function (streamIndex, videoIndex, active) {
        if (!this._instance['onActiveVideoLayer']) {
            return;
        }
        return this._instance['onActiveVideoLayer'](t_StreamIndex.ios_to_ts(streamIndex), Number(videoIndex), active);
    };
    return ios_IExternalVideoEncoderEventHandler;
}(ByteRTCExternalVideoEncoderEventHandler));
var android_IMediaPlayerEventHandler = /** @class */ (function (_super) {
    __extends(android_IMediaPlayerEventHandler, _super);
    function android_IMediaPlayerEventHandler(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    android_IMediaPlayerEventHandler.prototype.onMediaPlayerStateChanged = function (playerId, state, error) {
        if (!this._instance['onMediaPlayerStateChanged']) {
            return;
        }
        return this._instance['onMediaPlayerStateChanged'](Number(playerId), t_PlayerState.android_to_ts(state), t_PlayerError.android_to_ts(error));
    };
    android_IMediaPlayerEventHandler.prototype.onMediaPlayerPlayingProgress = function (playerId, progress) {
        if (!this._instance['onMediaPlayerPlayingProgress']) {
            return;
        }
        return this._instance['onMediaPlayerPlayingProgress'](Number(playerId), Number(progress));
    };
    return android_IMediaPlayerEventHandler;
}(IMediaPlayerEventHandler));
var ios_IMediaPlayerEventHandler = /** @class */ (function (_super) {
    __extends(ios_IMediaPlayerEventHandler, _super);
    function ios_IMediaPlayerEventHandler(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    ios_IMediaPlayerEventHandler.prototype.onMediaPlayerStateChanged$state$error = function (playerId, state, error) {
        if (!this._instance['onMediaPlayerStateChanged']) {
            return;
        }
        return this._instance['onMediaPlayerStateChanged'](Number(playerId), t_PlayerState.ios_to_ts(state), t_PlayerError.ios_to_ts(error));
    };
    ios_IMediaPlayerEventHandler.prototype.onMediaPlayerPlayingProgress$progress = function (playerId, progress) {
        if (!this._instance['onMediaPlayerPlayingProgress']) {
            return;
        }
        return this._instance['onMediaPlayerPlayingProgress'](Number(playerId), Number(progress));
    };
    return ios_IMediaPlayerEventHandler;
}(ByteRTCMediaPlayerEventHandler));
var android_IAudioFrameObserver = /** @class */ (function (_super) {
    __extends(android_IAudioFrameObserver, _super);
    function android_IAudioFrameObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    android_IAudioFrameObserver.prototype.onRecordAudioFrame = function (audioFrame) {
        if (!this._instance['onRecordAudioFrame']) {
            return;
        }
        return this._instance['onRecordAudioFrame'](packObject(audioFrame, IAudioFrame));
    };
    android_IAudioFrameObserver.prototype.onPlaybackAudioFrame = function (audioFrame) {
        if (!this._instance['onPlaybackAudioFrame']) {
            return;
        }
        return this._instance['onPlaybackAudioFrame'](packObject(audioFrame, IAudioFrame));
    };
    android_IAudioFrameObserver.prototype.onRemoteUserAudioFrame = function (streamKey, audioFrame) {
        if (!this._instance['onRemoteUserAudioFrame']) {
            return;
        }
        return this._instance['onRemoteUserAudioFrame'](packObject(streamKey, RemoteStreamKey), packObject(audioFrame, IAudioFrame));
    };
    android_IAudioFrameObserver.prototype.onMixedAudioFrame = function (audioFrame) {
        if (!this._instance['onMixedAudioFrame']) {
            return;
        }
        return this._instance['onMixedAudioFrame'](packObject(audioFrame, IAudioFrame));
    };
    return android_IAudioFrameObserver;
}(IAudioFrameObserver));
var ios_IAudioFrameObserver = /** @class */ (function (_super) {
    __extends(ios_IAudioFrameObserver, _super);
    function ios_IAudioFrameObserver(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    ios_IAudioFrameObserver.prototype.onRecordAudioFrame = function (audioFrame) {
        if (!this._instance['onRecordAudioFrame']) {
            return;
        }
        return this._instance['onRecordAudioFrame'](packObject(audioFrame, IAudioFrame));
    };
    ios_IAudioFrameObserver.prototype.onPlaybackAudioFrame = function (audioFrame) {
        if (!this._instance['onPlaybackAudioFrame']) {
            return;
        }
        return this._instance['onPlaybackAudioFrame'](packObject(audioFrame, IAudioFrame));
    };
    ios_IAudioFrameObserver.prototype.onRemoteUserAudioFrame$audioFrame = function (streamKey, audioFrame) {
        if (!this._instance['onRemoteUserAudioFrame']) {
            return;
        }
        return this._instance['onRemoteUserAudioFrame'](packObject(streamKey, RemoteStreamKey), packObject(audioFrame, IAudioFrame));
    };
    ios_IAudioFrameObserver.prototype.onMixedAudioFrame = function (audioFrame) {
        if (!this._instance['onMixedAudioFrame']) {
            return;
        }
        return this._instance['onMixedAudioFrame'](packObject(audioFrame, IAudioFrame));
    };
    return ios_IAudioFrameObserver;
}(ByteRTCAudioFrameObserver));
var android_IMediaPlayerCustomSourceProvider = /** @class */ (function (_super) {
    __extends(android_IMediaPlayerCustomSourceProvider, _super);
    function android_IMediaPlayerCustomSourceProvider(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    return android_IMediaPlayerCustomSourceProvider;
}(IMediaPlayerCustomSourceProvider));
var ios_IMediaPlayerCustomSourceProvider = /** @class */ (function (_super) {
    __extends(ios_IMediaPlayerCustomSourceProvider, _super);
    function ios_IMediaPlayerCustomSourceProvider(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    return ios_IMediaPlayerCustomSourceProvider;
}(ByteRTCMediaPlayerCustomSourceProvider));
var android_IAudioFrameProcessor = /** @class */ (function (_super) {
    __extends(android_IAudioFrameProcessor, _super);
    function android_IAudioFrameProcessor(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    return android_IAudioFrameProcessor;
}(IAudioFrameProcessor));
var ios_IAudioFrameProcessor = /** @class */ (function (_super) {
    __extends(ios_IAudioFrameProcessor, _super);
    function ios_IAudioFrameProcessor(_instance) {
        var _this = _super.call(this) || this;
        _this._instance = _instance;
        return _this;
    }
    return ios_IAudioFrameProcessor;
}(ByteRTCAudioFrameProcessor));

var ISpatialAudio = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ISpatialAudio_1() {
        }
        ISpatialAudio_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        ISpatialAudio_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCSpatialAudio).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = ISpatialAudio$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Spatial Audio
         * @author majun.lvhiei
         * @brief Enable/disable spatial audio function.
         * @param enable Whether to enable spatial audio function: <br>
         *        - true：Enable
         *        - false：Disable(Default setting)
         * @note You need to call {@link updatePosition updatePosition} as well to really enjoy the spatial audio effect.
         *
         */
        ISpatialAudio_1.prototype.enableSpatialAudio = function (enable) {
            var _this = this;
            var a = function () { return (_this._instance.enableSpatialAudio(enable), void 0); };
            var i = function () { return (_this._instance.enableSpatialAudio(enable), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio management
         * @author luomingkang.264
         * @brief Turn off the effect of the orientation of the local user as the sound source. <br>
         *        After the effect is off, all the other users in the room listen to the local user as if the local user is in right front of each of them.
         * @note
         *        - After the orientation effect as the sound source is disabled, you cannot enable it during the lifetime of the `SpatialAudio` instance.
         *        - Calling this API does not affect the orientation effect of the local user as a listener. See {@link updateSelfPosition updateSelfPosition} and {@link updateRemotePosition updateRemotePosition}.
         *
         */
        ISpatialAudio_1.prototype.disableRemoteOrientation = function () {
            var _this = this;
            var a = function () { return (_this._instance.disableRemoteOrientation(), void 0); };
            var i = function () { return (_this._instance.disableRemoteOrientation(), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.52
         * @detail api
         * @region Audio management
         * @author wangjunzheng
         * @brief Sets the coordinate and orientation of the local user as a listener in the rectangular coordinate system the local user built to achieve expected spatial audio effects.
         * @param positionInfo  Information on the local user's position. Refer to  {@link PositionInfo PositionInfo} for details.
         * @return
         *        - 0: Success.
         *        - <0: Failure.
         *        - -2: Failure. The reason is that any two of the 3D coordinate vectors of your position are not perpendicular to each other.
         * @note
         *        - You need to call this API after joining the room.
         *        - Before calling this API, you should call {@link enableSpatialAudio enableSpatialAudio} first to enable the spatial audio function.
         *        - The settings made locally will not influence other users' spatial audio experience.
         *
         */
        ISpatialAudio_1.prototype.updateSelfPosition = function (positionInfo) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.updateSelfPosition(unpackObject(positionInfo)));
            };
            var i = function () {
                return Number(_this._instance.updateSelfPosition(unpackObject(positionInfo)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.52
         * @detail api
         * @region Audio management
         * @author wangjunzheng
         * @brief Sets the coordinate and orientation of the remote user as a speaker in the rectangular coordinate system of the local user. In this case, the local user hears from the remote user with the expected spatial audio effects.
         * @param uid User ID
         * @param positionInfo Information on the remote user's position. Refer to {@link PositionInfo PositionInfo} for details.
         * @return
         *        - 0: Success.
         *        - <0: Failure.
         *        - -2: Failure. The reason is that any two of the 3D coordinate vectors of the position of the remote user are not perpendicular to each other.
         * @note
         *        - You must call this API after creating the room.
         *        - The settings made locally will not influence other users' spatial audio experience.
         *
         */
        ISpatialAudio_1.prototype.updateRemotePosition = function (uid, positionInfo) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.updateRemotePosition(uid, unpackObject(positionInfo)));
            };
            var i = function () {
                return Number(_this._instance.updateRemotePosition(uid, unpackObject(positionInfo)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.52
         * @detail api
         * @region Audio management
         * @author wangjunzheng
         * @brief Disables all spatial audio effects set by calling {@link updateRemotePosition updateRemotePosition} for a certain remote user.
         * @param uid User ID of the remote user.
         * @return
         *        - 0: Success.
         *        - <0: Failure.
         *
         */
        ISpatialAudio_1.prototype.removeRemotePosition = function (uid) {
            var _this = this;
            var a = function () { return Number(_this._instance.removeRemotePosition(uid)); };
            var i = function () { return Number(_this._instance.removeRemotePosition(uid)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.52
         * @detail api
         * @region Audio management
         * @author wangjunzheng
         * @brief Disables all spatial audio effects set by calling {@link updateRemotePosition updateRemotePosition} for all remote users.
         * @return
         *        - 0: Success.
         *        - <0: Failure.
         *
         */
        ISpatialAudio_1.prototype.removeAllRemotePosition = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.removeAllRemotePosition()); };
            var i = function () { return Number(_this._instance.removeAllRemotePosition()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return ISpatialAudio_1;
    }());
    __setFunctionName(_classThis, "ISpatialAudio");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IVideoDeviceManager = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IVideoDeviceManager_1() {
        }
        IVideoDeviceManager_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        IVideoDeviceManager_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCVideoDeviceManager).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = IVideoDeviceManager$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @region  Video Facility Management
         * @author likai.666
         * @brief  Get a list of video capture devices in the current system.
         * @return  Contains a list of all video capture devices in the system. See {@link VideoDeviceInfo VideoDeviceInfo}.
         *
         */
        IVideoDeviceManager_1.prototype.android_enumerateVideoCaptureDevices = function () {
            var _this = this;
            var $ = function () { return _this._instance.enumerateVideoCaptureDevices(); };
            return $();
        };
        /** {en}
         * @valid since 3.56
         * @detail api
         * @region  Video Facility Management
         * @author likai.666
         * @brief  Set the current video capture device
         * @param  deviceId Video device ID, which can be obtained through {@link enumerateVideoCaptureDevices enumerateVideoCaptureDevices}
         * @return
         *         - 0: Success.
         *         +! 0: failure
         *
         */
        IVideoDeviceManager_1.prototype.setVideoCaptureDevice = function (deviceId) {
            var _this = this;
            var a = function () { return Number(_this._instance.setVideoCaptureDevice(deviceId)); };
            var i = function () { return Number(_this._instance.setVideoCaptureDevice(deviceId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform ios
         * @detail api
         * @region Video Device Management
         * @author zhangzhenyu.samuel
         * @brief Get the currently-using video capture device
         * @param  deviceID video device ID
         * @return
         *         - 0: Success.
         *         +! 0: failure
         */
        IVideoDeviceManager_1.prototype.ios_getVideoCaptureDevice = function (deviceID) {
            var _this = this;
            var $ = function () { return Number(_this._instance.getVideoCaptureDevice(deviceID)); };
            return $();
        };
        return IVideoDeviceManager_1;
    }());
    __setFunctionName(_classThis, "IVideoDeviceManager");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IKTVPlayer = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IKTVPlayer_1() {
        }
        Object.defineProperty(IKTVPlayer_1.prototype, "ios_delegate", {
            /**
             * @platform ios
             */
            /**
             * @platform ios
             */
            get: function () {
                return this._instance.delegate;
            },
            set: function (value) {
                this._instance.delegate = value;
            },
            enumerable: false,
            configurable: true
        });
        IKTVPlayer_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        IKTVPlayer_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCKTVPlayer).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = IKTVPlayer$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Sets the KTV player event handler.
         * @param playerEventHandler KTV player event handler. See {@link IKTVPlayerEventHandler IKTVPlayerEventHandler}.
         *
         */
        IKTVPlayer_1.prototype.android_setPlayerEventHandler = function (playerEventHandler) {
            var _this = this;
            var $ = function () { return (_this._instance.setPlayerEventHandler(playerEventHandler), void 0); };
            return $();
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Plays the music.
         * @param musicId Music ID. <br>
         *        If the song with the same musicId is playing when you call this API, the music will restart from the starting position. An error will be triggered if the audio file corresponding to musicId does not exist.
         * @param trackType Audio track type of the KTV player. See {@link AudioTrackType AudioTrackType}.
         * @param playType Audio play type. See {@link AudioPlayType AudioPlayType}.
         * @note
         *       - After calling this API, you will receive the music play state through {@link onPlayStateChanged onPlayStateChanged} callback.
         *       - If the music ID is invalid, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3023 and a playState of 4.
         *       - If you didn't join the room, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3022 and a playState of 4.
         *       - If the music file does not exist, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3020 and a playState of 4.
         *
         */
        IKTVPlayer_1.prototype.playMusic = function (musicId, trackType, playType) {
            var _this = this;
            var a = function () { return (_this._instance.playMusic(musicId, t_AudioTrackType.ts_to_android(trackType), t_AudioPlayType.ts_to_android(playType)),
                void 0); };
            var i = function () { return (_this._instance.playMusic(musicId, t_AudioTrackType.ts_to_ios(trackType), t_AudioPlayType.ts_to_ios(playType)),
                void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Pauses the music.
         * @param musicId Music ID.
         * @note
         *       - After calling this API, you will receive the music play state through {@link onPlayStateChanged onPlayStateChanged} callback.
         *       - If the music ID is invalid, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3023 and a playState of 4.
         *       - If you didn't join the room, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3022 and a playState of 4.
         *
         */
        IKTVPlayer_1.prototype.pauseMusic = function (musicId) {
            var _this = this;
            var a = function () { return (_this._instance.pauseMusic(musicId), void 0); };
            var i = function () { return (_this._instance.pauseMusic(musicId), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Resumes playing the music.
         * @param musicId Music ID.
         * @note
         *       - After calling this API, you will receive the music play state through {@link onPlayStateChanged onPlayStateChanged} callback.
         *       - If the music ID is invalid, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3023 and a playState of 4.
         *       - If you didn't join the room, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3022 and a playState of 4.
         *
         */
        IKTVPlayer_1.prototype.resumeMusic = function (musicId) {
            var _this = this;
            var a = function () { return (_this._instance.resumeMusic(musicId), void 0); };
            var i = function () { return (_this._instance.resumeMusic(musicId), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Stops playing the music.
         * @param musicId Music ID.
         * @note
         *       - After calling this API, you will receive the music play state through {@link onPlayStateChanged onPlayStateChanged} callback.
         *       - If the music ID is invalid, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3023 and a playState of 4.
         *       - If you didn't join the room, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3022 and a playState of 4.
         *
         */
        IKTVPlayer_1.prototype.stopMusic = function (musicId) {
            var _this = this;
            var a = function () { return (_this._instance.stopMusic(musicId), void 0); };
            var i = function () { return (_this._instance.stopMusic(musicId), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Sets the starting position of the music file.
         * @param musicId Music ID.
         * @param position The starting position of the music file in milliseconds. The value must be less than the total length of the music.
         * @note
         *       - The music must be playing when you call this API.
         *       - After calling this API, you will receive the music play state through {@link onPlayStateChanged onPlayStateChanged} callback.
         *       - If the music ID is invalid, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3023 and a playState of 4.
         *       - If you didn't join the room, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3022 and a playState of 4.
         *
         */
        IKTVPlayer_1.prototype.seekMusic = function (musicId, position) {
            var _this = this;
            var a = function () { return (_this._instance.seekMusic(musicId, position), void 0); };
            var i = function () { return (_this._instance.seekMusic(musicId, position), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Sets the volume of the playing music. The music must be playing when you set the volume.
         * @param musicId Music ID.
         * @param volume Volume. Adjustment range: [0,400]. <br>
         *         - 0: Mute.
         *         - 100: Original volume.
         *         - 400: 4 times the original volume (with overflow protection).
         * @note
         *       - The music must be playing when you call this API.
         *       - If the set volume is greater than 400, it will be adjusted by the maximum value of 400; if the set volume is less than 0, it will be adjusted by the minimum value of 0.
         *       - If the music ID is invalid, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3023 and a playState of 4.
         *       - If you didn't join the room, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3022 and a playState of 4.
         *
         */
        IKTVPlayer_1.prototype.setMusicVolume = function (musicId, volume) {
            var _this = this;
            var a = function () { return (_this._instance.setMusicVolume(musicId, volume), void 0); };
            var i = function () { return (_this._instance.setMusicVolume(musicId, volume), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Switches the audio track type between the original track and the instrumental track.
         * @param musicId Music ID.
         * @note The music must be playing when you call this API.
         *
         */
        IKTVPlayer_1.prototype.switchAudioTrackType = function (musicId) {
            var _this = this;
            var a = function () { return (_this._instance.switchAudioTrackType(musicId), void 0); };
            var i = function () { return (_this._instance.switchAudioTrackType(musicId), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Transposes up/down the music being played.
         * @param musicId Music ID.
         * @param pitch The pitch up/down value relative to the original pitch, in the range of [-12, 12], with the default value of 0. <br>
         *              The difference in pitch between two adjacent values is a semitone. A positive value indicates an increase in pitch, and a negative value indicates a decrease in pitch. A larger absolute value means more pitch increase or decrease.
         * @note
         *       - The music must be in the playing when you call this API.
         *       - If the set pitch is greater than 12, it will be adjusted by the maximum value of 12; if the set pitch is less than –12, it will be adjusted by the minimum value of –12.
         *       - If the music ID is invalid, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3023 and a playState of 4.
         *       - If you didn't join the room, you will receive the {@link onPlayStateChanged onPlayStateChanged} callback, with an errorCode of -3022 and a playState of 4.
         *
         */
        IKTVPlayer_1.prototype.setMusicPitch = function (musicId, pitch) {
            var _this = this;
            var a = function () { return (_this._instance.setMusicPitch(musicId, pitch), void 0); };
            var i = function () { return (_this._instance.setMusicPitch(musicId, pitch), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return IKTVPlayer_1;
    }());
    __setFunctionName(_classThis, "IKTVPlayer");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IVideoEffect = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IVideoEffect_1() {
        }
        IVideoEffect_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        IVideoEffect_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCVideoEffect).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = IVideoEffect$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author zhushufan.ref
         * @brief Checks video effect license, sets the video effect resource model path, and initializes video effect.
         * @param licenseFile The absolute path of the license file for authorization.
         * @param algoModelDir The absolute path of the Effects SDK's models file.
         * @return
         *      - 0: Success.
         *      - –1000: The Effects SDK is not integrated.
         *      - –1002: Your Effects SDK's version is incompatible.
         *      - < 0: Other error. See [error code table](https://docs.byteplus.com/effects/docs/error-code-table) for specific instructions.
         *
         */
        IVideoEffect_1.prototype.initCVResource = function (licenseFile, algoModelDir) {
            var _this = this;
            var a = function () { return Number(_this._instance.initCVResource(licenseFile, algoModelDir)); };
            var i = function () { return Number(_this._instance.initCVResource(licenseFile, algoModelDir)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author zhushufan.ref
         * @brief Enables video effects including beauty and color filters.
         * @return
         *      - 0: Success.
         *      - –1000: The Effects SDK is not integrated.
         *      - –1001: This API is unavailable for your Effects SDK.
         *      - –1002: Your Effects SDK's version is incompatible.
         *      - < 0: Other error. See [error code table](https://docs.byteplus.com/effects/docs/error-code-table) for specific instructions.
         * @note
         *      - You must call {@link initCVResource initCVResource} before calling this API.
         *      - This API does not turn on video effects directly, you must call {@link setEffectNodes setEffectNodes} or {@link setColorFilter setColorFilter} next.
         *      - Call {@link disableVideoEffect disableVideoEffect} to turn off video effects.
         *
         */
        IVideoEffect_1.prototype.enableVideoEffect = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.enableVideoEffect()); };
            var i = function () { return Number(_this._instance.enableVideoEffect()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author zhushufan.ref
         * @brief Disables video effects.
         * @return
         *      - 0: Success.
         *      - –1000: The Effects SDK is not integrated.
         *      - –1001: This API is unavailable for your Effects SDK.
         *      - –1002: Your Effects SDK's version is incompatible.
         *      - < 0: Other error. See [error code table](https://docs.byteplus.com/effects/docs/error-code-table) for specific instructions.
         * @note Call {@link enableVideoEffect enableVideoEffect} to enable video effects.
         *
         */
        IVideoEffect_1.prototype.disableVideoEffect = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.disableVideoEffect()); };
            var i = function () { return Number(_this._instance.disableVideoEffect()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author zhushufan.ref
         * @brief Sets the video effects material package.
         * @param effectNodes Array of effect material package paths. <br>
         *        To remove the current video effect, set it to null.
         * @return
         *      - 0: Success.
         *      - –1000: The Effects SDK is not integrated.
         *      - –1001: This API is unavailable for your Effects SDK.
         *      - –1002: Your Effects SDK's version is incompatible.
         *      - < 0: Other error. See [error code table](https://docs.byteplus.com/effects/docs/error-code-table) for specific instructions.
         * @note You must call {@link enableVideoEffect enableVideoEffect} before calling this API.
         *
         */
        IVideoEffect_1.prototype.setEffectNodes = function (effectNodes) {
            var _this = this;
            var a = function () { return Number(_this._instance.setEffectNodes(effectNodes)); };
            var i = function () { return Number(_this._instance.setEffectNodes(effectNodes)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author zhushufan.ref
         * @brief Sets the intensity of video effects.
         * @param effectNode The absolute path of the effects resource package, see [Resource Package Structure](https://docs.byteplus.com/effects/docs/resource-package-structure-v421-and-later).
         * @param key The name of the material key to be set, see [Functions of Resource Keys](https://docs.byteplus.com/effects/docs/functions-of-resource-keys-v421-and-later) for the value.
         * @param value The intensity value that needs to be set, the value range [0,1], and the setting is invalid when it exceeds the range.
         * @return
         *      - 0: Success.
         *      - –1000: The Effects SDK is not integrated.
         *      - –1001: This API is unavailable for your Effects SDK.
         *      - –1002: Your Effects SDK's version is incompatible.
         *      - < 0: Other error. See [error code table](https://docs.byteplus.com/effects/docs/error-code-table) for specific instructions.
         *
         */
        IVideoEffect_1.prototype.updateEffectNode = function (effectNode, key, value) {
            var _this = this;
            var a = function () { return Number(_this._instance.updateEffectNode(effectNode, key, value)); };
            var i = function () { return Number(_this._instance.updateEffectNode(effectNode, key, value)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author zhushufan.ref
         * @brief Sets the color filter.
         * @param filterRes Filter effects package absolute path.
         * @return
         *      - 0: Success.
         *      - –1000: The Effects SDK is not integrated.
         *      - –1001: This API is unavailable for your Effects SDK.
         *      - –1002: Your Effects SDK's version is incompatible.
         *      - < 0: Other error. See [error code table](https://docs.byteplus.com/effects/docs/error-code-table) for specific instructions.
         * @note Call {@link setColorFilterIntensity setColorFilterIntensity} to set the intensity of the color filter enabled. Set the intensity to 0 to turn off color filter.
         *
         */
        IVideoEffect_1.prototype.setColorFilter = function (filterRes) {
            var _this = this;
            var a = function () { return Number(_this._instance.setColorFilter(filterRes)); };
            var i = function () { return Number(_this._instance.setColorFilter(filterRes)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author zhushufan.ref
         * @brief Sets the intensity of the color filter enabled.
         * @param intensity Filter intensity. The value range [0,1] is set to be invalid when the range is exceeded. <br>
         *                  Set the intensity to 0 to turn off color filter.
         * @return
         *      - 0: Success.
         *      - –1000: The Effects SDK is not integrated.
         *      - –1001: This API is unavailable for your Effects SDK.
         *      - –1002: Your Effects SDK's version is incompatible.
         *      - < 0: Other error. See [error code table](https://docs.byteplus.com/effects/docs/error-code-table) for specific instructions.
         *
         */
        IVideoEffect_1.prototype.setColorFilterIntensity = function (intensity) {
            var _this = this;
            var a = function () { return Number(_this._instance.setColorFilterIntensity(intensity)); };
            var i = function () { return Number(_this._instance.setColorFilterIntensity(intensity)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author zhushufan.ref
         * @brief Sets the original background to a specified image or a solid color.
         * @param backgroundStickerRes The absolute path of virtual background effects.
         * @param source Virtual background source. See {@link VirtualBackgroundSource VirtualBackgroundSource}.
         * @return
         *      - 0: Success.
         *      - –1000: The Effects SDK is not integrated.
         *      - –1001: This API is unavailable for your Effects SDK.
         *      - –1002: Your Effects SDK's version is incompatible.
         *      - < 0: Other error. See [error code table](https://docs.byteplus.com/effects/docs/error-code-table) for specific instructions.
         * @note
         *      - You must call {@link initCVResource initCVResource} before calling this API.
         *      - Call {@link disableVirtualBackground disableVirtualBackground} to turn off the virtual background.
         *
         */
        IVideoEffect_1.prototype.enableVirtualBackground = function (backgroundStickerRes, source) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.enableVirtualBackground(backgroundStickerRes, unpackObject(source)));
            };
            var i = function () {
                return Number(_this._instance.enableVirtualBackground(backgroundStickerRes, unpackObject(source)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author wangjunlin.3182
         * @brief Turns off the virtual background.
         * @return
         *      - 0: Success.
         *      - –1000: The Effects SDK is not integrated.
         *      - –1001: This API is unavailable for your Effects SDK.
         *      - –1002: Your Effects SDK's version is incompatible.
         *      - < 0: Other error. See [error code table](https://docs.byteplus.com/effects/docs/error-code-table) for specific instructions.
         * @note After calling {@link enableVirtualBackground enableVirtualBackground} to enable the virtual background function, you can call this API to turn it off.
         *
         */
        IVideoEffect_1.prototype.disableVirtualBackground = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.disableVirtualBackground()); };
            var i = function () { return Number(_this._instance.disableVirtualBackground()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author wangjunlin.3182
         * @brief Starts face detection and registers the observer for the result. <br>
         *        With this observer, you will receive {@link onFaceDetectResult onFaceDetectResult} periodically.
         * @param observer See {@link IFaceDetectionObserver IFaceDetectionObserver}.
         * @param intervalMs The minimum time interval between two callbacks in milliseconds. The value should be greater than 0. The actual time interval is between interval_ms and interval_ms+the time slot of a captured video frame.
         * @param faceModelPath The absolute path of the face detection algorithm file. Typically it is the tt_face_vXXX.model file in the ttfacemodel folder.
         * @return
         *      - 0: Success.
         *      - –1000: The Effects SDK is not integrated.
         *      - –1001: This API is unavailable for your Effects SDK.
         *      - –1002: Your Effects SDK's version is incompatible.
         *      - -1004: Initializing. This function will be available when the initialization is completed.
         *      - < 0: Other error. See [error code table](https://docs.byteplus.com/effects/docs/error-code-table) for specific instructions.
         *
         */
        IVideoEffect_1.prototype.enableFaceDetection = function (observer, intervalMs, faceModelPath) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.enableFaceDetection(packObject(observer, android_IFaceDetectionObserver), intervalMs, faceModelPath));
            };
            var i = function () {
                return Number(_this._instance.enableFaceDetection(packObject(observer, ios_IFaceDetectionObserver), intervalMs, faceModelPath));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author wangjunlin.3182
         * @brief Stops face detection.
         * @return
         *      - 0: Success.
         *      - –1000: The Effects SDK is not integrated.
         *      - –1001: This API is unavailable for your Effects SDK.
         *      - –1002: Your Effects SDK's version is incompatible.
         *      - < 0: Other error. See [error code table](https://docs.byteplus.com/effects/docs/error-code-table) for specific instructions.
         *
         */
        IVideoEffect_1.prototype.disableFaceDetection = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.disableFaceDetection()); };
            var i = function () { return Number(_this._instance.disableFaceDetection()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return IVideoEffect_1;
    }());
    __setFunctionName(_classThis, "IVideoEffect");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RTCVideo = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RTCVideo_1() {
        }
        /** {en}
         * @platform android
         * @detail api
         * @region Engine Management
         * @author wangzhanqiang
         * @brief Creates an engine instance. <br>
         *        This is the very first API that you must call if you want to use all the RTC capabilities. <br>
         *        If there is no engine instance in current process, calling this API will create one. If an engine instance has been created, calling this API again will have the created engine instance returned.
         * @param context Android application context
         * @param handler Handler sent from SDK to App. See {@link IRTCVideoEventHandler IRTCVideoEventHandler}
         * @param config SDK Engine Config，see {@link EngineConfig EngineConfig}
         * @return
         *         - RTCVideo: A successfully created engine instance.
         *         - Null: EngineConfig is inValid see {@link EngineConfig EngineConfig}. Failed to load the so file
         * @note The lifecycle of the handler must be longer than that of the RTCVideo, i.e. the handler must be created before calling {@link createRTCVideo createRTCVideo} and destroyed after calling {@link destroyRTCVideo destroyRTCVideo}.
         * @order 1
         *
         */
        RTCVideo_1.android_createRTCVideo_context$appId$handler$eglContext$parameters = function (context, appId, handler, eglContext, parameters) {
            var $ = function () {
                return RTCVideo$1.createRTCVideo_context$appId$handler$eglContext$parameters(context, appId, handler, eglContext, parameters);
            };
            return $();
        };
        /** {en}
         * @detail api
         * @region Engine management
         * @author wangzhanqiang
         * @brief Destroy the engine instance created by {@link createRTCVideo createRTCVideo}, and release all related resources.
         * @note
         *       - Call this API after all business scenarios related to the engine instance are destroyed.
         *       - When the API is called, RTC SDK destroys all memory associated with the engine instance and stops any interaction with the media server.
         *       - Calling this API will start the SDK exit logic. The engine thread is held until the exit logic is complete. The engine thread is retained until the exit logic is complete. Therefore, do not call this API directly in the callback thread, or it will cause a deadlock. This function takes a long time to execute, so it's not recommended to call this API in the main thread, or the main thread may be blocked.
         * @order 3
         *
         */
        RTCVideo_1.destroyRTCVideo = function () {
            var a = function () { return (RTCVideo$1.destroyRTCVideo(), void 0); };
            var i = function () { return (ByteRTCVideo.destroyRTCVideo(), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Engine Management
         * @author wangzhanqiang
         * @brief Get the current version number of the SDK.
         * @return The current SDK version number.
         * @order 5
         *
         */
        RTCVideo_1.getSDKVersion = function () {
            var a = function () { return String(RTCVideo$1.getSDKVersion()); };
            var i = function () { return String(ByteRTCVideo.getSDKVersion()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Engine Management
         * @author caofanglu
         * @brief Configures the local log parameters of RTC SDK, including the logging level, directory, the limits for total log file size, and the prefix to the log file.
         * @param logConfig Local log parameters. See {@link RTCLogConfig RTCLogConfig}.
         * @return
         *        - 0: Success.
         *        - –1: Failure. This API must be called before creating engine.
         *        - –2: Failure. Invalid parameters.
         * @note This API must be called before {@link createRTCVideo createRTCVideo}.
         * @order 30
         *
         */
        RTCVideo_1.setLogConfig = function (logConfig) {
            var a = function () { return Number(RTCVideo$1.setLogConfig(unpackObject(logConfig))); };
            var i = function () { return Number(ByteRTCVideo.setLogConfig(unpackObject(logConfig))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Engine management
         * @author panjian.fishing
         * @brief Gets the description text of different error codes and warning codes in the SDK.
         * @param code The values obtained through {@link onWarning onWarning} and {@link onError onError} callbacks, <br>
         *      For details, please refer to {@link ErrorCode ErrorCode} and {@link WarningCode WarningCode}
         * @return String  Description text
         * @order 15
         *
         */
        RTCVideo_1.getErrorDescription = function (code) {
            var a = function () { return String(RTCVideo$1.getErrorDescription(code)); };
            var i = function () { return String(ByteRTCVideo.getErrorDescription(code)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        RTCVideo_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RTCVideo_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCVideo).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RTCVideo$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region  Engine Management
         * @author wangzhanqiang
         * @brief  The receiving class that sets engine event callbacks must inherit from {@link IRTCVideoEventHandler IRTCVideoEventHandler}.
         * @param engineEventHandler <br>
         *        Event processor interface class. See {@link IRTCVideoEventHandler IRTCVideoEventHandler}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - The caller needs to implement a class that inherits from {@link IRTCVideoEventHandler IRTCVideoEventHandler} and override the events that need attention.
         *         - The callback is asynchronous recall
         *         - All event callbacks will be triggered in a separate callback thread. Please pay attention to all operations related to the thread running environment when receiving callback events, such as operations that need to be performed in the UI thread.
         *           Do not directly operate in the implementation of the callback function.
         * @order 20
         *
         */
        RTCVideo_1.prototype.setRtcVideoEventHandler = function (engineEventHandler) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setRtcVideoEventHandler(packObject(engineEventHandler, android_RTCVideoEventHandler)));
            };
            var i = function () {
                _this._instance.delegate = packObject(engineEventHandler, ios_RTCVideoEventHandler);
                return 0;
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @author dixing
         * @brief Gets audio device management API class.
         * @return See {@link IRTCAudioDeviceManager IRTCAudioDeviceManager}.
         *
         */
        RTCVideo_1.prototype.android_getAudioDeviceManager = function () {
            var _this = this;
            var $ = function () { return _this._instance.getAudioDeviceManager(); };
            return $();
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author zhangzhenyu.samuel
         * @brief Enable internal video capture immediately. The default setting is off. <br>
         *        Internal video capture refers to: capturing video using the built-in module. <br>
         *        The local client will be informed via {@link onVideoDeviceStateChanged onVideoDeviceStateChanged} after starting video capture by calling this API. <br>
         *        The remote clients in the room will be informed of the state change via {@link onUserStartVideoCapture onUserStartVideoCapture} after the visible client starts video capture by calling this API.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - Since the upgrade in v3.37.0, you need to add Kotlin plugin to Gradle in the project to use this API.
         *        - Call {@link stopVideoCapture stopVideoCapture} to stop the internal video capture. Otherwise, the internal video capture will sustain until you destroy the engine instance.
         *        - Once you create the engine instance, you can start internal video capture regardless of the video publishing state. The video stream will start publishing only after the video capture starts.
         *        - To switch from custom to internal video capture, stop publishing before disabling the custom video capture module and then call this API to enable the internal video capture.
         *        - Call {@link switchCamera switchCamera} to switch the camera used by the internal video capture module.
         *        - If the default video format can not meet your requirement, contact our technical specialist to help you with Cloud Config. After that, you can push and apply these configurations to Android clients at any time.
         *
         */
        RTCVideo_1.prototype.startVideoCapture = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.startVideoCapture()); };
            var i = function () { return Number(_this._instance.startVideoCapture()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author zhangzhenyu.samuel
         * @brief Disable internal video capture immediately. The default is off. <br>
         *        Internal video capture refers to: capturing video using the built-in module. <br>
         *        The local client will be informed via {@link onVideoDeviceStateChanged onVideoDeviceStateChanged} after stopping video capture by calling this API. <br>
         *        The remote clients in the room will be informed of the state change via {@link onUserStopVideoCapture onUserStopVideoCapture} after the visible client stops video capture by calling this API.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - Call startVideoCapture {@link startVideoCapture} to enable the internal video capture.
         *        - Without calling this API the internal video capture will sustain until you destroy the engine instance.
         *
         */
        RTCVideo_1.prototype.stopVideoCapture = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopVideoCapture()); };
            var i = function () { return Number(_this._instance.stopVideoCapture()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio management
         * @author dixing
         * @brief Start internal audio capture. The default is off. <br>
         *         Internal audio capture refers to: capturing audio using the built-in module. <br>
         *         The local client will be informed via {@link onAudioDeviceStateChanged onAudioDeviceStateChanged} after starting audio capture by calling this API. <br>
         *         The remote clients in the room will be informed of the state change via {@link onUserStartAudioCapture onUserStartAudioCapture} after the visible user starts audio capture by calling this API.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - To enable a microphone without the user's permission will trigger {@link onAudioDeviceStateChanged onAudioDeviceStateChanged}.
         *        - Call {@link stopAudioCapture stopAudioCapture} to stop the internal audio capture. Otherwise, the internal audio capture will sustain until you destroy the engine instance.
         *        -  To mute and unmute microphones, we recommend using {@link publishStream publishStream} and {@link unpublishStream unpublishStream}, other than {@link stopAudioCapture stopAudioCapture} and this API. Because starting and stopping capture devices often need some time waiting for the response of the device, that may lead to a short silence during the communication.
         *        - To switch from custom to internal audio capture, stop publishing before disabling the custom audio capture module and then call this API to enable the internal audio capture.
         *
         */
        RTCVideo_1.prototype.startAudioCapture = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.startAudioCapture()); };
            var i = function () { return Number(_this._instance.startAudioCapture()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region audio management
         * @author dixing
         * @brief Stop internal audio capture. The default is off. <br>
         *        Internal audio capture refers to: capturing audio using the built-in module. <br>
         *         The local client will be informed via {@link onAudioDeviceStateChanged onAudioDeviceStateChanged} after stopping audio capture by calling this API. <br>
         *         The remote clients in the room will be informed of the state change via {@link onUserStopAudioCapture onUserStopAudioCapture} after the visible client stops audio capture by calling this API.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - Call {@link startAudioCapture startAudioCapture} to enable the internal audio capture.
         *        - Without calling this API the internal audio capture will sustain until you destroy the engine instance.
         *
         */
        RTCVideo_1.prototype.stopAudioCapture = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopAudioCapture()); };
            var i = function () { return Number(_this._instance.stopAudioCapture()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio management
         * @author zhangyuanyuan.0101
         * @brief Sets the audio scenarios. <br>
         *        You can choose the appropriate audio scenario according to your application. <br>
         *        After selecting the audio scenario, the SDK will automatically apply the call volume/media volume based on the client's audio capture and playback devices and status, and synchronously change the corresponding audio-related algorithm configurations and capture settings.
         * @param audioScenario  Audio scenarios. See {@link AudioScenarioType AudioScenarioType}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - It is recommended to call this API before joining the room and calling other audio related interfaces. If this API is called afterwards, audio lag may be introduced.
         *         - Call volume is more suitable for calls, meetings and other scenarios that demand information accuracy. Call volume will activate the system hardware signal processor, making the sound clearer. The volume cannot be reduced to 0.
         *         - Media volume is more suitable for entertainment scenarios, which require musical expression. The volume can be reduced to 0.
         *
         */
        RTCVideo_1.prototype.setAudioScenario = function (audioScenario) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setAudioScenario(t_AudioScenarioType.ts_to_android(audioScenario)));
            };
            var i = function () {
                return Number(_this._instance.setAudioScenario(t_AudioScenarioType.ts_to_ios(audioScenario)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region audio management
         * @author zhangyuanyuan.0101
         * @brief Sets the sound quality. Call this API to change the sound quality if the audio settings in the current {@link ChannelProfile ChannelProfile} can not meet your requirements.
         * @param audioProfile  Sound quality. See {@link AudioProfileType AudioProfileType}
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - This method can be called before and after entering the room.
         *         - Support dynamic switching of sound quality during a call.
         *
         */
        RTCVideo_1.prototype.setAudioProfile = function (audioProfile) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setAudioProfile(t_AudioProfileType.ts_to_android(audioProfile)));
            };
            var i = function () {
                return Number(_this._instance.setAudioProfile(t_AudioProfileType.ts_to_ios(audioProfile)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region audio management
         * @author liuchuang
         * @brief Set the Active Noise Cancellation(ANC) mode during audio and video communications.
         * @param ansMode ANC modes. See {@link AnsMode AnsMode}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *       - You can call this API before or after entering a room. When you repeatedly call it, only the last call takes effect.
         *       - The noise reduction algorithm includes both traditional noise reduction and AI noise reduction. Traditional noise reduction is primarily aimed at suppressing steady noises, such as the hum of air conditioners and the whir of fans. AI noise reduction, on the other hand, is mainly designed to suppress non-stationary noises, like the tapping of keyboards and the clattering of tables and chairs.
         *       - Before version V3.57.1, AI noise reduction can only be enabled through this interface when the following {@link ChannelProfile ChannelProfile} scenarios are engaged:
         *          - Gaming voice mode: `CHANNEL_PROFILE_GAME(2)`
         *          - High-fidelity gaming mode: `CHANNEL_PROFILE_GAME_HD(8)`
         *          - Cloud gaming mode: `CHANNEL_PROFILE_CLOUD_GAME(3)`
         *          - 1 vs 1 audio/video call: `CHANNEL_PROFILE_CHAT(5)`
         *          - Multi-client synchronized audio/video playback: `CHANNEL_PROFILE_LW_TOGETHER(7)`
         *          - Personal devices in cloud meetings: `CHANNEL_PROFIEL_MEETING`
         *          - Classroom interaction mode: `CHANNEL_PROFILE_MEETING_ROOM(17)`
         *          - Meeting room terminals in cloud meetings: `CHANNEL_PROFILE_CLASSROOM(18)`
         *
         */
        RTCVideo_1.prototype.setAnsMode = function (ansMode) {
            var _this = this;
            var a = function () { return Number(_this._instance.setAnsMode(t_AnsMode.ts_to_android(ansMode))); };
            var i = function () { return Number(_this._instance.setAnsMode(t_AnsMode.ts_to_ios(ansMode))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @valid since 3.32
         * @region American Sound Effect Management
         * @author wangjunzheng
         * @brief Set the sound change effect type
         * @param voiceChanger The sound change effect type. See {@link VoiceChangerType VoiceChangerType}
         * @return API call result: <br>
         *        - 0: Success.
         *        - <0: Failure. See {@link ReturnStatus ReturnStatus} for specific reasons.
         * @note
         *         - To use this feature, you need to integrate the SAMI library. See [On-Demand Plugin Integration](#1108726).
         *         - You can call it before and after entering the room.
         *         - Effective for both internal and external audio source.
         *         - Only valid for mono-channel audio.
         *         - Mutually exclusive with {@link setVoiceReverbType setVoiceReverbType}, and the effects set later will override the effects set first.
         *
         */
        RTCVideo_1.prototype.setVoiceChangerType = function (voiceChanger) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setVoiceChangerType(t_VoiceChangerType.ts_to_android(voiceChanger)));
            };
            var i = function () {
                return Number(_this._instance.setVoiceChangerType(t_VoiceChangerType.ts_to_ios(voiceChanger)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @valid since 3.32
         * @region Bel Sound Effect Management
         * @author wangjunzheng
         * @brief Set the reverb effect type
         * @param voiceReverb Reverb effect type. See {@link VoiceReverbType VoiceReverbType}
         * @return API call result: <br>
         *        - 0: Success.
         *        - <0: Failure. See {@link ReturnStatus ReturnStatus} for specific reasons.
         * @note
         *         - You can call it before and after entering the room.
         *         - Effective for both internal and external audio source.
         *         - Only valid for mono-channel audio.
         *         - Mutually exclusive with {@link setVoiceChangerType setVoiceChangerType}, and the effects set later will override the effects set first.
         *
         */
        RTCVideo_1.prototype.setVoiceReverbType = function (voiceReverb) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setVoiceReverbType(t_VoiceReverbType.ts_to_android(voiceReverb)));
            };
            var i = function () {
                return Number(_this._instance.setVoiceReverbType(t_VoiceReverbType.ts_to_ios(voiceReverb)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author wangjunzheng
         * @brief Set the equalization effect for the local captured audio. The audio includes both internal captured audio and external captured voice, but not the mixing audio file.
         * @param voiceEqualizationConfig See {@link VoiceEqualizationConfig VoiceEqualizationConfig}.
         * @return
         *         - 0: Success.
         *         - < 0: Failure.
         * @note According to the Nyquist acquisition rate, the audio acquisition rate must be greater than twice the set center frequency. Otherwise, the setting will not be effective.
         *
         */
        RTCVideo_1.prototype.setLocalVoiceEqualization = function (voiceEqualizationConfig) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setLocalVoiceEqualization(unpackObject(voiceEqualizationConfig)));
            };
            var i = function () {
                return Number(_this._instance.setLocalVoiceEqualization(unpackObject(voiceEqualizationConfig)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author wangjunzheng
         * @brief Set the reverb effect for the local captured audio. The audio includes both internal captured audio and external captured voice, but not the mixing audio file.
         * @param config See {@link VoiceReverbConfig VoiceReverbConfig}.
         * @return
         *         - 0: Success.
         *         - < 0: Failure.
         * @note Call {@link enableLocalVoiceReverb enableLocalVoiceReverb} to enable the reverb effect.
         *
         */
        RTCVideo_1.prototype.setLocalVoiceReverbParam = function (config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setLocalVoiceReverbParam(unpackObject(config)));
            };
            var i = function () {
                return Number(_this._instance.setLocalVoiceReverbParam(unpackObject(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author wangjunzheng
         * @brief Enable the reverb effect for the local captured voice.
         * @param enable
         * @return
         *         - 0: Success.
         *         - < 0: Failure.
         * @note Call {@link setLocalVoiceReverbParam setLocalVoiceReverbParam} to set the reverb effect.
         *
         */
        RTCVideo_1.prototype.enableLocalVoiceReverb = function (enable) {
            var _this = this;
            var a = function () { return Number(_this._instance.enableLocalVoiceReverb(enable)); };
            var i = function () { return Number(_this._instance.enableLocalVoiceReverb(enable)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author sunhang.io
         * @brief Sets the view to be used for local video rendering and the rendering mode.
         * @param streamIndex Video stream type. See [StreamIndex](70083#streamindex-2).
         * @param videoCanvas View information and rendering mode. See {@link VideoCanvas VideoCanvas}.
         * @return
         *         - 0: Success
         *         - -1: videoCanvas is empty
         * @note
         *       - You should bind your stream to a view before joining the room. This setting will remain in effect after you leave the room.
         *       - If you need to unbind the local video stream from the current view, you can call this API and set the videoCanvas to `null`.
         *
         */
        RTCVideo_1.prototype.setLocalVideoCanvas = function (streamIndex, videoCanvas) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setLocalVideoCanvas(t_StreamIndex.ts_to_android(streamIndex), unpackObject(videoCanvas)));
            };
            var i = function () {
                return Number(_this._instance.setLocalVideoCanvas(t_StreamIndex.ts_to_ios(streamIndex), unpackObject(videoCanvas)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region  video management
         * @author wangfujun.911
         * @brief Update the render mode and background color of local video rendering
         * @param streamIndex See [StreamIndex](70083#streamindex-2)
         * @param renderMode See {@link VideoCanvas VideoCanvas}.renderMode
         * @param backgroundColor See {@link VideoCanvas VideoCanvas}.backgroundColor
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note Calling this API during local video rendering will be effective immediately.
         *
         */
        RTCVideo_1.prototype.updateLocalVideoCanvas = function (streamIndex, renderMode, backgroundColor) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.updateLocalVideoCanvas(t_StreamIndex.ts_to_android(streamIndex), t_RenderMode.ts_to_android(renderMode), backgroundColor));
            };
            var i = function () {
                return Number(_this._instance.updateLocalVideoCanvas(t_StreamIndex.ts_to_ios(streamIndex), t_RenderMode.ts_to_ios(renderMode), backgroundColor));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.56
         * @detail api
         * @region Video management
         * @author zhongshenyou
         * @brief Modifies remote video frame rendering settings, including render mode, background color, and rotation angle, while using the internal rendering of the SDK.
         * @param streamKey Information about the remote stream. See {@link RemoteStreamKey RemoteStreamKey}.
         * @param remoteVideoRenderConfig Video rendering settings. See {@link RemoteVideoRenderConfig RemoteVideoRenderConfig}.
         * @return
         *        - 0: Success.
         *        - < 0 : Failure. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - After setting the rendering configuration for the remote video frame with {@link setRemoteVideoCanvas setRemoteVideoCanvas}, you can call this API to update settings including render mode, background color, and rotation angle.
         *        - Calling this API during remote video rendering will be effective immediately.
         *
         */
        RTCVideo_1.prototype.updateRemoteStreamVideoCanvas = function (streamKey, remoteVideoRenderConfig) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.updateRemoteStreamVideoCanvas(unpackObject(streamKey), unpackObject(remoteVideoRenderConfig)));
            };
            var i = function () {
                return Number(_this._instance.updateRemoteStreamVideoCanvas(unpackObject(streamKey), unpackObject(remoteVideoRenderConfig)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Custom Video Capturing & Rendering
         * @author sunhang.io
         * @brief Sets the view to be used for remote video rendering and the rendering mode. <br>
         *        To unbind the canvas, set `videoCanvas` to Null.
         * @param streamKey See {@link RemoteStreamKey RemoteStreamKey}.
         * @param videoCanvas View information and rendering mode. See {@link VideoCanvas VideoCanvas}. Starting from version 3.56, you can set the rotation angle of the remote video rendering using `renderRotation`.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note When the local user leaves the room, the setting will be invalid. The remote user leaving the room does not affect the setting.
         *
         */
        RTCVideo_1.prototype.setRemoteVideoCanvas = function (streamKey, videoCanvas) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setRemoteVideoCanvas(unpackObject(streamKey), unpackObject(videoCanvas)));
            };
            var i = function () {
                return Number(_this._instance.setRemoteVideoCanvas(unpackObject(streamKey), unpackObject(videoCanvas)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @hidden not available
         * @detail api
         * @region Audio & Video Processing
         * @author yinkaisheng
         * @brief Sets the super resolution mode for remote video stream.
         * @param streamKey Remote stream information that specifies the source and type of the video stream. See {@link RemoteStreamKey RemoteStreamKey}.
         * @param mode Super resolution mode. See {@link VideoSuperResolutionMode VideoSuperResolutionMode}.
         * @return. <br>
         *        - 0: RETURN_STATUS_SUCCESS. It does not indicate the actual status of the super resolution mode, you should refer to {@link onRemoteVideoSuperResolutionModeChanged onRemoteVideoSuperResolutionModeChanged} callback.
         *        - -1: RETURN_STATUS_NATIVE_IN_VALID. Native library is not loaded.
         *        - -2: RETURN_STATUS_PARAMETER_ERR. Invalid parameter.
         *        - -9: RETURN_STATUS_SCREEN_NOT_SUPPORT. Failure. Screen stream is not supported.
         *        See {@link ReturnStatus ReturnStatus} for more return value indications.
         * @note
         *        - Call this API after joining room.
         *        - The original resolution of the remote video stream should not exceed 640 × 360 pixels.
         *        - You can only turn on super-resolution mode for one stream.
         *
         */
        RTCVideo_1.prototype.setRemoteVideoSuperResolution = function (streamKey, mode) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setRemoteVideoSuperResolution(unpackObject(streamKey), t_VideoSuperResolutionMode.ts_to_android(mode)));
            };
            var i = function () {
                return Number(_this._instance.setRemoteVideoSuperResolution(unpackObject(streamKey), t_VideoSuperResolutionMode.ts_to_ios(mode)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @hidden not available
         * @detail api
         * @region Audio & Video Processing
         * @author Yujianli
         * @brief Sets the video noise reduction mode.
         * @param mode Video noise reduction mode. Refer to {@link VideoDenoiseMode VideoDenoiseMode} for more details.
         * @return
         *        - 0: Success. Please refer to {@link onVideoDenoiseModeChanged onVideoDenoiseModeChanged} callback for the actual state of video noise reduction mode.
         *        - < 0: Failure.
         *
         */
        RTCVideo_1.prototype.android_setVideoDenoiser = function (mode) {
            var _this = this;
            var $ = function () { return Number(_this._instance.setVideoDenoiser(mode)); };
            return $();
        };
        /** {en}
         * @detail api
         * @region Video management
         * @author wangjunlin.3182
         * @brief Sets the mirror mode for the captured video stream.
         * @param mirrorType Mirror type. See {@link MirrorType MirrorType}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - Switching video streams does not affect the settings of the mirror type.
         *         - This API is not applicable to screen-sharing streams.
         *         - When using an external renderer, you can set `mirrorType` to `0` and `3`, but you cannot set it to `1`.
         *         - Before you call this API, the initial states of each video stream are as follows:
         *         <table>
         *            <tr><th></th><th>Front-facing camera</th><th>Back-facing camera</th><th>Custom capturing</th><th>Built-in camera</th></tr>
         *            <tr><td>Mobile device</td><td>The preview is mirrored. The published video stream is not mirrored.</td><td>The preview and the published video stream are not mirrored.</td><td>The preview and the published video stream are not mirrored.</td><td>/</td></tr>
         *            <tr><td>PC</td><td>/</td><td>/</td><td>The preview and the published video stream are not mirrored.</td><td>The preview is mirrored. The published video stream is not mirrored.</td></tr>
         *         </table>
         *
         */
        RTCVideo_1.prototype.setLocalVideoMirrorType = function (mirrorType) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setLocalVideoMirrorType(t_MirrorType.ts_to_android(mirrorType)));
            };
            var i = function () {
                return Number(_this._instance.setLocalVideoMirrorType(t_MirrorType.ts_to_ios(mirrorType)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @valid since 3.57
         * @region Video Management
         * @brief When using internal rendering, enable mirroring for the remote stream.
         * @param remoteStreamKey Information about the remote stream, used to specify the source and attributes of the video stream that needs to be mirrored, see {@link RemoteStreamKey RemoteStreamKey}.
         * @param mirrorType The mirror type for the remote stream, see {@link RemoteMirrorType RemoteMirrorType}.
         * @return
         *        - 0: Successful call.
         *        - < 0: Call failed, see {@link ReturnStatus ReturnStatus} for more error details.
         *
         */
        RTCVideo_1.prototype.setRemoteVideoMirrorType = function (remoteStreamKey, mirrorType) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setRemoteVideoMirrorType(unpackObject(remoteStreamKey), t_RemoteMirrorType.ts_to_android(mirrorType)));
            };
            var i = function () {
                return Number(_this._instance.setRemoteVideoMirrorType(unpackObject(remoteStreamKey), t_RemoteMirrorType.ts_to_ios(mirrorType)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @brief Set the orientation of the video capture. By default, the App direction is used as the orientation reference. <br>
         *        During rendering, the receiving client rotates the video in the same way as the sending client did.
         * @param rotationMode Rotation reference can be the orientation of the App or gravity. Refer to {@link VideoRotationMode VideoRotationMode} for details.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - The orientation setting is effective for internal video capture only. That is, the orientation setting is not effective to the custom video source or the screen-sharing stream.
         *        - If the video capture is on, the setting will be effective once you call this API. If the video capture is off, the setting will be effective on when capture starts.
         *
         */
        RTCVideo_1.prototype.setVideoRotationMode = function (rotationMode) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setVideoRotationMode(t_VideoRotationMode.ts_to_android(rotationMode)));
            };
            var i = function () {
                return Number(_this._instance.setVideoRotationMode(t_VideoRotationMode.ts_to_ios(rotationMode)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author zhangzhenyu.samuel
         * @brief Switch to the front-facing/back-facing camera used in the internal video capture <br>
         *        The local client will be informed via {@link onVideoDeviceStateChanged onVideoDeviceStateChanged} after calling this API.
         * @param cameraId Camera ID. Refer to {@link CameraId CameraId} for more details.
         * @return
         *         - 0: Success
         *         - < 0: Failure
         * @note
         *         - Front-facing camera is the default camera.
         *         - If the internal video capturing is on, the switch is effective once you call this API. If the internal video capturing is off, the setting will be effective when capture starts.
         *
         */
        RTCVideo_1.prototype.switchCamera = function (cameraId) {
            var _this = this;
            var a = function () { return Number(_this._instance.switchCamera(t_CameraId.ts_to_android(cameraId))); };
            var i = function () { return Number(_this._instance.switchCamera(t_CameraId.ts_to_ios(cameraId))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author dixing
         * @brief Set the current audio playback route. The default device is set via {@link setDefaultAudioRoute setDefaultAudioRoute}. <br>
         *         When the audio playback route changes, you will receive {@link onAudioRouteChanged onAudioRouteChanged}.
         * @param audioRoute Audio route. Refer to {@link AudioRoute AudioRoute}. <br>
         *        For Android device, the valid audio playback devices may vary due to different audio device connection status. See [Set the Audio Route](https://docs.byteplus.com/byteplus-rtc/docs/117836).
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *      - You can implement most scenarios by calling {@link setDefaultAudioRoute setDefaultAudioRoute} and the default audio route switching strategy of the RTC SDK. For details about the strategy, see [Set the Audio Route](https://docs.byteplus.com/byteplus-rtc/docs/117836). You should use this API in a few exceptional scenarios like manually switching audio route with external audio device connected.
         *      - This interface is only supported in the `AUDIO_SCENARIO_COMMUNICATION` audio scenario. Call {@link setAudioScenario setAudioScenario} to switch between different audio scenarios.
         *      - For the volume type in different audio scenarios, refer to {@link AudioScenarioType AudioScenarioType}.
         *
         */
        RTCVideo_1.prototype.setAudioRoute = function (audioRoute) {
            var _this = this;
            var a = function () { return Number(_this._instance.setAudioRoute(t_AudioRoute.ts_to_android(audioRoute))); };
            var i = function () { return Number(_this._instance.setAudioRoute(t_AudioRoute.ts_to_ios(audioRoute))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio management
         * @author dixing
         * @brief Get the information of currently-using playback route.
         * @return See {@link AudioRoute AudioRoute}.
         * @note To set the audio playback route, see {@link setAudioRoute setAudioRoute}.
         *
         */
        RTCVideo_1.prototype.getAudioRoute = function () {
            var _this = this;
            var a = function () { return t_AudioRoute.android_to_ts(_this._instance.getAudioRoute()); };
            var i = function () { return t_AudioRoute.ios_to_ts(_this._instance.getAudioRoute()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author dixing
         * @brief Set the speaker or earpiece as the default audio playback device.
         * @param route Audio playback device. Refer to {@link AudioRoute AudioRoute}. You can only use earpiece and speakerphone.
         * @return
         *         - 0: Success.
         *         - < 0: failure. It fails when the device designated is neither a speaker nor an earpiece.
         * @note For the default audio route switching strategy of the RTC SDK, see [Set the Audio Route](https://docs.byteplus.com/byteplus-rtc/docs/117836).
         *
         */
        RTCVideo_1.prototype.setDefaultAudioRoute = function (route) {
            var _this = this;
            var a = function () { return Number(_this._instance.setDefaultAudioRoute(t_AudioRoute.ts_to_android(route))); };
            var i = function () { return Number(_this._instance.setDefaultAudioRoute(t_AudioRoute.ts_to_ios(route))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author zhangyuanyuan.0101
         * @brief Enable the audio process mode for external sound card.
         * @param enable <br>
         *        - true: enable
         *        - false: disable (by default)
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - When you use external sound card for audio capture, enable this mode for better audio quality.
         *         - When using the mode, you can only use earphones. If you need to use internal or external speaker, disable this mode.
         *
         */
        RTCVideo_1.prototype.enableExternalSoundCard = function (enable) {
            var _this = this;
            var a = function () { return Number(_this._instance.enableExternalSoundCard(enable)); };
            var i = function () { return Number(_this._instance.enableExternalSoundCard(enable)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.58.1
         * @detail api
         * @region Volume management
         * @author shiyayun
         * @brief Set whether to mute the recording signal (without changing the local hardware).
         * @param index Stream index, specifying the main stream or screen stream volume adjustment. See [StreamIndex](70083#streamindex-2).
         * @param mute Whether to mute audio capture. <br>
         *        - True: Mute (disable microphone)
         *        - False: (Default) Enable microphone
         * @return
         *        - 0: Success.
         *        - < 0 : Failure. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *         - Calling this API does not affect the status of SDK audio stream publishing.
         *         - Adjusting the volume by calling {@link setCaptureVolume setCaptureVolume} after muting will not cancel the mute state. The volume state will be retained until unmuted.
         *         - You can use this interface to set the capture volume before or after calling {@link startAudioCapture startAudioCapture} to enable audio capture.
         *
         */
        RTCVideo_1.prototype.muteAudioCapture = function (index, mute) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.muteAudioCapture(t_StreamIndex.ts_to_android(index), mute));
            };
            var i = function () {
                return Number(_this._instance.muteAudioCapture(t_StreamIndex.ts_to_ios(index), mute));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Volume management
         * @author huangshouqin
         * @brief Adjust the volume of the audio capture
         * @param index Index of the stream, whose volume needs to be adjusted. Refer to [StreamIndex](70083#streamindex-2) for more details.
         * @param volume Ratio of capture volume to original volume. <br>
         *              This changes the volume property of the audio data other than the hardware volume.<br> Ranging: [0,400]. Unit: \% <br>
         *              To ensure the audio quality, we recommend setting the volume to `100`. <br>
         *        - 0: Mute
         *        - 100: Original volume. To ensure the audio quality, we recommend [0, 100].
         *        - 400: Four times the original volume with signal-clipping protection.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note  Call this API to set the volume of the audio capture before or during the audio capture.
         *
         */
        RTCVideo_1.prototype.setCaptureVolume = function (index, volume) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setCaptureVolume(t_StreamIndex.ts_to_android(index), volume));
            };
            var i = function () {
                return Number(_this._instance.setCaptureVolume(t_StreamIndex.ts_to_ios(index), volume));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region volume management
         * @author huangshouqin
         * @brief Adjusts the locally playing volume after mixing sounds of all remote users. You can call this API before or during the playback.
         * @param volume Ratio(\%) of playback volume to original volume, in the range [0, 400], with overflow protection. <br>
         *        To ensure the audio quality, we recommend setting the volume to `100`. <br>
         *        - 0: mute
         *        - 100: original volume
         *        - 400: Four times the original volume with signal-clipping protection.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note Suppose a remote user A is always within the range of the target user whose playback volume will be adjusted, if you use both this method and {@link setRemoteAudioPlaybackVolume setRemoteAudioPlaybackVolume}{@link setRemoteRoomAudioPlaybackVolume /setRemoteRoomAudioPlaybackVolume}, the volume that the local user hears from user A is the overlay of both settings.
         *
         */
        RTCVideo_1.prototype.setPlaybackVolume = function (volume) {
            var _this = this;
            var a = function () { return Number(_this._instance.setPlaybackVolume(volume)); };
            var i = function () { return Number(_this._instance.setPlaybackVolume(volume)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio Mixing
         * @author wangjunzheng
         * @brief Change local voice to a different key, mostly used in Karaoke scenarios. <br>
         *        You can adjust the pitch of local voice such as ascending or descending with this method.
         * @param pitch The value that is higher or lower than the original local voice within a range from -12 to 12. The default value is 0, i.e. No adjustment is made. <br>
         *        The difference in pitch between two adjacent values within the value range is a semitone, with positive values indicating an ascending tone and negative values indicating a descending tone, and the larger the absolute value set, the more the pitch is raised or lowered. <br>
         *        Out of the value range, the setting fails and triggers {@link onWarning onWarning} callback, indicating `WARNING_CODE_SET_SCREEN_STREAM_INVALID_VOICE_PITCH` for invalid value setting with {@link WarningCode WarningCode}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         *
         */
        RTCVideo_1.prototype.setLocalVoicePitch = function (pitch) {
            var _this = this;
            var a = function () { return Number(_this._instance.setLocalVoicePitch(pitch)); };
            var i = function () { return Number(_this._instance.setLocalVoicePitch(pitch)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio Management
         * @author majun.lvhiei
         * @brief Enables/disables the loudness equalization function. <br>
         *        If you call this API with the parameter set to True, the loudness of user's voice will be adjusted to -16lufs. If then you also call {@link setAudioMixingLoudness setAudioMixingLoudness} and import the original loudness of the audio data used in audio mixing, the loudness will be adjusted to -20lufs when the audio data starts to play.
         * @param enable Whether to enable loudness equalization function: <br>
         *        - true: Yes
         *        - false: No
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note You must call this API before starting to play the audio file with {@link startAudioMixing startAudioMixing}.
         *
         */
        RTCVideo_1.prototype.enableVocalInstrumentBalance = function (enable) {
            var _this = this;
            var a = function () { return Number(_this._instance.enableVocalInstrumentBalance(enable)); };
            var i = function () { return Number(_this._instance.enableVocalInstrumentBalance(enable)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio Management
         * @author majun.lvhiei
         * @brief Enables/disables the playback ducking function. This function is usually used in scenarios where short videos or music will be played simultaneously during RTC calls. <br>
         *        With the function on, if remote voice is detected, the local media volume will be lowered to ensure the clarity of the remote voice. If remote voice disappears, the local media volume restores.
         * @param enable Whether to enable playback ducking: <br>
         *        - true: Yes
         *        - false: No
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         *
         */
        RTCVideo_1.prototype.enablePlaybackDucking = function (enable) {
            var _this = this;
            var a = function () { return Number(_this._instance.enablePlaybackDucking(enable)); };
            var i = function () { return Number(_this._instance.enablePlaybackDucking(enable)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Real-time messaging
         * @author hanchenchen.c
         * @brief Log in first to call {@link sendUserMessageOutsideRoom sendUserMessageOutsideRoom} and {@link sendServerMessage sendServerMessage} to send P2P messages or send messages to a server without joining the RTC room. <br>
         *        To log out, call {@link logout logout}.
         * @param token <br>
         *        Token is required during login for authentication. <br>
         *        This Token is different from that required by calling joinRoom. You can assign any value even null to `roomId` to generate a login token. During developing and testing, you can use temporary tokens generated on the console. Deploy the token generating application on your server.
         * @param uid <br>
         *        User ID <br>
         *        User ID is unique within one appid.
         * @return
         *        - 0: Success.
         *        - <0: Failure. See {@link ReturnStatus ReturnStatus} for specific reasons.
         * @note  You will receive {@link onLoginResult onLoginResult} after calling this API and log in successfully. But remote users will not receive notification about that.
         *
         */
        RTCVideo_1.prototype.login = function (token, uid) {
            var _this = this;
            var a = function () { return Number(_this._instance.login(token, uid)); };
            var i = function () { return Number(_this._instance.login(token, uid)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail After api
         * @region  real-time messaging
         * @author hanchenchen.c
         * @brief Call this method to log out, it is impossible to call methods related to out-of-room messages and end-to-server messages or receive related callbacks.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - After calling this interface to log out, you must first call {@link login login} to log in.
         *        - After local users call this method to log out, they will receive the result of the {@link onLogout onLogout} callback notification, and remote users will not receive the notification.
         *
         */
        RTCVideo_1.prototype.logout = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.logout()); };
            var i = function () { return Number(_this._instance.logout()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Real-time messaging
         * @author hanchenchen.c
         * @brief Update the Token <br>
         *        Token used by the user for login has a certain valid period. When the Token expires, you need to call this method to update the login Token information. <br>
         *         When calling the {@link login login} method to log in, if an expired token is used, the login will fail and you will receive an {@link onLoginResult onLoginResult} callback notification with an error code of 'LOGIN_ERROR_CODE_INVALID_TOKEN'. You need to reacquire the token and call this method to update the token.
         * @param token <br>
         *        Updated dynamic key
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - If the token is invalid and the login fails, the SDK will automatically log in again after updating the token by calling this method, and the user does not need to call the {@link login login} method himself.
         *        - Token expires, if you have successfully logged in, it will not be affected. An expired Token error will be notified to the user the next time you log in with an expired Token, or when you log in again due to a disconnection due to poor local network conditions.
         *
         */
        RTCVideo_1.prototype.updateLoginToken = function (token) {
            var _this = this;
            var a = function () { return Number(_this._instance.updateLoginToken(token)); };
            var i = function () { return Number(_this._instance.updateLoginToken(token)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Real-time messaging
         * @author hanchenchen.c
         * @brief Set application server parameters <br>
         *        Client side calls {@link sendServerMessage sendServerMessage} or {@link sendServerBinaryMessage sendServerBinaryMessage} Before sending a message to the application server, you must set a valid signature and application server address.
         * @param signature Dynamic signature. The App server may use the signature to verify the source of messages. <br>
         *                  You need to define the signature yourself. It can be any non-empty string. It is recommended to encode information such as UID into the signature. <br>
         *                  The signature will be sent to the address set through the "url" parameter in the form of a POST request.
         * @param url The address of the application server
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - The user must call {@link login login} to log in before calling this interface.
         *        - After calling this interface, the SDK will use {@link onServerParamsSetResult onServerParamsSetResult} to return the corresponding result.
         *
         */
        RTCVideo_1.prototype.setServerParams = function (signature, url) {
            var _this = this;
            var a = function () { return Number(_this._instance.setServerParams(signature, url)); };
            var i = function () { return Number(_this._instance.setServerParams(signature, url)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region real-time messaging
         * @author hanchenchen.c
         * @brief Query the login status of the opposite or local user
         * @param peerUserID The user ID to be queried
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - You must call {@link login login} to log in before calling this interface.
         *        - After calling this interface, the SDK notifies the query result using the {@link onGetPeerOnlineStatus onGetPeerOnlineStatus} callback.
         *        - Before sending an out-of-room message, the user can know whether the peer user is logged in through this interface to decide whether to send a message. You can also check your login status through this interface.
         *
         */
        RTCVideo_1.prototype.getPeerOnlineStatus = function (peerUserID) {
            var _this = this;
            var a = function () { return Number(_this._instance.getPeerOnlineStatus(peerUserID)); };
            var i = function () { return Number(_this._instance.getPeerOnlineStatus(peerUserID)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Real-time messaging
         * @author hanchenchen.c
         * @brief Send a text message (P2P) to a specified user outside the room
         * @param uid User ID of the message receiver
         * @param message <br>
         *        Text message content sent. <br>
         *         Message does not exceed 64 KB.
         * @param config Message type, see {@link MessageConfig MessageConfig}.
         * @return
         *         - > 0: Sent successfully, return the number of the sent message, increment from 1
         *         - -1: Sent failed, RTCVideo instance not created
         *         - -2: Sent failed, uid is empty
         * @note
         *        - Before sending an out-of-room text message, you must call {@link login login} to login.
         *        - After the user calls this interface to send a text message, he will receive an {@link onUserMessageSendResultOutsideRoom onUserMessageSendResultOutsideRoom} callback to know whether the message was successfully sent.
         *        - If the text message is sent successfully, the user specified by uid receives the message via the {@link onUserMessageReceivedOutsideRoom onUserMessageReceivedOutsideRoom} callback.
         *
         */
        RTCVideo_1.prototype.sendUserMessageOutsideRoom = function (uid, message, config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.sendUserMessageOutsideRoom(uid, message, t_MessageConfig.ts_to_android(config)));
            };
            var i = function () {
                return Number(_this._instance.sendUserMessageOutsideRoom(uid, message, t_MessageConfig.ts_to_ios(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Real-time messaging
         * @author hanchenchen.c
         * @brief Send binary messages (P2P) to the specified user outside the room
         * @param uid User ID of the message receiver
         * @param buffer <br>
         *        Binary message content sent <br>
         *        Message does not exceed 46KB.
         * @param config Message type, see {@link MessageConfig MessageConfig}.
         * @return
         *         - > 0: Sent successfully, return the number of the sent message this time, increment from 1
         *         - -1: Sent failed, RTCVideo instance not created
         *         - -2: Sent failed, uid is empty
         * @note
         *        - Before sending out-of-room binary messages, you should call {@link login login} first.
         *        - After the user calls this interface to send a binary message, he will receive an {@link onUserMessageSendResultOutsideRoom onUserMessageSendResultOutsideRoom} callback to notify whether the message was sent successfully;
         *        - If the binary message is sent successfully, the user specified by uid will receive the message through the {@link onUserBinaryMessageReceivedOutsideRoom onUserBinaryMessageReceivedOutsideRoom} callback.
         *
         */
        RTCVideo_1.prototype.sendUserBinaryMessageOutsideRoom = function (uid, buffer, config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.sendUserBinaryMessageOutsideRoom(uid, buffer, t_MessageConfig.ts_to_android(config)));
            };
            var i = function () {
                return Number(_this._instance.sendUserBinaryMessageOutsideRoom(uid, buffer, t_MessageConfig.ts_to_ios(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Real-time messaging
         * @author hanchenchen.c
         * @brief The client side sends a text message to the application server (P2Server)
         * @param message <br>
         *        The content of the text message sent <br>
         *        The message does not exceed 64 KB.
         * @return
         *         - > 0: Sent successfully, return the number of the sent message, increment from 1
         *         - -1: Sent failed, RTCVideo instance not created
         * @note
         *        - Before sending a text message to the application server, you must first call {@link login login} to complete the login, and then call {@link setServerParams setServerParams} Set up the application server.
         *        - After calling this interface, you will receive an {@link onServerMessageSendResult onServerMessageSendResult} callback to inform the message sender whether the message was sent successfully.
         *        - If the text message is sent successfully, the application server that previously called the {@link setServerParams setServerParams} setting will receive the message.
         *
         */
        RTCVideo_1.prototype.sendServerMessage = function (message) {
            var _this = this;
            var a = function () { return Number(_this._instance.sendServerMessage(message)); };
            var i = function () { return Number(_this._instance.sendServerMessage(message)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Real-time messaging
         * @author hanchenchen.c
         * @brief Client side sends binary messages to the application server (P2Server)
         * @param buffer <br>
         *        Binary message content sent <br>
         *        Message does not exceed 46KB.
         * @return
         *         - > 0: Sent successfully, return the number of the sent message, increment from 1
         *         - -1: Sent failed, RTCVideo instance not created
         * @note
         *        - Before sending a binary message to the application server, you must first call {@link login login} to complete the login, and then call {@link setServerParams setServerParams} Set up the application server.
         *        - After calling this interface, you will receive an {@link onServerMessageSendResult onServerMessageSendResult} callback to inform the message sender that the sending succeeded or failed;
         *        - If the binary message is sent successfully, the application server that previously called the {@link setServerParams setServerParams} setting will receive the message.
         *
         */
        RTCVideo_1.prototype.sendServerBinaryMessage = function (buffer) {
            var _this = this;
            var a = function () { return Number(_this._instance.sendServerBinaryMessage(buffer)); };
            var i = function () { return Number(_this._instance.sendServerBinaryMessage(buffer)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Pre-call network detection
         * @author hanchenchen.c
         * @brief Enable pre-call network detection
         * @param isTestUplink   Whether to detect uplink bandwidth
         * @param expectedUplinkBitrate   Expected uplink bandwidth in kbps, unit: kbps<br>Range: `{0, [100-10000]}`, `0`: Auto, that RTC will set the highest bite rate.
         * @param isTestDownlink   Whether to detect downlink bandwidth
         * @param expectedDownlinkBitrate   Expected downlink bandwidth in kbps, unit: kbps<br>Range: `{0, [100-10000]}`, `0`: Auto, that RTC will set the highest bite rate.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - After successfully calling this interface, you will receive {@link onNetworkDetectionResult onNetworkDetectionResult} within 3s and every 2s thereafter notifying the probe results;
         *        - If the probe stops, you will receive {@link onNetworkDetectionStopped onNetworkDetectionStopped} to notify the probe to stop.
         *
         */
        RTCVideo_1.prototype.startNetworkDetection = function (isTestUplink, expectedUplinkBitrate, isTestDownlink, expectedDownlinkBitrate) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.startNetworkDetection(isTestUplink, expectedUplinkBitrate, isTestDownlink, expectedDownlinkBitrate));
            };
            var i = function () {
                return Number(_this._instance.startNetworkDetection(isTestUplink, expectedUplinkBitrate, isTestDownlink, expectedDownlinkBitrate));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Pre-call network probe
         * @author hanchenchen.c
         * @brief Stop pre-call network probe
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - After calling this interface, you will receive an {@link onNetworkDetectionStopped onNetworkDetectionStopped} callback to notify the probe to stop.
         *
         */
        RTCVideo_1.prototype.stopNetworkDetection = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopNetworkDetection()); };
            var i = function () { return Number(_this._instance.stopNetworkDetection()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio Data Callback
         * @author gongzhengduo
         * @brief Enable audio frames callback and set the format for the specified type of audio frames.
         * @param method Audio data callback method. See {@link AudioFrameCallbackMethod AudioFrameCallbackMethod}. <br>
         *               If `method` is set as `AUDIO_FRAME_CALLBACK_RECORD(0)`, `AUDIO_FRAME_CALLBACK_PLAYBACK(1)`, or `AUDIO_FRAME_CALLBACK_MIXED(2)`, set `format` to the accurate value listed in the audio parameters format. <br>
         *               If `method` is set as `AUDIO_FRAME_CALLBACK_REMOTE_USER(3)`, set `format` to `auto`.
         * @param format Audio parameters format. See {@link AudioFormat AudioFormat}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note After calling this API and {@link registerAudioFrameObserver registerAudioFrameObserver}, {@link IAudioFrameObserver IAudioFrameObserver} will receive the corresponding audio data callback. However, these two APIs are independent of each other and the calling order is not restricted.
         *
         */
        RTCVideo_1.prototype.enableAudioFrameCallback = function (method, format) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.enableAudioFrameCallback(t_AudioFrameCallbackMethod.ts_to_android(method), unpackObject(format)));
            };
            var i = function () {
                return Number(_this._instance.enableAudioFrameCallback(t_AudioFrameCallbackMethod.ts_to_ios(method), unpackObject(format)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio Data Callback
         * @author gongzhengduo
         * @brief Disables audio data callback.
         * @param method Audio data callback method. See {@link AudioFrameCallbackMethod AudioFrameCallbackMethod}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note Call this API after calling {@link enableAudioFrameCallback enableAudioFrameCallback}.
         *
         */
        RTCVideo_1.prototype.disableAudioFrameCallback = function (method) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.disableAudioFrameCallback(t_AudioFrameCallbackMethod.ts_to_android(method)));
            };
            var i = function () {
                return Number(_this._instance.disableAudioFrameCallback(t_AudioFrameCallbackMethod.ts_to_ios(method)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio Data Callback
         * @author gongzhengduo
         * @brief Register an audio frame observer.
         * @param observer Audio data callback observer. See {@link IAudioFrameObserver IAudioFrameObserver}. Use `null` to cancel the registration.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note After calling this API and {@link enableAudioFrameCallback enableAudioFrameCallback}, {@link IAudioFrameObserver IAudioFrameObserver} receives the corresponding audio data callback. You can retrieve the audio data and perform processing on it without affecting the audio that RTC SDK uses to encode or render.
         *
         */
        RTCVideo_1.prototype.registerAudioFrameObserver = function (observer) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.registerAudioFrameObserver(packObject(observer, android_IAudioFrameObserver)));
            };
            var i = function () {
                return Number(_this._instance.registerAudioFrameObserver(packObject(observer, ios_IAudioFrameObserver)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author gongzhengduo
         * @brief  Register a custom audio preprocessor. <br>
         *         After that, you can call {@link enableAudioProcessor enableAudioProcessor} to process the audio streams that either captured locally or received from the remote side. RTC SDK then encodes or renders the processed data.
         * @param processor Custom audio processor. See {@link IAudioFrameProcessor IAudioFrameProcessor}。 <br>
         *        SDK only holds weak references to the processor, you should guarantee its Life Time. To cancel registration, set the parameter to nullptr.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         * - When this interface is repeatedly called, only the last call takes effect.
         * - Refer to [Custom Audio Processing](https://docs.byteplus.com/en/byteplus-rtc/docs/80635) for more information.
         *
         */
        RTCVideo_1.prototype.registerAudioProcessor = function (processor) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.registerAudioProcessor(packObject(processor, android_IAudioFrameProcessor)));
            };
            var i = function () {
                return Number(_this._instance.registerAudioProcessor(packObject(processor, ios_IAudioFrameProcessor)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author likai.666
         * @valid since 3.51
         * @brief Set the step size for each digital zooming control to the local videos.
         * @param type Required. Identifying which type the `size` is referring to. Refer to {@link ZoomConfigType ZoomConfigType}.
         * @param size Required. Reserved to three decimal places. It defaults to `0`. <br>
         *                  The meaning and range vary from different `type`s. If the scale or moving distance exceeds the range, the limit is taken as the result. <br>
         *                  - `kZoomFocusOffset`: Increasement or decrease to the scaling factor. Range: [0, 7]. For example, when it is set to 0.5 and {@link setVideoDigitalZoomControl setVideoDigitalZoomControl} is called to zoom in, the scale will increase `0.5`. The scale ranges [1，8] and defaults to `1`, which means an original size.
         *                  - `kZoomMoveOffset`：Ratio of the distance to the border of video images. It ranges [0, 0.5] and defaults to `0`, which means no offset. When you call {@link setVideoDigitalZoomControl setVideoDigitalZoomControl} and choose `CAMERA_MOVE_LEFT`, the moving distance is size x original width. While for the `CAMERA_MOVE_UP`, the moving distance is size x original height. Suppose that a video spans 1080 px and the `size` is set to `0.5` so that the distance would be 0.5 x 1080 px = 540 px.
         * @return
         *        - 0: Success.
         *        - ! 0: Failure.
         * @note
         *        - Only one size can be set for a single call. You must call this API to pass values respectively if you intend to set multiple `size`s.
         *        - As the default `size` is `0`, you must call this API before performing any digital zoom control by calling {@link setVideoDigitalZoomControl setVideoDigitalZoomControl} or {@link startVideoDigitalZoomControl startVideoDigitalZoomControl}.
         *
         */
        RTCVideo_1.prototype.setVideoDigitalZoomConfig = function (type, size) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setVideoDigitalZoomConfig(t_ZoomConfigType.ts_to_android(type), size));
            };
            var i = function () {
                return Number(_this._instance.setVideoDigitalZoomConfig(t_ZoomConfigType.ts_to_ios(type), size));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author likai.666
         * @valid since 3.51
         * @brief Digital zoom or move the local video image once. This action affects both the video preview locally and the stream published.
         * @param direction Action of the digital zoom control. Refer to {@link ZoomDirectionType ZoomDirectionType}.
         * @return
         *        - 0: Success.
         *        - ! 0: Failure.
         * @note
         *        - As the default offset is `0`, you must call {@link setVideoDigitalZoomConfig setVideoDigitalZoomConfig} before this API.
         *        - You can only move video images after they are magnified via this API or {@link startVideoDigitalZoomControl startVideoDigitalZoomControl}.
         *        - When you request an out-of-range scale or movement, SDK will execute it with the limits. For example, when the image has been moved to the border, the image cannot be zoomed out, or has been magnified to 8x.
         *        - Call {@link startVideoDigitalZoomControl startVideoDigitalZoomControl} to have a continuous and repeatedly digital zoom control.
         *        - Refer to {@link setCameraZoomRatio setCameraZoomRatio} if you intend to have an optical zoom control to the camera.
         *
         */
        RTCVideo_1.prototype.setVideoDigitalZoomControl = function (direction) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setVideoDigitalZoomControl(t_ZoomDirectionType.ts_to_android(direction)));
            };
            var i = function () {
                return Number(_this._instance.setVideoDigitalZoomControl(t_ZoomDirectionType.ts_to_ios(direction)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author likai.666
         * @valid since 3.51
         * @brief Continuous and repeatedly digital zoom control. This action effect both the video preview locally and the stream published.
         * @param direction Action of the digital zoom control. Refer to {@link ZoomDirectionType ZoomDirectionType}.
         * @return
         *        - 0: Success.
         *        - ! 0: Failure.
         * @note
         *        - As the default offset is `0`, you must call {@link setVideoDigitalZoomConfig setVideoDigitalZoomConfig} before this API.
         *        - You can only move video images after they are magnified via this API or {@link setVideoDigitalZoomControl setVideoDigitalZoomControl}.
         *        - The control process stops when the scale reaches the limit, or the images have been moved to the border. if the next action exceeds the scale or movement range, SDK will execute it with the limits.
         *        - Call {@link stopVideoDigitalZoomControl stopVideoDigitalZoomControl} to stop the ongoing zoom control.
         *        - Call {@link setVideoDigitalZoomControl setVideoDigitalZoomControl} to have a one-time digital zoom control.
         *        - Refer to {@link setCameraZoomRatio setCameraZoomRatio} if you intend to have an optical zoom control to the camera.
         *
         */
        RTCVideo_1.prototype.startVideoDigitalZoomControl = function (direction) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.startVideoDigitalZoomControl(t_ZoomDirectionType.ts_to_android(direction)));
            };
            var i = function () {
                return Number(_this._instance.startVideoDigitalZoomControl(t_ZoomDirectionType.ts_to_ios(direction)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author likai.666
         * @valid since 3.51
         * @brief Stop the ongoing digital zoom control instantly.
         * @return
         *        - 0: Success.
         *        - ! 0: Failure.
         * @note Refer to {@link startVideoDigitalZoomControl startVideoDigitalZoomControl} for starting digital zooming.
         *
         */
        RTCVideo_1.prototype.stopVideoDigitalZoomControl = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopVideoDigitalZoomControl()); };
            var i = function () { return Number(_this._instance.stopVideoDigitalZoomControl()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Data Callback
         * @author liuyangyang
         * @brief Register a local video frame observer. <br>
         *        This method applys to both internal capturing and custom capturing. <br>
         *        After calling this API, SDK triggers {@link onLocalEncodedVideoFrame onLocalEncodedVideoFrame} whenever a video frame is captured.
         * @param observer Local video frame observer. See {@link ILocalEncodedVideoFrameObserver ILocalEncodedVideoFrameObserver}. You can cancel the registration by setting it to `null`.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note You can call this API before or after entering the RTC room. Calling this API before entering the room ensures that video frames are monitored and callbacks are triggered as early as possible.
         *
         */
        RTCVideo_1.prototype.registerLocalEncodedVideoFrameObserver = function (observer) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.registerLocalEncodedVideoFrameObserver(packObject(observer, android_ILocalEncodedVideoFrameObserver)));
            };
            var i = function () {
                return Number(_this._instance.registerLocalEncodedVideoFrameObserver(packObject(observer, ios_ILocalEncodedVideoFrameObserver)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region video management
         * @author wangzhanqiang
         * @brief Video data callback after registering remote encoding. <br>
         *        After registration, when the SDK detects a remote encoded video frame, it will trigger the {@link onRemoteEncodedVideoFrame onRemoteEncodedVideoFrame} callback
         * @param observer Remote encoded video data monitor. See {@link IRemoteEncodedVideoFrameObserver IRemoteEncodedVideoFrameObserver}
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - See [Custom Video Encoding and Decoding](https://docs.byteplus.com/byteplus-rtc/docs/82921#custom-video-decoding) for more details about custom video decoding.
         *        - This method applys to manual subscription mode and can be called either before or after entering the Room. It is recommended to call it before entering the room.
         *        - The engine needs to be unregistered before it is destroyed. Call this method to set the parameter to "null".
         *
         */
        RTCVideo_1.prototype.registerRemoteEncodedVideoFrameObserver = function (observer) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.registerRemoteEncodedVideoFrameObserver(packObject(observer, android_IRemoteEncodedVideoFrameObserver)));
            };
            var i = function () {
                return Number(_this._instance.registerRemoteEncodedVideoFrameObserver(packObject(observer, ios_IRemoteEncodedVideoFrameObserver)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author liuyangyang
         * @brief Set the video source, including the screen recordings. <br>
         *        The internal video capture is the default, which refers to capturing video using the built-in module.
         * @param index Stream index. Refer to [StreamIndex](70083#streamindex-2) for more details.
         * @param type Video source type. Refer to {@link VideoSourceType VideoSourceType} for more details.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - You can call this API whether the user is in a room or not.
         *         - Calling this API to switch to the custom video source will stop the enabled internal video capture.
         *         - To switch to internal video capture, call this API to stop custom capture and then call {@link startVideoCapture startVideoCapture} to enable internal video capture.
         *         - To push custom encoded video frames to the SDK, call this API to switch `VideoSourceType` to `VIDEO_SOURCE_TYPE_ENCODED_WITH_SIMULCAST(2)` or `VIDEO_SOURCE_TYPE_ENCODED_WITHOUT_SIMULCAST(3)`.
         *
         */
        RTCVideo_1.prototype.setVideoSourceType = function (index, type) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setVideoSourceType(t_StreamIndex.ts_to_android(index), t_VideoSourceType.ts_to_android(type)));
            };
            var i = function () {
                return Number(_this._instance.setVideoSourceType(t_VideoSourceType.ts_to_ios(type), t_StreamIndex.ts_to_ios(index)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.52
         * @detail api
         * @region Push to CDN
         * @author liyunlong.zx
         * @brief Create a new task of pushing mixed media streams to CDN and sets the relevant configurations. <br>
         *        When pushing more than one live streams in the same task, SDK will first mix those streams into one single stream and then push it to CDN.
         * @param taskId Task ID. The length should not exceed 126 bytes. <br>
         *        You may want to push more than one mixed stream to CDN from the same room. When you do that, use different ID for corresponding tasks; if you will start only one task, use an empty string.
         * @param mixedConfig Configurations to be set when pushing streams to CDN. See {@link MixedStreamConfig MixedStreamConfig}.
         * @param observer Invalid parameter. Please ignore it.
         * @return API call result: <br>
         *        - 0: Success
         *        - !0: Failure
         * @note
         *       - Before calling this API，you need to enable Push to CDN on the [console](https://console.byteplus.com/rtc/workplaceRTC).
         *       - After calling this API, you will be informed of the result and errors during the pushing process via the {@link onMixingEvent onMixingEvent} callback.
         *       - If you have subscribed to the push-to-CDN server callback in the [console](https://console.byteplus.com/rtc/cloudRTC?tab=callback), calling this API will receive a [TranscodeStarted](https://docs.byteplus.com/en/byteplus-rtc/docs/75125#transcodestarted) server callback notification. When calling this API repeatedly, subsequent calls to this API will trigger both [TranscodeStarted](https://docs.byteplus.com/en/byteplus-rtc/docs/75125#transcodestarted) and [TranscodeUpdated](https://docs.byteplus.com/en/byteplus-rtc/docs/75125#transcodeupdated) callbacks.
         *       - Call {@link stopPushStreamToCDN stopPushStreamToCDN} to stop pushing streams to CDN.
         *
         */
        RTCVideo_1.prototype.startPushMixedStreamToCDN = function (taskId, mixedConfig, observer) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.startPushMixedStreamToCDN(taskId, unpackObject(mixedConfig), packObject(observer, android_IMixedStreamObserver)));
            };
            var i = function () {
                return Number(_this._instance.startPushMixedStreamToCDN(taskId, unpackObject(mixedConfig), packObject(observer, ios_IMixedStreamObserver)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.52
         * @detail api
         * @region Push to CDN
         * @author liyunlong.zx
         * @brief Update parameters needed when pushing mixed media streams to CDN. You will be informed of the change via the {@link onMixingEvent onMixingEvent} callback. <br>
         *        After calling {@link startPushMixedStreamToCDN startPushMixedStreamToCDN} to enable the function of pushing streams to CDN, you can call this API to update the relevant configurations.
         * @param taskId Task ID. Specifys of which pushing task you want to update the parameters.
         * @param mixedConfig Configurations that you want to update. See {@link MixedStreamConfig MixedStreamConfig} for specific indications. You can update any property for the task unless it is specified as unavailable for updates. <br>
         *                    If you left some properties blank, you can expect these properties to be set to their default values.
         * @return API call result: <br>
         *        - 0: Success
         *        - !0: Failure
         *
         */
        RTCVideo_1.prototype.updatePushMixedStreamToCDN = function (taskId, mixedConfig) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.updatePushMixedStreamToCDN(taskId, unpackObject(mixedConfig)));
            };
            var i = function () {
                return Number(_this._instance.updatePushMixedStreamToCDN(taskId, unpackObject(mixedConfig)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Push to CDN
         * @author liujingchao
         * @brief Create a new task of pushing a single media stream to CDN.
         * @param taskId Task ID. <br>
         *        You may want to start more than one task to push streams to CDN. When you do that, use different IDs for corresponding tasks; if you will start only one task, use an empty string.
         * @param param Configurations for pushing a single stream to CDN. See {@link PushSingleStreamParam PushSingleStreamParam}.
         * @param observer Register this observer to receive callbacks from the SDK. See {@link IPushSingleStreamToCDNObserver IPushSingleStreamToCDNObserver}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *       - Before calling this API，you need to enable Push to CDN on the [console](https://console.byteplus.com/rtc/workplaceRTC).
         *       - After calling this API, you will be informed of the result and errors during the pushing process with {@link onStreamPushEvent onStreamPushEvent}.
         *       - Call {@link stopPushStreamToCDN stopPushStreamToCDN} to stop the task.
         *       - Since this API does not perform encoding and decoding, the video stream pushed to RTMP will change according to the resolution, encoding method, and turning off the camera of the end of pushing streams.
         *
         */
        RTCVideo_1.prototype.startPushSingleStreamToCDN = function (taskId, param, observer) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.startPushSingleStreamToCDN(taskId, unpackObject(param), packObject(observer, android_IPushSingleStreamToCDNObserver)));
            };
            var i = function () {
                return Number(_this._instance.startPushSingleStreamToCDN(taskId, unpackObject(param), packObject(observer, ios_IPushSingleStreamToCDNObserver)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Push to CDN
         * @author liujingchao
         * @brief Stops the task to push a single media stream to CDN. <br>
         *        This API can be used to stop both pushing single and mixed stream to CDN. You need to distinguish the tasks to be stopped by different "taskId".
         * @param taskId Task ID. Specifys the task you want to stop.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - To start pushing single stream to CDN, see {@link startPushSingleStreamToCDN startPushSingleStreamToCDN}.
         *        - To start pushing mixed stream to CDN, see {@link startPushMixedStreamToCDN startPushMixedStreamToCDN}.
         *
         */
        RTCVideo_1.prototype.stopPushStreamToCDN = function (taskId) {
            var _this = this;
            var a = function () { return Number(_this._instance.stopPushStreamToCDN(taskId)); };
            var i = function () { return Number(_this._instance.stopPushStreamToCDN(taskId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author liuyangyang
         * @brief Set the video capture parameters for internal capture of the RTC SDK. <br>
         *         If your project uses the SDK internal capture module, you can specify the video capture parameters including preference, resolution and frame rate through this interface.
         * @param videoCaptureConfig Video capture parameters. See: {@link VideoCaptureConfig VideoCaptureConfig}.
         * @return
         *         - 0: Success;
         *         - < 0: Failure;
         * @note
         *  - This interface can be called after the engine is created. It is recommended to call this interface before calling {@link startVideoCapture startVideoCapture}.
         *  - It is recommended that different Engines on the same device use the same video capture parameters.
         *  - If you used the internal module to start video capture before calling this interface, the capture parameters default to Auto.
         *
         */
        RTCVideo_1.prototype.setVideoCaptureConfig = function (videoCaptureConfig) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setVideoCaptureConfig(unpackObject(videoCaptureConfig)));
            };
            var i = function () {
                return Number(_this._instance.setVideoCaptureConfig(unpackObject(videoCaptureConfig)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author zhaomingliang
         * @brief Enables/Disables the mode of publishing multiple video streams with different encoding configuration.
         * @param enabled Whether to enable the mode of publishing multiple video streams: <br>
         *        - true: Yes
         *        - false: No(Default setting)
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - You should call this API
         *            - before entering the room, or
         *            - after entering the room but before publishing streams
         *        - When the simulcast mode is turned on, it cannot be turned off dynamically, nor can the parameters for video encoding be updated.
         *        - After setting this API to "True", you can call [setVideoEncoderConfig](#RTCVideo-setvideoencoderconfig-1) to set encoding configuration for each stream before you publish stream.
         *        - If this function is off, or if this function is on but you don't set the configuration of any stream, only one stream will be sent with a resolution of 640px × 360px and a frame rate of 15fps.
         *
         */
        RTCVideo_1.prototype.enableSimulcastMode = function (enabled) {
            var _this = this;
            var a = function () { return Number(_this._instance.enableSimulcastMode(enabled)); };
            var i = function () { return Number(_this._instance.enableSimulcastMode(enabled)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author zhaomingliang
         * @brief \<span id="RTCVideo-setvideoencoderconfig-1">\</span>Video publisher call this API to set the parameters of the maximum resolution video stream that is expected to be published, including resolution, frame rate, bitrate, and fallback strategy in poor network conditions. <br>
         *        You can only set configuration for one stream with this API. If you want to set configuration for multiple streams, Call [setVideoEncoderConfig](#RTCVideo-setvideoencoderconfig-2).
         * @param maxSolution The maximum video encoding parameter. See {@link VideoEncoderConfig VideoEncoderConfig}.
         * @return  API call result: <br>
         *        - 0: Success
         *        - ! 0: Failure
         * @note
         *        - You can use {@link enableSimulcastMode enableSimulcastMode} simultaneously to publish streams with different resolutions. Specifically, if you want to publish multiple streams with different resolutions, you need to call this method and enable the simulcast mode with {@link enableSimulcastMode enableSimulcastMode} before publishing your streams. The SDK will intelligently adjust the number of streams to be published (up to 4) and their parameters based on the settings of the subscribing end. The resolution set by calling this method will be the maximum resolution among the streams. For specific rules, please refer to [Simulcasting](https://docs.byteplus.com/en/byteplus-rtc/docs/70139).
         *        - Without calling this API, SDK will only publish one stream for you with a resolution of 640px × 360px and a frame rate of 15fps.
         *        - In custom capturing scenario, you must call this API to set encoding configurations to ensure the integrity of the picture received by the remote users.
         *        - This API is applicable to the video stream captured by the camera, see {@link setScreenVideoEncoderConfig setScreenVideoEncoderConfig} for setting parameters for screen sharing video stream.
         *
         */
        RTCVideo_1.prototype.setVideoEncoderConfig = function (channelSolutions) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setVideoEncoderConfig(channelSolutions.map(function ($item) { return unpackObject($item); })));
            };
            var i = function () {
                return Number(_this._instance.setVideoEncoderConfig(channelSolutions.map(function ($item) { return unpackObject($item); })));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Screen Sharing
         * @author zhoubohui
         * @brief Set the encoding configuration for shared-screen streams, including the resolution, frame rate, bitrate, and fallback strategies under challenging network conditions.
         * @param screenSolution The encoding configuration for shared-screen streams. See {@link ScreenVideoEncoderConfig ScreenVideoEncoderConfig}.
         * @return
         *        - 0: Success.
         *        - ! 0: Failure.
         * @note We recommend that you set the encoding configuration before video capture. Otherwise, the video will be captured based on the default configuration(1080p\@15fps).
         *
         */
        RTCVideo_1.prototype.setScreenVideoEncoderConfig = function (screenSolution) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setScreenVideoEncoderConfig(unpackObject(screenSolution)));
            };
            var i = function () {
                return Number(_this._instance.setScreenVideoEncoderConfig(unpackObject(screenSolution)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.58
         * @detail api
         * @region Video Management
         * @brief Enables the Alpha channel encoding feature for custom captured video frames. <br>
         *        Suitable for scenarios where the video subject and background need to be separated at the push stream end, and the background can be custom rendered at the pull stream end.
         * @param streamIndex The type of video stream for which this feature should be enabled. Currently, only StreamIndex.STREAM_INDEX_MAIN, i.e., the main stream, is supported.
         * @param alphaLayout The relative position of the separated Alpha channel to the RGB channel information. Currently, only AlphaLayout.TOP is supported, which means it is placed above the RGB channel information.
         * @return Method call result: <br>
         *         - 0: Success;
         *         - !0: Failure.
         * @note
         *        - This API only applies to custom captured video frames that use the RGBA color model, including VideoPixelFormat.TEXTURE_2D, VideoPixelFormat.TEXTURE_OES, VideoPixelFormat.RGBA.
         *        - This API must be called before publishing the video stream.
         *        - After calling this API to enable Alpha channel encoding, you must call {@link pushExternalVideoFrame pushExternalVideoFrame} to push the custom captured video frames to the RTC SDK. If a video frame format that is not supported is pushed, calling {@link pushExternalVideoFrame pushExternalVideoFrame} will return the error code ReturnStatus.RETURN_STATUS_PARAMETER_ERR.
         *
         */
        RTCVideo_1.prototype.enableAlphaChannelVideoEncode = function (streamIndex, alphaLayout) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.enableAlphaChannelVideoEncode(t_StreamIndex.ts_to_android(streamIndex), t_AlphaLayout.ts_to_android(alphaLayout)));
            };
            var i = function () {
                return Number(_this._instance.enableAlphaChannelVideoEncode(t_StreamIndex.ts_to_ios(streamIndex), t_AlphaLayout.ts_to_ios(alphaLayout)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.58
         * @detail api
         * @region Video Management
         * @brief Disables the Alpha channel encoding feature for externally captured video frames.
         * @param streamIndex The type of video stream for which this feature should be disabled. Currently, only supports setting to StreamIndex.STREAM_INDEX_MAIN, i.e., the main stream.
         * @return Method call result: <br>
         *         - 0: Success;
         *         - !0: Failure.
         * @note This API must be called after stopping the publish of the video stream.
         *
         */
        RTCVideo_1.prototype.disableAlphaChannelVideoEncode = function (streamIndex) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.disableAlphaChannelVideoEncode(t_StreamIndex.ts_to_android(streamIndex)));
            };
            var i = function () {
                return Number(_this._instance.disableAlphaChannelVideoEncode(t_StreamIndex.ts_to_ios(streamIndex)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Custom Audio Capture and Rendering
         * @author gongzhengduo
         * @brief  Switch the audio capture type.
         * @param type Audio input source type. See {@link AudioSourceType AudioSourceType} <br>
         *            Use internal audio capture by default. The audio capture type and the audio render type may be different from each other.
         * @return   Method call result: <br>
         *         - >0: Success.
         *         - -1: Failure.
         * @note
         *       - You can call this API before or after joining the room.
         *       - If you call this API to switch from internal audio capture to custom capture, the internal audio capture is automatically disabled. You must call {@link pushExternalAudioFrame pushExternalAudioFrame} to push custom captured audio data to RTC SDK for transmission.
         *       - If you call this API to switch from custom capture to internal capture, you must then call {@link startAudioCapture startAudioCapture} to enable internal capture.
         *
         */
        RTCVideo_1.prototype.setAudioSourceType = function (type) {
            var _this = this;
            var a = function () { return Number(_this._instance.setAudioSourceType(t_AudioSourceType.ts_to_android(type))); };
            var i = function () { return Number(_this._instance.setAudioSourceType(t_AudioSourceType.ts_to_ios(type))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Custom Audio Capture and Rendering
         * @author gongzhengduo
         * @brief  Switch the audio render type.
         * @param type Audio output source type. See {@link AudioRenderType AudioRenderType}. <br>
         *             Use internal audio render by default. The audio capture type and the audio render type may be different from each other.
         * @return   Method call result: <br>
         *         - >0: Success.
         *         - -1: Failure.
         * @note
         *       - You can call this API before or after joining the room.
         *       - After calling this API to enable custom audio rendering, call {@link pullExternalAudioFrame pullExternalAudioFrame} for audio data.
         *
         */
        RTCVideo_1.prototype.setAudioRenderType = function (type) {
            var _this = this;
            var a = function () { return Number(_this._instance.setAudioRenderType(t_AudioRenderType.ts_to_android(type))); };
            var i = function () { return Number(_this._instance.setAudioRenderType(t_AudioRenderType.ts_to_ios(type))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Custom audio acquisition rendering
         * @author gongzhengduo
         * @brief Pulls audio data for external playback. <br>
         *        After calling this method, the SDK will actively fetch the audio data to play, including the decoded and mixed audio data from the remote source, for external playback.
         * @param audioFrame Audio data frame. See {@link AudioFrame AudioFrame}
         * @return  Method call result <br>
         *           - 0: Setup succeeded
         *           - < 0: Setup failed
         * @note
         *        - Before pulling external audio data, {@link setAudioRenderType setAudioRenderType} must be called Enable custom audio rendering.
         *        - You should pull audio data every 10 milliseconds since the duration of a RTC SDK audio frame is 10 milliseconds. Samples x call frequency = audioFrame's sample rate. Assume that the sampling rate is set to 48000, call this API every 10 ms, so that 480 sampling points should be pulled each time.
         *        - The audio sampling format is S16. The data format in the audio buffer is PCM data, and its capacity size is audioFrame.samples × audioFrame.channel × 2.
         *
         */
        RTCVideo_1.prototype.pullExternalAudioFrame = function (audioFrame) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.pullExternalAudioFrame(unpackObject(audioFrame)));
            };
            var i = function () {
                return Number(_this._instance.pullExternalAudioFrame(unpackObject(audioFrame)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Room Management
         * @author shenpengliang
         * @brief Create a room instance. <br>
         *        This API only returns a room instance. You still need to call {@link joinRoom joinRoom} to actually create/join the room. <br>
         *        Each call of this API creates one {@link RTCRoom RTCRoom} instance. Call this API as many times as the number of rooms you need, and then call {@link joinRoom joinRoom} of each RTCRoom instance to join multiple rooms at the same time. <br>
         *        In multi-room mode, a user can subscribe to media streams in the joined rooms at the same time.
         * @param roomId The string matches the regular expression: `[a-zA-Z0-9_\@\\-\\.]{1,128}`.
         * @return {@link RTCRoom RTCRoom} instance.
         * @note
         *       - If the room that you wish to join already exists, you still need to call this API first to create the RTCRoom instance, and then call {@link joinRoom joinRoom}.
         *       - Do not create multiple rooms with the same roomId, otherwise the newly created room instance will replace the old one.
         *       - To forward streams to the other rooms, call {@link startForwardStreamToRooms startForwardStreamToRooms} instead of enabling Multi-room mode.
         *
         */
        RTCVideo_1.prototype.createRTCRoom = function (roomId) {
            var _this = this;
            var a = function () { return packObject(_this._instance.createRTCRoom(roomId), RTCRoom); };
            var i = function () { return packObject(_this._instance.createRTCRoom(roomId), RTCRoom); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio & Video Fallback
         * @author panjian.fishing
         * @brief Sets the fallback option for published audio & video streams. <br>
         *        You can call this API to set whether to automatically lower the resolution you set of the published streams under limited network conditions.
         * @param option Fallback option, see {@link PublishFallbackOption PublishFallbackOption}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - This API only works after you call {@link enableSimulcastMode enableSimulcastMode} to enable the mode of publishing multiple streams.
         *         - You must call this API before entering the room.
         *         - After calling this method, if there is a performance degradation or recovery due to poor performance or network conditions, the local end will receive early warnings through the {@link onPerformanceAlarms onPerformanceAlarms} callback to adjust the capture device.
         *         - After you allow video stream to fallback, your stream subscribers will receive {@link onSimulcastSubscribeFallback onSimulcastSubscribeFallback} when the resolution of your published stream are lowered or restored.
         *         - You can alternatively set fallback options with distrubutions from server side, which is of higher priority.
         *
         */
        RTCVideo_1.prototype.setPublishFallbackOption = function (option) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setPublishFallbackOption(t_PublishFallbackOption.ts_to_android(option)));
            };
            var i = function () {
                return Number(_this._instance.setPublishFallbackOption(t_PublishFallbackOption.ts_to_ios(option)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region  audio & video fallback
         * @author panjian.fishing
         * @brief  Set user priority.
         * @param roomid Room ID
         * @param uid <br>
         *         The ID of the remote user.
         * @param priority <br>
         *         Priority for remote users. See enumeration type {@link RemoteUserPriority RemoteUserPriority}.
         * @return
         *         - 0: Success.
         *         - < 0: Failed.
         * @note
         *         - This method is used with {@link setSubscribeFallbackOption setSubscribeFallbackOption}.
         *         - If the subscription flow fallback option is turned on, weak connections or insufficient performance will give priority to ensuring the quality of the flow received by high-priority users.
         *         - This method can be used before and after entering the room, and the priority of the remote user can be modified.
         *
         */
        RTCVideo_1.prototype.setRemoteUserPriority = function (roomid, uid, priority) {
            throw new Error('not implement');
        };
        /** {en}
         * @detail api
         * @region Message
         * @author wangzhanqiang
         * @brief \<span id="RTCVideo-sendseimessage-2">\</span>Sends SEI data. <br>
         *        In a video call scenario, SEI is sent with the video frame, while in a voice call scenario, SDK will automatically publish a black frame with a resolution of 16 × 16 pixels to carry SEI data.
         * @param streamIndex Specifys the type of media stream that carries SEI data. See [StreamIndex](70083#streamindex-2). <br>
         *        In a voice call, you should set this parameter to `STREAM_INDEX_MAIN`, otherwise the SEI data is discarded and cannot be sent to the remote user.
         * @param message SEI data. No more than 4 KB SEI data per frame is recommended.
         * @param repeatCount Number of times a message is sent repeatedly. The value range is [0, max{29, \%{video frame rate}-1}]. Recommended range: [2,4]. <br>
         *                    After calling this API, the SEI data will be added to a consecutive `\%{repeatCount}+1` number of video frames starting from the current frame.
         * @param mode SEI sending mode. See {@link SEICountPerFrame SEICountPerFrame}.
         * @return
         *         - >= 0: The number of SEIs to be added to the video frame
         *         - < 0: Failure
         * @note
         *         - We recommend the number of SEI messages per second should not exceed the current video frame rate. In a voice call, the blank-frame rate is 15 fps.
         *         - In a voice call, this API can be called to send SEI data only in internal capture mode.
         *         - In a video call, the custom captured video frame can also be used for sending SEI data if the original video frame contains no SEI data, otherwise calling this method will not take effect.
         *         - Each video frame carrys only the SEI data received within 2s before and after. In a voice call scenario, if no SEI data is sent within 1min after calling this API, SDK will automatically cancel publishing black frames.
         *         - After the message is sent successfully, the remote user who subscribed your video stream will receive {@link onSEIMessageReceived onSEIMessageReceived}.
         *         - When you switch from a voice call to a video call, SEI data will automatically start to be sent with normally captured video frames instead of black frames.
         *
         */
        RTCVideo_1.prototype.sendSEIMessage = function (streamIndex, message, repeatCount, mode) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.sendSEIMessage(t_StreamIndex.ts_to_android(streamIndex), message, repeatCount, t_SEICountPerFrame.ts_to_android(mode)));
            };
            var i = function () {
                return Number(_this._instance.sendSEIMessage(t_StreamIndex.ts_to_ios(streamIndex), message, repeatCount, t_SEICountPerFrame.ts_to_ios(mode)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Engine management
         * @author wangzhanqiang
         * @brief Sets the business ID <br>
         *        You can use businessId to distinguish different business scenarios. You can customize your businessId to serve as a sub AppId, which can share and refine the function of the AppId, but it does not need authentication.
         * @param businessId <br>
         *        Your customized businessId <br>
         *        BusinessId is a tag, and you can customize its granularity.
         * @return
         *         - 0: Success
         *         - < 0: Failure
         *         - -6001: The user is already in the room.
         *         - -6002: The input is invalid. Legal characters include all lowercase letters, uppercase letters, numbers, and four other symbols, including '.', '-','_', and '\@'.
         * @note
         *         - You must call this API before entering the room, otherwise it will be invalid.
         * @order 25
         *
         */
        RTCVideo_1.prototype.setBusinessId = function (businessId) {
            var _this = this;
            var a = function () { return Number(_this._instance.setBusinessId(businessId)); };
            var i = function () { return Number(_this._instance.setBusinessId(businessId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio & Video Processing
         * @author zhushufan.ref
         * @brief Gets video effect interfaces.
         * @return Video effect interfaces. See {@link IVideoEffect IVideoEffect}.
         *
         */
        RTCVideo_1.prototype.getVideoEffectInterface = function () {
            var _this = this;
            var a = function () { return packObject(_this._instance.getVideoEffectInterface(), IVideoEffect); };
            var i = function () { return packObject(_this._instance.getVideoEffectInterface(), IVideoEffect); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio & Video Processing
         * @author wangjunlin.3182
         * @brief Enables/Disables basic beauty effects.
         * @param enable Whether to enable basic beauty effects. <br>
         *        - true: Enables basic beauty effects.
         *        - false: (Default) Disables basic beauty effects.
         * @return
         *        - 0: Success.
         *        - –1000: The Effect SDK is not integrated.
         *        - –1001: This API is not available for your current RTC SDK.
         *        - –1002: This API is not available for your current Effect SDK. You can upgrade your Effect SDK to v4.4.2+.
         *        - –1003: Contact our technical support team for further instructions.
         *        - –1004: Downloading related resources. The beauty effects will take effect after downloading.
         *        - <0: Failure. Effect SDK internal error. For specific error code, see [Error Code Table](https://docs.byteplus.com/effects/docs/error-code-table).
         * @note
         *        - You cannot use the basic beauty effects and the advanced effect features at the same time. See [how to use advanced effect features](https://docs.byteplus.com/byteplus-rtc/docs/114717) for more information.
         *        - You need to integrate Effect SDK before calling this API. Effect SDK v4.4.2+ is recommended.
         *        - Call {@link setBeautyIntensity setBeautyIntensity} to set the beauty effect intensity. If you do not set the intensity before calling this API, the default intensity will be enabled. The default values for the intensity of each beauty mode are as follows: 0.7 for brightning, 0.8 for smoothing, 0.5 for sharpening, and 0.7 for clarity.
         *        - This API is not applicable to screen capturing.
         *
         */
        RTCVideo_1.prototype.enableEffectBeauty = function (enable) {
            var _this = this;
            var a = function () { return Number(_this._instance.enableEffectBeauty(enable)); };
            var i = function () { return Number(_this._instance.enableEffectBeauty(enable)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio & Video Processing
         * @author wangjunlin.3182
         * @brief Sets the beauty effect intensity.
         * @param beautyMode Basic beauty effect. See {@link EffectBeautyMode EffectBeautyMode}.
         * @param intensity Beauty effect intensity in range of [0,1]. When you set it to 0, the beauty effect will be turned off. <br>
         *                  The default values for the intensity of each beauty mode are as follows: 0.7 for brightning, 0.8 for smoothing, 0.5 for sharpening, and 0.7 for clarity.
         * @return
         *        - 0: Success.
         *        - –1000: The Effect SDK is not integrated.
         *        - –1001: This API is not available for your current RTC SDK.
         *        - <0: Failure. Effect SDK internal error. For specific error code, see [error codes](https://docs.byteplus.com/effects/docs/error-code-table).
         * @note
         *        - If you call this API before calling {@link enableEffectBeauty enableEffectBeauty}, the default settings of beauty effect intensity will adjust accordingly.
         *        - If you destroy the engine, the beauty effect settings will be invalid.
         *
         */
        RTCVideo_1.prototype.setBeautyIntensity = function (beautyMode, intensity) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setBeautyIntensity(t_EffectBeautyMode.ts_to_android(beautyMode), intensity));
            };
            var i = function () {
                return Number(_this._instance.setBeautyIntensity(t_EffectBeautyMode.ts_to_ios(beautyMode), intensity));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio & Video Processing
         * @author wangjunlin.3182
         * @brief Sets the orientation of the video frame before custom video processing and encoding. The default value is `Adaptive`. <br>
         *        You should set the orientation to `Portrait` when using video effects or custom processing. <br>
         *        You should set the orientation to `Portrait` or `Landscape` when pushing a single stream to the CDN.
         * @param orientation Orientation of the video frame. See {@link VideoOrientation VideoOrientation}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - The orientation setting is only applicable to internal captured video sources. For custom captured video sources, setting the video frame orientation may result in errors, such as swapping width and height. Screen sources do not support video frame orientation setting.
         *        - We recommend setting the orientation before joining room. The updates of encoding configurations and the orientation are asynchronous, therefore can cause a brief malfunction in preview if you change the orientation after joining room.
         *
         */
        RTCVideo_1.prototype.setVideoOrientation = function (orientation) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setVideoOrientation(t_VideoOrientation.ts_to_android(orientation)));
            };
            var i = function () {
                return Number(_this._instance.setVideoOrientation(t_VideoOrientation.ts_to_ios(orientation)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region  engine management
         * @author panjian.fishing
         * @brief  Setting runtime parameters
         * @param params Preserved parameters.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note Call this API before {@link joinRoom joinRoom} and {@link startAudioCapture startAudioCapture}.
         * @order 25
         *
         */
        RTCVideo_1.prototype.setRuntimeParameters = function (params) {
            var _this = this;
            var a = function () { return Number(_this._instance.setRuntimeParameters(params)); };
            var i = function () { return Number(_this._instance.setRuntimeParameters(params)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Get [IRTCVideo](https://docs.byteplus.com/byteplus-rtc/docs/70095#irtcvideo) in C++ layer.
         * @return
         *         - >0：Success. Return the address of `IRTCVideo` in C++ layer.
         *         - -1：Failure.
         * @note In some scenarios, getting and working with `IRTCVideo` in C++ layer has much higher execution efficiency than through the Java encapsulation layer. Typical scenarios include: custom processing of video/audio frames, encryption of audio and video calls, etc.
         *
         */
        RTCVideo_1.prototype.getNativeHandle = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.getNativeHandle()); };
            var i = function () { return Number(_this._instance.getNativeHandle()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @hidden currently not available
         * @detail api
         * @region speech recognition service
         * @author luomingkang
         * @brief Turn off speech recognition service
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         *
         */
        RTCVideo_1.prototype.stopASR = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopASR()); };
            var i = function () { return Number(_this._instance.stopASR()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Local recording
         * @author wangzhanqiang
         * @brief This method records the audio & video data during the call to a local file.
         * @param type Stream property, specifying whether to record mainstream or screen streams. See [StreamIndex](70083#streamindex-2)
         * @param config Local recording parameter configuration. See {@link RecordingConfig RecordingConfig}
         * @param recordingType Locally recorded media type, see {@link RecordingType RecordingType}
         * @return 0: Normal <br>
         *        -1: Parameter setting exception <br>
         *        -2: The current version of the SDK does not support this feature, please contact technical support staff
         * @note
         *         - Tune When you use this method, you get an {@link onRecordingStateUpdate onRecordingStateUpdate} callback.
         *         - If the recording is normal, the system will notify the recording progress through the {@link onRecordingProgressUpdate onRecordingProgressUpdate} callback every second.
         *
         */
        RTCVideo_1.prototype.startFileRecording = function (type, config, recordingType) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.startFileRecording(t_StreamIndex.ts_to_android(type), unpackObject(config), t_RecordingType.ts_to_android(recordingType)));
            };
            var i = function () {
                return Number(_this._instance.startFileRecording(t_StreamIndex.ts_to_ios(type), unpackObject(config), t_RecordingType.ts_to_ios(recordingType)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Local recording
         * @author wangzhanqiang
         * @brief Stop local recording
         * @param type Stream property, specify to stop mainstream or screen stream recording. See [StreamIndex](70083#streamindex-2)
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - Call {@link startFileRecording startFileRecording} After starting local recording, you must call this method to stop recording.
         *         - After calling this method, you will receive an {@link onRecordingStateUpdate onRecordingStateUpdate} callback prompting you to record the result.
         *
         */
        RTCVideo_1.prototype.stopFileRecording = function (type) {
            var _this = this;
            var a = function () { return Number(_this._instance.stopFileRecording(t_StreamIndex.ts_to_android(type))); };
            var i = function () { return Number(_this._instance.stopFileRecording(t_StreamIndex.ts_to_ios(type))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author huangshouqin
         * @brief Starts recording audio communication, and generate the local file. <br>
         *        If you call this API before or after joining the room without internal audio capture, then the recording task can still begin but the data will not be recorded in the local files. Only when you call {@link startAudioCapture startAudioCapture} to enable internal audio capture, the data will be recorded in the local files.
         * @param config See {@link AudioRecordingConfig AudioRecordingConfig}.
         * @return
         *        - 0: Success
         *        - -2: Invalid parameters
         *        - -3: Not valid in this SDK. Please contact the technical support.
         * @note
         *        - All audio effects are valid in the file. Mixed audio file is not included in the file.
         *        - Call {@link stopAudioRecording stopAudioRecording} to stop recording.
         *        - You can call this API before and after joining the room. If this API is called before you join the room, you need to call {@link stopAudioRecording stopAudioRecording} to stop recording. If this API is called after you join the room, the recording task ends automatically. If you join multiple rooms, audio from all rooms are recorded in one file.
         *        - After calling the API, you'll receive {@link onAudioRecordingStateUpdate onAudioRecordingStateUpdate}.
         *
         */
        RTCVideo_1.prototype.startAudioRecording = function (config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.startAudioRecording(unpackObject(config)));
            };
            var i = function () {
                return Number(_this._instance.startAudioRecording(unpackObject(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author huangshouqin
         * @brief Stop audio recording.
         * @return
         *         - 0: Success
         *         - <0: Failure
         * @note Call {@link startAudioRecording startAudioRecording} to start the recording task.
         *
         */
        RTCVideo_1.prototype.stopAudioRecording = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopAudioRecording()); };
            var i = function () { return Number(_this._instance.stopAudioRecording()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.53
         * @detail api
         * @brief Create an instance for audio effect player.
         * @return See {@link IAudioEffectPlayer IAudioEffectPlayer}.
         *
         */
        RTCVideo_1.prototype.getAudioEffectPlayer = function () {
            var _this = this;
            var a = function () { return packObject(_this._instance.getAudioEffectPlayer(), IAudioEffectPlayer); };
            var i = function () { return packObject(_this._instance.getAudioEffectPlayer(), IAudioEffectPlayer); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @valid since 3.53
         * @brief Create a media player instance.
         * @param playerId Media player id. The range is `[0, 3]`. You can create up to 4 instances at the same time. If it exceeds the range, nullptr will be returned.
         * @return Media player instance. See {@link IMediaPlayer IMediaPlayer}.
         *
         */
        RTCVideo_1.prototype.getMediaPlayer = function (playerId) {
            var _this = this;
            var a = function () { return packObject(_this._instance.getMediaPlayer(playerId), IMediaPlayer); };
            var i = function () { return packObject(_this._instance.getMediaPlayer(playerId), IMediaPlayer); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Screen Sharing
         * @author liyi.000
         * @brief Sets the screen audio source type. (internal capture/custom capture)
         * @param sourceType Screen audio source type. See {@link AudioSourceType AudioSourceType}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *       - The default screen audio source type is RTC SDK internal capture.
         *       - You should call this API before calling {@link publishScreen publishScreen}. Otherwise, you will receive {@link onWarning onWarning} with 'WARNING_CODE_SET_SCREEN_AUDIO_SOURCE_TYPE_FAILED'.
         *       - When using internal capture, you need to call {@link startScreenCapture startScreenCapture} to start capturing. After that, as you switch to an external source by calling this API, the internal capture will stop.
         *       - When using custom capture, you need to call {@link pushScreenAudioFrame pushScreenAudioFrame} to push the audio stream to the RTC SDK.
         *       - Whether you use internal capture or custom capture, you must call {@link publishScreen publishScreen} to publish the captured screen audio stream.
         *
         */
        RTCVideo_1.prototype.setScreenAudioSourceType = function (sourceType) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setScreenAudioSourceType(t_AudioSourceType.ts_to_android(sourceType)));
            };
            var i = function () {
                return Number(_this._instance.setScreenAudioSourceType(t_AudioSourceType.ts_to_ios(sourceType)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Screen sharing
         * @author liyi.000
         * @brief Set the mixing mode of the screen audio stream and the audio stream collected by the microphone during screen sharing
         * @param index Mixing mode. See [StreamIndex](70083#streamindex-2) <br>
         *         - 'STREAM_INDEX_MAIN': Mixing the screen audio stream and the audio stream collected by the microphone
         *         - 'STREAM_INDEX_SCREEN': By default, it divides the screen audio stream and the audio stream collected by the microphone into two audio streams
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note You should call this method before {@link publishScreen publishScreen}. Otherwise, you will receive an error from {@link onWarning onWarning}: 'WARNING_CODE_SET_SCREEN_STREAM_INDEX_FAILED
         *
         */
        RTCVideo_1.prototype.setScreenAudioStreamIndex = function (index) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setScreenAudioStreamIndex(t_StreamIndex.ts_to_android(index)));
            };
            var i = function () {
                return Number(_this._instance.setScreenAudioStreamIndex(t_StreamIndex.ts_to_ios(index)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Screen Sharing
         * @author wangqianqian.1104
         * @brief The RTC SDK start capturing the screen audio and/or video stream internally.
         * @param type Media type. See {@link ScreenMediaType ScreenMediaType}
         * @param mediaProjectionResultData The Intent obtained after applying for screen sharing permission from the Android device. See [getMediaProjection](https://developer.android.com/reference/android/media/projection/MediaProjectionManager#getMediaProjection (int,\% 20android.content. Intent)).
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - The call of this API takes effects only when you are using RTC SDK to record screen. You will get a warning by  {@link onVideoDeviceWarning onVideoDeviceWarning} or {@link onAudioDeviceWarning onAudioDeviceWarning} after calling this API when the source is set to an external recorder.
         *         - After capturing, you need to call {@link publishScreen publishScreen} to push to the remote end.
         *         - You will receive {@link onVideoDeviceStateChanged onVideoDeviceStateChanged} and {@link onAudioDeviceStateChanged onAudioDeviceStateChanged} when the capturing is started.
         *         - To stop capturing, call {@link stopScreenCapture stopScreenCapture}.
         *
         */
        RTCVideo_1.prototype.startScreenCapture = function (type, mediaProjectionResultData) {
            throw new Error('not implement');
        };
        /** {en}
         * @detail api
         * @region Screen Sharing
         * @author wangqianqian.1104
         * @brief Updates the media type of the internal screen capture.
         * @param type Media type. See {@link ScreenMediaType ScreenMediaType}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note Call this API after calling {@link startScreenCapture startScreenCapture}.
         *
         */
        RTCVideo_1.prototype.updateScreenCapture = function (type) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.updateScreenCapture(t_ScreenMediaType.ts_to_android(type)));
            };
            var i = function () {
                return Number(_this._instance.updateScreenCapture(t_ScreenMediaType.ts_to_ios(type)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        RTCVideo_1.prototype.stopScreenCapture = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopScreenCapture()); };
            var i = function () { return Number(_this._instance.stopScreenCapture()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video management
         * @author wangzhanqiang
         * @brief Register custom coded frame push event callback
         * @param handler Custom coded frame callback class. See {@link IExternalVideoEncoderEventHandler IExternalVideoEncoderEventHandler}
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - This method needs to be called before entering the room.
         *        - The engine needs to be unregistered before it is destroyed. Call this method to set the parameter to "null".
         *
         */
        RTCVideo_1.prototype.setExternalVideoEncoderEventHandler = function (handler) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setExternalVideoEncoderEventHandler(packObject(handler, android_IExternalVideoEncoderEventHandler)));
            };
            var i = function () {
                return Number(_this._instance.setExternalVideoEncoderEventHandler(packObject(handler, ios_IExternalVideoEncoderEventHandler)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author wangzhanqiang
         * @brief Before subscribing to the remote video stream, set the remote video data decoding method
         * @param key The remote stream information specifies which video stream to decode. See {@link RemoteStreamKey RemoteStreamKey}.
         * @param config  Video decoding method. See {@link VideoDecoderConfig VideoDecoderConfig}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - When you want to custom decode a remote stream, you need to call {@link registerRemoteEncodedVideoFrameObserver registerRemoteEncodedVideoFrameObserver} to register the remote video stream monitor, and then call the interface to set the decoding method to custom decoding. The monitored video data will be called back through {@link onRemoteEncodedVideoFrame onRemoteEncodedVideoFrame}.
         *        - Since version 3.56, for automatic subscription, you can set the `RoomId` and `UserId` of `key` as `nullptr`. In this case, the decoding settings set by calling the API applies to all remote main streams or screen sharing streams based on the `StreamIndex` value of `key`.
         *
         */
        RTCVideo_1.prototype.setVideoDecoderConfig = function (key, config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setVideoDecoderConfig(unpackObject(key), t_VideoDecoderConfig.ts_to_android(config)));
            };
            var i = function () {
                return Number(_this._instance.setVideoDecoderConfig(unpackObject(key), t_VideoDecoderConfig.ts_to_ios(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author liuyangyang
         * @brief After subscribing to the remote video stream, request the keyframe
         * @param streamKey Remote stream information to the remote. See {@link RemoteStreamKey RemoteStreamKey}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - This method is only suitable for manual subscription mode and is used after successful subscription to the remote flow.
         *         - This method is suitable for calling {@link setVideoDecoderConfig setVideoDecoderConfig} to turn on the custom decoding function, and the custom decoding fails
         *
         */
        RTCVideo_1.prototype.requestRemoteVideoKeyFrame = function (streamKey) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.requestRemoteVideoKeyFrame(unpackObject(streamKey)));
            };
            var i = function () {
                return Number(_this._instance.requestRemoteVideoKeyFrame(unpackObject(streamKey)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio management
         * @author majun.lvhiei
         * @brief Enable/Disable in-ear monitoring.
         * @param mode Whether to enable in-ear monitoring. See {@link EarMonitorMode EarMonitorMode}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - In-ear monitoring is effective for audios captured by the RTC SDK.
         *         - We recommend that you use wired earbuds/headphones for a low-latency experience.
         *         - The RTC SDK supports both the hardware-level in-ear monitoring and the SDK-level in-ear monitoring. Most hardware-level in-ear monitors enjoy lower latency and better audio quality. If your App is in the special list of the smartphone manufacturer， RTC SDK uses hardware-level ear monitoring by default.
         *
         */
        RTCVideo_1.prototype.setEarMonitorMode = function (mode) {
            var _this = this;
            var a = function () { return Number(_this._instance.setEarMonitorMode(t_EarMonitorMode.ts_to_android(mode))); };
            var i = function () { return Number(_this._instance.setEarMonitorMode(t_EarMonitorMode.ts_to_ios(mode))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio management
         * @author majun.lvhiei
         * @brief Set the monitoring volume.
         * @param volume  The monitoring volume with the adjustment range between 0\% and 100\%.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - Call {@link setEarMonitorMode setEarMonitorMode} before setting the volume.
         *
         */
        RTCVideo_1.prototype.setEarMonitorVolume = function (volume) {
            var _this = this;
            var a = function () { return Number(_this._instance.setEarMonitorVolume(volume)); };
            var i = function () { return Number(_this._instance.setEarMonitorVolume(volume)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio Management
         * @author wangjunzheng
         * @brief Enable audio information prompts. After that, you will receive {@link onLocalAudioPropertiesReport onLocalAudioPropertiesReport}, {@link onRemoteAudioPropertiesReport onRemoteAudioPropertiesReport}, and {@link onActiveSpeaker onActiveSpeaker}.
         * @param config See {@link AudioPropertiesConfig AudioPropertiesConfig}
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         *
         */
        RTCVideo_1.prototype.enableAudioPropertiesReport = function (config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.enableAudioPropertiesReport(unpackObject(config)));
            };
            var i = function () {
                return Number(_this._instance.enableAudioPropertiesReport(unpackObject(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio management
         * @author wangjunzheng
         * @brief Send audio stream synchronization information. The message is sent to the remote end through the audio stream and synchronized with the audio stream. After the interface is successfully called, the remote user will receive a {@link onStreamSyncInfoReceived onStreamSyncInfoReceived} callback.
         * @param data Message content.
         * @param config Configuration related to audio stream synchronization information. See {@link StreamSycnInfoConfig StreamSycnInfoConfig}.
         * @return
         *         - > = 0: Message sent successfully. Returns the number of successful sends.
         *         - -1: Message sending failed. Message length greater than 16 bytes.
         *         - -2: Message sending failed. The content of the incoming message is empty.
         *         - -3: Message sending failed. This screen stream was not published when the message was synchronized through the screen stream.
         *         - -4: Message sending failed. This audio stream is not yet published when you synchronize messages with an audio stream captured by a microphone or custom device, as described in {@link ErrorCode ErrorCode}.
         * @note
         * - Regarding the frequency, we recommend no more than 50 calls per second.
         * - When using `CHANNEL_PROFILE_INTERACTIVE_PODCAST` as room profile, the data will be delivered. For other coom profiles, the data may be lost when the local user is muted.
         *
         */
        RTCVideo_1.prototype.sendStreamSyncInfo = function (data, config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.sendStreamSyncInfo(data, unpackObject(config)));
            };
            var i = function () {
                return Number(_this._instance.sendStreamSyncInfo(data, unpackObject(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region  video management
         * @author zhangzhenyu.samuel
         * @brief  Detect the currently used camera (front/postcondition), whether flash is supported.
         * @return
         *         - true: Support
         *         - false: Not supported
         * @note  You must have called {@link startVideoCapture startVideoCapture} for video capture using the SDK internal capture module to detect flash capability.
         *
         */
        RTCVideo_1.prototype.isCameraTorchSupported = function () {
            var _this = this;
            var a = function () { return _this._instance.isCameraTorchSupported(); };
            var i = function () { return _this._instance.isCameraTorchSupported(); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author zhangzhenyu.samuel
         * @brief Detect whether the currently used camera (front/postcondition) supports zoom (digital/optical zoom).
         * @return
         *         - true: Support
         *         - false: Not supported
         * @note  Camera zoom capability can only be detected if {@link startVideoCapture startVideoCapture} is used for video capture using the SDK internal capture module.
         *
         */
        RTCVideo_1.prototype.isCameraZoomSupported = function () {
            var _this = this;
            var a = function () { return _this._instance.isCameraZoomSupported(); };
            var i = function () { return _this._instance.isCameraZoomSupported(); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region  video management
         * @author zhangzhenyu.samuel
         * @brief Change the optical zoom magnification.
         * @param zoom  Zoom magnification of the currently used camera (front/postcondition). The value range is [1, < Maximum Zoom Multiplier >]. <br>
         *              The maximum zoom factor can be obtained by calling {@link getCameraZoomMaxRatio getCameraZoomMaxRatio}.
         * @return
         *         - 0: Success.
         *         - < 0: Failed.
         * @note
         *         - The camera zoom factor can only be set when {@link startVideoCapture startVideoCapture} is called for video capture using the SDK internal capture module.
         *         - The setting result fails after calling {@link stopVideoCapture stopVideoCapture} to turn off internal collection.
         *         - Call {@link setVideoDigitalZoomConfig setVideoDigitalZoomConfig} to set digital zoom. Call {@link setVideoDigitalZoomControl setVideoDigitalZoomControl} to perform digital zoom.
         *
         */
        RTCVideo_1.prototype.setCameraZoomRatio = function (zoom) {
            var _this = this;
            var a = function () { return Number(_this._instance.setCameraZoomRatio(zoom)); };
            var i = function () { return Number(_this._instance.setCameraZoomRatio(zoom)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video management
         * @author zhangzhenyu.samuel
         * @brief Get the maximum zoom factor of the currently used camera (front/postcondition)
         * @return Maximum zoom factor
         * @note You must have called {@link startVideoCapture startVideoCapture} using the SDK internal capture module for video capture, the maximum zoom factor of the camera can be detected.
         *
         */
        RTCVideo_1.prototype.getCameraZoomMaxRatio = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.getCameraZoomMaxRatio()); };
            var i = function () { return Number(_this._instance.getCameraZoomMaxRatio()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region  video management
         * @author zhangzhenyu.samuel
         * @brief  Turn on/off the flash state of the currently used camera (front/postcondition)
         * @param torchState  Flash state. Refer to {@link TorchState TorchState}
         * @return
         *         - 0: Success.
         *         - < 0: Failed.
         * @note
         *         - The flash can only be set if you have called {@link startVideoCapture startVideoCapture} for video capture using the SDK internal capture module.
         *         - The setting result fails after calling {@link stopVideoCapture stopVideoCapture} to turn off internal collection.
         *
         */
        RTCVideo_1.prototype.setCameraTorch = function (torchState) {
            var _this = this;
            var a = function () { return Number(_this._instance.setCameraTorch(t_TorchState.ts_to_android(torchState))); };
            var i = function () { return Number(_this._instance.setCameraTorch(t_TorchState.ts_to_ios(torchState))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author zhangzhenyu.samuel
         * @brief Checks if manual focus is available for the currently used camera.
         * @return
         *        - true: Available.
         *        - false: Unavailable.
         * @note You must call {@link startVideoCapture startVideoCapture} to start SDK internal video capturing before calling this API.
         *
         */
        RTCVideo_1.prototype.isCameraFocusPositionSupported = function () {
            var _this = this;
            var a = function () { return _this._instance.isCameraFocusPositionSupported(); };
            var i = function () { return _this._instance.isCameraFocusPositionSupported(); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author zhangzhenyu.samuel
         * @brief Sets the manual focus position for the currently used camera.
         * @param x The x-coordinate of the focus point in range of [0, 1]. The upper-left corner of the canvas is set as the origin.
         * @param y The y-coordinate of the focus point in range of [0, 1]. The upper-left corner of the canvas is set as the origin.
         * @return
         *        - 0: Success.
         *        - < 0: Failure.
         * @note
         *        - You must call {@link startVideoCapture startVideoCapture} to start SDK internal video capturing, and use SDK internal rendering before calling this API.
         *        - The focus point setting will be canceled when you move the device.
         *        - The camera focus point setting will be invalid after calling {@link stopVideoCapture stopVideoCapture} to stop internal capturing.
         *
         */
        RTCVideo_1.prototype.setCameraFocusPosition = function (x, y) {
            var _this = this;
            var a = function () { return Number(_this._instance.setCameraFocusPosition(x, y)); };
            var i = function () { return Number(_this._instance.setCameraFocusPosition(x)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author zhangzhenyu.samuel
         * @brief Checks if manual exposure setting is available for the currently used camera.
         * @return
         *        - true: Available.
         *        - false: Unavailable.
         * @note You must call {@link startVideoCapture startVideoCapture} to start SDK internal video capturing before calling this API.
         *
         */
        RTCVideo_1.prototype.isCameraExposurePositionSupported = function () {
            var _this = this;
            var a = function () { return _this._instance.isCameraExposurePositionSupported(); };
            var i = function () { return _this._instance.isCameraExposurePositionSupported(); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author zhangzhenyu.samuel
         * @brief Sets the manual exposure position for the currently used camera.
         * @param x The x-coordinate of the exposure point in range of [0, 1]. The upper-left corner of the canvas is set as the origin.
         * @param y The y-coordinate of the focus point in range of [0, 1]. The upper-left corner of the canvas is set as the origin.
         * @return
         *        - 0: Success.
         *        - < 0: Failure.
         * @note
         *        - You must call {@link startVideoCapture startVideoCapture} to start SDK internal video capturing, and use SDK internal rendering before calling this API.
         *        - The exposure point setting will be canceled when you move the device.
         *        - The camera exposure point setting will be invalid after calling {@link stopVideoCapture stopVideoCapture} to stop internal capturing.
         *
         */
        RTCVideo_1.prototype.setCameraExposurePosition = function (x, y) {
            var _this = this;
            var a = function () { return Number(_this._instance.setCameraExposurePosition(x, y)); };
            var i = function () { return Number(_this._instance.setCameraExposurePosition(x)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author zhangzhenyu.samuel
         * @brief Sets the exposure compensation for the currently used camera.
         * @param val Exposure compensation in range of [-1, 1]. Default to 0, which means no exposure compensation.
         * @return
         *        - 0: Success.
         *        - < 0: Failure.
         * @note
         *        - You must call {@link startVideoCapture startVideoCapture} to start SDK internal video capturing, and use SDK internal rendering before calling this API.
         *        - The camera exposure compensation setting will be invalid after calling {@link stopVideoCapture stopVideoCapture} to stop internal capturing.
         *
         */
        RTCVideo_1.prototype.setCameraExposureCompensation = function (val) {
            var _this = this;
            var a = function () { return Number(_this._instance.setCameraExposureCompensation(val)); };
            var i = function () { return Number(_this._instance.setCameraExposureCompensation(val)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @valid since 353
         * @author yinkaisheng
         * @brief Enable or disable face auto exposure mode during internal video capture. This mode fixes the problem that the face is too dark under strong backlight; but it will also cause the problem of too bright/too dark in the area outside the ROI region.
         * @param enable Whether to enable the mode. True by default.
         * @return
         *        - 0: Success.
         *        - < 0: Failure.
         * @note You must call this API before calling {@link startVideoCapture startVideoCapture} to enable internal capture to make the setting valid.
         *
         */
        RTCVideo_1.prototype.enableCameraAutoExposureFaceMode = function (enable) {
            var _this = this;
            var a = function () { return Number(_this._instance.enableCameraAutoExposureFaceMode(enable)); };
            var i = function () { return Number(_this._instance.enableCameraAutoExposureFaceMode(enable)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @hidden(macOS)
         * @detail api
         * @valid since 353
         * @brief Set the minimum frame rate of of the dynamic framerate mode during internal video capture.
         * @param framerate The minimum value in fps. The default value is 7. <br>
         *                  The maximum value of the dynamic framerate mode is set by calling {@link setVideoCaptureConfig setVideoCaptureConfig}. When minimum value exceeds the maximum value, the frame rate is set to a fixed value as the maximum value; otherwise, dynamic framerate mode is enabled.
         * @return
         *        - 0: Success.
         *        - !0: Failure.
         * @note
         *        - You must call this API before calling {@link startVideoCapture startVideoCapture} to enable internal capture to make the setting valid.
         *        - If the maximum frame rate changes due to performance degradation, static adaptation, etc., the set minimum frame rate value will be re-compared with the new maximum value. Changes in comparison results may cause switch between fixed and dynamic frame rate modes.
         *
         */
        RTCVideo_1.prototype.setCameraAdaptiveMinimumFrameRate = function (framerate) {
            var _this = this;
            var a = function () { return Number(_this._instance.setCameraAdaptiveMinimumFrameRate(framerate)); };
            var i = function () { return Number(_this._instance.setCameraAdaptiveMinimumFrameRate(framerate)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @author qipengxiang
         * @hidden currently not available
         * @detail api
         * @brief Start publishing a public media stream. <br>
         *        Users within the same `appID` can call {@link startPlayPublicStream startPlayPublicStream} to subscribe to the public stream regardless the user has joined which room or has not joined any room.
         * @param publicStreamId ID of the public stream
         * @param publicStream Properties of the public stream. Refer to {@link PublicStreaming PublicStreaming} for more details. <br>
         *              A public stream can include a bundle of media streams and appears as the designated layout.
         * @return
         *        - 0: Success. And you will be informed by {@link onPushPublicStreamResult onPushPublicStreamResult}.
         *        - !0: Failure because of invalid parameter or empty parameters.
         * @note
         *        - Call {@link updatePublicStreamParam updatePublicStreamParam} to update the properties of the public stream which is published by the same user. Calling this API with the same stream ID repeatedly by the same user can not update the existing public stream.
         *        - If Users with different userID call this API with the same stream ID, the public stream will be updated with the parameters passed in the latest call.
         *        - To publish multiple public streams, call this API with different stream ID respectively.
         *        - To stop publishing the public stream, call {@link stopPushPublicStream stopPushPublicStream}.
         *        - Please contact ts to enable this function before using it.
         *
         */
        RTCVideo_1.prototype.startPushPublicStream = function (publicStreamId, publicStream) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.startPushPublicStream(publicStreamId, unpackObject(publicStream)));
            };
            var i = function () {
                return Number(_this._instance.startPushPublicStream(publicStreamId, unpackObject(publicStream)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @hidden currently not available.
         * @detail api
         * @brief Stop the public stream published by the current user. <br>
         *        Refer to {@link startPushPublicStream startPushPublicStream} for details about starting publishing a public stream.
         * @param publicStreamId ID of the public stream <br>
         *                  The public stream must be published by the current user.
         * @return
         *        - 0: Success
         *        - !0: Failure
         *
         */
        RTCVideo_1.prototype.stopPushPublicStream = function (publicStreamId) {
            var _this = this;
            var a = function () { return Number(_this._instance.stopPushPublicStream(publicStreamId)); };
            var i = function () { return Number(_this._instance.stopPushPublicStream(publicStreamId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @hidden currently not available.
         * @detail api
         * @brief Update the properties of the public stream published by the current user. <br>
         *        Refer to {@link startPushPublicStream startPushPublicStream} for details about starting publishing a public stream.
         * @param publicStreamId ID of the public stream <br>
         *              The stream to be updated must be published by the current user.
         * @param transcoding Properties of the public stream. Refer to {@link PublicStreaming PublicStreaming} for more details.current user.
         * @return
         *        - 0: Success
         *        - !0: Failure
         * @note Make sure the public stream has started successfully via {@link onPushPublicStreamResult onPushPublicStreamResult} before calling this API.
         *
         */
        RTCVideo_1.prototype.updatePublicStreamParam = function (publicStreamId, transcoding) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.updatePublicStreamParam(publicStreamId, unpackObject(transcoding)));
            };
            var i = function () {
                return Number(_this._instance.updatePublicStreamParam(publicStreamId, unpackObject(transcoding)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        RTCVideo_1.prototype.startPlayPublicStream = function (publicStreamId) {
            var _this = this;
            var a = function () { return Number(_this._instance.startPlayPublicStream(publicStreamId)); };
            var i = function () { return Number(_this._instance.startPlayPublicStream(publicStreamId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @hidden currently not available.
         * @detail api
         * @brief Cancel subscribing the public stream. <br>
         *        Call this method to cancel subscribing to the public stream by calling {@link startPlayPublicStream sstartPlayPublicStream}.
         * @param publicStreamId ID of the public stream
         * @return
         *        - 0: Success
         *        - !0: Failure
         *
         */
        RTCVideo_1.prototype.stopPlayPublicStream = function (publicStreamId) {
            var _this = this;
            var a = function () { return Number(_this._instance.stopPlayPublicStream(publicStreamId)); };
            var i = function () { return Number(_this._instance.stopPlayPublicStream(publicStreamId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @hidden currently not available.
         * @detail api
         * @brief Assign a internal render view to the public stream
         * @param publicStreamId ID of the public stream
         * @param canvas Internal render view. Set to be a blank view if you want to unbind. Refer to {@link VideoCanvas VideoCanvas} for more details.
         * @return
         *        - 0: Success
         *        - !0: Failure
         *
         */
        RTCVideo_1.prototype.setPublicStreamVideoCanvas = function (publicStreamId, canvas) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setPublicStreamVideoCanvas(publicStreamId, unpackObject(canvas)));
            };
            var i = function () {
                return Number(_this._instance.setPublicStreamVideoCanvas(publicStreamId, unpackObject(canvas)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @valid since 3.51
         * @author qipengxiang
         * @brief Set the audio playback volume of the public stream.
         * @param publicStreamId ID of the public stream
         * @param volume Ratio(\%) of the audio playback volume to the original volume, in the range `[0, 400]`, with overflow protection. The default volume is 100. <br>
         *               To ensure the audio quality, the recommended range is `[0,  100]`.
         * @return
         *         - 0: Success.
         *         - -2: Wrong parameter.
         *
         */
        RTCVideo_1.prototype.setPublicStreamAudioPlaybackVolume = function (publicStreamId, volume) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setPublicStreamAudioPlaybackVolume(publicStreamId, volume));
            };
            var i = function () {
                return Number(_this._instance.setPublicStreamAudioPlaybackVolume(publicStreamId, volume));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Network Management
         * @author qipengxiang
         * @brief Starts a call test. <br>
         *        Before entering the room, you can call this API to test whether your local audio/video equipment as well as the upstream and downstream networks are working correctly. <br>
         *        Once the test starts, SDK will record your sound or video. If you receive the playback within the delay range you set, the test is considered normal.
         * @param config Test configurations, see {@link EchoTestConfig EchoTestConfig}.
         * @param delayTime Delayed audio/video playback time specifying how long you expect to receive the playback after starting the. The range of the value is [2,10] in seconds and the default value is 2.
         * @return API call result: <br>
         *        - 0: Success
         *        - -1: Failure, testing in progress
         *        - -2: Failure, you are in the room
         *        - -3: Failure, neither video nor audio is captured
         *        - -4: Failure, parameter exception
         *        - -5: Failure, the roomID is already used
         * @note
         *        - Once you start the test, you can either call {@link stopEchoTest stopEchoTest} or wait until the test stops automatically after 60s, to start the next test or enter the room.
         *        - All APIs related to device control and stream control called before this API are invalidated during the test and are restored after the test.
         *        - All APIs related to device control, stream control, and room entry called during the test do not take effect, and you will receive {@link onWarning onWarning} with the warning code `WARNING_CODE_IN_ECHO_TEST_MODE`.
         *        - You will receive the test result from {@link onEchoTestResult onEchoTestResult}.
         *
         */
        RTCVideo_1.prototype.startEchoTest = function (config, delayTime) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.startEchoTest(unpackObject(config), delayTime));
            };
            var i = function () {
                return Number(_this._instance.startEchoTest(unpackObject(config), delayTime));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Network Management
         * @author qipengxiang
         * @brief Stop the current call test. <br>
         *        After calling {@link startEchoTest startEchoTest}, you must call this API to stop the test.
         * @return API call result: <br>
         *        - 0: Success
         *        - -1: Failure, no test is in progress
         * @note After stopping the test with this API, all the system devices and streams are restored to the state they were in before the test.
         *
         */
        RTCVideo_1.prototype.stopEchoTest = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopEchoTest()); };
            var i = function () { return Number(_this._instance.stopEchoTest()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio & Video Processing
         * @author zhushufan.ref
         * @brief Removes video watermark from designated video stream.
         * @param streamIndex Targeting stream index of the watermark. See [StreamIndex](70083#streamindex-2).
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         *
         */
        RTCVideo_1.prototype.clearVideoWatermark = function (streamIndex) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.clearVideoWatermark(t_StreamIndex.ts_to_android(streamIndex)));
            };
            var i = function () {
                return Number(_this._instance.clearVideoWatermark(t_StreamIndex.ts_to_ios(streamIndex)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio & Video Transport
         * @author liuyangyang
         * @brief Set an alternative image when the local internal video capture is not enabled. <br>
         *        When you call `stopVideoCapture`, an alternative image will be pushed. You can set the path to null or open the camera to stop publishing the image. <br>
         *        You can repeatedly call this API to update the image.
         * @param filePath Set the path of the static image. <br>
         *        You can use the absolute path (file://xxx) or the asset directory path (/assets/xx.png). The maximum size for the path is 512 bytes. <br>
         *        You can upload a .JPG, .JPEG, .PNG, or .BMP file. <br>
         *        When the aspect ratio of the image is inconsistent with the video encoder configuration, the image will be proportionally resized, with the remaining pixels rendered black. The framerate and the bitrate are consistent with the video encoder configuration.
         * @return
         *        - 0: Success.
         *        - -1: Failure.
         * @note
         *        - The API is only effective when publishing an internally captured video.
         *        - You cannot locally preview the image.
         *        - You can call this API before and after joining an RTC room. In the multi-room mode, the image can be only displayed in the room you publish the stream.
         *        - You cannot apply effects like filters and mirroring to the image, while you can watermark the image.
         *        - The image is not effective for a screen-sharing stream.
         *        - When you enable the simulcast mode, the image will be added to all video streams, and it will be proportionally scaled down to smaller encoding configurations.
         *
         */
        RTCVideo_1.prototype.setDummyCaptureImagePath = function (filePath) {
            var _this = this;
            var a = function () { return Number(_this._instance.setDummyCaptureImagePath(filePath)); };
            var i = function () { return Number(_this._instance.setDummyCaptureImagePath(filePath)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region  cloud proxy
         * @author daining.nemo
         * @brief  Start cloud proxy
         * @param  cloudProxiesInfo cloud proxy informarion list. See {@link CloudProxyInfo CloudProxyInfo}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - Call this API before joining the room.
         *         - Start pre-call network detection after starting cloud proxy.
         *         - After starting cloud proxy and connects the cloud proxy server successfully, receives {@link onCloudProxyConnected onCloudProxyConnected}.
         *         - To stop cloud proxy, call {@link stopCloudProxy stopCloudProxy}.
         *
         */
        RTCVideo_1.prototype.startCloudProxy = function (cloudProxiesInfo) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.startCloudProxy(cloudProxiesInfo.map(function ($item) { return unpackObject($item); })));
            };
            var i = function () {
                return Number(_this._instance.startCloudProxy(cloudProxiesInfo.map(function ($item) { return unpackObject($item); })));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region  cloud proxy
         * @author daining.nemo
         * @brief  Stop cloud proxy
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note To start cloud proxy, call {@link startCloudProxy startCloudProxy}.
         *
         */
        RTCVideo_1.prototype.stopCloudProxy = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopCloudProxy()); };
            var i = function () { return Number(_this._instance.stopCloudProxy()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author wangjunzheng
         * @brief Create a karaoke scoring management interface.
         * @return Karaoke scoring management interface. See {@link ISingScoringManager ISingScoringManager}.
         *
         */
        RTCVideo_1.prototype.getSingScoringManager = function () {
            var _this = this;
            var a = function () { return packObject(_this._instance.getSingScoringManager(), ISingScoringManager); };
            var i = function () { return packObject(_this._instance.getSingScoringManager(), ISingScoringManager); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author songxiaomeng.19
         * @brief Obtain the synchronization network time information.
         * @return See {@link NetworkTimeInfo NetworkTimeInfo}.
         * @note
         *        - When you call this API for the first time, you starts synchornizing the network time information and receive the return value `0`. After the synchonization finishes, you will receive {@link onNetworkTimeSynchronized onNetworkTimeSynchronized}. After that, calling this API will get you the correct network time.
         *        - Under chorus scenario, participants shall start audio mixing at the same network time.
         *
         */
        RTCVideo_1.prototype.getNetworkTimeInfo = function () {
            var _this = this;
            var a = function () { return packObject(_this._instance.getNetworkTimeInfo(), NetworkTimeInfo); };
            var i = function () { return packObject(_this._instance.getNetworkTimeInfo(), NetworkTimeInfo); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @hidden currently not available
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Creates the KTV manager interfaces.
         * @return KTV manager interfaces. See {@link IKTVManager IKTVManager}.
         *
         */
        RTCVideo_1.prototype.getKTVManager = function () {
            var _this = this;
            var a = function () { return packObject(_this._instance.getKTVManager(), IKTVManager); };
            var i = function () { return packObject(_this._instance.getKTVManager(), IKTVManager); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio Management
         * @author zhangcaining
         * @brief Start echo detection before joining a room.
         * @param testAudioFilePath Absolute path of the music file for the detection. It is expected to encode with UTF-8. The following files are supported: mp3, aac, m4a, 3gp, wav. <br>
         *       We recommend to assign a music file whose duration is between 10 to 20 seconds. <br>
         *        Do not pass a Silent file.
         * @return Method call result: <br>
         *         - 0: Success.
         *        - -1: Failure due to the onging process of the previous detection. Call {@link stopHardwareEchoDetection stopHardwareEchoDetection} to stop it before calling this API again.
         *        - -2: Failure due to an invalid file path or file format.
         * @note
         *        - You can use this feature only when {@link ChannelProfile ChannelProfile} is set to `CHANNEL_PROFIEL_MEETING` or `CHANNEL_PROFILE_MEETING_ROOM`.
         *        - Before calling this API, ask the user for the permissions to access the local audio devices.
         *        - Before calling this api, make sure the audio devices are activate and keep the capture volume and the playback volume within a reasonable range.
         *        - The detection result is passed as the argument of onHardwareEchoDetectionResult.
         *        - During the detection, the SDK is not able to response to the other testing APIs, such as {@link startEchoTest startEchoTest}, {@link startAudioDeviceRecordTest startAudioDeviceRecordTest} or {@link startAudioPlaybackDeviceTest startAudioPlaybackDeviceTest}.
         *        - Call {@link stopHardwareEchoDetection stopHardwareEchoDetection} to stop the detection and release the audio devices.
         *
         */
        RTCVideo_1.prototype.startHardwareEchoDetection = function (testAudioFilePath) {
            var _this = this;
            var a = function () { return Number(_this._instance.startHardwareEchoDetection(testAudioFilePath)); };
            var i = function () { return Number(_this._instance.startHardwareEchoDetection(testAudioFilePath)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Audio Management
         * @author zhangcaining
         * @brief Stop the echo detection before joining a room.
         * @return Method call result: <br>
         *        - 0: Success.
         *        - -1: Failure.
         * @note
         *        - Refer to {@link startHardwareEchoDetection startHardwareEchoDetection} for information on how to start a echo detection.
         *        - We recommend calling this API to stop the detection once getting the detection result from {@link onHardwareEchoDetectionResult onHardwareEchoDetectionResult}.
         *        - You must stop the echo detection to release the audio devices before the user joins a room. Otherwise, the detection may interfere with the call.
         *
         */
        RTCVideo_1.prototype.stopHardwareEchoDetection = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopHardwareEchoDetection()); };
            var i = function () { return Number(_this._instance.stopHardwareEchoDetection()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Enable cellular network assisted communication to improve call quality.
         * @param config See {@link MediaTypeEnhancementConfig MediaTypeEnhancementConfig}.
         * @return Method call result: <br>
         *        - 0: Success.
         *        - -1: Failure, internal error.
         *        - -2: Failure, invalid parameters.
         * @note The function is off by default.
         *
         */
        RTCVideo_1.prototype.setCellularEnhancement = function (config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setCellularEnhancement(unpackObject(config)));
            };
            var i = function () {
                return Number(_this._instance.setCellularEnhancement(unpackObject(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @valid since 3.56
         * @detail api
         * @region Video Facility Management
         * @author likai.666
         * @brief Create a video Facility Management instance
         * @return Video Facility Management instance. See {@link IVideoDeviceManager IVideoDeviceManager}
         *
         */
        RTCVideo_1.prototype.android_getVideoDeviceManager = function () {
            var _this = this;
            var $ = function () { return _this._instance.getVideoDeviceManager(); };
            return $();
        };
        /** {en}
         * @detail api
         * @brief Set the rotation of the video images captured from the local device. <br>
         *        Call this API to rotate the videos when the camera is fixed upside down or tilted. For rotating videos on a phone, we recommend to use {@link setVideoRotationMode setVideoRotationMode}.
         * @param rotation It defaults to `VIDEO_ROTATION_0(0)`, which means not to rotate. Refer to {@link VideoRotation VideoRotation}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - For the videos captured by the internal module, the rotation will be combined with that set by calling {@link setVideoRotationMode setVideoRotationMode}.
         *        - This API affects the external-sourced videos. The final rotation would be the original rotation angles adding up with the rotation set by calling this API.
         *        - The elements added during the video pre-processing stage, such as video sticker and background applied using {@link enableVirtualBackground:withSource: enableVirtualBackground} will also be rotated by this API.
         *        - The rotation would be applied to both locally rendered video s and those sent out. However, if you need to rotate a video which is intended for pushing to CDN individually, use {@link setVideoOrientation setVideoOrientation}.
         *
         */
        RTCVideo_1.prototype.setVideoCaptureRotation = function (rotation) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setVideoCaptureRotation(t_VideoRotation.ts_to_android(rotation)));
            };
            var i = function () {
                return Number(_this._instance.setVideoCaptureRotation(t_VideoRotation.ts_to_ios(rotation)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform ios
         * @hidden(macOS)
         * @detail api
         * @region Audio Management
         * @author dixing
         * @brief  On iOS, you can change the Bluetooth profile when the media volume is set in all scenarios.
         * @param mode The Bluetooth profiles. See {@link ByteRTCBluetoothMode ByteRTCBluetoothMode}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ByteRTCReturnStatus ByteRTCReturnStatus} for more details
         * @note You will receive {@link rtcEngine:onAudioDeviceWarning:deviceType:deviceWarning rtcEngine:onAudioDeviceWarning:deviceType:deviceWarning:} in the following scenarios: 1) You cannot change the Bluetooth profile to HFP.;2) The media volume is not set in all scenarios. We suggest that you call {@link ByteRTCVideosetaudioscenario setAudioScenario:} to set the media volume scenario before calling this API.
         */
        RTCVideo_1.prototype.ios_setBluetoothMode = function (mode) {
            var _this = this;
            var $ = function () { return Number(_this._instance.setBluetoothMode(mode)); };
            return $();
        };
        /** {en}
         * @platform ios
         * @detail api
         * @region Video Management
         * @author zhaomingliang
         * @brief Video publisher call this API to set the parameters of the maximum resolution video stream that is expected to be published, including resolution, frame rate, bitrate, and fallback strategy in poor network conditions. <br>
         *        You can only set configuration for one stream with this API. If you want to set configuration for multiple streams, Call {@link setVideoEncoderConfig setVideoEncoderConfig:}.
         * @param encoderConfig The maximum video encoding parameter. See {@link ByteRTCVideoEncoderConfig ByteRTCVideoEncoderConfig}.
         * @return  API call result: <br>
         *        - 0: Success
         *        - ! 0: Failure
         * @note
         *        - You can use {@link enableSimulcastMode enableSimulcastMode:} simultaneously to publish streams with different resolutions. Specifically, if you want to publish multiple streams with different resolutions, you need to call this method and enable the simulcast mode with {@link enableSimulcastMode enableSimulcastMode:} before publishing your streams. The SDK will intelligently adjust the number of streams to be published (up to 4) and their parameters based on the settings of the subscribing end. The resolution set by calling this method will be the maximum resolution among the streams. For specific rules, please refer to [Simulcasting](https://docs.byteplus.com/en/byteplus-rtc/docs/70139).
         *        - Without calling this API, SDK will only publish one stream for you with a resolution of 640px × 360px and a frame rate of 15fps.
         *        - In custom capturing, you must call this API to set the encoding parameters to ensure the integrity of the picture received by remote users.
         *        - This API is applicable to the video stream captured by the camera, see {@link setScreenVideoEncoderConfig setScreenVideoEncoderConfig:} for setting parameters for screen sharing video stream.
         */
        RTCVideo_1.prototype.ios_setMaxVideoEncoderConfig = function (encoderConfig) {
            var _this = this;
            var $ = function () { return Number(_this._instance.setMaxVideoEncoderConfig(encoderConfig)); };
            return $();
        };
        /** {en}
         * @platform ios
         * @detail api
         * @region  encryption
         * @author wangjunlin.3182
         * @brief Sets custom encryption and decryption methods.
         * @param handler Custom encryption handler, which needs to implement the encryption and decryption method. See {@link ByteRTCEncryptHandler ByteRTCEncryptHandler}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ByteRTCReturnStatus ByteRTCReturnStatus} for more details
         * @note
         *        - The method and {@link setEncryptInfo:key setEncryptInfo:key:} are mutually exclusive relationships, that is, according to the call order, the last call method takes effect version.
         *        - This method must be called before calling {@link joinRoom:userInfo:roomConfig joinRoom:userInfo:roomConfig:}, which can be called repeatedly, taking the last called parameter as the effective parameter.
         *        - Whether encrypted or decrypted, the length of the modified data needs to be controlled under 180\%. That is, if the input data is 100 bytes, the processed data must be less than 180 bytes. If the encryption or decryption result exceeds the limit, the audio & video frame may be discarded.
         *        - Data encryption/decryption is performed serially, so depending on the implementation The method may affect the final rendering efficiency. Whether to use this method needs to be carefully evaluated by the user.
         */
        RTCVideo_1.prototype.ios_setCustomizeEncryptHandler = function (handler) {
            var _this = this;
            var $ = function () { return Number(_this._instance.setCustomizeEncryptHandler(handler)); };
            return $();
        };
        /** {en}
         * @platform ios
         * @hidden(macOS)
         * @detail api
         * @region  Screen Sharing
         * @author wangzhanqiang
         * @brief  Set Extension configuration. It should be set before capturing screen internally.
         * @param groupId  Your app and Extension should belong to the same App Group. You need to put in their Group ID here.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ByteRTCReturnStatus ByteRTCReturnStatus} for more details
         * @note You must call this API immediately after calling {@link createRTCVideo:delegate:parameters createRTCVideo:delegate:parameters:}. You only need to call this API once in the life cycle of the engine instance.
         */
        RTCVideo_1.prototype.ios_setExtensionConfig = function (groupId) {
            var _this = this;
            var $ = function () { return Number(_this._instance.setExtensionConfig(groupId)); };
            return $();
        };
        /** {en}
         * @platform ios
         * @hidden(macOS)
         * @detail api
         * @region  Screen Sharing
         * @author wangzhanqiang
         * @brief Sends message to screen capture Extension
         * @param messsage  Message sent to the Extension
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ByteRTCReturnStatus ByteRTCReturnStatus} for more details
         * @note
         *       - Call this API after calling {@link startScreenCapture:bundleId startScreenCapture:bundleId:}.
         *       - The extension will receive {@link onReceiveMessageFromApp onReceiveMessageFromApp:} when the message is sent.
         */
        RTCVideo_1.prototype.ios_sendScreenCaptureExtensionMessage = function (messsage) {
            var _this = this;
            var $ = function () { return Number(_this._instance.sendScreenCaptureExtensionMessage(messsage)); };
            return $();
        };
        return RTCVideo_1;
    }());
    __setFunctionName(_classThis, "RTCVideo");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var RTCRoom = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function RTCRoom_1() {
        }
        Object.defineProperty(RTCRoom_1.prototype, "ios_delegate", {
            /** {en}
             * @platform ios
             * @detail callback
             */
            get: function () {
                return this._instance.delegate;
            },
            set: function (value) {
                this._instance.delegate = value;
            },
            enumerable: false,
            configurable: true
        });
        RTCRoom_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        RTCRoom_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRoom).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = RTCRoom$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region  multi-room
         * @author shenpengliang
         * @brief Listens for event callbacks related to the {@link RTCRoom RTCRoom} instance by setting the event handler of this instance.
         * @param rtcRoomEventHandler Refer to {@link IRTCRoomEventHandler IRTCRoomEventHandler}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         *
         */
        RTCRoom_1.prototype.setRTCRoomEventHandler = function (rtcRoomEventHandler) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setRTCRoomEventHandler(packObject(rtcRoomEventHandler, android_RTCRoomEventHandler)));
            };
            var i = function () {
                return Number(_this._instance.setRTCRoomDelegate(packObject(rtcRoomEventHandler, ios_RTCRoomEventHandler)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Room Management
         * @author yejing.luna
         * @brief Subscribes to all remote media streams captured by camera/microphone. Or update the subscribe options of all subscribed user.
         * @param type Media stream type, used for specifying whether to subscribe to the audio stream or the video stream. See {@link MediaStreamType MediaStreamType}.
         * @return API call result: <br>
         *        - 0: Success
         *        - !0: Failure
         * @note
         *        - If the subscription options conflict with the previous ones, they are subject to the configurations in the last call.
         *        - With the Audio selection enabled, if the number of media streams exceeds the limit, we recommend you call {@link subscribeStream subscribeStream} to subscribe each target media stream other than calling this API.
         *        - After calling this API, you will be informed of the calling result with {@link onStreamSubscribed onStreamSubscribed}.
         *        - Once the local user subscribes to the stream of a remote user, the subscription to the remote user will sustain until the local user leaves the room or unsubscribe from it by calling {@link unsubscribeStream unsubscribeStream}.
         *        - Any other exceptions will be included in {@link onStreamStateChanged onStreamStateChanged}, see {@link ErrorCode ErrorCode} for the reasons.
         *
         */
        RTCRoom_1.prototype.subscribeAllStreams = function (type) {
            var _this = this;
            var a = function () { return Number(_this._instance.subscribeAllStreams(t_MediaStreamType.ts_to_android(type))); };
            var i = function () {
                return Number(_this._instance.subscribeAllStreamsWithMediaStreamType(t_MediaStreamType.ts_to_ios(type)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Room Management
         * @author yejing.luna
         * @brief Unsubscribes from all remote media streams captured by camera/microphone. <br>
         *        You can call this API to unsubscribe from streams that are subscribed to either automatically or manually.
         * @param type Media stream type, used for specifying whether to unsubscribe from the audio stream or the video stream. See {@link MediaStreamType MediaStreamType}.
         * @return API call result: <br>
         *        - 0: Success
         *        - !0: Failure
         * @note
         *        - After calling this API, you will be informed of the calling result with {@link onStreamSubscribed onStreamSubscribed}.
         *        - Any other exceptions will be included in {@link onStreamStateChanged onStreamStateChanged}, see {@link ErrorCode ErrorCode} for the reasons.
         *
         */
        RTCRoom_1.prototype.unsubscribeAllStreams = function (type) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.unsubscribeAllStreams(t_MediaStreamType.ts_to_android(type)));
            };
            var i = function () {
                return Number(_this._instance.unsubscribeAllStreamsWithMediaStreamType(t_MediaStreamType.ts_to_ios(type)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region  multiple rooms
         * @author shenpengliang
         * @brief Leave and destroy the room instance created by calling {@link createRTCRoom createRTCRoom}.
         *
         */
        RTCRoom_1.prototype.destroy = function () {
            var _this = this;
            var a = function () { return (_this._instance.destroy(), void 0); };
            var i = function () { return (_this._instance.destroy(), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Multiple rooms
         * @author shenpengliang
         * @brief Join the room. <br>
         *        After creating a room by calling {@link createRTCRoom createRTCRoom}, call this API to join the room and make audio & video calls with other users in the room.
         * @param token Dynamic key. It is used for authentication and verification of users entering the room. <br>
         *         You need to bring Token to enter the room. When testing, you can use the console to generate temporary tokens. The official launch requires the use of the key SDK to generate and issue tokens at your server level. See [Use Token to complete authentication](#70121) for token validity and generation method. <br>
         *         Apps with different AppIDs are not interoperable. <br>
         *         Make sure that the AppID used to generate the Token is the same as the AppID used to create the engine, otherwise it will cause the join room to fail.
         * @param userInfo User information. See {@link UserInfo UserInfo}.
         * @param roomConfig Room parameter configuration, set the room mode and whether to automatically publish or subscribe to the flow. See {@link RTCRoomConfig RTCRoomConfig} for the specific configuration mode.
         * @return
         *         - 0: Success.
         *         - -1: RoomID/userI nfo.uid contains invalid parameters.
         *         - -2: Already in the room. After the interface call is successful, as long as the return value of 0 is received and {@link leaveRoom leaveRoom} is not called successfully, this return value is triggered when the room entry interface is called again, regardless of whether the filled room ID and user ID are duplicated.
         *         The reason for the failure will be communicated via the {@link onRoomStateChanged onRoomStateChanged} callback.
         * @note
         *        - In the same room with the same App ID, the user ID of each user must be unique. If two users have the same user ID, the user who entered the room later will kick the user who entered the room out of the room, and the user who entered the room will receive the {@link onRoomStateChanged onRoomStateChanged} callback notification. For the error type. See kErrorCodeDuplicateLogin in  {@link ERROR_CODE_DUPLICATE_LOGIN ERROR_CODE_DUPLICATE_LOGIN}.
         *        - Local users will receive {@link onRoomStateChanged onRoomStateChanged} callback notification after calling this method to join the room successfully. If the local user is also a visible user, the remote user will receive an {@link onUserJoined onUserJoined} callback notification when joining the room.
         *        - By default, the user is visible in an RTC room. Joining fails when the number of users in an RTC room reaches the upper limit. To avoid this, call {@link setUserVisibility setUserVisibility} to change the visibility of the audience users to `false` by considering the capacity for the invisible users is much larger than that for visible users. An RTC room can accommodate a maximum of 50 visible users, and 30 media streams can be published simultaneously. For more information, see [Capability of Users and Streams](https://docs.byteplus.com/en/byteplus-rtc/docs/257549).
         *        - After the user successfully joins the room, the SDK may lose connection to the server in case of poor local network conditions. At this point, {@link onConnectionStateChanged onConnectionStateChanged} callback will be triggered and the SDK will automatically retry until it successfully reconnects to the server. After successful reconnection, {@link onRoomStateChanged onRoomStateChanged} callback notification will be received locally.
         *
         */
        RTCRoom_1.prototype.joinRoom = function (token, userInfo, roomConfig) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.joinRoom(token, unpackObject(userInfo), unpackObject(roomConfig)));
            };
            var i = function () {
                return Number(_this._instance.joinRoom(token, unpackObject(userInfo), unpackObject(roomConfig)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Multiple rooms
         * @author shenpengliang
         * @brief Leave the room. <br>
         *        The user calls this method to leave the room, end the call process, and release all call-related resources. <br>
         *        This method is an asynchronous operation, and the call returns without actually exiting the room. After you actually exit the room, you will receive a callback notification from {@link onLeaveRoom onLeaveRoom} locally.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - After a user who calls {@link setUserVisibility setUserVisibility} to make himself visible leaves the room, other users in the room will receive a callback notification from {@link onUserLeave onUserLeave}.
         *        - If the engine is destroyed immediately after this method is called, the SDK will not be able to trigger the {@link onLeaveRoom onLeaveRoom} callback.
         *
         */
        RTCRoom_1.prototype.leaveRoom = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.leaveRoom()); };
            var i = function () { return Number(_this._instance.leaveRoom()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Room management
         * @author shenpengliang
         * @brief Set the visibility of the user in the room. The local user is visible to others by default before calling this API. <br>
         *        An RTC room can accommodate a maximum of 50 visible users, and 30 media streams can be published simultaneously. For more information, see [Room Capacity](https://docs.byteplus.com/en/byteplus-rtc/docs/257549).
         * @param enable Visibility of the user in the room. <br>
         *        - true: The user can publish media streams. The other users in the room get informed of the behaviors of the user, such as joining room, starting video capture, and leaving room.
         *        - false: The user cannot publish media streams. The other users in the room do not get informed of the behaviors of the user, such as joining room, starting video capture, or leaving room.
         * @return
         *        - 0: Success.
         *        - < 0 : Failure. See {@link ReturnStatus ReturnStatus}.
         * @note
         *        - You can call this API whether the user is in a room or not.
         *        - You will receive {@link onUserVisibilityChanged onUserVisibilityChanged} after calling this API. (Available since v3.54)
         *   &#x0020;  • If you call this API before joining room, and the set value is different from the default value, you will receive the callback when you join the room. <br>
         *   &#x0020;  • If you call this API after joining room, and the current visibility is different from the previous value, you will receive the callback. <br>
         *   &#x0020;  • When reconnecting after losing internet connection, if the visibility changes, you will receive the callback. <br>
         *        - When you call this API while you are in the room, the other users in the room will be informed via the following callback.
         *   &#x0020;  • When you switch from `false` to `true`, they will receive {@link onUserJoined onUserJoined}. <br>
         *   &#x0020;  • When you switch from `true` to `false`, they will receive {@link onUserLeave onUserLeave}. <br>
         *   &#x0020;  • The invisible user will receive the warning code, `WARNING_CODE_PUBLISH_STREAM_FORBIDEN`, when trying to publish media streams.
         *
         */
        RTCRoom_1.prototype.setUserVisibility = function (enable) {
            var _this = this;
            var a = function () { return Number(_this._instance.setUserVisibility(enable)); };
            var i = function () { return Number(_this._instance.setUserVisibility(enable)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author shenpengliang
         * @brief Update Token. <br>
         *        You must call this API to update token to ensure the RTC call to continue when you receive {@link onTokenWillExpire onTokenWillExpire}, {@link onPublishPrivilegeTokenWillExpire onPublishPrivilegeTokenWillExpire}, or {@link onSubscribePrivilegeTokenWillExpire onSubscribePrivilegeTokenWillExpire}.
         * @param token  Valid token. <br>
         *        If the Token is invalid, you will receive {@link onRoomStateChanged onRoomStateChanged} with the error code of `-1010`.
         * @return API call result: <br>
         *        - 0: Success.
         *        - <0: Failure. See {@link ReturnStatus ReturnStatus} for specific reasons.
         * @note
         *      - In versions before 3.50, the publish and subscribe privileges contained in the Token are reserved parameters with no actual control permissions. In version 3.50 and later, the publish/subscribe privileges will be effective for whitelisted users. Please contact the technical support team to include you in the whitelist if you need this function.
         *      - Do not call both {@link updateToken updateToken} and {@link joinRoom joinRoom} to update the Token. If you fail to join the room or have been removed from the room due to an expired or invalid Token, call {@link joinRoom joinRoom} with a valid token to rejoin the room.
         *
         */
        RTCRoom_1.prototype.updateToken = function (token) {
            var _this = this;
            var a = function () { return Number(_this._instance.updateToken(token)); };
            var i = function () { return Number(_this._instance.updateToken(token)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Multi-room
         * @author hanchenchen.c
         * @brief Send a point-to-point text message to the specified user in the room
         * @param userId User ID of the message receiver
         * @param messageStr Text message content sent. Message does not exceed 64 KB.
         * @param config See {@link MessageConfig MessageConfig}.
         * @return
         *         - > 0: Sent successfully, return the number of the sent message, increment from 1
         *         - -1: Sent failed, RTCRoom instance not created
         *         - -2: Sent failed, uid is empty
         * @note
         *       - Before sending an in-room text message, you must call {@link joinRoom joinRoom} to join the room.
         *       - After the call, you will receive an {@link onUserMessageSendResult onUserMessageSendResult} callback to notify that the message was sent successfully or failed;
         *       - If the message was sent successfully, the user specified by the userId will receive an {@link onUserMessageReceived onUserMessageReceived} callback.
         *
         */
        RTCRoom_1.prototype.sendUserMessage = function (userId, messageStr, config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.sendUserMessage(userId, messageStr, t_MessageConfig.ts_to_android(config)));
            };
            var i = function () {
                return Number(_this._instance.sendUserMessage(userId, messageStr, t_MessageConfig.ts_to_ios(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region multiroom
         * @author hanchenchen.c
         * @brief Sends a point-to-point binary message to the specified user in the room.
         * @param userId Message Receives user ID
         * @param buffer Binary message content sent. Message does not exceed 46KB.
         * @param config See {@link MessageConfig MessageConfig}
         * @note
         *       - Before sending in-room binary messages, you must call {@link joinRoom joinRoom} to join the room.
         *       - After the call, you will receive an {@link onUserMessageSendResult onUserMessageSendResult} callback to notify that the message was sent successfully or failed;
         *       - If the message was sent successfully, the user specified by the userId will receive an {@link onUserBinaryMessageReceived onUserBinaryMessageReceived} callback.
         *
         */
        RTCRoom_1.prototype.sendUserBinaryMessage = function (userId, buffer, config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.sendUserBinaryMessage(userId, buffer, t_MessageConfig.ts_to_android(config)));
            };
            var i = function () {
                return Number(_this._instance.sendUserBinaryMessage(userId, buffer, t_MessageConfig.ts_to_ios(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Multi-room
         * @author hanchenchen.c
         * @brief Mass text messages to all other users in the room.
         * @param messageStr The content of the text message sent. The message does not exceed 64 KB.
         * @note
         *        - Before broadcasting a text message in the room, you must call {@link joinRoom joinRoom} to join the room.
         *        - After the call, you will receive the {@link onRoomMessageSendResult onRoomMessageSendResult} callback;
         *        - Other users in the same room will receive the {@link onRoomMessageReceived onRoomMessageReceived} callback.
         *
         */
        RTCRoom_1.prototype.sendRoomMessage = function (messageStr) {
            var _this = this;
            var a = function () { return Number(_this._instance.sendRoomMessage(messageStr)); };
            var i = function () { return Number(_this._instance.sendRoomMessage(messageStr)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Multi-room
         * @author hanchenchen.c
         * @brief Group binary messages to all other users in the room.
         * @param buffer The content of the binary message sent. The message does not exceed 46KB.
         * @note
         *        - Before broadcasting binary messages in the room, you must call {@link joinRoom joinRoom} to join the room.
         *        - After the call, you will receive the {@link onRoomMessageSendResult onRoomMessageSendResult} callback;
         *        - Other users in the same room will receive the {@link onRoomBinaryMessageReceived onRoomBinaryMessageReceived} callback.
         *
         */
        RTCRoom_1.prototype.sendRoomBinaryMessage = function (buffer) {
            var _this = this;
            var a = function () { return Number(_this._instance.sendRoomBinaryMessage(buffer)); };
            var i = function () { return Number(_this._instance.sendRoomBinaryMessage(buffer)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Multi-room
         * @author wangzhanqiang
         * @brief Synchronizes published audio and video. <br>
         *        When the same user simultaneously uses separate devices to capture and publish audio and video, there is a possibility that the streams are out of sync due to the network disparity. In this case, you can call this API on the video publisher side and the SDK will automatically line the video stream up according to the timestamp of the audio stream, ensuring that the audio the receiver hears corresponds to the video the receiver watches.
         * @param audioUserId The ID of audio publisher. You can stop the current A/V synchronization by setting this parameter to null.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - You can call this API anytime before or after entering the room.
         *        - The source user IDs of the audio and video stream to be synchronized must be in the same RTC room.
         *        - When the A/V synchronization state changes, you will receive {@link onAVSyncStateChange onAVSyncStateChange}.
         *        - More than one pair of audio and video can be synchronized simultaneously in the same RTC room, but you should note that one single audio source cannot be synchronized with multiple video sources at the same time.
         *        - If you want to change the audio source, call this API again with a new `audioUserId`. If you want to change the video source, you need to stop the current synchronization first, then call this API on the new video publisher side.
         *
         */
        RTCRoom_1.prototype.setMultiDeviceAVSync = function (audioUserId) {
            var _this = this;
            var a = function () { return Number(_this._instance.setMultiDeviceAVSync(audioUserId)); };
            var i = function () { return Number(_this._instance.setMultiDeviceAVSync(audioUserId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Video Management
         * @author zhaomingliang
         * @brief Sets your expected configuration of the remote video stream that you want to subscribe to or have subscribed to.
         * @param userId ID of the remote video stream publisher you expect to configure subscription parameters for.
         * @param remoteVideoConfig The parameters you expect to configure for the remote video stream, see {@link RemoteVideoConfig RemoteVideoConfig}.
         * @return API call result: <br>
         *        - 0: Success.
         *        - <0: Failure. See {@link ReturnStatus ReturnStatus} for specific reasons.
         * @note
         *        - This API only works after the publisher calls {@link enableSimulcastMode enableSimulcastMode} to enable publishing multiple video streams, in which case the subscriber will receive the stream from the publisher that is closest to the set configuration;  otherwise the subscriber will only receive one video stream with a resolution of 640px × 360px and a frame rate of 15fps.
         *        - If you don't call this API after the publisher enables the function of publishing multiple streams, you will receive by default the video stream with the largest resolution set by the publisher.
         *        - You should call this API in the room. If you want to call it before entering the room, you should set the `remoteVideoConfig` in the roomConfig` when calling {@link joinRoom joinRoom}.
         *        - SDK will automatically select the stream to be published or subcribed based on the settings of both sides see for details.
         *
         */
        RTCRoom_1.prototype.setRemoteVideoConfig = function (userId, remoteVideoConfig) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setRemoteVideoConfig(userId, unpackObject(remoteVideoConfig)));
            };
            var i = function () {
                return Number(_this._instance.setRemoteVideoConfig(userId, unpackObject(remoteVideoConfig)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Room Management
         * @author shenpengliang
         * @brief Publishes media streams captured by camera/microphone in the current room.
         * @param type Media stream type, used for specifying whether to publish audio stream or video stream. See {@link MediaStreamType MediaStreamType}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - You don't need to call this API if you set it to Auto-publish when calling {@link joinRoom joinRoom}.
         *        - An invisible user cannot publish media streams. Call {@link setUserVisibility setUserVisibility} to change your visibility in the room.
         *        - Call {@link publishScreen publishScreen} to start screen sharing.
         *        - Call {@link startForwardStreamToRooms startForwardStreamToRooms} to forward the published streams to the other rooms.
         *        - After you call this API, the other users in the room will receive {@link onUserPublishStream onUserPublishStream}. Those who successfully received your streams will receive {@link onFirstRemoteAudioFrame onFirstRemoteAudioFrame}{@link onFirstRemoteVideoFrameDecoded /onFirstRemoteVideoFrameDecoded} at the same time.
         *        - Call {@link unpublishStream unpublishStream} to stop publishing streams.
         *
         */
        RTCRoom_1.prototype.publishStream = function (type) {
            var _this = this;
            var a = function () { return Number(_this._instance.publishStream(t_MediaStreamType.ts_to_android(type))); };
            var i = function () { return Number(_this._instance.publishStream(t_MediaStreamType.ts_to_ios(type))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Room Management
         * @author shenpengliang
         * @brief Stops publishing media streams captured by camera/microphone in the current room.
         * @param type Media stream type, used for specifying whether to stop publishing audio stream or video stream. See {@link MediaStreamType MediaStreamType}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - After calling {@link publishStream publishStream}, call this API to stop publishing streams.
         *         - After calling this API, the other users in the room will receive {@link onUserUnpublishStream onUserUnpublishStream}
         *
         */
        RTCRoom_1.prototype.unpublishStream = function (type) {
            var _this = this;
            var a = function () { return Number(_this._instance.unpublishStream(t_MediaStreamType.ts_to_android(type))); };
            var i = function () { return Number(_this._instance.unpublishStream(t_MediaStreamType.ts_to_ios(type))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Screen Sharing
         * @author liyi.000
         * @brief Publishes local screen sharing streams in the current room.
         * @param type Media stream type, used for specifying whether to publish audio stream or video stream. See {@link MediaStreamType MediaStreamType}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - You need to call this API to publish screen even if you set it to Auto-publish when calling {@link joinRoom joinRoom}.
         *         - An invisible user cannot publish media streams. Call {@link setUserVisibility setUserVisibility} to change your visibility in the room.
         *         - After you called this API, the other users in the room will receive {@link onUserPublishScreen onUserPublishScreen}. Those who successfully received your streams will receive {@link onFirstRemoteAudioFrame onFirstRemoteAudioFrame}{@link onFirstRemoteVideoFrameDecoded /onFirstRemoteVideoFrameDecoded} at the same time.
         *         - After calling this API, you'll receive {@link onScreenVideoFrameSendStateChanged onScreenVideoFrameSendStateChanged}.
         *         - Call {@link startForwardStreamToRooms startForwardStreamToRooms} to forward the published streams to the other rooms.
         *         - Call {@link unpublishScreen unpublishScreen} to stop publishing screen-sharing streams.
         *         - Refer to [Sharing Screen in Android](https://docs.byteplus.com/byteplus-rtc/docs/124176) for more information.
         *
         */
        RTCRoom_1.prototype.publishScreen = function (type) {
            var _this = this;
            var a = function () { return Number(_this._instance.publishScreen(t_MediaStreamType.ts_to_android(type))); };
            var i = function () { return Number(_this._instance.publishScreen(t_MediaStreamType.ts_to_ios(type))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Screen Sharing
         * @author liyi.000
         * @brief Stops publishing local screen sharing streams in the current room.
         * @param type Media stream type, used for specifying whether to stop publishing audio stream or video stream. See {@link MediaStreamType MediaStreamType}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - After calling {@link publishScreen publishScreen}, call this API to stop publishing streams.
         *         - After calling this API, the other users in the room will receive {@link onUserUnpublishScreen onUserUnpublishScreen}.
         *
         */
        RTCRoom_1.prototype.unpublishScreen = function (type) {
            var _this = this;
            var a = function () { return Number(_this._instance.unpublishScreen(t_MediaStreamType.ts_to_android(type))); };
            var i = function () { return Number(_this._instance.unpublishScreen(t_MediaStreamType.ts_to_ios(type))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Room Management
         * @author shenpengliang
         * @brief Subscribes to specific remote media streams captured by camera/microphone.  Or update the options of the subscribed user.
         * @param uid ID of the remote user who published the target audio/video stream.
         * @param type Media stream type, used for specifying whether to subscribe to the audio stream or the video stream. See {@link MediaStreamType MediaStreamType}.
         * @return API call result: <br>
         *        - 0: Success.
         *        - <0: Failure. See {@link ReturnStatus ReturnStatus} for specific reasons.
         * @note
         *        - Calling this API to update the subscribe configuration when the user has subscribed the remote user either by calling this API or by auto-subscribe.
         *        - You must first get the remote stream information through {@link onUserPublishStream onUserPublishStream} before calling this API to subscribe to streams accordingly.
         *        - After calling this API, you will be informed of the calling result with {@link onStreamSubscribed onStreamSubscribed}.
         *        - Once the local user subscribes to the stream of a remote user, the subscription to the remote user will sustain until the local user leaves the room or unsubscribe from it by calling {@link unsubscribeStream unsubscribeStream}.
         *        - Any other exceptions will be included in {@link onStreamStateChanged onStreamStateChanged}, see {@link ErrorCode ErrorCode} for the reasons.
         *
         */
        RTCRoom_1.prototype.subscribeStream = function (uid, type) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.subscribeStream(uid, t_MediaStreamType.ts_to_android(type)));
            };
            var i = function () {
                return Number(_this._instance.subscribeStream(uid, t_MediaStreamType.ts_to_ios(type)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Room Management
         * @author shenpengliang
         * @brief Unsubscribes from specific remote media streams captured by camera/microphone. <br>
         *        You can call this API in both automatic subscription mode and manual subscription mode.
         * @param uid The ID of the remote user who published the target audio/video stream.
         * @param type Media stream type, used for specifying whether to unsubscribe from the audio stream or the video stream. See {@link MediaStreamType MediaStreamType}.
         * @return API call result: <br>
         *        - 0: Success.
         *        - <0: Failure. See {@link ReturnStatus ReturnStatus} for specific reasons.
         * @note
         *        - After calling this API, you will be informed of the calling result with {@link onStreamSubscribed onStreamSubscribed}.
         *        - Any other exceptions will be included in {@link onStreamStateChanged onStreamStateChanged}, see {@link ErrorCode ErrorCode} for the reasons.
         *
         */
        RTCRoom_1.prototype.unsubscribeStream = function (uid, type) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.unsubscribeStream(uid, t_MediaStreamType.ts_to_android(type)));
            };
            var i = function () {
                return Number(_this._instance.unsubscribeStream(uid, t_MediaStreamType.ts_to_ios(type)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Room Management
         * @author shenpengliang
         * @brief Subscribes to specific screen sharing media stream.  Or update the subscribe options of the subscribed user.
         * @param uid The ID of the remote user who published the target screen audio/video stream.
         * @param type Media stream type, used for specifying whether to subscribe to the audio stream or the video stream. See {@link MediaStreamType MediaStreamType}.
         * @return API call result: <br>
         *        - 0: Success.
         *        - <0: Failure. See {@link ReturnStatus ReturnStatus} for specific reasons.
         * @note
         *        - Calling this API to update the subscribe configuration when the user has subscribed the remote user either by calling this API or by auto-subscribe.
         *        - You must first get the remote stream information through {@link onUserPublishScreen onUserPublishScreen} before calling this API to subscribe to streams accordingly.
         *        - After calling this API, you will be informed of the calling result with {@link onStreamSubscribed onStreamSubscribed}.
         *        - Once the local user subscribes to the stream of a remote user, the subscription to the remote user will sustain until the local user leaves the room or unsubscribe from it by calling {@link unsubscribeScreen unsubscribeScreen}.
         *        - Any other exceptions will be included in {@link onStreamStateChanged onStreamStateChanged}, see {@link ErrorCode ErrorCode} for the reasons.
         *
         */
        RTCRoom_1.prototype.subscribeScreen = function (uid, type) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.subscribeScreen(uid, t_MediaStreamType.ts_to_android(type)));
            };
            var i = function () {
                return Number(_this._instance.subscribeScreen(uid, t_MediaStreamType.ts_to_ios(type)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Room Management
         * @author shenpengliang
         * @brief Unsubscribes from specific screen sharing media stream. <br>
         *        You can call this API in both automatic subscription mode and manual subscription mode.
         * @param uid The ID of the remote user who published the target screen audio/video stream.
         * @param type Media stream type, used for specifying whether to unsubscribe from the audio stream or the video stream. See {@link MediaStreamType MediaStreamType}.
         * @return API call result: <br>
         *        - 0: Success.
         *        - <0: Failure. See {@link ReturnStatus ReturnStatus} for specific reasons.
         * @note
         *        - After calling this API, you will be informed of the calling result with {@link onStreamSubscribed onStreamSubscribed}.
         *        - Any other exceptions will be included in {@link onStreamStateChanged onStreamStateChanged}, see {@link ErrorCode ErrorCode} for the reasons.
         *
         */
        RTCRoom_1.prototype.unsubscribeScreen = function (uid, type) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.unsubscribeScreen(uid, t_MediaStreamType.ts_to_android(type)));
            };
            var i = function () {
                return Number(_this._instance.unsubscribeScreen(uid, t_MediaStreamType.ts_to_ios(type)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Multi-room
         * @author shenpengliang
         * @brief Pause receiving remote media streams.
         * @param mediaType Media stream type subscribed to. Refer to {@link PauseResumeControlMediaType PauseResumeControlMediaType} for more details.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - Calling this API does not change the capture state and the transmission state of the remote clients.
         *         - Calling this API does not cancel the subscription or change any subscription configuration.
         *         - To resume, call {@link resumeAllSubscribedStream resumeAllSubscribedStream}.
         *         - In a multi-room scenario, this API only pauses the reception of streams published in the current room.
         *
         */
        RTCRoom_1.prototype.pauseAllSubscribedStream = function (mediaType) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.pauseAllSubscribedStream(t_PauseResumeControlMediaType.ts_to_android(mediaType)));
            };
            var i = function () {
                return Number(_this._instance.pauseAllSubscribedStream(t_PauseResumeControlMediaType.ts_to_ios(mediaType)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Multi-room
         * @author shenpengliang
         * @brief Resume receiving remote media streams
         * @param mediaType Media stream type subscribed to. Refer to {@link PauseResumeControlMediaType PauseResumeControlMediaType} for more details.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *         - Calling this API does not change the capture state and the transmission state of the remote clients.
         *         - Calling this API does not change any subscription configuration.
         *
         */
        RTCRoom_1.prototype.resumeAllSubscribedStream = function (mediaType) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.resumeAllSubscribedStream(t_PauseResumeControlMediaType.ts_to_android(mediaType)));
            };
            var i = function () {
                return Number(_this._instance.resumeAllSubscribedStream(t_PauseResumeControlMediaType.ts_to_ios(mediaType)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Multi-room
         * @author shenpengliang
         * @brief Call to this method to stop relaying media stream to all rooms after calling {@link startForwardStreamToRooms startForwardStreamToRooms}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note
         *        - Call this method will trigger {@link onForwardStreamStateChanged onForwardStreamStateChanged}.
         *        - The other users in the room will receive callback of {@link onUserJoined onUserJoined} and {@link onUserPublishStream onUserPublishStream}{@link onUserPublishScreen /onUserPublishScreen} when you stop relaying.
         *        - To stop relaying media stream to specific rooms, call {@link updateForwardStreamToRooms updateForwardStreamToRooms} instead.
         *        - To resume the relaying in a short time, call {@link pauseForwardStreamToAllRooms pauseForwardStreamToAllRooms} instead and then call {@link resumeForwardStreamToAllRooms resumeForwardStreamToAllRooms} to recsume after that.
         *
         */
        RTCRoom_1.prototype.stopForwardStreamToRooms = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopForwardStreamToRooms()); };
            var i = function () { return Number(_this._instance.stopForwardStreamToRooms()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Multi-room
         * @author shenpengliang
         * @brief Call this method to pause relaying media stream to all rooms after calling {@link startForwardStreamToRooms startForwardStreamToRooms}. <br>
         *        After that, call {@link resumeForwardStreamToAllRooms resumeForwardStreamToAllRooms} to resume.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note The other users in the room will receive callback of {@link onUserUnpublishStream onUserUnpublishStream}{@link onUserUnpublishScreen /onUserUnpublishScreen} and {@link onUserLeave onUserLeave} when you pause relaying.
         *
         */
        RTCRoom_1.prototype.pauseForwardStreamToAllRooms = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.pauseForwardStreamToAllRooms()); };
            var i = function () { return Number(_this._instance.pauseForwardStreamToAllRooms()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Multi-room
         * @author shenpengliang
         * @brief Call this method to resume relaying to all rooms from the pause by calling {@link pauseForwardStreamToAllRooms pauseForwardStreamToAllRooms}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note The other users in the room will receive callback of {@link onUserJoined onUserJoined} and {@link onUserPublishStream onUserPublishStream}{@link onUserPublishScreen /onUserPublishScreen} when you resume relaying.
         *
         */
        RTCRoom_1.prototype.resumeForwardStreamToAllRooms = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.resumeForwardStreamToAllRooms()); };
            var i = function () { return Number(_this._instance.resumeForwardStreamToAllRooms()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Range Audio
         * @author luomingkang
         * @brief Gets range audio instance.
         * @return API call result: <br>
         *        - IRangeAudio: Success. You will get an {@link IRangeAudio IRangeAudio} returned from the SDK.
         *        - null: Failure. The current SDK does not offer range audio function.
         * @note The first time this API is called must be between you create a room and you actually enter the room. Refer to [Range Voice](https://docs.byteplus.com/byteplus-rtc/docs/114727) for more information.
         *
         */
        RTCRoom_1.prototype.getRangeAudio = function () {
            var _this = this;
            var a = function () { return packObject(_this._instance.getRangeAudio(), IRangeAudio); };
            var i = function () { return packObject(_this._instance.getRangeAudio(), IRangeAudio); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region  Spatial voice
         * @author wangjunzheng
         * @brief  Get location audio interface instances.
         * @return  Spatial audio management interface instance. If NULL is returned, spatial audio is not supported. See {@link ISpatialAudio ISpatialAudio}.
         * @note
         *        - The first time this API is called must be between you create a room and you actually enter the room.  Refer to [Spatial Audio](https://docs.byteplus.com/byteplus-rtc/docs/93903) for more information.
         *        - The spatial audio effect can only be turned on when using a device that supports true two-channel playback;
         *        - In the case of poor network conditions, even if this function is turned on, the spatial audio effect will not be generated;
         *        - Insufficient performance of the model may cause the audio card. When using a low-end machine, it is not recommended to turn on the spatial audio effect;
         *        - Spatial audio effects do not take effect when server level routing is enabled.
         *
         */
        RTCRoom_1.prototype.getSpatialAudio = function () {
            var _this = this;
            var a = function () { return packObject(_this._instance.getSpatialAudio(), ISpatialAudio); };
            var i = function () { return packObject(_this._instance.getSpatialAudio(), ISpatialAudio); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region  multi-room
         * @author zhangcaining
         * @brief  Adjusts the audio playback volume from all the remote users in a room.
         * @param volume Ratio(\%) of playback volume to original volume, in the range [0, 400], with overflow protection. <br>
         *               To ensure the audio quality, we recommend setting the volume to `100`. <br>
         *               - 0: mute
         *               - 100: original volume. Default value.
         *               - 400: Up to 4 times the original volume (with overflow protection)
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details
         * @note Suppose a remote user A is always within the range of the target user whose playback volume will be adjusted, <br>
         *        - If you use both this method and {@link setRemoteAudioPlaybackVolume setRemoteAudioPlaybackVolume}, the volume that the local user hears from user A is the volume set by the method called later.
         *        - If you use both this method and {@link setPlaybackVolume setPlaybackVolume}, the volume that the local user hears from user A is the overlay of both settings.
         *
         */
        RTCRoom_1.prototype.setRemoteRoomAudioPlaybackVolume = function (volume) {
            var _this = this;
            var a = function () { return Number(_this._instance.setRemoteRoomAudioPlaybackVolume(volume)); };
            var i = function () { return Number(_this._instance.setRemoteRoomAudioPlaybackVolume(volume)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.52
         * @detail api
         * @region Room Management
         * @author yejing.luna
         * @brief Set the priority of the local audio stream to be published.
         * @param audioSelectionPriority The priority of the local audio stream which defaults to be subscribable only up to the result of the Audio Selection. Refer to {@link AudioSelectionPriority AudioSelectionPriority}.
         * @note You must enable Audio Selection in the RTC console before using this API. You can call this API whether the user has joined a room. Refer to [Audio Selection](https://docs.byteplus.com/byteplus-rtc/docs/113547). <br>
         * The setting is independent in each room that the user joins.
         *
         */
        RTCRoom_1.prototype.setAudioSelectionConfig = function (audioSelectionPriority) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setAudioSelectionConfig(t_AudioSelectionPriority.ts_to_android(audioSelectionPriority)));
            };
            var i = function () {
                return Number(_this._instance.setAudioSelectionConfig(t_AudioSelectionPriority.ts_to_ios(audioSelectionPriority)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.52
         * @detail api
         * @region Room Management
         * @author lichangfeng.rtc
         * @brief Sets extra information about the room the local user joins.
         * @param key Key of the extra information, less than 10 bytes in length. <br>
         *        A maximum of 5 keys can exist in the same room, beyond which the first key will be replaced.
         * @param value Content of the extra information, less than 128 bytes in length.
         * @return API call result: <br>
         *        - 0: Success with a taskId returned.
         *        - <0: Failure. See {@link SetRoomExtraInfoResult SetRoomExtraInfoResult} for the reasons.
         * @note
         *        - Call {@link joinRoom joinRoom} first before you call this API to set extra information.
         *        - After calling this API, you will receive {@link onSetRoomExtraInfoResult onSetRoomExtraInfoResult} callback informing you the result of the setting.
         *        - After the extra information is successfully set, other users in the same room will receive the information through {@link onRoomExtraInfoUpdate onRoomExtraInfoUpdate} callback.
         *        - Users who join the room later will be notified of all extra information in the room set prior to entering.
         *
         */
        RTCRoom_1.prototype.setRoomExtraInfo = function (key, value) {
            var _this = this;
            var a = function () { return Number(_this._instance.setRoomExtraInfo(key, value)); };
            var i = function () { return Number(_this._instance.setRoomExtraInfo(key, value)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @hidden currently not available
         * @detail api
         * @region Subtitle translation service
         * @author qiaoxingwang
         * @brief Recognizes or translates the speech of all speakers in the room and converts the results into captions. <br>
         *        When calling this method, you can choose the subtitle mode in {@link SubtitleMode SubtitleMode}. If you choose the recognition mode, you will receive the {@link onSubtitleMessageReceived onSubtitleMessageReceived} callback which contains the transcribed text. <br>
         *        If you choose the translation mode, you will receive two {@link onSubtitleMessageReceived onSubtitleMessageReceived} callbacks simultaneously, one contains the transcribed text and the other contains the translated text. <br>
         *        After calling this method, you will receive the {@link onSubtitleStateChanged onSubtitleStateChanged} to inform you of whether subtitles are on.
         * @param subtitleConfig Subtitle configurations. Refer to {@link SubtitleConfig SubtitleConfig} for details.
         * @return
         *        -  0: Success.
         *        - !0: Failure.
         * @note
         *        - Call this method after joining the room.
         *        - You can set your source language to Chinese by calling `joinRoom` and importing a json formatted string `"source_language": "zh"` through the parameter of extraInfo, to English by importing `"source_language": "en"` , and to Japanese by importing `"source_language": "ja"` . If you don't set the source language, SDK will set the language of your system as the source language. If the language of your system is not Chinese, English or Japanese, SDK will set Chinese as the source language.
         *
         */
        RTCRoom_1.prototype.startSubtitle = function (subtitleConfig) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.startSubtitle(unpackObject(subtitleConfig)));
            };
            var i = function () {
                return Number(_this._instance.startSubtitle(unpackObject(subtitleConfig)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @hidden currently not available
         * @detail api
         * @region Subtitle translation service
         * @author qiaoxingwang
         * @brief Turns off subtitles. <br>
         *        After calling this method, you will receive the {@link onSubtitleStateChanged onSubtitleStateChanged} to inform you of whether subtitles are off.
         * @return
         *        -  0: Success.
         *        - !0: Failure.
         *
         */
        RTCRoom_1.prototype.stopSubtitle = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopSubtitle()); };
            var i = function () { return Number(_this._instance.stopSubtitle()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @valid since 3.53
         * @detail api
         * @author gechangwu
         * @brief Get room ID.
         * @return Room ID.
         *
         */
        RTCRoom_1.prototype.getRoomId = function () {
            var _this = this;
            var a = function () { return String(_this._instance.getRoomId()); };
            var i = function () { return String(_this._instance.getRoomId()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return RTCRoom_1;
    }());
    __setFunctionName(_classThis, "RTCRoom");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var ISingScoringManager = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function ISingScoringManager_1() {
        }
        ISingScoringManager_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        ISingScoringManager_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCSingScoringManager).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = ISingScoringManager$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author wangjunzheng
         * @brief Set the configuration of karaoke scoring.
         * @param config The parameters of karaoke scoring. See {@link SingScoringConfig SingScoringConfig}.
         * @return
         *        - 0：Success.
         *        - -1：Interface call failed.
         *        - -2： Karaoke scoring module not integrated.
         *        - >0： Other errors. For details, see[Error code].
         *
         */
        ISingScoringManager_1.prototype.setSingScoringConfig = function (config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setSingScoringConfig(unpackObject(config)));
            };
            var i = function () {
                return Number(_this._instance.setSingScoringConfig(unpackObject(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author wangjunzheng
         * @brief Start karaoke scoring.
         * @param position You can get the playback position where you start karaoke scoring. Unit: ms.
         * @param scoringInfoInterval Time interval between two real-time callbacks. Unit: ms; Default interval: 50 ms. Minimum interval: 20 ms.
         * @return
         *        - 0：Success.
         *        - -1：Interface call failed.
         *        - -2： Karaoke scoring module not integrated.
         *        - >0： Other error. For details, see[Error code].
         * @note
         *        - You can call this API after calling {@link initSingScoring initSingScoring} to initialize karaoke scoring.
         *        - After this interface is called, you will receive the scoring result {@link onCurrentScoringInfo onCurrentScoringInfo}  at set interval.
         *        - If you call the {@link startAudioMixing startAudioMixing} to play an audio file, call this interface after you receive {@link onAudioMixingStateChanged onAudioMixingStateChanged}(AUDIO_MIXING_STATE_PLAYING(1)).
         *
         */
        ISingScoringManager_1.prototype.startSingScoring = function (position, scoringInfoInterval) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.startSingScoring(position, scoringInfoInterval));
            };
            var i = function () {
                return Number(_this._instance.startSingScoring(position, scoringInfoInterval));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author wangjunzheng
         * @brief Stop karaoke scoring.
         * @return
         *        - 0：Success.
         *        - <0：Failure.
         *
         */
        ISingScoringManager_1.prototype.stopSingScoring = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopSingScoring()); };
            var i = function () { return Number(_this._instance.stopSingScoring()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author wangjunzheng
         * @brief Get the score for the previous lyric. You can call this API after {@link startSingScoring startSingScoring} is called.
         * @return
         *        - <0：Failed to get the score for the previous lyric.
         *        - >=0：The score for the previous lyric.
         *
         */
        ISingScoringManager_1.prototype.getLastSentenceScore = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.getLastSentenceScore()); };
            var i = function () { return Number(_this._instance.getLastSentenceScore()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author wangjunzheng
         * @brief Get the total score for the user's current performance.You can call this API after {@link startSingScoring startSingScoring} is called.
         * @return
         *        - <0：Failed to get the total score.
         *        - >=0：The current total score.
         *
         */
        ISingScoringManager_1.prototype.getTotalScore = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.getTotalScore()); };
            var i = function () { return Number(_this._instance.getTotalScore()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author wangjunzheng
         * @brief Get the average score for the user's current performance.
         * @return
         *        - <0：Failed to get the average score.
         *        - >=0：The average score.
         *
         */
        ISingScoringManager_1.prototype.getAverageScore = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.getAverageScore()); };
            var i = function () { return Number(_this._instance.getAverageScore()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return ISingScoringManager_1;
    }());
    __setFunctionName(_classThis, "ISingScoringManager");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IKTVManager = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IKTVManager_1() {
        }
        Object.defineProperty(IKTVManager_1.prototype, "ios_delegate", {
            /**
             * @platform ios
             */
            /**
             * @platform ios
             */
            get: function () {
                return this._instance.delegate;
            },
            set: function (value) {
                this._instance.delegate = value;
            },
            enumerable: false,
            configurable: true
        });
        IKTVManager_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        IKTVManager_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCKTVManager).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = IKTVManager$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @platform android
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Sets the KTV event handler.
         * @param ktvManagerEventHandler KTV event handler. See {@link IKTVManagerEventHandler IKTVManagerEventHandler}.
         *
         */
        IKTVManager_1.prototype.android_setKTVManagerEventHandler = function (ktvManagerEventHandler) {
            var _this = this;
            var $ = function () { return (_this._instance.setKTVManagerEventHandler(ktvManagerEventHandler), void 0); };
            return $();
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Sets the maximum cache for storing music files.
         * @param maxCacheSizeMB The maximum cache to be set in MB. <br>
         *        If the setting value is less than or equal to 0, it will be adjusted to 1,024 MB.
         *
         */
        IKTVManager_1.prototype.setMaxCacheSize = function (maxCacheSizeMB) {
            var _this = this;
            var a = function () { return (_this._instance.setMaxCacheSize(maxCacheSizeMB), void 0); };
            var i = function () { return (_this._instance.setMaxCacheSize(maxCacheSizeMB), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Gets music detail.
         * @param musicId Music ID.
         * @note After calling this API, you will receive the music detail through {@link onMusicDetailResult onMusicDetailResult} callback.
         *
         */
        IKTVManager_1.prototype.getMusicDetail = function (musicId) {
            var _this = this;
            var a = function () { return (_this._instance.getMusicDetail(musicId), void 0); };
            var i = function () { return (_this._instance.getMusicDetail(musicId), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Download music.
         * @param musicId Music ID.
         * @return Download task ID.
         * @note
         *       - If the music is successfully downloaded, you will receive {@link onDownloadSuccess onDownloadSuccess}.
         *       - If the music fails to download, you will receive {@link onDownloadFailed onDownloadFailed}.
         *       - When the music download progress is updated, you will receive {@link onDownloadMusicProgress onDownloadMusicProgress}.
         *
         */
        IKTVManager_1.prototype.downloadMusic = function (musicId) {
            var _this = this;
            var a = function () { return Number(_this._instance.downloadMusic(musicId)); };
            var i = function () { return Number(_this._instance.downloadMusic(musicId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Download lyrics.
         * @param musicId Music ID.
         * @param lyricType The lyrics file's format. See {@link DownloadLyricType DownloadLyricType}.
         * @return Download task ID.
         * @note
         *       - If the lyrics are successfully downloaded, you will receive {@link onDownloadSuccess onDownloadSuccess}.
         *       - If the lyrics fail to download, you will receive {@link onDownloadFailed onDownloadFailed}.
         *
         */
        IKTVManager_1.prototype.downloadLyric = function (musicId, lyricType) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.downloadLyric(musicId, t_DownloadLyricType.ts_to_android(lyricType)));
            };
            var i = function () {
                return Number(_this._instance.downloadLyric(musicId, t_DownloadLyricType.ts_to_ios(lyricType)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Download MIDI files.
         * @param musicId Music ID.
         * @return Download task ID.
         * @note
         *       - If the file is successfully downloaded, you will receive {@link onDownloadSuccess onDownloadSuccess}.
         *       - If the file fails to download, you will receive {@link onDownloadFailed onDownloadFailed}.
         *
         */
        IKTVManager_1.prototype.downloadMidi = function (musicId) {
            var _this = this;
            var a = function () { return Number(_this._instance.downloadMidi(musicId)); };
            var i = function () { return Number(_this._instance.downloadMidi(musicId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Cancels download task.
         * @param downloadId Download task ID.
         *
         */
        IKTVManager_1.prototype.cancelDownload = function (downloadId) {
            var _this = this;
            var a = function () { return (_this._instance.cancelDownload(downloadId), void 0); };
            var i = function () { return (_this._instance.cancelDownload(downloadId), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Clear music cache, including music and lyrics.
         *
         */
        IKTVManager_1.prototype.clearCache = function () {
            var _this = this;
            var a = function () { return (_this._instance.clearCache(), void 0); };
            var i = function () { return (_this._instance.clearCache(), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @author lihuan.wuti2ha
         * @brief Gets the KTV player.
         * @return KTV player interfaces. See {@link IKTVPlayer IKTVPlayer}.
         *
         */
        IKTVManager_1.prototype.getKTVPlayer = function () {
            var _this = this;
            var a = function () { return packObject(_this._instance.getKTVPlayer(), IKTVPlayer); };
            var i = function () { return packObject(_this._instance.getKTVPlayer(), IKTVPlayer); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return IKTVManager_1;
    }());
    __setFunctionName(_classThis, "IKTVManager");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IRangeAudio = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IRangeAudio_1() {
        }
        IRangeAudio_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        IRangeAudio_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCRangeAudio).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = IRangeAudio$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Range Audio
         * @author chuzhongtao
         * @brief Enable/disable the range audio function. <br>
         *        Range audio means that within a certain range in a same RTC room, the audio volume of the remote user received by the local user will be amplified/attenuated as the remote user moves closer/away. The audio coming from out of the range cannot be heard. See {@link updateReceiveRange updateReceiveRange} to set audio receiving range.
         * @param enable Whether to enable audio range function： <br>
         *        - true: Enable
         *        - false: Disable（Defaulting setting）
         * @note You can call this API anytime before or after entering a room. To ensure a smooth switch to the range audio mode after entering the room, you need to call {@link updatePosition updatePosition} before this API to set your own position coordinates, and then enable the range audio function.
         *
         */
        IRangeAudio_1.prototype.enableRangeAudio = function (enable) {
            var _this = this;
            var a = function () { return (_this._instance.enableRangeAudio(enable), void 0); };
            var i = function () { return (_this._instance.enableRangeAudio(enable), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Range Audio
         * @author chuzhongtao
         * @brief Updates the coordinate of the local user's position in the rectangular coordinate system in the current room.
         * @param pos 3D coordinate values, the default value is [0, 0, 0], see [Position](70083#position-2).
         * @return API call result: <br>
         *        - 0: Success
         *        - !0: Failure
         * @note
         *        - After calling this API, you should call {@link enableRangeAudio enableRangeAudio} to enable range audio function to actually enjoy the range audio effect.
         *
         */
        IRangeAudio_1.prototype.updatePosition = function (pos) {
            var _this = this;
            var a = function () { return Number(_this._instance.updatePosition(unpackObject(pos))); };
            var i = function () {
                return Number(_this._instance.updatePosition(unpackObject(pos)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Range Audio
         * @author chuzhongtao
         * @brief Updates the audio receiving range for the local user.
         * @param range Audio receiving range, see {@link ReceiveRange ReceiveRange}.
         * @return API call result: <br>
         *        - 0: Success
         *        - !0: Failure
         *
         */
        IRangeAudio_1.prototype.updateReceiveRange = function (range) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.updateReceiveRange(unpackObject(range)));
            };
            var i = function () {
                return Number(_this._instance.updateReceiveRange(unpackObject(range)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Range Audio
         * @author huangshouqin
         * @brief Set the volume roll-off mode that a 3D sound has in an audio source when using the Range Audio feature.
         * @param type Volume roll-off mode. It is linear roll-off mode by default. Refer to {@link AttenuationType AttenuationType} for more details.
         * @param coefficient Coefficient for the exponential roll-off mode. The default value is 1. It ranges [0.1,100]. We recommended to set it to `50`. The volume roll-off speed gets faster as this value increases.
         * @return Result of the call <br>
         *         - `0`: Success
         *         - `-1`: Failure because of calling this API before the user has joined a room or before enabling the Range Audio feature by calling {@link enableRangeAudio enableRangeAudio}.
         * @note Call {@link updateReceiveRange updateReceiveRange} to set the range outside which the volume of the sound does not attenuate.
         *
         */
        IRangeAudio_1.prototype.setAttenuationModel = function (type, coefficient) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setAttenuationModel(t_AttenuationType.ts_to_android(type), coefficient));
            };
            var i = function () {
                return Number(_this._instance.setAttenuationModel(t_AttenuationType.ts_to_ios(type), coefficient));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @region Range Audio
         * @author chuzhongtao
         * @brief Set the flags to mark the user groups, within which the users talk without attenuation. <br>
         *        In the RTC room, if the flags of the users intersects with each other, the users talk without attenuation. <br>
         *        For example, the user is a member of multiple teams, and teammates of the same team talks without attentuation. You can set the flag for each team, and includes the flags of the user's teams in the user's flags.
         * @param flags Array of flags.
         *
         */
        IRangeAudio_1.prototype.setNoAttenuationFlags = function (flags) {
            var _this = this;
            var a = function () { return (_this._instance.setNoAttenuationFlags(flags), void 0); };
            var i = function () { return (_this._instance.setNoAttenuationFlags(flags), void 0); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return IRangeAudio_1;
    }());
    __setFunctionName(_classThis, "IRangeAudio");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IAudioMixingManager = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IAudioMixingManager_1() {
        }
        IAudioMixingManager_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        IAudioMixingManager_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCAudioMixingManager).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = IAudioMixingManager$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return IAudioMixingManager_1;
    }());
    __setFunctionName(_classThis, "IAudioMixingManager");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IMediaPlayer = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IMediaPlayer_1() {
        }
        IMediaPlayer_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        IMediaPlayer_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCMediaPlayer).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = IMediaPlayer$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Open the audio file. <br>
         *        You can only open one audio file with one player instance at the same time. For multiple audio files at the same time, create multiple player instances. <br>
         *        For audio file in PCM format, see {@link openWithCustomSource openWithCustomSource}. `openWithCustomSource` and this API are mutually exclusive.
         * @param filePath Audio file paths. <br>
         *        URL of online file, URI of local file, full path to local file, or path to local file starting with `/assets/` are supported. For URL of online file, only the https protocol is supported. <br>
         *        Recommended sample rate for audio effect files: 8KHz、16KHz、22.05KHz、44.1KHz、48KHz. <br>
         *        Local audio effect file formats supported by different platforms: <br>
         *        <table>
         *           <tr><th></th><th>mp3</th><th>mp4</th><th>aac</th><th>m4a</th><th>3gp</th><th>wav</th><th>ogg</th><th>ts</th><th>wma</th></tr>
         *           <tr><td>Android</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td></td><td></td></tr>
         *           <tr><td>iOS/macOS</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td></td><td></td><td></td></tr>
         *           <tr><td>Windows</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td></td><td>Y</td><td>Y</td></tr>
         *        </table>
         *        Online audio effect file formats supported by different platforms. <br>
         *        <table>
         *           <tr><th></th><th>mp3</th><th>mp4</th><th>aac</th><th>m4a</th><th>3gp</th><th>wav</th><th>ogg</th><th>ts</th><th>wma</th></tr>
         *           <tr><td>Android</td><td>Y</td><td></td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td></td><td></td><td></td></tr>
         *           <tr><td>iOS/macOS</td><td>Y</td><td></td><td>Y</td><td>Y</td><td></td><td>Y</td><td></td><td></td><td></td></tr>
         *           <tr><td>Windows</td><td>Y</td><td></td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td></td><td>Y</td><td>Y</td></tr>
         *        </table>
         * @param config See {@link MediaPlayerConfig MediaPlayerConfig}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         *
         */
        IMediaPlayer_1.prototype.open = function (filePath, config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.open(filePath, unpackObject(config)));
            };
            var i = function () {
                return Number(_this._instance.open(filePath, unpackObject(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Start playing the audio. Call this API when you call {@link open open} and set `AutoPlay=False`.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         * - For audio file in PCM format, see {@link openWithCustomSource openWithCustomSource}. `openWithCustomSource` and this API are mutually exclusive.
         * - After calling this API, call {@link stop stop} to stop playing the audio file.
         *
         */
        IMediaPlayer_1.prototype.start = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.start()); };
            var i = function () { return Number(_this._instance.start()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Enable audio mixing with audio raw data. <br>
         *        To open the audio file, see {@link open open}. `open` and this API are mutually exclusive.
         * @param source See {@link MediaPlayerCustomSource MediaPlayerCustomSource}.
         * @param config See {@link MediaPlayerConfig MediaPlayerConfig}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *       - After calling this API, you must call {@link pushExternalAudioFrame pushExternalAudioFrame} to push audio data and start the audio mixing.
         *       - To stop the raw data audio mixing, call {@link stop stop}.
         *
         */
        IMediaPlayer_1.prototype.openWithCustomSource = function (source, config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.openWithCustomSource(unpackObject(source), unpackObject(config)));
            };
            var i = function () {
                return Number(_this._instance.openWithCustomSource(unpackObject(source), unpackObject(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief After calling {@link open open}, {@link start start}, or {@link openWithCustomSource openWithCustomSource} to start audio mixing, call this method to stop audio mixing.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         *
         */
        IMediaPlayer_1.prototype.stop = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stop()); };
            var i = function () { return Number(_this._instance.stop()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief After calling {@link open open}, or {@link start start} to start audio mixing, call this API to pause audio mixing.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *        - After calling this API to pause audio mixing, call {@link resume resume} to resume audio mixing.
         *        - The API is valid for audio file, not PCM data.
         *
         */
        IMediaPlayer_1.prototype.pause = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.pause()); };
            var i = function () { return Number(_this._instance.pause()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief After calling {@link pause pause} to pause audio mixing, call this API to resume audio mixing.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note The API is valid for audio file, not PCM data.
         *
         */
        IMediaPlayer_1.prototype.resume = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.resume()); };
            var i = function () { return Number(_this._instance.resume()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Adjusts the volume of the specified audio mixing, including media file mixing and PCM mixing.
         * @param volume The ratio of the volume to the original volume in \% with overflow protection. The range is `[0, 400]` and the recommended range is `[0, 100]`.
         * @param type See {@link AudioMixingType AudioMixingType}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note Call this API only when audio is mixing.
         *
         */
        IMediaPlayer_1.prototype.setVolume = function (volume, type) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setVolume(volume, t_AudioMixingType.ts_to_android(type)));
            };
            var i = function () {
                return Number(_this._instance.setVolume(volume, t_AudioMixingType.ts_to_ios(type)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Gets the current volume.
         * @param type See {@link AudioMixingType AudioMixingType}.
         * @return
         *        - >0: Success, the current volume.
         *        - < 0: Failed.
         * @note Call this API only when audio is mixing, including media file mixing and PCM mixing.
         *
         */
        IMediaPlayer_1.prototype.getVolume = function (type) {
            var _this = this;
            var a = function () { return Number(_this._instance.getVolume(t_AudioMixingType.ts_to_android(type))); };
            var i = function () { return Number(_this._instance.getVolume(t_AudioMixingType.ts_to_ios(type))); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Gets the duration of the media file.
         * @return
         *        - >0: Success, the duration of the media file in milliseconds.
         *        - < 0: Failed.
         * @note
         *        - Call this API only when audio is mixing.
         *        - The API is valid for audio file, not PCM data.
         *
         */
        IMediaPlayer_1.prototype.getTotalDuration = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.getTotalDuration()); };
            var i = function () { return Number(_this._instance.getTotalDuration()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Gets the actual playback duration of the mixed media file, in milliseconds.
         * @return
         *        - >0: Success, the actual playback time.
         *        - < 0: Failed.
         * @note
         *        - The actual playback time refers to the playback time of the song without being affected by stop, jump, double speed, and freeze. For example, if the song stops playing for 30 seconds at 1:30 or skips to 2:00, and then continues to play normally for 2 minutes, the actual playing time is 3 minutes and 30 seconds.
         *        - Call this API only when audio is mixing and the interval set by {@link setProgressInterval setProgressInterval} is above `0`.
         *        - The API is valid for audio file, not PCM data.
         *
         */
        IMediaPlayer_1.prototype.getPlaybackDuration = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.getPlaybackDuration()); };
            var i = function () { return Number(_this._instance.getPlaybackDuration()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Gets the playback progress of the media file.
         * @return
         *        - >0: Success, the playback progress of media file in ms.
         *        - < 0: Failed.
         * @note
         *        - Call this API only when audio is mixing.
         *        - The API is valid for audio file, not PCM data.
         *
         */
        IMediaPlayer_1.prototype.getPosition = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.getPosition()); };
            var i = function () { return Number(_this._instance.getPosition()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Set the pitch of the local audio file mixing. Usually used in karaoke scenes.
         * @param pitch The increase or decrease value compared with the original pitch of the music file. The range is `[-12, 12]`. The default value is 0. The pitch distance between two adjacent values is half a step. A positive value indicates a rising pitch, and a negative value indicates a falling pitch.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *        - Call this API only when audio is mixing.
         *        - Support audio file only and not PCM data.
         *
         */
        IMediaPlayer_1.prototype.setAudioPitch = function (pitch) {
            var _this = this;
            var a = function () { return Number(_this._instance.setAudioPitch(pitch)); };
            var i = function () { return Number(_this._instance.setAudioPitch(pitch)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Sets the starting playback position of the media file.
         * @param position The starting position of the media file in milliseconds. <br>
         *        You can get the total duration of the media file through {@link getTotalDuration getTotalDuration}. The value of position should be less than the total duration of the media file.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *        - The API is valid for audio file, not PCM data.
         *        - When playing online files, calling this API may cause playback delay.
         *
         */
        IMediaPlayer_1.prototype.setPosition = function (position) {
            var _this = this;
            var a = function () { return Number(_this._instance.setPosition(position)); };
            var i = function () { return Number(_this._instance.setPosition(position)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Sets the channel mode of the mixing of the media file.
         * @param mode The mode of channel. The default channel mode is the same as the source file. See {@link AudioMixingDualMonoMode AudioMixingDualMonoMode}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *       - Call this API only when audio is mixing.
         *       - Audio file is supported, but not PCM data.
         *
         */
        IMediaPlayer_1.prototype.setAudioDualMonoMode = function (mode) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setAudioDualMonoMode(t_AudioMixingDualMonoMode.ts_to_android(mode)));
            };
            var i = function () {
                return Number(_this._instance.setAudioDualMonoMode(t_AudioMixingDualMonoMode.ts_to_ios(mode)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Gets the track count of the current media file.
         * @return + >= 0：Success. Return the track count of the current media file.
         *         - < 0：Failed.
         * @note
         *       - Call this API only when audio is mixing.
         *       - This API is valid for audio file, not PCM data.
         *
         */
        IMediaPlayer_1.prototype.getAudioTrackCount = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.getAudioTrackCount()); };
            var i = function () { return Number(_this._instance.getAudioTrackCount()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Specifies the playback track of the current media file.
         * @param index The specified playback audio track, starting from 0, and the range is `[0, getAudioTrackCount()-1]`. The value must be less than the return value of {@link getAudioTrackCount getAudioTrackCount}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *       - Call this API only when audio is mixing.
         *       - This API is valid for audio file, not PCM data.
         *
         */
        IMediaPlayer_1.prototype.selectAudioTrack = function (index) {
            var _this = this;
            var a = function () { return Number(_this._instance.selectAudioTrack(index)); };
            var i = function () { return Number(_this._instance.selectAudioTrack(index)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Set the playback speed of the audio file.
         * @param speed The ratio of the actual playback speed than that of the original speed of the audio file in \%. The range is `[50,200]`. The default value is 100.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *       - Call this API only when audio is mixing.
         *       - The API is valid for audio file and not PCM data.
         *
         */
        IMediaPlayer_1.prototype.setPlaybackSpeed = function (speed) {
            var _this = this;
            var a = function () { return Number(_this._instance.setPlaybackSpeed(speed)); };
            var i = function () { return Number(_this._instance.setPlaybackSpeed(speed)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Set the interval of the periodic callback {@link onMediaPlayerPlayingProgress onMediaPlayerPlayingProgress} during audio mixing.
         * @param interval interval in ms. <br>
         *       - interval > 0: The callback is enabled. The actual interval is `10*(mod(10)+1)`.
         *       - interval <= 0: The callback is disabled.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *       - Call this API only when audio is mixing.
         *       - This API is valid for audio file, not PCM data.
         *
         */
        IMediaPlayer_1.prototype.setProgressInterval = function (interval) {
            var _this = this;
            var a = function () { return Number(_this._instance.setProgressInterval(interval)); };
            var i = function () { return Number(_this._instance.setProgressInterval(interval)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief To call {@link enableVocalInstrumentBalance enableVocalInstrumentBalance} to adjust the volume of the mixed media file or the PCM audio data, you must pass in its original loudness through this API.
         * @param loudness Original loudness in lufs. The range is `[-70.0, 0.0]`. <br>
         *       When the value is less than -70.0lufs, it will be adjusted to -70.0lufs by default, and if it is more than 0.0lufs, the loudness will not be equalized. The default value is 1.0lufs, which means no processing.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *       - Call this API only when audio is mixing.
         *       - The API is valid for audio file and PCM data.
         *
         */
        IMediaPlayer_1.prototype.setLoudness = function (loudness) {
            var _this = this;
            var a = function () { return Number(_this._instance.setLoudness(loudness)); };
            var i = function () { return Number(_this._instance.setLoudness(loudness)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Register an observer to receive related callbacks when the local media file is mixing.
         * @param observer See {@link IMediaPlayerAudioFrameObserver IMediaPlayerAudioFrameObserver}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note The API is valid for audio file, not PCM data.
         *
         */
        IMediaPlayer_1.prototype.registerAudioFrameObserver = function (observer) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.registerAudioFrameObserver(packObject(observer, android_IMediaPlayerAudioFrameObserver)));
            };
            var i = function () {
                return Number(_this._instance.registerAudioFrameObserver(packObject(observer, ios_IMediaPlayerAudioFrameObserver)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Push PCM audio frame data for mixing.
         * @param audioFrame See {@link AudioFrame AudioFrame}. <br>
         *                   - The audio sampling format must be S16. The data format within the audio buffer must be PCM, and its capacity size should be `audioFrame.samples × audioFrame.channel × 2`.
         *                   - A specific sample rate and the number of channels must be specified. Setting them to automatic is not supported.
         * @return
         *       - 0: Success.
         *       - < 0: Failed.
         * @note
         *      - Before calling this method, the raw audio data mixing must be enabled through {@link openWithCustomSource openWithCustomSource}.
         *      - Suggestions: Before pushing data for the first time, please cache a certain amount of data (like 200 ms) on the application side, and then push it at once. Schedule subsequent push operation every 10 ms with audio data of 10 ms.
         *      - To pause the playback, just pause the push.
         *
         */
        IMediaPlayer_1.prototype.pushExternalAudioFrame = function (audioFrame) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.pushExternalAudioFrame(unpackObject(audioFrame)));
            };
            var i = function () {
                return Number(_this._instance.pushExternalAudioFrame(unpackObject(audioFrame)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Set the event handler.
         * @param handler See {@link IMediaPlayerEventHandler IMediaPlayerEventHandler}.
         * @return
         *        - 0: Success.
         *        - < 0: Failed.
         *
         */
        IMediaPlayer_1.prototype.setEventHandler = function (handler) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setEventHandler(packObject(handler, android_IMediaPlayerEventHandler)));
            };
            var i = function () {
                return Number(_this._instance.setEventHandler(packObject(handler, ios_IMediaPlayerEventHandler)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return IMediaPlayer_1;
    }());
    __setFunctionName(_classThis, "IMediaPlayer");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();
var IAudioEffectPlayer = function () {
    var _classDecorators = [PackClass()];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    _classThis = /** @class */ (function () {
        function IAudioEffectPlayer_1() {
        }
        IAudioEffectPlayer_1.prototype.__init = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            this._instance = this.__new_instance.apply(this, args);
        };
        IAudioEffectPlayer_1.prototype.__new_instance = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var i = function () {
                var _a;
                return new ((_a = ByteRTCAudioEffectPlayer).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var a = function () {
                var _a;
                return new ((_a = IAudioEffectPlayer$1).bind.apply(_a, __spreadArray([void 0], args, false)))();
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Starts to play the audio effect file. <br>
         *        This API can be called multiple times with different IDs and filepaths for multiple effects at the same time.
         * @param effectId Audio effect ID. Used for identifying the audio effect, please ensure that the audio effect ID is unique. <br>
         *        If this API is called repeatedly with the same ID, the previous effect will stop and the next effect will start, and you'll receive {@link onAudioEffectPlayerStateChanged onAudioEffectPlayerStateChanged}.
         * @param filePath Audio effect file paths. <br>
         *        URL of online file, URI of local file, full path to local file, or path to local file starting with `/assets/` are supported. For URL of online file, only the https protocol is supported. <br>
         *        Recommended sample rate for audio effect files: 8KHz、16KHz、22.05KHz、44.1KHz、48KHz. <br>
         *        Local audio effect file formats supported by different platforms: <br>
         *        <table>
         *           <tr><th></th><th>mp3</th><th>mp4</th><th>aac</th><th>m4a</th><th>3gp</th><th>wav</th><th>ogg</th><th>ts</th><th>wma</th></tr>
         *           <tr><td>Android</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td></td><td></td></tr>
         *           <tr><td>iOS/macOS</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td></td><td></td><td></td></tr>
         *           <tr><td>Windows</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td></td><td>Y</td><td>Y</td></tr>
         *        </table>
         *        Online audio effect file formats supported by different platforms. <br>
         *        <table>
         *           <tr><th></th><th>mp3</th><th>mp4</th><th>aac</th><th>m4a</th><th>3gp</th><th>wav</th><th>ogg</th><th>ts</th><th>wma</th></tr>
         *           <tr><td>Android</td><td>Y</td><td></td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td></td><td></td><td></td></tr>
         *           <tr><td>iOS/macOS</td><td>Y</td><td></td><td>Y</td><td>Y</td><td></td><td>Y</td><td></td><td></td><td></td></tr>
         *           <tr><td>Windows</td><td>Y</td><td></td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td></td><td>Y</td><td>Y</td></tr>
         *        </table>
         * @param config See {@link AudioEffectPlayerConfig AudioEffectPlayerConfig}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *       - If the file has been loaded into memory via {@link preload preload}, make sure that the ID here is the same as the ID set by {@link preload preload}.
         *       - After starting to play an audio effect file, you can call the {@link stop stop} API to stop playing the audio effect file.
         *
         */
        IAudioEffectPlayer_1.prototype.start = function (effectId, filePath, config) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.start(effectId, filePath, unpackObject(config)));
            };
            var i = function () {
                return Number(_this._instance.start(effectId, filePath, unpackObject(config)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Stops the playback of audio effect files.
         * @param effectId Audio effect ID
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *       - After calling the {@link start start} API to start playing the audio effect file, you can call this API to stop playing the audio effect file.
         *       - After calling this API to stop playing an audio effect file, the audio effect file will be unloaded automatically.
         *
         */
        IAudioEffectPlayer_1.prototype.stop = function (effectId) {
            var _this = this;
            var a = function () { return Number(_this._instance.stop(effectId)); };
            var i = function () { return Number(_this._instance.stop(effectId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Stops playback of all audio effect files.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *       - After calling {@link start start} to start playing audio effect files, you can call this API to stop playing all audio effect files.
         *       - After calling this API to stop playing all audio effect files, the audio effect files will be unloaded automatically.
         *
         */
        IAudioEffectPlayer_1.prototype.stopAll = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.stopAll()); };
            var i = function () { return Number(_this._instance.stopAll()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Preloads specified music files into memory to avoid repeated loading when playing the same file frequently and reduce CPU usage.
         * @param effectId Audio effect ID。Used for identifying the audio effect. Please ensure that the audio effect ID is unique. <br>
         *        If this API is called repeatedly with the same ID, the later one will overwrite the previous one. <br>
         *        If you call {@link start start} first and then call this API with the same ID, the SDK will stop the previous effect and then load the next one, and you will receive {@link onAudioEffectPlayerStateChanged onAudioEffectPlayerStateChanged}. <br>
         *        After calling this API to preload A.mp3, if you need to call {@link start start} to play B.mp3 with the same ID, please call {@link unload unload} to unload A.mp3 first, otherwise SDK will report an error AUDIO_MIXING_ERROR_LOAD_CONFLICT.
         * @param filePath The filepath of effect file. URI of local file, full path to local file, or path to local files starting with `/assets/` are supported. <br>
         *        The length of the pre-loaded file must not exceed 20s. <br>
         *        Audio effect file formats supported are the same as {@link start start}.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *       - This API just preloads the specified audio effect file, and only calls the {@link start start} API to start playing the specified audio effect file.
         *       - The specified audio effect file preloaded by calling this API can be unloaded by {@link unload unload}.
         *
         */
        IAudioEffectPlayer_1.prototype.preload = function (effectId, filePath) {
            var _this = this;
            var a = function () { return Number(_this._instance.preload(effectId, filePath)); };
            var i = function () { return Number(_this._instance.preload(effectId, filePath)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Unloads the specified audio effect file.
         * @param effectId Audio effect ID
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note Call this API after {@link start start} or {@link preload preload}.
         *
         */
        IAudioEffectPlayer_1.prototype.unload = function (effectId) {
            var _this = this;
            var a = function () { return Number(_this._instance.unload(effectId)); };
            var i = function () { return Number(_this._instance.unload(effectId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Unloads all audio effect files.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         *
         */
        IAudioEffectPlayer_1.prototype.unloadAll = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.unloadAll()); };
            var i = function () { return Number(_this._instance.unloadAll()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Pauses the playback of audio effect files.
         * @param effectId Audio effect ID
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *       - After calling the {@link start start} API to start playing the audio effect file, you can pause the audio effect file by calling this API.
         *       - After calling this API to pause the audio effect file, you can call the {@link resume resume} API to resume playback.
         *
         */
        IAudioEffectPlayer_1.prototype.pause = function (effectId) {
            var _this = this;
            var a = function () { return Number(_this._instance.pause(effectId)); };
            var i = function () { return Number(_this._instance.pause(effectId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Pauses the Playback of all audio effect files.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *       - After calling the {@link start start} API to start playing audio effect files, you can pause playing all audio effect files by calling this API.
         *       - After calling this API to pause the playback of all audio effect files, you can call the {@link resumeAll resumeAll} API to resume all playback.
         *
         */
        IAudioEffectPlayer_1.prototype.pauseAll = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.pauseAll()); };
            var i = function () { return Number(_this._instance.pauseAll()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Resumes the playback of audio effect files.
         * @param effectId Audio effect ID
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note After calling the {@link pause pause} API to pause the audio effect file, you can resume playback by calling this API.
         *
         */
        IAudioEffectPlayer_1.prototype.resume = function (effectId) {
            var _this = this;
            var a = function () { return Number(_this._instance.resume(effectId)); };
            var i = function () { return Number(_this._instance.resume(effectId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Resumes the playback of all audio effect files.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note After calling the {@link pauseAll pauseAll} API to pause all the audio effect files being played, you can resume playback by calling this API.
         *
         */
        IAudioEffectPlayer_1.prototype.resumeAll = function () {
            var _this = this;
            var a = function () { return Number(_this._instance.resumeAll()); };
            var i = function () { return Number(_this._instance.resumeAll()); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Sets the start position of the audio effect file.
         * @param effectId Audio effect ID
         * @param position The starting playback position of the audio effect file in milliseconds. <br>
         *        You can get the total duration of the audio effect file by calling {@link getDuration getDuration}, the value of position should be less than the total duration of the audio effect file.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note
         *        - When playing online files, calling this API may cause a delay in playback.
         *        - Call this API after {@link start start}.
         *
         */
        IAudioEffectPlayer_1.prototype.setPosition = function (effectId, position) {
            var _this = this;
            var a = function () { return Number(_this._instance.setPosition(effectId, position)); };
            var i = function () { return Number(_this._instance.setPosition(effectId, position)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Gets the current position of audio effect file playback.
         * @param effectId  Audio effect ID
         * @return
         *        - >0: Success, the current progress of audio effect file playback in milliseconds.
         *        - < 0: Failure.
         * @note
         *        - When playing online files, calling this API may cause a delay in playback.
         *        - Call this API after {@link start start}.
         *
         */
        IAudioEffectPlayer_1.prototype.getPosition = function (effectId) {
            var _this = this;
            var a = function () { return Number(_this._instance.getPosition(effectId)); };
            var i = function () { return Number(_this._instance.getPosition(effectId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Adjusts the volume level of a specified audio effect, including audio effect file and PCM effect.
         * @param effectId Audio effect ID
         * @param volume The ratio of the volume to the original volume in \% with overflow protection. The range is `[0, 400]` and the recommended range is `[0, 100]`.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note Call this API after {@link start start}.
         *
         */
        IAudioEffectPlayer_1.prototype.setVolume = function (effectId, volume) {
            var _this = this;
            var a = function () { return Number(_this._instance.setVolume(effectId, volume)); };
            var i = function () { return Number(_this._instance.setVolume(effectId, volume)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Sets the volume of all audio effect, including audio effect files and PCM effects.
         * @param volume The ratio of the volume to the original volume in \% with overflow protection. The range is `[0, 400]` and the recommended range is `[0, 100]`.
         * @return
         *        - 0: Success.
         *        - < 0 : Fail. See {@link ReturnStatus ReturnStatus} for more details.
         * @note This API has a lower priority than {@link setVolume setVolume}, i.e. the volume of the audio effect set by {@link setVolume setVolume} is not affected by this API.
         *
         */
        IAudioEffectPlayer_1.prototype.setVolumeAll = function (volume) {
            var _this = this;
            var a = function () { return Number(_this._instance.setVolumeAll(volume)); };
            var i = function () { return Number(_this._instance.setVolumeAll(volume)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Gets the current volume.
         * @param effectId  Audio effect ID
         * @return
         *        - >0: Success, the current volume value.
         *        - < 0: Failed.
         * @note Call this API after {@link start start}.
         *
         */
        IAudioEffectPlayer_1.prototype.getVolume = function (effectId) {
            var _this = this;
            var a = function () { return Number(_this._instance.getVolume(effectId)); };
            var i = function () { return Number(_this._instance.getVolume(effectId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Get the duration of the audio effect file.
         * @param effectId  Audio effect ID
         * @return
         *        - >0: Success, the duration of the audio effect file in milliseconds.
         *        - < 0: failed.
         * @note Call this API after {@link start start}.
         *
         */
        IAudioEffectPlayer_1.prototype.getDuration = function (effectId) {
            var _this = this;
            var a = function () { return Number(_this._instance.getDuration(effectId)); };
            var i = function () { return Number(_this._instance.getDuration(effectId)); };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        /** {en}
         * @detail api
         * @brief Set the event handler.
         * @param handler See {@link IAudioEffectPlayerEventHandler IAudioEffectPlayerEventHandler}.
         * @return
         *        - 0: Success.
         *        - < 0: Failed.
         *
         */
        IAudioEffectPlayer_1.prototype.setEventHandler = function (handler) {
            var _this = this;
            var a = function () {
                return Number(_this._instance.setEventHandler(packObject(handler, android_IAudioEffectPlayerEventHandler)));
            };
            var i = function () {
                return Number(_this._instance.setEventHandler(packObject(handler, ios_IAudioEffectPlayerEventHandler)));
            };
            var $os = env.getOS();
            if ($os === 'android') {
                return a();
            }
            else if ($os === 'ios') {
                return i();
            }
            else {
                throw new Error('Not Support Platform ' + $os);
            }
        };
        return IAudioEffectPlayer_1;
    }());
    __setFunctionName(_classThis, "IAudioEffectPlayer");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();

var VertcVod$1 = function () {
    var _classDecorators = [NativeClass('com.volcengine.reactnative.vertc.vod.VertcVod')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _startVodPlayerCapture_decorators;
    var _stopVodPlayerCapture_decorators;
    _classThis = /** @class */ (function () {
        function VertcVod_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        VertcVod_1.prototype.startVodPlayerCapture = function (video, player, streamIndex) {
            throw new Error('not implement');
        };
        VertcVod_1.prototype.stopVodPlayerCapture = function (video) {
            throw new Error('not implement');
        };
        return VertcVod_1;
    }());
    __setFunctionName(_classThis, "VertcVod");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _startVodPlayerCapture_decorators = [NativeMethod()];
        _stopVodPlayerCapture_decorators = [NativeMethod()];
        __esDecorate(_classThis, null, _startVodPlayerCapture_decorators, { kind: "method", name: "startVodPlayerCapture", static: false, private: false, access: { has: function (obj) { return "startVodPlayerCapture" in obj; }, get: function (obj) { return obj.startVodPlayerCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopVodPlayerCapture_decorators, { kind: "method", name: "stopVodPlayerCapture", static: false, private: false, access: { has: function (obj) { return "stopVodPlayerCapture" in obj; }, get: function (obj) { return obj.stopVodPlayerCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();

var VertcVod = function () {
    var _classDecorators = [NativeClass('VertcVod')];
    var _classDescriptor;
    var _classExtraInitializers = [];
    var _classThis;
    var _instanceExtraInitializers = [];
    var _init_decorators;
    var _startVodPlayerCapture_decorators;
    var _stopVodPlayerCapture_decorators;
    _classThis = /** @class */ (function () {
        function VertcVod_1() {
            __runInitializers(this, _instanceExtraInitializers);
        }
        VertcVod_1.prototype.init = function () {
            throw new Error('not implement');
        };
        VertcVod_1.prototype.startVodPlayerCapture = function (video, player, options) {
            throw new Error('not implement');
        };
        VertcVod_1.prototype.stopVodPlayerCapture = function (video) {
            throw new Error('not implement');
        };
        return VertcVod_1;
    }());
    __setFunctionName(_classThis, "VertcVod");
    (function () {
        var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
        _init_decorators = [NativeMethodSync('init')];
        _startVodPlayerCapture_decorators = [NativeMethod('startVodPlayerCapture:player:options:')];
        _stopVodPlayerCapture_decorators = [NativeMethod('stopVodPlayerCapture:')];
        __esDecorate(_classThis, null, _init_decorators, { kind: "method", name: "init", static: false, private: false, access: { has: function (obj) { return "init" in obj; }, get: function (obj) { return obj.init; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _startVodPlayerCapture_decorators, { kind: "method", name: "startVodPlayerCapture", static: false, private: false, access: { has: function (obj) { return "startVodPlayerCapture" in obj; }, get: function (obj) { return obj.startVodPlayerCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _stopVodPlayerCapture_decorators, { kind: "method", name: "stopVodPlayerCapture", static: false, private: false, access: { has: function (obj) { return "stopVodPlayerCapture" in obj; }, get: function (obj) { return obj.stopVodPlayerCapture; } }, metadata: _metadata }, null, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
}();

extendsClassMethod(RTCVideo, 'feedback', function () {
    return function impl(options, info) {
        var _this = this;
        var a = function () {
            var roomInfo = new ProblemFeedbackRoomInfo$1(info.roomId, info.userId);
            var feedbackInfo = new ProblemFeedbackInfo$1(info.desc);
            feedbackInfo.roomInfo = [roomInfo];
            return Number(_this._instance.feedback(options.map(t_ProblemFeedbackOption.ts_to_android), feedbackInfo));
        };
        var i = function () {
            var roomInfo = new ByteRTCProblemFeedbackRoomInfo();
            roomInfo.roomId = info.roomId;
            roomInfo.userId = info.userId;
            var feedbackInfo = new ByteRTCProblemFeedbackInfo();
            feedbackInfo.problemDesc = info.desc;
            feedbackInfo.roomInfo = [roomInfo];
            return options.map(function (option) {
                return Number(_this._instance.feedback(t_ProblemFeedbackOption.ts_to_ios(option), feedbackInfo));
            });
        };
        var $os = env.getOS();
        if ($os === 'android') {
            return a();
        }
        else if ($os === 'ios') {
            return i();
        }
        else {
            throw new Error('Not Support Platform ' + $os);
        }
    };
});
extendsClassMethod(RTCVideo, 'setRemoteUserPriority', function () {
    return function impl(roomId, uid, priority) {
        var _this = this;
        var a = function () {
            return Number(_this._instance.setRemoteUserPriority(roomId, uid, t_RemoteUserPriority.ts_to_android(priority)));
        };
        var i = function () {
            return Number(_this._instance.setRemoteUserPriority(t_RemoteUserPriority.ts_to_ios(priority), roomId, uid));
        };
        var $os = env.getOS();
        if ($os === 'android') {
            return a();
        }
        else if ($os === 'ios') {
            return i();
        }
        else {
            throw new Error('Not Support Platform ' + $os);
        }
    };
});
extendsClassMethod(RTCVideo, 'setRuntimeParameters', function () {
    return function impl(params) {
        var _this = this;
        var a = function () {
            return Number(_this._instance.setRuntimeParameters(params));
        };
        var i = function () {
            return Number(_this._instance.setRuntimeParameters(params));
        };
        var $os = env.getOS();
        if ($os === 'android') {
            return a();
        }
        else if ($os === 'ios') {
            return i();
        }
        else {
            throw new Error('Not Support Platform ' + $os);
        }
    };
});
extendsClassMethod(RTCVideo, 'startScreenCapture', function () {
    return function impl(type, intent) {
        var _this = this;
        var a = function () {
            return Number(_this._instance.startScreenCapture(t_ScreenMediaType.ts_to_android(type), intent));
        };
        var i = function () {
            return Number(_this._instance.startScreenCapture(t_ScreenMediaType.ts_to_ios(type), intent));
        };
        var $os = env.getOS();
        if ($os === 'android') {
            return a();
        }
        else if ($os === 'ios') {
            return i();
        }
        else {
            throw new Error('Not Support Platform ' + $os);
        }
    };
});
extendsClassMethod(RTCVideo, 'setRemoteAudioPlaybackVolume', function () {
    return function impl(config, volume) {
        var _this = this;
        var a = function () {
            return Number(_this._instance.setRemoteAudioPlaybackVolume(config.roomId, config.userId, volume));
        };
        var i = function () {
            var streamKey = new ByteRTCRemoteStreamKey();
            streamKey.roomId = config.roomId;
            streamKey.userId = config.userId;
            streamKey.streamIndex = t_StreamIndex.ts_to_ios(config.streamIndex);
            return Number(_this._instance.setRemoteAudioPlaybackVolume(streamKey, volume));
        };
        var $os = env.getOS();
        if ($os === 'android') {
            return a();
        }
        else if ($os === 'ios') {
            return i();
        }
        else {
            throw new Error('Not Support Platform ' + $os);
        }
    };
});
var VodHelperKey = '_vod';
extendsClassMethod(RTCVideo, 'startVodPlayerCapture', function () {
    return function impl(player) {
        var _this = this;
        var streamIndex = exports.StreamIndex.STREAM_INDEX_SCREEN;
        var a = function () {
            var androidRtc = unpackObject(_this);
            var androidStreamIndex = t_StreamIndex.ts_to_android(streamIndex);
            // androidRtc.setVideoSourceType(
            //   androidStreamIndex,
            //   $p_a.VideoSourceType.VIDEO_SOURCE_TYPE_EXTERNAL,
            // );
            // androidRtc.setScreenAudioSourceType(
            //   $p_a.AudioSourceType.AUDIO_SOURCE_TYPE_EXTERNAL,
            // );
            var ins = new VertcVod$1();
            _this[VodHelperKey] = ins;
            return ins.startVodPlayerCapture(androidRtc, unpackObject(player), androidStreamIndex);
        };
        var i = function () {
            var iosRtc = unpackObject(_this);
            var ins = new VertcVod();
            _this[VodHelperKey] = ins;
            return ins.startVodPlayerCapture(iosRtc, unpackObject(player), {});
        };
        var $os = env.getOS();
        if ($os === 'android') {
            return a();
        }
        else if ($os === 'ios') {
            return i();
        }
        else {
            throw new Error('Not Support Platform ' + $os);
        }
    };
});
extendsClassMethod(RTCVideo, 'stopVodPlayerCapture', function () {
    return function impl() {
        var ins = this[VodHelperKey];
        if (ins) {
            ins.stopVodPlayerCapture(unpackObject(this));
        }
    };
});

var NativeSurfaceView = /** @class */ (function (_super) {
    __extends(NativeSurfaceView, _super);
    function NativeSurfaceView() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NativeSurfaceView;
}(NativeView));
var ApplicationContext = /** @class */ (function () {
    function ApplicationContext() {
    }
    return ApplicationContext;
}());
var ScreenIntent = /** @class */ (function () {
    function ScreenIntent() {
    }
    return ScreenIntent;
}());
var NativeVariables = function () {
    var _a;
    var _staticExtraInitializers = [];
    var _static_getApplicationContext_decorators;
    var _static_getScreenIntent_decorators;
    return _a = /** @class */ (function () {
            function NativeVariables() {
            }
            NativeVariables.getApplicationContext = function () {
                throw new Error('');
            };
            NativeVariables.getScreenIntent = function () {
                throw new Error('');
            };
            return NativeVariables;
        }()),
        (function () {
            var _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(null) : void 0;
            _static_getApplicationContext_decorators = [NativeVar('ApplicationContext', ApplicationContext)];
            _static_getScreenIntent_decorators = [NativeVar('screenIntent', ScreenIntent)];
            __esDecorate(_a, null, _static_getApplicationContext_decorators, { kind: "method", name: "getApplicationContext", static: true, private: false, access: { has: function (obj) { return "getApplicationContext" in obj; }, get: function (obj) { return obj.getApplicationContext; } }, metadata: _metadata }, null, _staticExtraInitializers);
            __esDecorate(_a, null, _static_getScreenIntent_decorators, { kind: "method", name: "getScreenIntent", static: true, private: false, access: { has: function (obj) { return "getScreenIntent" in obj; }, get: function (obj) { return obj.getScreenIntent; } }, metadata: _metadata }, null, _staticExtraInitializers);
            if (_metadata) Object.defineProperty(_a, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
            __runInitializers(_a, _staticExtraInitializers);
        })(),
        _a;
}();

/** {en}
 * @brief Request user to start screen capture
 */
var requestScreenCapture = function () { return __awaiter(void 0, void 0, void 0, function () {
    var intent;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                _a.trys.push([0, 3, , 4]);
                if (!(reactNative.Platform.OS === 'android')) return [3 /*break*/, 2];
                return [4 /*yield*/, NativeVariables.getScreenIntent()];
            case 1:
                intent = _a.sent();
                return [2 /*return*/, intent];
            case 2: return [3 /*break*/, 4];
            case 3:
                _a.sent();
                return [3 /*break*/, 4];
            case 4: return [2 /*return*/];
        }
    });
}); };
var isAndroid = function () { return reactNative.Platform.OS === 'android'; };
var isIOS = function () { return reactNative.Platform.OS === 'ios'; };
var platformBriefs = function (_a) {
    var android = _a.android, ios = _a.ios;
    if (isAndroid()) {
        return android();
    }
    if (isIOS()) {
        return ios();
    }
    throw new Error('Unsupported platform');
};

var proxyEngine = function (engine) {
    /** Render Local View */
    var originalSetLocalVideoCanvas = engine.setLocalVideoCanvas;
    engine.setLocalVideoCanvas = function (streamIndex, videoCanvas) {
        var viewId = videoCanvas.viewId, renderMode = videoCanvas.renderMode;
        var view = NativeView.getView(viewId, NativeSurfaceView);
        var canvas = new VideoCanvas();
        if (renderMode !== undefined) {
            canvas.renderMode = renderMode;
        }
        platformBriefs({
            android: function () {
                canvas.android_renderView = view;
            },
            ios: function () {
                canvas.ios_view = view;
            },
        });
        var result = originalSetLocalVideoCanvas.call(engine, streamIndex || exports.StreamIndex.STREAM_INDEX_MAIN, canvas);
        return result;
    };
    /** Render Remote View */
    var originalSetRemoteVideoCanvas = engine
        .setRemoteVideoCanvas;
    engine.setRemoteVideoCanvas = function (remoteInfo, videoCanvas) {
        var viewId = videoCanvas.viewId, renderMode = videoCanvas.renderMode;
        var view = NativeView.getView(viewId, NativeSurfaceView);
        var canvas = new VideoCanvas();
        if (renderMode !== undefined) {
            canvas.renderMode = renderMode;
        }
        var remoteStreamKey = platformBriefs({
            android: function () {
                canvas.android_renderView = view;
                var remoteStreamKey = new RemoteStreamKey(remoteInfo.roomId, remoteInfo.userId, remoteInfo.streamIndex || exports.StreamIndex.STREAM_INDEX_MAIN);
                remoteStreamKey.streamIndex = remoteInfo.streamIndex;
                return remoteStreamKey;
            },
            ios: function () {
                canvas.ios_view = view;
                var remoteStreamKey = new RemoteStreamKey();
                remoteStreamKey.roomId = remoteInfo.roomId;
                remoteStreamKey.userId = remoteInfo.userId;
                remoteStreamKey.streamIndex =
                    remoteInfo.streamIndex || exports.StreamIndex.STREAM_INDEX_MAIN;
                return remoteStreamKey;
            },
        });
        var result = originalSetRemoteVideoCanvas.call(engine, remoteStreamKey, canvas);
        return result;
    };
    /** Cellular Enhance */
    var originalSetCellularEnhancement = engine
        .setCellularEnhancement;
    engine.setCellularEnhancement = function (config) {
        var enhancementConfig = new MediaTypeEnhancementConfig();
        enhancementConfig.enhanceSignaling = config.enhanceSignaling;
        enhancementConfig.enhanceAudio = config.enhanceAudio;
        enhancementConfig.enhanceVideo = config.enhanceVideo;
        enhancementConfig.enhanceScreenAudio = config.enhanceScreenAudio;
        enhancementConfig.enhanceScreenVideo = config.enhanceScreenVideo;
        return originalSetCellularEnhancement.call(engine, enhancementConfig);
    };
    /** AudioProperties Report */
    var originalEnableAudioPropertiesReport = engine
        .enableAudioPropertiesReport;
    engine.enableAudioPropertiesReport = function (config) {
        var audioPropertiesConfig = platformBriefs({
            android: function () {
                return new AudioPropertiesConfig(config.interval, config.enableSpectrum, config.enableVad, config.localMainReportMode, config.smooth, config.audioReportMode);
            },
            ios: function () {
                var audioPropertiesConfig = new AudioPropertiesConfig();
                audioPropertiesConfig.interval = config.interval;
                audioPropertiesConfig.enableSpectrum = config.enableSpectrum;
                audioPropertiesConfig.enableVad = config.enableVad;
                audioPropertiesConfig.localMainReportMode = config.localMainReportMode;
                audioPropertiesConfig.smooth = config.smooth;
                audioPropertiesConfig.audioReportMode = config.audioReportMode;
                return audioPropertiesConfig;
            },
        });
        return originalEnableAudioPropertiesReport.call(engine, audioPropertiesConfig);
    };
    /** SetScreenVideoEncoderConfig */
    var originalSetScreenVideoEncoderConfig = engine
        .setScreenVideoEncoderConfig;
    engine.setScreenVideoEncoderConfig = function (config) {
        var screenVideoEncoderConfig = new ScreenVideoEncoderConfig();
        screenVideoEncoderConfig.width = config.width;
        screenVideoEncoderConfig.height = config.height;
        screenVideoEncoderConfig.frameRate = config.frameRate;
        screenVideoEncoderConfig.maxBitrate = config.maxBitrate;
        screenVideoEncoderConfig.minBitrate = config.minBitrate;
        screenVideoEncoderConfig.encodePreference = config.encodePrefer;
        return originalSetScreenVideoEncoderConfig.call(engine, screenVideoEncoderConfig);
    };
    /** StartScreenCapture */
    var originalStartScreenCapture = engine.startScreenCapture;
    engine.startScreenCapture = function (type, bundleId) { return __awaiter(void 0, void 0, void 0, function () {
        var intent;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (!bundleId) return [3 /*break*/, 1];
                    return [2 /*return*/, originalStartScreenCapture.call(engine, type, bundleId)];
                case 1: return [4 /*yield*/, requestScreenCapture()];
                case 2:
                    intent = _a.sent();
                    return [2 /*return*/, originalStartScreenCapture.call(engine, type, intent)];
            }
        });
    }); };
    /** RequestRemoteVideoKeyFrame */
    var originalRequestRemoteVideoKeyFrame = engine
        .requestRemoteVideoKeyFrame;
    engine.requestRemoteVideoKeyFrame = function (remoteInfo) {
        var remoteStreamKey = platformBriefs({
            android: function () {
                var remoteStreamKey = new RemoteStreamKey(remoteInfo.roomId, remoteInfo.userId, remoteInfo.streamIndex || exports.StreamIndex.STREAM_INDEX_MAIN);
                remoteStreamKey.streamIndex = remoteInfo.streamIndex;
                return remoteStreamKey;
            },
            ios: function () {
                var remoteStreamKey = new RemoteStreamKey();
                remoteStreamKey.roomId = remoteInfo.roomId;
                remoteStreamKey.userId = remoteInfo.userId;
                remoteStreamKey.streamIndex =
                    remoteInfo.streamIndex || exports.StreamIndex.STREAM_INDEX_MAIN;
                return remoteStreamKey;
            },
        });
        return originalRequestRemoteVideoKeyFrame.call(engine, remoteStreamKey);
    };
    /** Send Stream SyncInfo */
    var originalSendStreamSyncInfo = engine.sendStreamSyncInfo;
    engine.sendStreamSyncInfo = function (data, info) {
        var config = platformBriefs({
            android: function () {
                var androidConfig = new StreamSycnInfoConfig$1(t_StreamIndex.ts_to_android(info.streamIndex), info.repeatCount, t_SyncInfoStreamType.ts_to_android(info.streamType));
                return packObject(androidConfig, StreamSycnInfoConfig);
            },
            ios: function () {
                var iosConfig = new ByteRTCStreamSycnInfoConfig();
                iosConfig.streamIndex = t_StreamIndex.ts_to_ios(info.streamIndex);
                iosConfig.repeatCount = info.repeatCount;
                iosConfig.streamType = t_SyncInfoStreamType.ts_to_ios(info.streamType);
                return packObject(iosConfig, StreamSycnInfoConfig);
            },
        });
        return originalSendStreamSyncInfo.call(engine, data, config);
    };
    return engine;
};
var proxyRoom = function (room) {
    var originalJoinRoom = room.joinRoom;
    room.joinRoom = function (params) {
        var token = params.token, userId = params.userId, _a = params.extras, extras = _a === void 0 ? {} : _a, _b = params.roomConfigs, roomConfigs = _b === void 0 ? {
            profile: exports.ChannelProfile.CHANNEL_PROFILE_COMMUNICATION,
            isAutoPublish: true,
            isAutoSubscribeAudio: true,
            isAutoSubscribeVideo: true,
        } : _b;
        var _c = platformBriefs({
            android: function () {
                var userInfo = new UserInfo(userId, JSON.stringify(extras || {}));
                var roomInfo = new RTCRoomConfig(roomConfigs.profile, roomConfigs.isAutoPublish, roomConfigs.isAutoSubscribeAudio, roomConfigs.isAutoSubscribeVideo);
                return [userInfo, roomInfo];
            },
            ios: function () {
                var userInfo = new UserInfo();
                var roomInfo = new RTCRoomConfig();
                userInfo.userId = userId;
                userInfo.extraInfo = JSON.stringify(extras || {});
                roomInfo.isAutoPublish = roomConfigs.isAutoPublish;
                roomInfo.isAutoSubscribeAudio = roomConfigs.isAutoSubscribeAudio;
                roomInfo.isAutoSubscribeVideo = roomConfigs.isAutoSubscribeVideo;
                roomInfo.profile = roomConfigs.profile;
                return [userInfo, roomInfo];
            },
        }), userInfo = _c[0], roomInfo = _c[1];
        return originalJoinRoom.call(room, token, userInfo, roomInfo);
    };
    var originalSetRemoteVideoConfig = room.setRemoteVideoConfig;
    room.setRemoteVideoConfig = function (userId, remoteVideoConfig) {
        var remoteStreamInfo = platformBriefs({
            android: function () {
                var remoteStreamInfo = new RemoteVideoConfig(remoteVideoConfig.width, remoteVideoConfig.height, remoteVideoConfig.framerate);
                return remoteStreamInfo;
            },
            ios: function () {
                var remoteStreamInfo = new RemoteVideoConfig();
                remoteStreamInfo.width;
                remoteStreamInfo.height = remoteVideoConfig.height;
                remoteStreamInfo.framerate = remoteVideoConfig.framerate;
                return remoteStreamInfo;
            },
        });
        return originalSetRemoteVideoConfig.call(room, userId, remoteStreamInfo);
    };
    return room;
};
var proxyAudioEffectPlayer = function (audioEffectPlayer) {
    var originStart = audioEffectPlayer.start;
    audioEffectPlayer.start = function (effectId, path, config) {
        var audioEffectPlayerConfig = new AudioEffectPlayerConfig();
        audioEffectPlayerConfig.type = config.type;
        audioEffectPlayerConfig.playCount = config.playCount;
        audioEffectPlayerConfig.startPos = config.startPos;
        audioEffectPlayerConfig.pitch = config.pitch;
        return originStart.call(audioEffectPlayer, effectId, path, audioEffectPlayerConfig);
    };
    return audioEffectPlayer;
};
var proxyMediaPlayer = function (mediaPlayer) {
    var originOpen = mediaPlayer.open;
    mediaPlayer.open = function (filePath, config) {
        var mediaPlayerConfig = new MediaPlayerConfig();
        mediaPlayerConfig.type = config.type;
        mediaPlayerConfig.playCount = config.playCount;
        mediaPlayerConfig.startPos = config.startPos;
        mediaPlayerConfig.autoPlay = config.autoPlay;
        mediaPlayerConfig.callbackOnProgressInterval = config.progressInterval;
        mediaPlayerConfig.syncProgressToRecordFrame =
            config.syncProgressToRecordFrame;
        return originOpen.call(mediaPlayer, filePath, mediaPlayerConfig);
    };
    return mediaPlayer;
};

/** {en}
 * @detail api
 * @brief RTC core class, responsible for managing the created engine instance and room instance
 */
var RTCManager = /** @class */ (function () {
    function RTCManager() {
        var _this = this;
        /** {en}
         * @brief Get React Native SDK Version
         */
        this.getSDKVersion = function () { return "1.0.0"; };
        /** {en}
         * @brief Get Basic Android/iOS SDK Version
         */
        this.getBasicSDKVersion = function () { return RTCVideo.getSDKVersion(); };
        /** {en}
         * @brief Creates an engine instance.
         *        This is the very first API that you must call if you want to use all the RTC capabilities.
         *        If there is no engine instance in current process, calling this API will create one. If an engine instance has been created, calling this API again will have the created engine instance returned.
         * @param options Engine initialize params. See {@link ICreateRTCEngineOptions ICreateRTCEngineOptions}.
         * @return
         *         - engine: A successfully created engine instance.
         *         - null: ICreateRTCEngineOptions is inValid. See {@link ICreateRTCEngineOptions ICreateRTCEngineOptions}. Failed to load the so file.
         * @note The lifecycle of the handler must be longer than that of the RTCVideo, i.e. the handler must be destroyed after calling {@link destroyRTCEngine destroyRTCEngine}.
         */
        this.createRTCEngine = function (options) { return __awaiter(_this, void 0, void 0, function () {
            var appID, _a, parameters, targetEngine, context, eventHandler, engineConfig, handlers, engine, originCreateRTCRoom, originGetAudioEffectPlayer, originGetMediaPlayer;
            var _this = this;
            var _b, _c, _d;
            return __generator(this, function (_e) {
                switch (_e.label) {
                    case 0:
                        appID = options.appID, _a = options.parameters, parameters = _a === void 0 ? {} : _a;
                        parameters['rtc.platform'] = 10;
                        if (!(reactNative.Platform.OS === 'android')) return [3 /*break*/, 2];
                        return [4 /*yield*/, NativeVariables.getApplicationContext()];
                    case 1:
                        context = _e.sent();
                        eventHandler = new IRTCVideoEventHandler();
                        engineConfig = new EngineConfig(appID);
                        engineConfig.appID = appID;
                        // @ts-ignore
                        engineConfig.parameters = parameters;
                        // @ts-ignore
                        targetEngine = RTCVideo$1.createRTCVideo(context, eventHandler, engineConfig);
                        return [3 /*break*/, 3];
                    case 2:
                        handlers = new ByteRTCVideoDelegate();
                        targetEngine = ByteRTCVideo.createRTCVideo(appID, handlers, parameters);
                        _e.label = 3;
                    case 3:
                        engine = packObject(targetEngine, RTCVideo);
                        /** Proxy Engine */
                        this.engine = proxyEngine(engine);
                        originCreateRTCRoom = (_b = this.engine) === null || _b === void 0 ? void 0 : _b.createRTCRoom;
                        this.engine.createRTCRoom = function (roomId) {
                            var room = originCreateRTCRoom.call(_this.engine, roomId);
                            if (room) {
                                _this.room = proxyRoom(room);
                            }
                            return _this.room;
                        };
                        originGetAudioEffectPlayer = (_c = this.engine) === null || _c === void 0 ? void 0 : _c.getAudioEffectPlayer;
                        this.engine.getAudioEffectPlayer = function () {
                            var audioEffectPlayer = originGetAudioEffectPlayer.call(_this.engine);
                            if (audioEffectPlayer) {
                                _this.audioEffectPlayer = proxyAudioEffectPlayer(audioEffectPlayer);
                            }
                            return _this.audioEffectPlayer;
                        };
                        originGetMediaPlayer = (_d = this.engine) === null || _d === void 0 ? void 0 : _d.getMediaPlayer;
                        this.engine.getMediaPlayer = function (playerId) {
                            var mediaPlayer = originGetMediaPlayer.call(_this.engine, playerId);
                            if (mediaPlayer) {
                                _this.mediaPlayer = proxyMediaPlayer(mediaPlayer);
                            }
                            return _this.mediaPlayer;
                        };
                        return [2 /*return*/, this.engine];
                }
            });
        }); };
        /** {en}
         * @brief Destroy the engine instance created by {@link createRTCEngine createRTCEngine}, and release all related resources.
         * @note
         *       - Call this API after all business scenarios related to the engine instance are destroyed.
         *       - When the API is called, RTC SDK destroys all memory associated with the engine instance and stops any interaction with the media server.
         *       - Calling this API will start the SDK exit logic. The engine thread is held until the exit logic is complete. The engine thread is retained until the exit logic is complete. Therefore, do not call this API directly in the callback thread, or it will cause a deadlock. This function takes a long time to execute, so it's not recommended to call this API in the main thread, or the main thread may be blocked.
         */
        this.destroyRTCEngine = function () {
            return RTCVideo.destroyRTCVideo();
        };
    }
    /** {en}
     * @region Engine Management
     * @brief Configures the local log parameters of RTC SDK, including the logging level, directory, the limits for total log file size, and the prefix to the log file.
     * @param config Local log parameters.
     * @return
     *        - 0: Success.
     *        - –1: Failure. This API must be called before creating engine.
     *        - –2: Failure. Invalid parameters.
     * @note This API must be called before engine created.
     * @list Engine Management
     */
    RTCManager.prototype.setLogConfig = function (config) {
        var logConfig = platformBriefs({
            android: function () {
                var logConfig = new RTCLogConfig(config.logLevel, config.logPath, config.logFileSize, config.logFilenamePrefix);
                logConfig.logLevel = config.logLevel;
                return logConfig;
            },
            ios: function () {
                var logConfig = new RTCLogConfig();
                logConfig.logLevel = config.logLevel;
                logConfig.logPath = config.logPath;
                logConfig.logFileSize = config.logFileSize;
                logConfig.logFilenamePrefix = config.logFilenamePrefix;
                return logConfig;
            },
        });
        return RTCVideo.setLogConfig(logConfig);
    };
    /** {en}
     * @brief Set vod-player instance
     */
    RTCManager.prototype.setVodPlayer = function (vodPlayer) {
        this.vodPlayer = vodPlayer;
    };
    return RTCManager;
}());

var NativeViewComponentName = 'VertcView';
var NativeViewComponent = reactNative.requireNativeComponent(NativeViewComponentName);

/** {en}
 * @detail keytype
 * @brief The encryption type.
 */
exports.EncryptTypes = void 0;
(function (EncryptTypes) {
    /** {en}
     * @brief Not setting.
     */
    EncryptTypes[EncryptTypes["NONE"] = 0] = "NONE";
    /** {en}
     * @brief AES128CBC.
     */
    EncryptTypes[EncryptTypes["AES128CBC"] = 1] = "AES128CBC";
    /** {en}
     * @brief AES256CBC.
     */
    EncryptTypes[EncryptTypes["AES256CBC"] = 2] = "AES256CBC";
    /** {en}
     * @brief AES128ECB.
     */
    EncryptTypes[EncryptTypes["AES128ECB"] = 3] = "AES128ECB";
    /** {en}
     * @brief AES256ECB.
     */
    EncryptTypes[EncryptTypes["AES256ECB"] = 4] = "AES256ECB";
})(exports.EncryptTypes || (exports.EncryptTypes = {}));

exports.ApplicationContext = ApplicationContext;
exports.AudioEffectPlayerConfig = AudioEffectPlayerConfig;
exports.AudioFormat = AudioFormat;
exports.AudioFrame = AudioFrame;
exports.AudioMixingConfig = AudioMixingConfig;
exports.AudioPropertiesConfig = AudioPropertiesConfig;
exports.AudioPropertiesInfo = AudioPropertiesInfo;
exports.AudioRecordingConfig = AudioRecordingConfig;
exports.ByteRTCImage = ByteRTCImage;
exports.ByteRTCView = ByteRTCView;
exports.CloudProxyInfo = CloudProxyInfo;
exports.DownloadResult = DownloadResult;
exports.EchoTestConfig = EchoTestConfig;
exports.FaceDetectionResult = FaceDetectionResult;
exports.ForwardStreamEventInfo = ForwardStreamEventInfo;
exports.ForwardStreamStateInfo = ForwardStreamStateInfo;
exports.HotMusicInfo = HotMusicInfo;
exports.HumanOrientation = HumanOrientation;
exports.IAudioEffectPlayer = IAudioEffectPlayer;
exports.IAudioFrame = IAudioFrame;
exports.IAudioMixingManager = IAudioMixingManager;
exports.IKTVManager = IKTVManager;
exports.IKTVPlayer = IKTVPlayer;
exports.IMediaPlayer = IMediaPlayer;
exports.IRangeAudio = IRangeAudio;
exports.ISingScoringManager = ISingScoringManager;
exports.ISpatialAudio = ISpatialAudio;
exports.IVideoDeviceManager = IVideoDeviceManager;
exports.IVideoEffect = IVideoEffect;
exports.LiveTranscoding = LiveTranscoding;
exports.LocalAudioPropertiesInfo = LocalAudioPropertiesInfo;
exports.LocalAudioStats = LocalAudioStats;
exports.LocalStreamStats = LocalStreamStats;
exports.LocalVideoSinkConfig = LocalVideoSinkConfig;
exports.LocalVideoStats = LocalVideoStats;
exports.MediaPlayerConfig = MediaPlayerConfig;
exports.MediaPlayerCustomSource = MediaPlayerCustomSource;
exports.MediaTypeEnhancementConfig = MediaTypeEnhancementConfig;
exports.MixedStreamAudioConfig = MixedStreamAudioConfig;
exports.MixedStreamClientMixConfig = MixedStreamClientMixConfig;
exports.MixedStreamConfig = MixedStreamConfig;
exports.MixedStreamLayoutConfig = MixedStreamLayoutConfig;
exports.MixedStreamLayoutRegionConfig = MixedStreamLayoutRegionConfig;
exports.MixedStreamLayoutRegionImageWaterMarkConfig = MixedStreamLayoutRegionImageWaterMarkConfig;
exports.MixedStreamServerControlConfig = MixedStreamServerControlConfig;
exports.MixedStreamVideoConfig = MixedStreamVideoConfig;
exports.MusicInfo = MusicInfo;
exports.NativeSurfaceView = NativeSurfaceView;
exports.NativeUIView = NativeUIView;
exports.NativeVariables = NativeVariables;
exports.NativeViewComponent = NativeViewComponent;
exports.NetworkQualityStats = NetworkQualityStats;
exports.NetworkTimeInfo = NetworkTimeInfo;
exports.Orientation = Orientation;
exports.Position = Position;
exports.PositionInfo = PositionInfo;
exports.ProblemFeedbackInfo = ProblemFeedbackInfo;
exports.ProblemFeedbackRoomInfo = ProblemFeedbackRoomInfo;
exports.PublicStreaming = PublicStreaming;
exports.PushSingleStreamParam = PushSingleStreamParam;
exports.RPSampleBufferType = RPSampleBufferType;
exports.RTCASRConfig = RTCASRConfig;
exports.RTCEncodedVideoFrame = RTCEncodedVideoFrame;
exports.RTCLogConfig = RTCLogConfig;
exports.RTCManager = RTCManager;
exports.RTCRoom = RTCRoom;
exports.RTCRoomConfig = RTCRoomConfig;
exports.RTCRoomStats = RTCRoomStats;
exports.RTCStream = RTCStream;
exports.RTCUser = RTCUser;
exports.RTCVideo = RTCVideo;
exports.ReceiveRange = ReceiveRange;
exports.RecordingConfig = RecordingConfig;
exports.RecordingInfo = RecordingInfo;
exports.RecordingProgress = RecordingProgress;
exports.Rectangle = Rectangle;
exports.RemoteAudioPropertiesInfo = RemoteAudioPropertiesInfo;
exports.RemoteAudioStats = RemoteAudioStats;
exports.RemoteStreamKey = RemoteStreamKey;
exports.RemoteStreamStats = RemoteStreamStats;
exports.RemoteStreamSwitchEvent = RemoteStreamSwitchEvent;
exports.RemoteVideoConfig = RemoteVideoConfig;
exports.RemoteVideoRenderConfig = RemoteVideoRenderConfig;
exports.RemoteVideoSinkConfig = RemoteVideoSinkConfig;
exports.RemoteVideoStats = RemoteVideoStats;
exports.ScreenIntent = ScreenIntent;
exports.ScreenVideoEncoderConfig = ScreenVideoEncoderConfig;
exports.SingScoringConfig = SingScoringConfig;
exports.SingScoringRealtimeInfo = SingScoringRealtimeInfo;
exports.SourceWantedData = SourceWantedData;
exports.StandardPitchInfo = StandardPitchInfo;
exports.StreamSycnInfoConfig = StreamSycnInfoConfig;
exports.SubscribeConfig = SubscribeConfig;
exports.SubscribeVideoConfig = SubscribeVideoConfig;
exports.SubtitleConfig = SubtitleConfig;
exports.SubtitleMessage = SubtitleMessage;
exports.SysStats = SysStats;
exports.UIView = UIView;
exports.UserInfo = UserInfo;
exports.VideoCanvas = VideoCanvas;
exports.VideoCaptureConfig = VideoCaptureConfig;
exports.VideoEncoderConfig = VideoEncoderConfig;
exports.VideoFrame = VideoFrame;
exports.VideoFrameInfo = VideoFrameInfo;
exports.VideoPreprocessorConfig = VideoPreprocessorConfig;
exports.VirtualBackgroundSource = VirtualBackgroundSource;
exports.VoiceEqualizationConfig = VoiceEqualizationConfig;
exports.VoiceReverbConfig = VoiceReverbConfig;
exports.android_IAudioEffectPlayerEventHandler = android_IAudioEffectPlayerEventHandler;
exports.android_IAudioFileFrameObserver = android_IAudioFileFrameObserver;
exports.android_IAudioFrameObserver = android_IAudioFrameObserver;
exports.android_IAudioFrameProcessor = android_IAudioFrameProcessor;
exports.android_IExternalVideoEncoderEventHandler = android_IExternalVideoEncoderEventHandler;
exports.android_IFaceDetectionObserver = android_IFaceDetectionObserver;
exports.android_ILocalEncodedVideoFrameObserver = android_ILocalEncodedVideoFrameObserver;
exports.android_IMediaPlayerAudioFrameObserver = android_IMediaPlayerAudioFrameObserver;
exports.android_IMediaPlayerCustomSourceProvider = android_IMediaPlayerCustomSourceProvider;
exports.android_IMediaPlayerEventHandler = android_IMediaPlayerEventHandler;
exports.android_IMixedStreamObserver = android_IMixedStreamObserver;
exports.android_IPushSingleStreamToCDNObserver = android_IPushSingleStreamToCDNObserver;
exports.android_IRemoteEncodedVideoFrameObserver = android_IRemoteEncodedVideoFrameObserver;
exports.android_RTCRoomEventHandler = android_RTCRoomEventHandler;
exports.android_RTCVideoEventHandler = android_RTCVideoEventHandler;
exports.ios_IAudioEffectPlayerEventHandler = ios_IAudioEffectPlayerEventHandler;
exports.ios_IAudioFileFrameObserver = ios_IAudioFileFrameObserver;
exports.ios_IAudioFrameObserver = ios_IAudioFrameObserver;
exports.ios_IAudioFrameProcessor = ios_IAudioFrameProcessor;
exports.ios_IExternalVideoEncoderEventHandler = ios_IExternalVideoEncoderEventHandler;
exports.ios_IFaceDetectionObserver = ios_IFaceDetectionObserver;
exports.ios_ILocalEncodedVideoFrameObserver = ios_ILocalEncodedVideoFrameObserver;
exports.ios_IMediaPlayerAudioFrameObserver = ios_IMediaPlayerAudioFrameObserver;
exports.ios_IMediaPlayerCustomSourceProvider = ios_IMediaPlayerCustomSourceProvider;
exports.ios_IMediaPlayerEventHandler = ios_IMediaPlayerEventHandler;
exports.ios_IMixedStreamObserver = ios_IMixedStreamObserver;
exports.ios_IPushSingleStreamToCDNObserver = ios_IPushSingleStreamToCDNObserver;
exports.ios_IRemoteEncodedVideoFrameObserver = ios_IRemoteEncodedVideoFrameObserver;
exports.ios_RTCRoomEventHandler = ios_RTCRoomEventHandler;
exports.ios_RTCVideoEventHandler = ios_RTCVideoEventHandler;
exports.t_AACProfile = t_AACProfile;
exports.t_ASRAuthorizationType = t_ASRAuthorizationType;
exports.t_AVSyncState = t_AVSyncState;
exports.t_AlphaLayout = t_AlphaLayout;
exports.t_AnsMode = t_AnsMode;
exports.t_AttenuationType = t_AttenuationType;
exports.t_AudioAlignmentMode = t_AudioAlignmentMode;
exports.t_AudioChannel = t_AudioChannel;
exports.t_AudioDeviceType = t_AudioDeviceType;
exports.t_AudioFrameCallbackMethod = t_AudioFrameCallbackMethod;
exports.t_AudioFrameSource = t_AudioFrameSource;
exports.t_AudioMixingDualMonoMode = t_AudioMixingDualMonoMode;
exports.t_AudioMixingError = t_AudioMixingError;
exports.t_AudioMixingState = t_AudioMixingState;
exports.t_AudioMixingType = t_AudioMixingType;
exports.t_AudioPlayType = t_AudioPlayType;
exports.t_AudioPlaybackDevice = t_AudioPlaybackDevice;
exports.t_AudioProfileType = t_AudioProfileType;
exports.t_AudioPropertiesMode = t_AudioPropertiesMode;
exports.t_AudioQuality = t_AudioQuality;
exports.t_AudioRecordingErrorCode = t_AudioRecordingErrorCode;
exports.t_AudioRecordingState = t_AudioRecordingState;
exports.t_AudioRenderType = t_AudioRenderType;
exports.t_AudioReportMode = t_AudioReportMode;
exports.t_AudioRoute = t_AudioRoute;
exports.t_AudioSampleRate = t_AudioSampleRate;
exports.t_AudioScenarioType = t_AudioScenarioType;
exports.t_AudioSelectionPriority = t_AudioSelectionPriority;
exports.t_AudioSourceType = t_AudioSourceType;
exports.t_AudioTrackType = t_AudioTrackType;
exports.t_BandFrequency = t_BandFrequency;
exports.t_ByteRTCStreamMixingEvent = t_ByteRTCStreamMixingEvent;
exports.t_ByteRTCStreamMixingType = t_ByteRTCStreamMixingType;
exports.t_CameraId = t_CameraId;
exports.t_ChannelProfile = t_ChannelProfile;
exports.t_ColorSpace = t_ColorSpace;
exports.t_ConnectionState = t_ConnectionState;
exports.t_DataMessageSourceType = t_DataMessageSourceType;
exports.t_DownloadFileType = t_DownloadFileType;
exports.t_DownloadLyricType = t_DownloadLyricType;
exports.t_EarMonitorMode = t_EarMonitorMode;
exports.t_EchoTestResult = t_EchoTestResult;
exports.t_EffectBeautyMode = t_EffectBeautyMode;
exports.t_ErrorCode = t_ErrorCode;
exports.t_FallbackOrRecoverReason = t_FallbackOrRecoverReason;
exports.t_FirstFramePlayState = t_FirstFramePlayState;
exports.t_FirstFrameSendState = t_FirstFrameSendState;
exports.t_ForwardStreamError = t_ForwardStreamError;
exports.t_ForwardStreamEvent = t_ForwardStreamEvent;
exports.t_ForwardStreamState = t_ForwardStreamState;
exports.t_HardwareEchoDetectionResult = t_HardwareEchoDetectionResult;
exports.t_KTVErrorCode = t_KTVErrorCode;
exports.t_KTVPlayerErrorCode = t_KTVPlayerErrorCode;
exports.t_LocalAudioStreamError = t_LocalAudioStreamError;
exports.t_LocalAudioStreamState = t_LocalAudioStreamState;
exports.t_LocalLogLevel = t_LocalLogLevel;
exports.t_LocalProxyError = t_LocalProxyError;
exports.t_LocalProxyState = t_LocalProxyState;
exports.t_LocalProxyType = t_LocalProxyType;
exports.t_LocalVideoRenderPosition = t_LocalVideoRenderPosition;
exports.t_LocalVideoStreamError = t_LocalVideoStreamError;
exports.t_LocalVideoStreamState = t_LocalVideoStreamState;
exports.t_LoginErrorCode = t_LoginErrorCode;
exports.t_LogoutReason = t_LogoutReason;
exports.t_LyricStatus = t_LyricStatus;
exports.t_MediaDeviceError = t_MediaDeviceError;
exports.t_MediaDeviceState = t_MediaDeviceState;
exports.t_MediaDeviceType = t_MediaDeviceType;
exports.t_MediaDeviceWarning = t_MediaDeviceWarning;
exports.t_MediaPlayerCustomSourceMode = t_MediaPlayerCustomSourceMode;
exports.t_MediaPlayerCustomSourceSeekWhence = t_MediaPlayerCustomSourceSeekWhence;
exports.t_MediaPlayerCustomSourceStreamType = t_MediaPlayerCustomSourceStreamType;
exports.t_MediaStreamType = t_MediaStreamType;
exports.t_MessageConfig = t_MessageConfig;
exports.t_MirrorType = t_MirrorType;
exports.t_MixedStreamAlternateImageFillMode = t_MixedStreamAlternateImageFillMode;
exports.t_MixedStreamAudioCodecType = t_MixedStreamAudioCodecType;
exports.t_MixedStreamAudioProfile = t_MixedStreamAudioProfile;
exports.t_MixedStreamClientMixVideoFormat = t_MixedStreamClientMixVideoFormat;
exports.t_MixedStreamLayoutRegionType = t_MixedStreamLayoutRegionType;
exports.t_MixedStreamMediaType = t_MixedStreamMediaType;
exports.t_MixedStreamPushMode = t_MixedStreamPushMode;
exports.t_MixedStreamRenderMode = t_MixedStreamRenderMode;
exports.t_MixedStreamSEIContentMode = t_MixedStreamSEIContentMode;
exports.t_MixedStreamType = t_MixedStreamType;
exports.t_MixedStreamVideoCodecType = t_MixedStreamVideoCodecType;
exports.t_MixedStreamVideoType = t_MixedStreamVideoType;
exports.t_MulDimSingScoringMode = t_MulDimSingScoringMode;
exports.t_MusicFilterType = t_MusicFilterType;
exports.t_MusicHotType = t_MusicHotType;
exports.t_MuteState = t_MuteState;
exports.t_NetworkDetectionLinkType = t_NetworkDetectionLinkType;
exports.t_NetworkDetectionStopReason = t_NetworkDetectionStopReason;
exports.t_NetworkQuality = t_NetworkQuality;
exports.t_PauseResumeControlMediaType = t_PauseResumeControlMediaType;
exports.t_PerformanceAlarmMode = t_PerformanceAlarmMode;
exports.t_PerformanceAlarmReason = t_PerformanceAlarmReason;
exports.t_PlayState = t_PlayState;
exports.t_PlayerError = t_PlayerError;
exports.t_PlayerState = t_PlayerState;
exports.t_ProblemFeedbackOption = t_ProblemFeedbackOption;
exports.t_PublicStreamErrorCode = t_PublicStreamErrorCode;
exports.t_PublishFallbackOption = t_PublishFallbackOption;
exports.t_RTCASRErrorCode = t_RTCASRErrorCode;
exports.t_RTCNetworkType = t_RTCNetworkType;
exports.t_RTCScreenVideoEncoderPreference = t_RTCScreenVideoEncoderPreference;
exports.t_RTCStreamMixingErrorCode = t_RTCStreamMixingErrorCode;
exports.t_RTCStreamSinglePushEvent = t_RTCStreamSinglePushEvent;
exports.t_RTCUserOfflineReason = t_RTCUserOfflineReason;
exports.t_RTCVideoEncoderPreference = t_RTCVideoEncoderPreference;
exports.t_RecordingErrorCode = t_RecordingErrorCode;
exports.t_RecordingFileType = t_RecordingFileType;
exports.t_RecordingState = t_RecordingState;
exports.t_RecordingType = t_RecordingType;
exports.t_RemoteAudioState = t_RemoteAudioState;
exports.t_RemoteAudioStateChangeReason = t_RemoteAudioStateChangeReason;
exports.t_RemoteMirrorType = t_RemoteMirrorType;
exports.t_RemoteUserPriority = t_RemoteUserPriority;
exports.t_RemoteVideoRenderPosition = t_RemoteVideoRenderPosition;
exports.t_RemoteVideoState = t_RemoteVideoState;
exports.t_RemoteVideoStateChangeReason = t_RemoteVideoStateChangeReason;
exports.t_RenderMode = t_RenderMode;
exports.t_ReturnStatus = t_ReturnStatus;
exports.t_RoomMessageSendResult = t_RoomMessageSendResult;
exports.t_SEICountPerFrame = t_SEICountPerFrame;
exports.t_SEIStreamUpdateEventType = t_SEIStreamUpdateEventType;
exports.t_ScreenMediaType = t_ScreenMediaType;
exports.t_SetRoomExtraInfoResult = t_SetRoomExtraInfoResult;
exports.t_StreamIndex = t_StreamIndex;
exports.t_StreamRemoveReason = t_StreamRemoveReason;
exports.t_SubscribeMediaType = t_SubscribeMediaType;
exports.t_SubscribeState = t_SubscribeState;
exports.t_SubtitleErrorCode = t_SubtitleErrorCode;
exports.t_SubtitleMode = t_SubtitleMode;
exports.t_SubtitleState = t_SubtitleState;
exports.t_SyncInfoStreamType = t_SyncInfoStreamType;
exports.t_TorchState = t_TorchState;
exports.t_TranscoderContentControlType = t_TranscoderContentControlType;
exports.t_TranscoderLayoutRegionType = t_TranscoderLayoutRegionType;
exports.t_UserMessageSendResult = t_UserMessageSendResult;
exports.t_UserOnlineStatus = t_UserOnlineStatus;
exports.t_UserVisibilityChangeError = t_UserVisibilityChangeError;
exports.t_VideoApplyRotation = t_VideoApplyRotation;
exports.t_VideoCodecType = t_VideoCodecType;
exports.t_VideoContentType = t_VideoContentType;
exports.t_VideoDecoderConfig = t_VideoDecoderConfig;
exports.t_VideoDenoiseMode = t_VideoDenoiseMode;
exports.t_VideoDenoiseModeChangedReason = t_VideoDenoiseModeChangedReason;
exports.t_VideoDeviceType = t_VideoDeviceType;
exports.t_VideoFrameType = t_VideoFrameType;
exports.t_VideoOrientation = t_VideoOrientation;
exports.t_VideoPictureType = t_VideoPictureType;
exports.t_VideoPixelFormat = t_VideoPixelFormat;
exports.t_VideoRenderMirrorType = t_VideoRenderMirrorType;
exports.t_VideoRotation = t_VideoRotation;
exports.t_VideoRotationMode = t_VideoRotationMode;
exports.t_VideoSourceType = t_VideoSourceType;
exports.t_VideoSuperResolutionMode = t_VideoSuperResolutionMode;
exports.t_VideoSuperResolutionModeChangedReason = t_VideoSuperResolutionModeChangedReason;
exports.t_VirtualBackgroundSourceType = t_VirtualBackgroundSourceType;
exports.t_VoiceChangerType = t_VoiceChangerType;
exports.t_VoiceReverbType = t_VoiceReverbType;
exports.t_WarningCode = t_WarningCode;
exports.t_ZoomConfigType = t_ZoomConfigType;
exports.t_ZoomDirectionType = t_ZoomDirectionType;
